(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   2834706,      56552]
NotebookOptionsPosition[   2827889,      56349]
NotebookOutlinePosition[   2828226,      56364]
CellTagsIndexPosition[   2828183,      56361]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["DGame",
  FontSlant->"Italic"],
 ": solving delayed safety games"
}], "Title",
 CellChangeTimes->{
  3.7234378171228456`*^9, {3.725590681782782*^9, 3.725590697142686*^9}}],

Cell[TextData[{
 "The tool ",
 StyleBox["DGame",
  FontSlant->"Italic"],
 " is dedicated to synthesizing controllers for safety games under delayed \
information. The key idea of the synthesis procedure is to compute a series \
of finite-memory winning strategies ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Xi]", "k"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " while increasing delays from ",
 StyleBox["k",
  FontSlant->"Italic"],
 " = 0 to the finally interesting delay ",
 StyleBox["k",
  FontSlant->"Italic"],
 " = \[Delta]. The algorithm takes as input a delayed two-player safety game ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["G", "\[Delta]"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and returns either ",
 StyleBox["WINNING",
  FontSlant->"Italic"],
 " associated with a winning strategy (\[Alpha], ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Xi]", "\[Delta]"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " ) for the controller if ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["G", "\[Delta]"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " is controllable, or ",
 StyleBox["LOSING",
  FontSlant->"Italic"],
 " otherwise with an integer ",
 StyleBox["m",
  FontSlant->"Italic"],
 " indicating that the winning strategy vanishes when lifting delay to ",
 StyleBox["m",
  FontSlant->"Italic"],
 ". \n\nCurrent version: v1.0\nValidated on platform: ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 10, 64bit-Ubuntu-Desktop-14.10/17.04\nLatest modification: on Jan. 22, \
2018, by Mingshuai Chen, SKLCS-ISCAS\n\nCorresponding e-mail: \
chenms@ios.ac.cn\nList of contributors: Mingshuai Chen, Martin \
Fr\[ADoubleDot]nzle, Yangjia Li, Peter N. Mosaad, and Naijun Zhan\n\nComments \
and bug-reports are higly appreciated.\n\[Copyright] 2018 ",
 StyleBox["DGame",
  FontSlant->"Italic"],
 ", State Key Lab. of Computer Science, ISCAS. All rights reserved."
}], "Text",
 InitializationCell->True,
 CellChangeTimes->{{3.7234350112088013`*^9, 3.723435060937286*^9}, {
   3.723435192610417*^9, 3.7234351938417788`*^9}, {3.723435344625846*^9, 
   3.723435355880945*^9}, {3.723435395289072*^9, 3.7234354227854853`*^9}, {
   3.723435495050391*^9, 3.72343561280167*^9}, {3.723435658618808*^9, 
   3.723435695776771*^9}, {3.723436207026643*^9, 3.723436211297701*^9}, {
   3.723436518481542*^9, 3.723436519425972*^9}, {3.723436561682073*^9, 
   3.72343668419429*^9}, {3.723436731786162*^9, 3.723436780522533*^9}, {
   3.723436810585538*^9, 3.723436891682428*^9}, {3.7234369936667147`*^9, 
   3.723437037722496*^9}, {3.723437121123434*^9, 3.723437142090692*^9}, {
   3.723437174290389*^9, 3.723437180577662*^9}, {3.7234372245631437`*^9, 
   3.723437292075129*^9}, {3.7234373319382343`*^9, 3.723437457857831*^9}, {
   3.723437499009584*^9, 3.7234375226109858`*^9}, 3.72343765607572*^9, {
   3.723437689203598*^9, 3.723437713177771*^9}, 3.723437751457923*^9, {
   3.723437956875626*^9, 3.7234379901797237`*^9}, {3.725590705346745*^9, 
   3.725590895905891*^9}, {3.725590930441671*^9, 3.72559093567302*^9}, {
   3.725590981816627*^9, 3.7255909888877277`*^9}, {3.7255910233273582`*^9, 
   3.725591050423066*^9}, 3.725591102392172*^9, {3.725591159808784*^9, 
   3.7255911681765327`*^9}}],

Cell[CellGroupData[{

Cell["Source code", "Section",
 CellChangeTimes->{3.725591624008356*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"MAIN", " ", "PROCEDURE"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"main", "[", 
     RowBox[{
     "g_", ",", "init_", ",", "bad_", ",", "lag_", ",", "graphical_"}], "]"}],
     ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "vlist", ",", "vnum", ",", "elist", ",", "enum", ",", "weights", ",", 
        "actions", ",", "adjm", ",", "shapes", ",", "wpre", ",", "predc", ",",
         "preact", ",", "compp", ",", "wpost", ",", "wtemp0", ",", "wtemp1", 
        ",", "s0", ",", "s", ",", "ss", ",", "stemp", ",", "sstemp", ",", 
        "emptS", ",", "succ", ",", "succsafe", ",", "alter", ",", "pat", ",", 
        "succact", ",", "succactsafe", ",", "v", ",", "x", ",", "y", ",", "i",
         ",", "j", ",", "k", ",", "win", ",", "uncontrollable", ",", 
        "freshgoback", ",", "vanish", ",", "times", ",", "ttemp"}], "}"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"!", 
          RowBox[{"DirectedGraphQ", "[", "g", "]"}]}], ",", 
         RowBox[{
          RowBox[{"Print", "[", "\"\<Not directed graph.\>\"", "]"}], ";", 
          RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"vlist", "=", 
        RowBox[{"VertexList", "[", "g", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"vnum", "=", 
        RowBox[{"VertexCount", "[", "g", "]"}]}], ";", "\[IndentingNewLine]", 
       
       RowBox[{"elist", "=", 
        RowBox[{"EdgeList", "[", "g", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"enum", "=", 
        RowBox[{"EdgeCount", "[", "g", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"weights", "=", 
        RowBox[{"PropertyValue", "[", 
         RowBox[{"g", ",", "EdgeWeight"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"actions", "=", 
        RowBox[{"Cases", "[", 
         RowBox[{
          RowBox[{"DeleteDuplicates", "[", "weights", "]"}], ",", 
          RowBox[{"Except", "[", "u", "]"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"adjm", "=", 
        RowBox[{"AdjacencyMatrix", "[", "g", "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"shapes", "=", 
        RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"graphical", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
         RowBox[{"For", "[", 
          RowBox[{
           RowBox[{"i", "=", "1"}], ",", 
           RowBox[{"i", "\[LessEqual]", 
            RowBox[{"Length", "[", "vlist", "]"}]}], ",", 
           RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"MemberQ", "[", 
              RowBox[{"init", ",", 
               RowBox[{"vlist", "[", 
                RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
             RowBox[{"AppendTo", "[", 
              RowBox[{"shapes", ",", 
               RowBox[{
                RowBox[{"vlist", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "\[Rule]", 
                "\"\<RoundedTriangle\>\""}]}], "]"}], ",", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"MemberQ", "[", 
                RowBox[{"bad", ",", 
                 RowBox[{"vlist", "[", 
                  RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
               RowBox[{"AppendTo", "[", 
                RowBox[{"shapes", ",", 
                 RowBox[{
                  RowBox[{"vlist", "[", 
                   RowBox[{"[", "i", "]"}], "]"}], "\[Rule]", 
                  "\"\<ConcaveSquare\>\""}]}], "]"}], ",", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Mod", "[", 
                   RowBox[{
                    RowBox[{"vlist", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", "2"}], "]"}], 
                  "\[Equal]", "1"}], ",", 
                 RowBox[{"AppendTo", "[", 
                  RowBox[{"shapes", ",", 
                   RowBox[{
                    RowBox[{"vlist", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "\[Rule]", 
                    "\"\<Circle\>\""}]}], "]"}], ",", 
                 RowBox[{"AppendTo", "[", 
                  RowBox[{"shapes", ",", 
                   RowBox[{
                    RowBox[{"vlist", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "\[Rule]", 
                    "\"\<Square\>\""}]}], "]"}]}], "]"}]}], "]"}]}], "]"}]}], 
          "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"times", "=", 
        RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"ttemp", "=", 
        RowBox[{"TimeUsed", "[", "]"}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"generating", " ", "s0", " ", "by", " ", "fixed"}], "-", 
         RowBox[{"point", " ", "iteration"}]}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"s0", "=", 
        RowBox[{"<|", "|>"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"wpre", "=", "bad"}], ";", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "1"}], ",", 
         RowBox[{"i", "\[LessEqual]", 
          RowBox[{"Length", "[", "vlist", "]"}]}], ",", 
         RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"OddQ", "[", 
            RowBox[{"vlist", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"MemberQ", "[", 
              RowBox[{"bad", ",", 
               RowBox[{"vlist", "[", 
                RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
             RowBox[{"AppendTo", "[", 
              RowBox[{"s0", ",", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"vlist", "[", 
                   RowBox[{"[", "i", "]"}], "]"}], ",", 
                  RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
                RowBox[{"{", "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"succ", "=", 
               RowBox[{"vlist", "[", 
                RowBox[{"[", 
                 RowBox[{"successor", "[", 
                  RowBox[{"adjm", ",", "i"}], "]"}], "]"}], "]"}]}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{"succ", "\[Equal]", 
                 RowBox[{"{", "}"}]}], ",", 
                RowBox[{"AppendTo", "[", 
                 RowBox[{"wpre", ",", 
                  RowBox[{"vlist", "[", 
                   RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], "]"}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"AppendTo", "[", 
               RowBox[{"s0", ",", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"vlist", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                   RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
                 RowBox[{"Flatten", "[", 
                  RowBox[{"Table", "[", 
                   RowBox[{
                    RowBox[{"weights", "[", 
                    RowBox[{"[", 
                    RowBox[{"Flatten", "[", 
                    RowBox[{"Position", "[", 
                    RowBox[{"elist", ",", 
                    RowBox[{
                    RowBox[{"vlist", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "\[DirectedEdge]", 
                    RowBox[{"succ", "[", 
                    RowBox[{"[", "j", "]"}], "]"}]}]}], "]"}], "]"}], "]"}], 
                    "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", "1", ",", 
                    RowBox[{"Length", "[", "succ", "]"}]}], "}"}]}], "]"}], 
                  "]"}]}]}], "]"}]}]}], "]"}]}], "]"}]}], 
        "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"i", "=", "1"}], ";", "\[IndentingNewLine]", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"i", "\[LessEqual]", 
          RowBox[{"Length", "[", "wpre", "]"}]}], ",", "\[IndentingNewLine]", 
         
         RowBox[{
          RowBox[{"predc", "=", 
           RowBox[{"vlist", "[", 
            RowBox[{"[", 
             RowBox[{"predecessor", "[", 
              RowBox[{"adjm", ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"Position", "[", 
                  RowBox[{"vlist", ",", 
                   RowBox[{"wpre", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}], "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"predc", "\[Equal]", 
             RowBox[{"{", "}"}]}], ",", 
            RowBox[{
             RowBox[{"i", "=", 
              RowBox[{"i", "+", "1"}]}], ";", 
             RowBox[{"Continue", "[", "]"}]}]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"OddQ", "[", 
             RowBox[{"wpre", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"compp", "=", 
              RowBox[{"Complement", "[", 
               RowBox[{"predc", ",", "wpre"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"!", 
                RowBox[{"compp", "\[Equal]", 
                 RowBox[{"{", "}"}]}]}], ",", 
               RowBox[{"wpre", "=", 
                RowBox[{"Join", "[", 
                 RowBox[{"wpre", ",", "compp"}], "]"}]}]}], "]"}]}], ",", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
            RowBox[{"For", "[", 
             RowBox[{
              RowBox[{"j", "=", "1"}], ",", 
              RowBox[{"j", "\[LessEqual]", 
               RowBox[{"Length", "[", "predc", "]"}]}], ",", 
              RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"preact", "=", 
                RowBox[{"weights", "[", 
                 RowBox[{"[", 
                  RowBox[{"Flatten", "[", 
                   RowBox[{"Position", "[", 
                    RowBox[{"elist", ",", 
                    RowBox[{
                    RowBox[{"predc", "[", 
                    RowBox[{"[", "j", "]"}], "]"}], "\[DirectedEdge]", 
                    RowBox[{"wpre", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}]}], "]"}], "]"}], "]"}], 
                 "]"}]}], ";", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"s0", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"predc", "[", 
                    RowBox[{"[", "j", "]"}], "]"}], ",", 
                   RowBox[{"{", "}"}]}], "}"}], "]"}], "=", 
                RowBox[{"Complement", "[", 
                 RowBox[{
                  RowBox[{"s0", "[", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"predc", "[", 
                    RowBox[{"[", "j", "]"}], "]"}], ",", 
                    RowBox[{"{", "}"}]}], "}"}], "]"}], ",", "preact"}], 
                 "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"!", 
                   RowBox[{"MemberQ", "[", 
                    RowBox[{"wpre", ",", 
                    RowBox[{"predc", "[", 
                    RowBox[{"[", "j", "]"}], "]"}]}], "]"}]}], "&&", 
                  RowBox[{
                   RowBox[{"s0", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"predc", "[", 
                    RowBox[{"[", "j", "]"}], "]"}], ",", 
                    RowBox[{"{", "}"}]}], "}"}], "]"}], "\[Equal]", 
                   RowBox[{"{", "}"}]}]}], ",", "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"AppendTo", "[", 
                   RowBox[{"wpre", ",", 
                    RowBox[{"predc", "[", 
                    RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ";"}]}], 
                "\[IndentingNewLine]", "]"}], ";"}]}], "\[IndentingNewLine]", 
             "]"}]}], "\[IndentingNewLine]", "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"i", "=", 
           RowBox[{"i", "+", "1"}]}], ";"}]}], "\[IndentingNewLine]", "]"}], 
       ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"s0", "=", 
          RowBox[{"<|", "|>"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"wpre", "=", "bad"}], ";", "\[IndentingNewLine]", 
         RowBox[{"While", "[", 
          RowBox[{"True", ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"wtemp0", "=", 
             RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"wtemp1", "=", 
             RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"wpost", "=", 
             RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"For", "[", 
             RowBox[{
              RowBox[{"i", "=", "1"}], ",", 
              RowBox[{"i", "\[LessEqual]", 
               RowBox[{"Length", "[", "vlist", "]"}]}], ",", 
              RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"succ", "=", 
                RowBox[{"vlist", "[", 
                 RowBox[{"[", 
                  RowBox[{"successor", "[", 
                   RowBox[{"adjm", ",", "i"}], "]"}], "]"}], "]"}]}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{"OddQ", "[", 
                  RowBox[{"vlist", "[", 
                   RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{"SubsetQ", "[", 
                    RowBox[{"wpre", ",", "succ"}], "]"}], ",", 
                   RowBox[{"AppendTo", "[", 
                    RowBox[{"wtemp0", ",", 
                    RowBox[{"vlist", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], "]"}], ",", 
                 "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"If", "[", 
                   RowBox[{
                    RowBox[{"IntersectingQ", "[", 
                    RowBox[{"wpre", ",", "succ"}], "]"}], ",", 
                    RowBox[{"AppendTo", "[", 
                    RowBox[{"wtemp1", ",", 
                    RowBox[{"vlist", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], "]"}], ";"}]}],
                 "\[IndentingNewLine]", "]"}], ";"}]}], "\[IndentingNewLine]",
              "]"}], ";", "\[IndentingNewLine]", 
            RowBox[{"wpost", "=", 
             RowBox[{"Union", "[", 
              RowBox[{"wpre", ",", "wtemp0", ",", "wtemp1"}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"wpre", "\[Equal]", "wpost"}], ",", 
              RowBox[{"Break", "[", "]"}], ",", 
              RowBox[{"wpre", "=", "wpost"}]}], "]"}], ";"}]}], 
          "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{"For", "[", 
          RowBox[{
           RowBox[{"i", "=", "1"}], ",", 
           RowBox[{"i", "\[LessEqual]", 
            RowBox[{"Length", "[", "vlist", "]"}]}], ",", 
           RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"OddQ", "[", 
               RowBox[{"vlist", "[", 
                RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{"MemberQ", "[", 
                  RowBox[{"wpost", ",", 
                   RowBox[{"vlist", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
                 "\[IndentingNewLine]", 
                 RowBox[{"AppendTo", "[", 
                  RowBox[{"s0", ",", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"vlist", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                    RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
                    RowBox[{"{", "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"succ", "=", 
                   RowBox[{"vlist", "[", 
                    RowBox[{"[", 
                    RowBox[{"successor", "[", 
                    RowBox[{"adjm", ",", "i"}], "]"}], "]"}], "]"}]}], ";", 
                  "\[IndentingNewLine]", 
                  RowBox[{"succsafe", "=", 
                   RowBox[{"Complement", "[", 
                    RowBox[{"succ", ",", "wpost"}], "]"}]}], ";", 
                  "\[IndentingNewLine]", 
                  RowBox[{"succactsafe", "=", 
                   RowBox[{"Flatten", "[", 
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{"weights", "[", 
                    RowBox[{"[", 
                    RowBox[{"Flatten", "[", 
                    RowBox[{"Position", "[", 
                    RowBox[{"elist", ",", 
                    RowBox[{
                    RowBox[{"vlist", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "\[DirectedEdge]", 
                    RowBox[{"succsafe", "[", 
                    RowBox[{"[", "j", "]"}], "]"}]}]}], "]"}], "]"}], "]"}], 
                    "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", "1", ",", 
                    RowBox[{"Length", "[", "succsafe", "]"}]}], "}"}]}], 
                    "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
                  RowBox[{"AppendTo", "[", 
                   RowBox[{"s0", ",", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"vlist", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                    RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
                    RowBox[{"Sort", "[", "succactsafe", "]"}]}]}], "]"}], 
                  ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}], 
             "\[IndentingNewLine]", "]"}], ";"}]}], "\[IndentingNewLine]", 
          "]"}], ";"}], "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
       
       RowBox[{"(*", 
        RowBox[{"graphical", " ", "mode"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"graphical", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Print", "[", "\"\<Original graph:\>\"", "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Print", "[", 
           RowBox[{"Graph", "[", 
            RowBox[{"elist", ",", 
             RowBox[{"VertexSize", "\[Rule]", ".6"}], ",", 
             RowBox[{"VertexLabels", "\[Rule]", 
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"vlist", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "\[Rule]", 
                 RowBox[{"Placed", "[", 
                  RowBox[{
                   RowBox[{"vlist", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"1", "/", "2"}], ",", 
                    RowBox[{"1", "/", "2"}]}], "}"}]}], "]"}]}], ",", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "1", ",", "vnum"}], "}"}]}], "]"}]}], ",", 
             
             RowBox[{"BaselinePosition", "\[Rule]", "Axis"}], ",", 
             RowBox[{"VertexShapeFunction", "\[Rule]", "shapes"}], ",", 
             RowBox[{"EdgeLabels", "\[Rule]", 
              RowBox[{"Thread", "[", 
               RowBox[{"elist", "\[Rule]", "weights"}], "]"}]}], ",", 
             RowBox[{"ImageSize", "\[Rule]", "600"}]}], "]"}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"Print", "[", "\"\<Under delay = 0 :\>\"", "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Print", "[", 
           RowBox[{"Graph", "[", 
            RowBox[{"elist", ",", 
             RowBox[{"VertexSize", "\[Rule]", ".6"}], ",", 
             RowBox[{"VertexLabels", "\[Rule]", 
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"vlist", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "\[Rule]", 
                 RowBox[{"Placed", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"vlist", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                    RowBox[{"Style", "[", 
                    RowBox[{
                    RowBox[{"stra2label", "[", 
                    RowBox[{"s0", ",", 
                    RowBox[{"vlist", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", "Red"}], 
                    "]"}]}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"1", "/", "2"}], ",", 
                    RowBox[{"1", "/", "2"}]}], "}"}], ",", "Above"}], "}"}]}],
                   "]"}]}], ",", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "1", ",", "vnum"}], "}"}]}], "]"}]}], ",", 
             
             RowBox[{"BaselinePosition", "\[Rule]", "Axis"}], ",", 
             RowBox[{"VertexShapeFunction", "\[Rule]", "shapes"}], ",", 
             RowBox[{"EdgeLabels", "\[Rule]", 
              RowBox[{"Thread", "[", 
               RowBox[{"elist", "\[Rule]", "weights"}], "]"}]}], ",", 
             RowBox[{"ImageSize", "\[Rule]", "600"}]}], "]"}], "]"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(*", 
          RowBox[{"text", " ", "mode"}], "*)"}], "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Print", "[", "\"\<Under delay = 0 :\>\"", "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Print", "[", "s0", "]"}]}]}], 
        RowBox[{"(*", 
         RowBox[{";", "\[IndentingNewLine]", 
          RowBox[{"Print", "[", 
           RowBox[{"\"\<\>", 
            RowBox[{"(*", 
             RowBox[{
             "hidden", " ", "for", " ", "the", " ", "sake", " ", "of", " ", 
              "space"}], "*)"}], "\"\<]\>"}]}]}], "*)"}], 
        "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"AppendTo", "[", 
        RowBox[{"times", ",", 
         RowBox[{"TimeUsed", "[", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"Cases", "[", 
            RowBox[{
             RowBox[{"Normal", "[", "s0", "]"}], ",", 
             RowBox[{
              RowBox[{"Pattern", "[", 
               RowBox[{"pat", ",", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"init", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", "x_"}], "}"}], 
                 "\[Rule]", "y_"}]}], "]"}], "\[RuleDelayed]", "y"}]}], "]"}],
            "]"}], "\[Equal]", 
          RowBox[{"{", "}"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"win", "=", "False"}], ";", "\[IndentingNewLine]", 
          RowBox[{"Print", "[", 
           RowBox[{
           "\"\<Not possible for sure-winning anymore under delay=0\>\"", 
            ",", "\"\< with uncontrollable initial state \>\"", ",", 
            RowBox[{"init", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", " ", "\"\<.\\n\>\""}], 
           "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{"Print", "[", 
           RowBox[{"\"\<Time = \>\"", ",", " ", 
            RowBox[{
             RowBox[{"times", "[", 
              RowBox[{"[", 
               RowBox[{"-", "1"}], "]"}], "]"}], "-", "ttemp"}]}], "]"}], ";",
           "\[IndentingNewLine]", 
          RowBox[{"Return", "[", "]"}], ";"}]}], "\[IndentingNewLine]", "]"}],
        ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"s", "=", "s0"}], ";", "\[IndentingNewLine]", 
       RowBox[{"win", "=", "True"}], ";", "\[IndentingNewLine]", 
       RowBox[{"uncontrollable", "=", 
        RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"freshgoback", "=", "True"}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"k", "=", "1"}], ",", 
         RowBox[{"k", "\[LessEqual]", "lag"}], ",", 
         RowBox[{"k", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"ss", "=", 
           RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"Print", "[", 
           RowBox[{"\"\<Under delay = \>\"", ",", "k", ",", "\"\< :\>\""}], 
           "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"OddQ", "[", "k", "]"}], ",", "\[IndentingNewLine]", 
            RowBox[{"For", "[", 
             RowBox[{
              RowBox[{"i", "=", "1"}], ",", 
              RowBox[{"i", "\[LessEqual]", 
               RowBox[{"Length", "[", "vlist", "]"}]}], ",", 
              RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{"EvenQ", "[", 
                 RowBox[{"vlist", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"succ", "=", 
                  RowBox[{"vlist", "[", 
                   RowBox[{"[", 
                    RowBox[{"successor", "[", 
                    RowBox[{"adjm", ",", "i"}], "]"}], "]"}], "]"}]}], ";", 
                 "\[IndentingNewLine]", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"Length", "[", "succ", "]"}], "\[Equal]", "1"}], 
                   ",", 
                   RowBox[{"alter", "=", 
                    RowBox[{"succ", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], ",", 
                   RowBox[{"alter", "=", 
                    RowBox[{"Alternatives", "@@", "succ"}]}]}], "]"}], ";", 
                 "\[IndentingNewLine]", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{"MemberQ", "[", 
                    RowBox[{"bad", ",", 
                    RowBox[{"vlist", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
                   "\[IndentingNewLine]", 
                   RowBox[{"(*", 
                    RowBox[{
                    "mark", " ", "as", " ", "\"\<{}\>\"", " ", "directly", 
                    " ", "for", " ", "bad", " ", "states"}], "*)"}], 
                   "\[IndentingNewLine]", 
                   RowBox[{"stemp", "=", 
                    RowBox[{"Cases", "[", 
                    RowBox[{
                    RowBox[{"Normal", "[", "s", "]"}], ",", 
                    RowBox[{
                    RowBox[{"Pattern", "[", 
                    RowBox[{"pat", ",", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"alter", ",", "x_"}], "}"}], "\[Rule]", "y_"}]}], 
                    "]"}], "\[RuleDelayed]", 
                    RowBox[{"x", "\[Rule]", 
                    RowBox[{"{", "}"}]}]}]}], "]"}]}], ",", 
                   "\[IndentingNewLine]", 
                   RowBox[{
                    RowBox[{"stemp", "=", 
                    RowBox[{"Cases", "[", 
                    RowBox[{
                    RowBox[{"Normal", "[", "s", "]"}], ",", 
                    RowBox[{
                    RowBox[{"Pattern", "[", 
                    RowBox[{"pat", ",", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"alter", ",", "x_"}], "}"}], "\[Rule]", "y_"}]}], 
                    "]"}], "\[RuleDelayed]", 
                    RowBox[{"x", "\[Rule]", "y"}]}]}], "]"}]}], ";"}]}], 
                  "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
                 RowBox[{"(*", 
                  RowBox[{
                   RowBox[{"Print", "[", 
                    RowBox[{"\"\<Intersecting at state \>\"", ",", 
                    RowBox[{"vlist", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ";"}], "*)"}], 
                 "\[IndentingNewLine]", 
                 RowBox[{"sstemp", "=", 
                  RowBox[{"intersect", "[", 
                   RowBox[{"stemp", ",", 
                    RowBox[{"vlist", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], ";", 
                 "\[IndentingNewLine]", 
                 RowBox[{"(*", 
                  RowBox[{
                   RowBox[{"Print", "[", "\"\<Done intersecting.\>\"", "]"}], 
                   ";"}], "*)"}], "\[IndentingNewLine]", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"Length", "[", "stemp", "]"}], "\[NotEqual]", 
                    "0"}], ",", 
                   RowBox[{
                    RowBox[{"ss", "=", 
                    RowBox[{"Join", "[", 
                    RowBox[{"ss", ",", "sstemp"}], "]"}]}], ";", 
                    "\[IndentingNewLine]", "\[IndentingNewLine]", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"!", 
                    RowBox[{"MemberQ", "[", 
                    RowBox[{"bad", ",", 
                    RowBox[{"vlist", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"emptS", "=", 
                    RowBox[{"Cases", "[", 
                    RowBox[{"sstemp", ",", 
                    RowBox[{"Pattern", "[", 
                    RowBox[{"pat", ",", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"v_", ",", "x_"}], "}"}], "\[Rule]", 
                    RowBox[{"{", "}"}]}]}], "]"}]}], "]"}]}], ";", 
                    "\[IndentingNewLine]", "\[IndentingNewLine]", 
                    RowBox[{"For", "[", 
                    RowBox[{
                    RowBox[{"j", "=", "1"}], ",", 
                    RowBox[{"j", "\[LessEqual]", 
                    RowBox[{"Length", "[", "emptS", "]"}]}], ",", 
                    RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"!", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"emptS", "[", 
                    RowBox[{"[", "j", "]"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", 
                    RowBox[{"{", "}"}]}]}], 
                    RowBox[{"(*", 
                    RowBox[{"&&", 
                    RowBox[{"!", 
                    RowBox[{"MemberQ", "[", 
                    RowBox[{
                    RowBox[{"Cases", "[", 
                    RowBox[{"stemp", ",", 
                    RowBox[{
                    RowBox[{"Pattern", "[", 
                    RowBox[{"pat", ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"emptS", "[", 
                    RowBox[{"[", "j", "]"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "\[Rule]", "y_"}]}], 
                    "]"}], "\[RuleDelayed]", "y"}]}], "]"}], ",", 
                    RowBox[{"{", "}"}]}], "]"}]}]}], "*)"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"If", "[", 
                    RowBox[{"freshgoback", ",", 
                    RowBox[{
                    RowBox[{"freshgoback", "=", "False"}], ";", 
                    "\[IndentingNewLine]", "\[IndentingNewLine]", 
                    RowBox[{"(*", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"shrink", " ", "the", " ", "possibly"}], "-", 
                    RowBox[{"spurious", " ", "strategies", " ", "s", " ", 
                    "and", " ", "ss", " ", "to", " ", "correct", " ", 
                    "ones"}]}], ",", " ", 
                    RowBox[{"by", " ", "backward", " ", 
                    RowBox[{"recursion", ".", " ", "Defined"}], " ", "here", 
                    " ", "to", " ", "access", " ", "s", " ", "and", " ", "ss",
                     " ", "as", " ", "static", " ", 
                    RowBox[{"variables", "."}]}]}], "*)"}], 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"goback", "[", 
                    RowBox[{"indexS_", ",", "history_"}], "]"}], ":=", 
                    RowBox[{"Module", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    "S", ",", "predS", ",", "indexpredS", ",", "predSact", 
                    ",", "pS", ",", "predpredS", ",", "indexpredpredS", ",", 
                    "tS", ",", "sequence", ",", "strtS", ",", "ii", ",", "jj",
                     ",", "vv"}], "}"}], ",", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"S", "=", 
                    RowBox[{"vlist", "[", 
                    RowBox[{"[", "indexS", "]"}], "]"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"indexpredS", "=", 
                    RowBox[{"predecessor", "[", 
                    RowBox[{"adjm", ",", "indexS"}], "]"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"predS", "=", 
                    RowBox[{"vlist", "[", 
                    RowBox[{"[", "indexpredS", "]"}], "]"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"(*", 
                    RowBox[{
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Length", "[", "predS", "]"}], "\[Equal]", "1"}], 
                    ",", 
                    RowBox[{"alterp", "=", 
                    RowBox[{"predS", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], ",", 
                    RowBox[{"alterp", "=", 
                    RowBox[{"Alternatives", "@@", "predS"}]}]}], "]"}], ";"}],
                     "*)"}], "\[IndentingNewLine]", 
                    RowBox[{"(*", 
                    RowBox[{
                    RowBox[{"predSact", "=", 
                    RowBox[{"weights", "[", 
                    RowBox[{"[", 
                    RowBox[{"Flatten", "[", 
                    RowBox[{"Position", "[", 
                    RowBox[{"elist", ",", 
                    RowBox[{"alterp", "\[DirectedEdge]", "S"}]}], "]"}], 
                    "]"}], "]"}], "]"}]}], ";"}], "*)"}], 
                    "\[IndentingNewLine]", 
                    RowBox[{"predSact", "=", 
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{"weights", "[", 
                    RowBox[{"[", 
                    RowBox[{"Flatten", "[", 
                    RowBox[{"Position", "[", 
                    RowBox[{"elist", ",", 
                    RowBox[{
                    RowBox[{"predS", "[", 
                    RowBox[{"[", "jj", "]"}], "]"}], "\[DirectedEdge]", 
                    "S"}]}], "]"}], "]"}], "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"jj", ",", 
                    RowBox[{"Length", "[", "predS", "]"}]}], "}"}]}], "]"}]}],
                     ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
                    RowBox[{"For", "[", 
                    RowBox[{
                    RowBox[{"ii", "=", "1"}], ",", 
                    RowBox[{"ii", "\[LessEqual]", 
                    RowBox[{"Length", "[", "predS", "]"}]}], ",", 
                    RowBox[{"ii", "++"}], ",", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"pS", "=", 
                    RowBox[{"predS", "[", 
                    RowBox[{"[", "ii", "]"}], "]"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"sequence", "=", 
                    RowBox[{"Prepend", "[", 
                    RowBox[{
                    RowBox[{"history", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ";;", 
                    RowBox[{"-", "2"}]}], "]"}], "]"}], ",", 
                    RowBox[{"predSact", "[", 
                    RowBox[{"[", "ii", "]"}], "]"}]}], "]"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"MemberQ", "[", 
                    RowBox[{
                    RowBox[{"s", "[", 
                    RowBox[{"{", 
                    RowBox[{"pS", ",", "sequence"}], "}"}], "]"}], ",", 
                    RowBox[{
                    RowBox[{"history", "[", 
                    RowBox[{"[", 
                    RowBox[{"-", "1"}], "]"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"s", "[", 
                    RowBox[{"{", 
                    RowBox[{"pS", ",", "sequence"}], "}"}], "]"}], "=", 
                    RowBox[{"Complement", "[", 
                    RowBox[{
                    RowBox[{"s", "[", 
                    RowBox[{"{", 
                    RowBox[{"pS", ",", "sequence"}], "}"}], "]"}], ",", 
                    RowBox[{"history", "[", 
                    RowBox[{"[", 
                    RowBox[{"-", "1"}], "]"}], "]"}]}], "]"}]}], ";", 
                    "\[IndentingNewLine]", "\[IndentingNewLine]", 
                    RowBox[{"indexpredpredS", "=", 
                    RowBox[{"predecessor", "[", 
                    RowBox[{"adjm", ",", 
                    RowBox[{"indexpredS", "[", 
                    RowBox[{"[", "ii", "]"}], "]"}]}], "]"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"predpredS", "=", 
                    RowBox[{"vlist", "[", 
                    RowBox[{"[", "indexpredpredS", "]"}], "]"}]}], ";", 
                    "\[IndentingNewLine]", "\[IndentingNewLine]", 
                    RowBox[{"For", "[", 
                    RowBox[{
                    RowBox[{"jj", "=", "1"}], ",", 
                    RowBox[{"jj", "\[LessEqual]", 
                    RowBox[{"Length", "[", "predpredS", "]"}]}], ",", 
                    RowBox[{"jj", "++"}], ",", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"tS", "=", 
                    RowBox[{"predpredS", "[", 
                    RowBox[{"[", "jj", "]"}], "]"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"indexpredpredS", "[", 
                    RowBox[{"[", "jj", "]"}], "]"}], "\[GreaterEqual]", 
                    "indexS"}], "||", 
                    RowBox[{"MemberQ", "[", 
                    RowBox[{"bad", ",", "tS"}], "]"}]}], ",", 
                    RowBox[{"Continue", "[", "]"}]}], "]"}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"ss", "=", 
                    RowBox[{"Association", "[", "ss", "]"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"MemberQ", "[", 
                    RowBox[{
                    RowBox[{"ss", "[", 
                    RowBox[{"{", 
                    RowBox[{"tS", ",", "sequence"}], "}"}], "]"}], ",", 
                    RowBox[{
                    RowBox[{"history", "[", 
                    RowBox[{"[", 
                    RowBox[{"-", "1"}], "]"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"ss", "[", 
                    RowBox[{"{", 
                    RowBox[{"tS", ",", "sequence"}], "}"}], "]"}], "=", 
                    RowBox[{"Complement", "[", 
                    RowBox[{
                    RowBox[{"ss", "[", 
                    RowBox[{"{", 
                    RowBox[{"tS", ",", "sequence"}], "}"}], "]"}], ",", 
                    RowBox[{"history", "[", 
                    RowBox[{"[", 
                    RowBox[{"-", "1"}], "]"}], "]"}]}], "]"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"strtS", "=", 
                    RowBox[{"ss", "[", 
                    RowBox[{"{", 
                    RowBox[{"tS", ",", "sequence"}], "}"}], "]"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"ss", "=", 
                    RowBox[{"Normal", "[", "ss", "]"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"strtS", "\[Equal]", 
                    RowBox[{"{", "}"}]}], ",", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"AppendTo", "[", 
                    RowBox[{"uncontrollable", ",", "tS"}], "]"}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"goback", "[", 
                    RowBox[{
                    RowBox[{"indexpredpredS", "[", 
                    RowBox[{"[", "jj", "]"}], "]"}], ",", "sequence"}], 
                    "]"}]}]}], "]"}]}], ",", 
                    RowBox[{"ss", "=", 
                    RowBox[{"Normal", "[", "ss", "]"}]}]}], 
                    "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", 
                    "]"}]}]}], "\[IndentingNewLine]", "]"}]}]}], 
                    "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", 
                    "]"}]}]}]}], 
                    RowBox[{"(*", 
                    RowBox[{";", "\[IndentingNewLine]", 
                    RowBox[{"Print", "[", "\"\<goback defined.\>\"", "]"}], 
                    ";"}], "*)"}], "\[IndentingNewLine]", "]"}], ";", 
                    "\[IndentingNewLine]", "\[IndentingNewLine]", 
                    RowBox[{"(*", 
                    RowBox[{
                    RowBox[{"Print", "[", 
                    RowBox[{"\"\<Shrinking the strategy at \>\"", ",", 
                    RowBox[{"emptS", "[", 
                    RowBox[{"[", "j", "]"}], "]"}], ",", "\"\< ...\>\""}], 
                    "]"}], ";"}], "*)"}], "\[IndentingNewLine]", 
                    RowBox[{"goback", "[", 
                    RowBox[{"i", ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"emptS", "[", 
                    RowBox[{"[", "j", "]"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}]}], 
                    RowBox[{"(*", 
                    RowBox[{";", "\[IndentingNewLine]", 
                    RowBox[{"Print", "[", "\"\<Done shrinking.\>\"", "]"}], 
                    ";"}], "*)"}], "\[IndentingNewLine]", "]"}]}], "]"}], 
                    ";"}]}], "\[IndentingNewLine]", "]"}]}]}], 
                  "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
                 "\[IndentingNewLine]", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"!", 
                    RowBox[{"MemberQ", "[", 
                    RowBox[{"bad", ",", 
                    RowBox[{"vlist", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], "&&", 
                    RowBox[{
                    RowBox[{"Flatten", "[", 
                    RowBox[{"Cases", "[", 
                    RowBox[{"sstemp", ",", 
                    RowBox[{
                    RowBox[{"Pattern", "[", 
                    RowBox[{"pat", ",", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"v_", ",", "x_"}], "}"}], "\[Rule]", "y_"}]}], 
                    "]"}], "\[RuleDelayed]", "y"}]}], "]"}], "]"}], 
                    "\[Equal]", 
                    RowBox[{"{", "}"}]}]}], ",", "\[IndentingNewLine]", 
                   RowBox[{
                    RowBox[{"AppendTo", "[", 
                    RowBox[{"uncontrollable", ",", 
                    RowBox[{"vlist", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ";"}]}], "]"}], 
                 ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"Flatten", "[", 
                    RowBox[{"Cases", "[", 
                    RowBox[{
                    RowBox[{"Normal", "[", "s", "]"}], ",", 
                    RowBox[{
                    RowBox[{"Pattern", "[", 
                    RowBox[{"pat", ",", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"init", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", "x_"}], "}"}], 
                    "\[Rule]", "y_"}]}], "]"}], "\[RuleDelayed]", "y"}]}], 
                    "]"}], "]"}], "\[Equal]", 
                    RowBox[{"{", "}"}]}], ",", "\[IndentingNewLine]", 
                   RowBox[{
                    RowBox[{"win", "=", "False"}], ";", "\[IndentingNewLine]", 
                    RowBox[{"AppendTo", "[", 
                    RowBox[{"uncontrollable", ",", 
                    RowBox[{"init", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Break", "[", "]"}], ";"}]}], "]"}]}]}], 
               "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}],
            "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"EvenQ", "[", "k", "]"}], ",", "\[IndentingNewLine]", 
            RowBox[{"For", "[", 
             RowBox[{
              RowBox[{"i", "=", "1"}], ",", 
              RowBox[{"i", "\[LessEqual]", 
               RowBox[{"Length", "[", "vlist", "]"}]}], ",", 
              RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{"OddQ", "[", 
                 RowBox[{"vlist", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"succ", "=", 
                  RowBox[{"vlist", "[", 
                   RowBox[{"[", 
                    RowBox[{"successor", "[", 
                    RowBox[{"adjm", ",", "i"}], "]"}], "]"}], "]"}]}], ";", 
                 "\[IndentingNewLine]", 
                 RowBox[{"succact", "=", 
                  RowBox[{"Table", "[", 
                   RowBox[{
                    RowBox[{"weights", "[", 
                    RowBox[{"[", 
                    RowBox[{"Flatten", "[", 
                    RowBox[{"Position", "[", 
                    RowBox[{"elist", ",", 
                    RowBox[{
                    RowBox[{"vlist", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "\[DirectedEdge]", 
                    RowBox[{"succ", "[", 
                    RowBox[{"[", "j", "]"}], "]"}]}]}], "]"}], "]"}], "]"}], 
                    "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", "1", ",", 
                    RowBox[{"Length", "[", "succ", "]"}]}], "}"}]}], "]"}]}], 
                 ";", "\[IndentingNewLine]", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"Length", "[", "succ", "]"}], "\[Equal]", "1"}], 
                   ",", 
                   RowBox[{"alter", "=", 
                    RowBox[{"succ", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], ",", 
                   RowBox[{"alter", "=", 
                    RowBox[{"Alternatives", "@@", "succ"}]}]}], "]"}], ";", 
                 "\[IndentingNewLine]", "\[IndentingNewLine]", 
                 RowBox[{"stemp", "=", 
                  RowBox[{"Cases", "[", 
                   RowBox[{
                    RowBox[{"Normal", "[", "s", "]"}], ",", 
                    RowBox[{"Pattern", "[", 
                    RowBox[{"pat", ",", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"alter", ",", "x_"}], "}"}], "\[Rule]", "y_"}]}], 
                    "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
                 "\[IndentingNewLine]", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"Length", "[", "stemp", "]"}], "\[NotEqual]", 
                    "0"}], ",", "\[IndentingNewLine]", 
                   RowBox[{"(*", 
                    RowBox[{
                    RowBox[{"Print", "[", 
                    RowBox[{"\"\<Prepending at state \>\"", ",", 
                    RowBox[{"vlist", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ";"}], "*)"}], 
                   "\[IndentingNewLine]", 
                   RowBox[{
                    RowBox[{"sstemp", "=", 
                    RowBox[{"prepend", "[", 
                    RowBox[{"stemp", ",", "succ", ",", "succact", ",", 
                    RowBox[{"vlist", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", "bad"}], "]"}]}], 
                    ";", 
                    RowBox[{"ss", "=", 
                    RowBox[{"Join", "[", 
                    RowBox[{"ss", ",", "sstemp"}], "]"}]}]}]}], "]"}], ";", 
                 "\[IndentingNewLine]", 
                 RowBox[{"(*", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"disappearance", " ", "of", " ", "sure"}], "-", 
                    RowBox[{
                    "winning", " ", "strategy", " ", "if", " ", "all", " ", 
                    "the", " ", "labels", " ", 
                    RowBox[{"w", ".", "r", ".", "t", ".", " ", "one"}], " ", 
                    "particular", " ", "initial", " ", "state", " ", "are", 
                    " ", "of", " ", "the", " ", "form", " ", "\"\<xx\>\""}]}],
                    "\[Rule]", 
                   RowBox[{"{", "}"}]}], "*)"}], "\[IndentingNewLine]", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"MemberQ", "[", 
                    RowBox[{"init", ",", 
                    RowBox[{"vlist", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "&&", 
                    RowBox[{
                    RowBox[{"Flatten", "[", 
                    RowBox[{"Cases", "[", 
                    RowBox[{"sstemp", ",", 
                    RowBox[{
                    RowBox[{"Pattern", "[", 
                    RowBox[{"pat", ",", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"v_", ",", "x_"}], "}"}], "\[Rule]", "y_"}]}], 
                    "]"}], "\[RuleDelayed]", "y"}]}], "]"}], "]"}], 
                    "\[Equal]", 
                    RowBox[{"{", "}"}]}]}], ",", "\[IndentingNewLine]", 
                   RowBox[{
                    RowBox[{"win", "=", "False"}], ";", "\[IndentingNewLine]", 
                    RowBox[{"AppendTo", "[", 
                    RowBox[{"uncontrollable", ",", 
                    RowBox[{"vlist", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Break", "[", "]"}], ";"}]}], 
                  "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", 
               "]"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]",
            "]"}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"graphical", "\[Equal]", "1"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"Print", "[", 
             RowBox[{"Graph", "[", 
              RowBox[{"elist", ",", 
               RowBox[{"VertexSize", "\[Rule]", ".6"}], ",", 
               RowBox[{"VertexLabels", "\[Rule]", 
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"vlist", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "\[Rule]", 
                   RowBox[{"Placed", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"vlist", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                    RowBox[{"Style", "[", 
                    RowBox[{
                    RowBox[{"stra2label", "[", 
                    RowBox[{"ss", ",", 
                    RowBox[{"vlist", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", "Red"}], 
                    "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"1", "/", "2"}], ",", 
                    RowBox[{"1", "/", "2"}]}], "}"}], ",", "Above"}], "}"}]}],
                     "]"}]}], ",", 
                  RowBox[{"{", 
                   RowBox[{"i", ",", "1", ",", "vnum"}], "}"}]}], "]"}]}], 
               ",", 
               RowBox[{"BaselinePosition", "\[Rule]", "Axis"}], ",", 
               RowBox[{"VertexShapeFunction", "\[Rule]", "shapes"}], ",", 
               RowBox[{"EdgeLabels", "\[Rule]", 
                RowBox[{"Thread", "[", 
                 RowBox[{"elist", "\[Rule]", "weights"}], "]"}]}], ",", 
               RowBox[{"ImageSize", "\[Rule]", "600"}]}], "]"}], "]"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"Print", "[", "ss", "]"}]}], 
           RowBox[{"(*", 
            RowBox[{";", "\[IndentingNewLine]", 
             RowBox[{"Print", "[", 
              RowBox[{"\"\<\>", 
               RowBox[{"(*", 
                RowBox[{
                "hidden", " ", "for", " ", "the", " ", "sake", " ", "of", " ",
                  "space"}], "*)"}], "\"\<]\>"}]}]}], "*)"}], 
           "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{"s", "=", 
           RowBox[{"Association", "[", "ss", "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"times", ",", 
            RowBox[{"TimeUsed", "[", "]"}]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{
            RowBox[{"Print", "[", 
             RowBox[{"\"\<Time = \>\"", ",", " ", 
              RowBox[{
               RowBox[{"times", "[", 
                RowBox[{"[", 
                 RowBox[{"-", "1"}], "]"}], "]"}], "-", "ttemp"}]}], "]"}], 
            ";"}], "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"vanish", "=", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"EvenQ", "[", "k", "]"}], ",", 
             RowBox[{"k", "-", "1"}], ",", "k"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"uncontrollable", " ", "=", " ", 
           RowBox[{"DeleteDuplicates", "[", "uncontrollable", "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"!", "win"}], ",", 
            RowBox[{
             RowBox[{"Print", "[", 
              RowBox[{
              "\"\<Not possible for sure-winning anymore under delay=\>\"", 
               ",", "vanish", ",", "\"\< with uncontrollable states \>\"", 
               ",", "uncontrollable", ",", " ", "\"\<.\\n\>\""}], "]"}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"Break", "[", "]"}], ";"}]}], "\[IndentingNewLine]", 
           "]"}]}]}], "\[IndentingNewLine]", "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"times", "=", 
        RowBox[{"times", "-", "ttemp"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{
        "\"\<Computation time under increasing delays : \\n\>\"", ",", 
         "times"}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"graphical", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"ListLinePlot", "[", 
           RowBox[{
            RowBox[{"Prepend", "[", 
             RowBox[{
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"i", ",", 
                  RowBox[{"times", "[", 
                   RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "1", ",", 
                  RowBox[{"Length", "[", "times", "]"}]}], "}"}]}], "]"}], 
              ",", 
              RowBox[{"{", 
               RowBox[{"0", ",", "0"}], "}"}]}], "]"}], ",", " ", 
            RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
            RowBox[{"AxesLabel", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"\"\<delay d\>\"", ",", "\"\<time\>\""}], "}"}]}], ",", 
            
            RowBox[{"Mesh", "\[Rule]", "All"}], ",", 
            RowBox[{"ImageSize", "\[Rule]", "600"}]}], "]"}], "]"}]}], "]"}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"Return", "[", "]"}], ";"}]}], "\[IndentingNewLine]", "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"stra2label", "[", 
     RowBox[{"s_", ",", "v_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"label", ",", "x", ",", "y"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"label", "=", 
        RowBox[{"Cases", "[", 
         RowBox[{
          RowBox[{"Normal", "[", "s", "]"}], ",", 
          RowBox[{
           RowBox[{"HoldPattern", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"v", ",", "x_"}], "}"}], "\[Rule]", "y_"}], "]"}], 
           "\[RuleDelayed]", 
           RowBox[{
            RowBox[{"InputForm", "[", 
             RowBox[{"StringJoin", "[", 
              RowBox[{"ToString", "/@", "x"}], "]"}], "]"}], "\[Rule]", 
            "y"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Return", "[", 
        RowBox[{"Row", "[", 
         RowBox[{"label", ",", "\"\<\\n\>\""}], "]"}], "]"}], ";"}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"successor", "[", 
     RowBox[{"adjm_", ",", "vindex_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"row", ",", "succ"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"row", "=", 
        RowBox[{"adjm", "[", 
         RowBox[{"[", "vindex", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Return", "[", 
        RowBox[{"Flatten", "[", 
         RowBox[{"Position", "[", 
          RowBox[{
           RowBox[{"List", "@@", "row"}], ",", 
           RowBox[{"_", "?", "Positive"}]}], "]"}], "]"}], "]"}], ";"}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"predecessor", "[", 
     RowBox[{"adjm_", ",", "vindex_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"column", ",", "predec"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"column", "=", 
        RowBox[{
         RowBox[{"Transpose", "[", "adjm", "]"}], "[", 
         RowBox[{"[", "vindex", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Return", "[", 
        RowBox[{"Flatten", "[", 
         RowBox[{"Position", "[", 
          RowBox[{
           RowBox[{"List", "@@", "column"}], ",", 
           RowBox[{"_", "?", "Positive"}]}], "]"}], "]"}], "]"}], ";"}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"intersect", "[", 
      RowBox[{"st_", ",", "v_"}], "]"}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"ss", ",", "stemp", ",", "i", ",", "j"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"stemp", "=", "st"}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Length", "[", "stemp", "]"}], "\[Equal]", "1"}], ",", 
          RowBox[{"ss", "=", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"v", ",", 
               RowBox[{
                RowBox[{"Keys", "[", "stemp", "]"}], "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "}"}], "\[Rule]", 
             RowBox[{
              RowBox[{"Values", "[", "stemp", "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"For", "[", 
            RowBox[{
             RowBox[{"i", "=", "1"}], ",", 
             RowBox[{"i", "\[LessEqual]", 
              RowBox[{"Length", "[", "stemp", "]"}]}], ",", 
             RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"stemp", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "===", 
                 RowBox[{"-", "1"}]}], ",", 
                RowBox[{"Continue", "[", "]"}]}], "]"}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"For", "[", 
               RowBox[{
                RowBox[{"j", "=", 
                 RowBox[{"i", "+", "1"}]}], ",", 
                RowBox[{"j", "\[LessEqual]", 
                 RowBox[{"Length", "[", "stemp", "]"}]}], ",", 
                RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"stemp", "[", 
                    RowBox[{"[", "j", "]"}], "]"}], "===", 
                    RowBox[{"-", "1"}]}], ",", 
                   RowBox[{"Continue", "[", "]"}]}], "]"}], ";", 
                 "\[IndentingNewLine]", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"Keys", "[", 
                    RowBox[{"stemp", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "]"}], "\[Equal]", 
                    RowBox[{"Keys", "[", 
                    RowBox[{"stemp", "[", 
                    RowBox[{"[", "j", "]"}], "]"}], "]"}]}], ",", 
                   "\[IndentingNewLine]", 
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"stemp", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "=", 
                    RowBox[{"Intersection", "[", 
                    RowBox[{
                    RowBox[{"Values", "[", 
                    RowBox[{"stemp", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
                    RowBox[{"Values", "[", 
                    RowBox[{"stemp", "[", 
                    RowBox[{"[", "j", "]"}], "]"}], "]"}]}], "]"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"stemp", "[", 
                    RowBox[{"[", "j", "]"}], "]"}], "=", 
                    RowBox[{"-", "1"}]}], ";"}]}], "\[IndentingNewLine]", 
                  "]"}]}]}], "\[IndentingNewLine]", "]"}]}]}], 
            "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
           RowBox[{"stemp", "=", 
            RowBox[{"Select", "[", 
             RowBox[{"stemp", ",", 
              RowBox[{
               RowBox[{"#", "=!=", 
                RowBox[{"-", "1"}]}], "&"}]}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"ss", "=", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"{", 
                RowBox[{"v", ",", 
                 RowBox[{
                  RowBox[{"Keys", "[", "stemp", "]"}], "[", 
                  RowBox[{"[", "i", "]"}], "]"}]}], "}"}], "\[Rule]", 
               RowBox[{
                RowBox[{"Values", "[", "stemp", "]"}], "[", 
                RowBox[{"[", "i", "]"}], "]"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "1", ",", 
                RowBox[{"Length", "[", "stemp", "]"}]}], "}"}]}], "]"}]}], 
           ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
        
        RowBox[{"Return", "[", "ss", "]"}], ";"}]}], "\[IndentingNewLine]", 
      "]"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"intersect", "[", 
     RowBox[{"st_", ",", "v_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "ss", ",", "temp", ",", "stemp", ",", "stemptemp", ",", "pat", ",", 
        "y", ",", "i", ",", "j"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"stemp", "=", "st"}], ";", "\[IndentingNewLine]", 
       RowBox[{"stemptemp", "=", 
        RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Length", "[", "stemp", "]"}], "\[Equal]", "1"}], ",", 
         RowBox[{"ss", "=", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"v", ",", 
              RowBox[{
               RowBox[{"Keys", "[", "stemp", "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], "}"}], "\[Rule]", 
            RowBox[{
             RowBox[{"Values", "[", "stemp", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"While", "[", 
           RowBox[{
            RowBox[{"stemp", "\[NotEqual]", 
             RowBox[{"{", "}"}]}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"temp", "=", 
              RowBox[{
               RowBox[{"Keys", "[", "stemp", "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"Values", "[", "stemp", "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", 
                RowBox[{"{", "}"}]}], ",", "\[IndentingNewLine]", 
               RowBox[{"AppendTo", "[", 
                RowBox[{"stemptemp", ",", 
                 RowBox[{"temp", "\[Rule]", 
                  RowBox[{"{", "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"AppendTo", "[", 
                 RowBox[{"stemptemp", ",", 
                  RowBox[{"temp", "\[Rule]", 
                   RowBox[{"Intersection", "@@", 
                    RowBox[{"Cases", "[", 
                    RowBox[{"stemp", ",", 
                    RowBox[{
                    RowBox[{"Pattern", "[", 
                    RowBox[{"pat", ",", 
                    RowBox[{"temp", "\[Rule]", "y_"}]}], "]"}], 
                    "\[RuleDelayed]", "y"}]}], "]"}]}]}]}], "]"}], ";"}]}], 
              "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
             RowBox[{"stemp", "=", 
              RowBox[{"DeleteCases", "[", 
               RowBox[{"stemp", ",", 
                RowBox[{"Pattern", "[", 
                 RowBox[{"pat", ",", 
                  RowBox[{"temp", "\[Rule]", "y_"}]}], "]"}]}], "]"}]}], 
             ";"}]}], "\[IndentingNewLine]", "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"ss", "=", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"{", 
               RowBox[{"v", ",", 
                RowBox[{
                 RowBox[{"Keys", "[", "stemptemp", "]"}], "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], "}"}], "\[Rule]", 
              RowBox[{
               RowBox[{"Values", "[", "stemptemp", "]"}], "[", 
               RowBox[{"[", "i", "]"}], "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"Length", "[", "stemptemp", "]"}]}], "}"}]}], "]"}]}], 
          ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Return", "[", "ss", "]"}], ";"}]}], "\[IndentingNewLine]", 
     "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"prepend", "[", 
     RowBox[{"st_", ",", "succ_", ",", "succact_", ",", "v_", ",", "bad_"}], 
     "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"ss", ",", "stemp", ",", "succ2act", ",", "i"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"stemp", "=", "st"}], ";", "\[IndentingNewLine]", 
       RowBox[{"ss", "=", 
        RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"succ2act", "=", 
        RowBox[{"Thread", "[", 
         RowBox[{"succ", "\[Rule]", "succact"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "1"}], ",", 
         RowBox[{"i", "\[LessEqual]", 
          RowBox[{"Length", "[", "stemp", "]"}]}], ",", 
         RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"MemberQ", "[", 
             RowBox[{"bad", ",", "v"}], "]"}], ",", "\[IndentingNewLine]", 
            RowBox[{"(*", 
             RowBox[{
             "mark", " ", "as", " ", "\"\<{}\>\"", " ", "directly", " ", 
              "for", " ", "bad", " ", "states"}], "*)"}], 
            "\[IndentingNewLine]", 
            RowBox[{"AppendTo", "[", 
             RowBox[{"ss", ",", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"v", ",", 
                 RowBox[{"Prepend", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"Keys", "[", 
                    RowBox[{"stemp", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ",", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"Keys", "[", 
                    RowBox[{"stemp", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "/.", "succ2act"}]}], 
                  "]"}]}], "}"}], "\[Rule]", 
               RowBox[{"{", "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"AppendTo", "[", 
              RowBox[{"ss", ",", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"v", ",", 
                  RowBox[{"Prepend", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"Keys", "[", 
                    RowBox[{"stemp", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Keys", "[", 
                    RowBox[{"stemp", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "/.", "succ2act"}]}], 
                   "]"}]}], "}"}], "\[Rule]", 
                RowBox[{"Values", "[", 
                 RowBox[{"stemp", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "]"}]}]}], "]"}], ";"}]}], 
           "\[IndentingNewLine]", "]"}], ";"}]}], "\[IndentingNewLine]", 
        "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Return", "[", "ss", "]"}], ";"}]}], "\[IndentingNewLine]", 
     "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.679223202829571*^9, 3.679223278437739*^9}, {
   3.67922332014705*^9, 3.679223439133549*^9}, {3.679223597285616*^9, 
   3.679223644603707*^9}, {3.67922369653592*^9, 3.679223704304227*^9}, 
   3.679223745301376*^9, {3.679223887698839*^9, 3.679223996976369*^9}, {
   3.679224079248383*^9, 3.679224132510179*^9}, {3.679224845144917*^9, 
   3.679224866945943*^9}, {3.679224911741082*^9, 3.67922491489446*^9}, {
   3.679225038969646*^9, 3.679225072922038*^9}, 3.67922517213904*^9, {
   3.67922521242542*^9, 3.679225244155544*^9}, {3.679225279313424*^9, 
   3.679225381265962*^9}, {3.67922544084154*^9, 3.679225462877068*^9}, {
   3.679225542875165*^9, 3.679225557979255*^9}, 3.679225656501378*^9, {
   3.679226180035772*^9, 3.679226202116338*^9}, {3.679226266666771*^9, 
   3.679226283916304*^9}, {3.679226317975041*^9, 3.679226329247156*^9}, {
   3.679226453596949*^9, 3.679226519002698*^9}, {3.679226857148445*^9, 
   3.679226907272013*^9}, {3.679229647189011*^9, 3.679229654522181*^9}, {
   3.679230352159607*^9, 3.679230353061153*^9}, {3.67923071802935*^9, 
   3.679230855800637*^9}, {3.679230907312702*^9, 3.679230976394665*^9}, {
   3.679234991566363*^9, 3.679234997956382*^9}, {3.679235074326954*^9, 
   3.679235163650137*^9}, {3.679235226595488*^9, 3.679235343319427*^9}, {
   3.679235406202302*^9, 3.67923540869575*^9}, {3.679290564992358*^9, 
   3.679290570621698*^9}, {3.679291223691299*^9, 3.679291224141943*^9}, {
   3.679291292521463*^9, 3.679291294292991*^9}, {3.679291417836634*^9, 
   3.67929149183738*^9}, {3.679291645470495*^9, 3.679291701051778*^9}, {
   3.679291961248053*^9, 3.679291976872381*^9}, {3.679292141048404*^9, 
   3.679292177220054*^9}, {3.679292221133952*^9, 3.679292226413322*^9}, {
   3.679292299390845*^9, 3.679292305486059*^9}, {3.679292458180228*^9, 
   3.679292484898763*^9}, {3.679292564826299*^9, 3.679292571129406*^9}, {
   3.679292702135689*^9, 3.679292747115601*^9}, {3.6792961784034758`*^9, 
   3.67929618098198*^9}, {3.679298989068443*^9, 3.679299014257933*^9}, {
   3.679299224359662*^9, 3.679299257701649*^9}, {3.679299318559581*^9, 
   3.679299391648931*^9}, {3.679299507065237*^9, 3.679299508439256*^9}, {
   3.679299539044643*^9, 3.67929953930136*^9}, {3.679299606266042*^9, 
   3.679299631102609*^9}, {3.679299697248675*^9, 3.679299745667977*^9}, {
   3.67929989540049*^9, 3.679299925923386*^9}, {3.67929996657553*^9, 
   3.679299983869439*^9}, {3.679300796599114*^9, 3.679300875659873*^9}, {
   3.679301460173773*^9, 3.679301478105064*^9}, {3.679301567043441*^9, 
   3.679301709774614*^9}, {3.679302214249966*^9, 3.679302235870366*^9}, {
   3.679302282336185*^9, 3.679302329984342*^9}, {3.679302371294635*^9, 
   3.679302408215824*^9}, {3.679302533255304*^9, 3.679302580265386*^9}, {
   3.679302733920787*^9, 3.679302748818563*^9}, {3.679302781418649*^9, 
   3.679302783510837*^9}, {3.679302818457866*^9, 3.679302828255771*^9}, {
   3.679302861153539*^9, 3.679302869842349*^9}, {3.679302939912245*^9, 
   3.679302944192207*^9}, {3.679302988957414*^9, 3.679303025504368*^9}, {
   3.679303076600326*^9, 3.679303077592862*^9}, 3.679303160347795*^9, {
   3.679303438342846*^9, 3.679303449372035*^9}, {3.679303487353854*^9, 
   3.679303516626237*^9}, {3.679303590206996*^9, 3.679303599448344*^9}, {
   3.679303676441395*^9, 3.679303690679569*^9}, {3.67930395899726*^9, 
   3.679303968465424*^9}, {3.679304019361115*^9, 3.679304034571824*^9}, {
   3.679304076773824*^9, 3.679304112064315*^9}, {3.679305146313378*^9, 
   3.679305169215621*^9}, {3.679305982311329*^9, 3.679306001471641*^9}, {
   3.679306190943007*^9, 3.679306219311152*^9}, {3.679306253028934*^9, 
   3.67930625405839*^9}, {3.679306289852007*^9, 3.67930630019604*^9}, {
   3.679307286843055*^9, 3.679307294037899*^9}, {3.679307943613325*^9, 
   3.679307993083086*^9}, {3.679308129871863*^9, 3.679308214816544*^9}, {
   3.679308293989234*^9, 3.67930830829053*^9}, {3.679308341289704*^9, 
   3.679308343851444*^9}, {3.679308549388082*^9, 3.679308587622865*^9}, {
   3.679308680998411*^9, 3.679308744399*^9}, {3.679308805948608*^9, 
   3.679308818411887*^9}, {3.679308870546577*^9, 3.679308875792821*^9}, {
   3.679309095590812*^9, 3.679309098162472*^9}, {3.679309164920952*^9, 
   3.679309236371243*^9}, {3.679311180273478*^9, 3.679311183290365*^9}, {
   3.679311268224928*^9, 3.679311271385745*^9}, {3.679311393234554*^9, 
   3.679311421193701*^9}, {3.679311467346256*^9, 3.679311489469393*^9}, {
   3.679312332546099*^9, 3.679312362520067*^9}, {3.679312394364828*^9, 
   3.679312428649311*^9}, {3.679312569422119*^9, 3.67931259013757*^9}, {
   3.679312637475559*^9, 3.679312641024954*^9}, {3.679332550912237*^9, 
   3.679332565786839*^9}, {3.679332738497321*^9, 3.679332745031294*^9}, {
   3.679332777334371*^9, 3.679332793006475*^9}, {3.67933338315812*^9, 
   3.679333398402003*^9}, {3.679333498548856*^9, 3.679333548735721*^9}, {
   3.679333629447224*^9, 3.679333641948432*^9}, {3.679333721507678*^9, 
   3.679333773901551*^9}, {3.679333812266415*^9, 3.679333828310719*^9}, {
   3.679333948498517*^9, 3.679333957220567*^9}, {3.679334034883289*^9, 
   3.679334070132599*^9}, {3.679334110061883*^9, 3.679334131727717*^9}, {
   3.679334167214702*^9, 3.679334168244823*^9}, 3.679334207013553*^9, 
   3.679334311784793*^9, {3.679334416099892*^9, 3.679334416510986*^9}, {
   3.67933444652031*^9, 3.679334468704596*^9}, {3.679334517509368*^9, 
   3.679334519252561*^9}, {3.679335540639396*^9, 3.679335591145098*^9}, {
   3.679335785878219*^9, 3.679335790762449*^9}, {3.679336266769977*^9, 
   3.679336334407215*^9}, {3.67933641363281*^9, 3.679336482709221*^9}, {
   3.679336551326079*^9, 3.679336555126883*^9}, {3.679336633072594*^9, 
   3.679336687760009*^9}, {3.679337198693585*^9, 3.679337215920885*^9}, {
   3.679337263726556*^9, 3.679337263875817*^9}, {3.679337395478917*^9, 
   3.679337407635707*^9}, {3.679337465046953*^9, 3.67933747143199*^9}, {
   3.679337503063911*^9, 3.679337527692548*^9}, {3.679338381080781*^9, 
   3.679338394155959*^9}, {3.679339132007285*^9, 3.679339160575649*^9}, {
   3.679339196936729*^9, 3.679339216592656*^9}, {3.679339255409132*^9, 
   3.679339278389667*^9}, {3.67933980408919*^9, 3.679339933487629*^9}, {
   3.679340004364495*^9, 3.67934002499845*^9}, {3.679340200798798*^9, 
   3.679340306089289*^9}, {3.679340891919328*^9, 3.6793409122448*^9}, {
   3.679340999336752*^9, 3.679341010478682*^9}, {3.679341049662284*^9, 
   3.679341204228926*^9}, {3.679341270507947*^9, 3.679341272075955*^9}, {
   3.679341306253544*^9, 3.679341343918867*^9}, {3.679341670501862*^9, 
   3.679341673497383*^9}, {3.679342059097542*^9, 3.679342127709997*^9}, {
   3.67934216454173*^9, 3.679342166413551*^9}, {3.67934232224641*^9, 
   3.679342331201463*^9}, {3.679342497788343*^9, 3.679342530449217*^9}, {
   3.679342818091256*^9, 3.679342853704549*^9}, {3.679342913842396*^9, 
   3.679342919165746*^9}, {3.679342957718811*^9, 3.679343046671063*^9}, {
   3.679343153498999*^9, 3.679343155669273*^9}, {3.679343217326061*^9, 
   3.679343224740615*^9}, {3.679343648681093*^9, 3.679343652539943*^9}, {
   3.679344043234529*^9, 3.679344060671654*^9}, {3.679344140872404*^9, 
   3.679344174442759*^9}, {3.679344207530773*^9, 3.6793442899972258`*^9}, {
   3.679344790861665*^9, 3.679344793167095*^9}, {3.679344886337427*^9, 
   3.679344947078314*^9}, {3.679345164709052*^9, 3.679345207092536*^9}, {
   3.679345241005363*^9, 3.67934525528931*^9}, {3.679345308070017*^9, 
   3.679345308315624*^9}, {3.679345410753674*^9, 3.679345466688775*^9}, {
   3.679345905567633*^9, 3.679345906242055*^9}, {3.679346574926686*^9, 
   3.679346604218533*^9}, {3.67934665416338*^9, 3.679346656094257*^9}, {
   3.679346822920658*^9, 3.679346858556256*^9}, {3.679347015625299*^9, 
   3.679347022215581*^9}, {3.679347095643854*^9, 3.679347254054646*^9}, 
   3.67934730665071*^9, {3.679347447111535*^9, 3.679347452513156*^9}, 
   3.679347886178029*^9, {3.679347927289777*^9, 3.679348014979414*^9}, {
   3.679348089219966*^9, 3.679348103043908*^9}, {3.679348228971568*^9, 
   3.679348307367478*^9}, {3.679348351210411*^9, 3.679348603292384*^9}, 
   3.679348707563066*^9, {3.679348752599128*^9, 3.679348752831038*^9}, {
   3.679348796877238*^9, 3.679348806958742*^9}, {3.679348869697384*^9, 
   3.679349080843321*^9}, {3.679349129382576*^9, 3.679349177155597*^9}, {
   3.679349213615044*^9, 3.67934921410777*^9}, {3.679349294511546*^9, 
   3.679349295118573*^9}, {3.679349382162437*^9, 3.679349386199127*^9}, {
   3.679349726521852*^9, 3.679349729591468*^9}, {3.679349856408542*^9, 
   3.679349976629771*^9}, {3.679350148080331*^9, 3.679350170160368*^9}, {
   3.679350506264777*^9, 3.679350582751909*^9}, {3.679350616015554*^9, 
   3.679350727025208*^9}, {3.679350811828962*^9, 3.679350817065104*^9}, {
   3.679350853828417*^9, 3.679350859697271*^9}, {3.679350991051761*^9, 
   3.67935101561185*^9}, {3.679351054234952*^9, 3.679351185770997*^9}, {
   3.679351282488773*^9, 3.679351309690242*^9}, {3.679351362525916*^9, 
   3.67935137398632*^9}, {3.679351572291441*^9, 3.679351572818125*^9}, {
   3.679387065620252*^9, 3.679387086772121*^9}, {3.679387361738169*^9, 
   3.679387399474502*^9}, {3.679387540937772*^9, 3.679387634409497*^9}, {
   3.67938774221718*^9, 3.679387747278454*^9}, {3.679387792208842*^9, 
   3.679387836553247*^9}, {3.679387985982971*^9, 3.67938798663051*^9}, {
   3.679388318908952*^9, 3.679388325443017*^9}, {3.679388566122625*^9, 
   3.67938865842524*^9}, {3.679388706348762*^9, 3.679388713696721*^9}, {
   3.679388767503622*^9, 3.679388853203132*^9}, {3.679388884523926*^9, 
   3.679388898016567*^9}, {3.6795158618509*^9, 3.679515896534594*^9}, {
   3.67951593585796*^9, 3.679515945285744*^9}, 3.679516065128532*^9, {
   3.679632865940861*^9, 3.679632867427679*^9}, {3.679632927707834*^9, 
   3.67963294546089*^9}, {3.679633048266926*^9, 3.679633123177293*^9}, 
   3.679633216635749*^9, {3.679633301272361*^9, 3.679633351598478*^9}, {
   3.679633387702113*^9, 3.679633408500796*^9}, {3.679633443691063*^9, 
   3.679633444729304*^9}, 3.679633480621703*^9, {3.679633564671546*^9, 
   3.679633599805528*^9}, {3.679633706392897*^9, 3.679633811149793*^9}, {
   3.679633855263624*^9, 3.679633907282463*^9}, {3.683091594319299*^9, 
   3.683091796345111*^9}, 3.683091957703282*^9, {3.683092114909584*^9, 
   3.683092146638745*^9}, {3.683092241043786*^9, 3.683092266924927*^9}, {
   3.68309230187112*^9, 3.683092350937126*^9}, {3.683092593666084*^9, 
   3.683092612217062*^9}, {3.683092810530135*^9, 3.68309282971227*^9}, {
   3.683417636624484*^9, 3.683417711535283*^9}, {3.686026436969077*^9, 
   3.686026492249494*^9}, {3.686029471553811*^9, 3.68602949055087*^9}, {
   3.6860297401905107`*^9, 3.686029810721941*^9}, {3.686029846532463*^9, 
   3.686029919367399*^9}, {3.6860300234590473`*^9, 3.686030030105744*^9}, {
   3.686030187084013*^9, 3.686030195437728*^9}, {3.6860302837551126`*^9, 
   3.686030306512747*^9}, {3.68603033663253*^9, 3.686030397203065*^9}, {
   3.686030448875123*^9, 3.686030467340399*^9}, {3.686030519923791*^9, 
   3.6860305201176*^9}, 3.686030606177116*^9, {3.6860323755163527`*^9, 
   3.6860324748584347`*^9}, {3.6860325125614157`*^9, 3.686032531550898*^9}, {
   3.686032591436919*^9, 3.686032715812623*^9}, {3.68603275105273*^9, 
   3.686032752832868*^9}, {3.686032862973668*^9, 3.686032929215008*^9}, {
   3.686032994884694*^9, 3.6860330525572767`*^9}, 3.686033304142631*^9, 
   3.686033354430633*^9, {3.686034161571289*^9, 3.686034180415309*^9}, {
   3.686034511760976*^9, 3.6860345256234083`*^9}, 3.686035094158503*^9, {
   3.6860352164559107`*^9, 3.686035220434876*^9}, {3.686035706165894*^9, 
   3.686035913337325*^9}, {3.686036031677273*^9, 3.686036065821509*^9}, 
   3.686036130777458*^9, {3.686036191792254*^9, 3.686036219154821*^9}, {
   3.686036267742275*^9, 3.686036436631274*^9}, {3.686036483605424*^9, 
   3.686036516861463*^9}, {3.6860365736586237`*^9, 3.6860365779206467`*^9}, {
   3.6860367711582813`*^9, 3.686036771576354*^9}, {3.686037887708857*^9, 
   3.6860379088879137`*^9}, {3.686037941980213*^9, 3.6860380390302973`*^9}, {
   3.6860381473895817`*^9, 3.686038151511251*^9}, {3.686038253587501*^9, 
   3.6860382554017277`*^9}, {3.68603828678156*^9, 3.6860382919176064`*^9}, {
   3.686038382688182*^9, 3.686038411339407*^9}, {3.6860384842994204`*^9, 
   3.68603850182613*^9}, {3.686038712416645*^9, 3.68603873120192*^9}, {
   3.68603876917725*^9, 3.6860387693468113`*^9}, {3.686038862911087*^9, 
   3.686038873426354*^9}, 3.6860389198440447`*^9, {3.686039238533113*^9, 
   3.686039263873096*^9}, {3.6860393018650093`*^9, 3.6860393346646423`*^9}, {
   3.686039423285345*^9, 3.686039434246648*^9}, {3.686039661477953*^9, 
   3.6860396662197647`*^9}, {3.686039872340939*^9, 3.68603987885876*^9}, {
   3.686043755549906*^9, 3.686043757876196*^9}, {3.686044502575194*^9, 
   3.68604451234527*^9}, {3.6860445719624233`*^9, 3.6860447077520847`*^9}, {
   3.686044758391955*^9, 3.686044758729144*^9}, {3.686045558275519*^9, 
   3.68604556232574*^9}, 3.686045669990038*^9, {3.6860457046409473`*^9, 
   3.6860457312973413`*^9}, {3.6860457746887817`*^9, 
   3.6860458937566433`*^9}, {3.686045988547739*^9, 3.686046001089592*^9}, 
   3.686047510367975*^9, 3.6860476295451803`*^9, {3.693035954306168*^9, 
   3.693036043825767*^9}, {3.69303610746808*^9, 3.6930361586297626`*^9}, {
   3.693036221515477*^9, 3.693036226669416*^9}, {3.6930364555922117`*^9, 
   3.693036456038742*^9}, {3.6930365424341993`*^9, 3.693036571419804*^9}, {
   3.69303675959132*^9, 3.6930367976626368`*^9}, {3.6930372225953493`*^9, 
   3.693037228080419*^9}, {3.693037320045815*^9, 3.693037336885956*^9}, {
   3.693093073600478*^9, 3.693093184997016*^9}, {3.693093224553858*^9, 
   3.693093249956583*^9}, {3.693198555261196*^9, 3.693198612046322*^9}, 
   3.693208018953802*^9, {3.693382526644041*^9, 3.693382552747693*^9}, {
   3.693382946823946*^9, 3.69338296510711*^9}, 3.693439858767026*^9, 
   3.693442295184987*^9, 3.693795512446856*^9, {3.693795584061015*^9, 
   3.6937956349842367`*^9}, {3.6939687101343527`*^9, 3.693968734609221*^9}, {
   3.693972831257464*^9, 3.6939728350378103`*^9}, {3.693972882724498*^9, 
   3.693972882895729*^9}, {3.6939729312939987`*^9, 3.6939729336573753`*^9}, {
   3.693972989046061*^9, 3.6939730139399977`*^9}, {3.693973124720256*^9, 
   3.6939731973307543`*^9}, {3.69397335380202*^9, 3.693973384671501*^9}, 
   3.6939739234507627`*^9, {3.693974253927248*^9, 3.693974258054831*^9}, {
   3.693974291794354*^9, 3.693974374105729*^9}, {3.6939744280099363`*^9, 
   3.6939744359058523`*^9}, {3.693974471402494*^9, 3.6939744856460657`*^9}, {
   3.693974524549775*^9, 3.693974538846373*^9}, {3.693974579568839*^9, 
   3.6939746243643513`*^9}, 3.693975101416469*^9, {3.693975146477274*^9, 
   3.693975149367097*^9}, {3.693975328285659*^9, 3.693975375658615*^9}, 
   3.693975611845434*^9, {3.69397564922062*^9, 3.6939756502206497`*^9}, {
   3.6939757457636957`*^9, 3.693975772939427*^9}, {3.693975936799238*^9, 
   3.6939759470636806`*^9}, {3.6939759936868763`*^9, 3.6939760243861*^9}, {
   3.693976311242889*^9, 3.693976318063203*^9}, {3.693976378627502*^9, 
   3.6939763877695217`*^9}, {3.693976446590865*^9, 3.693976455651319*^9}, {
   3.693977109089307*^9, 3.6939771482083817`*^9}, {3.693977272768957*^9, 
   3.6939772736684723`*^9}, {3.6939775261617203`*^9, 3.693977534822486*^9}, {
   3.693977748724525*^9, 3.693977826769491*^9}, {3.693977875230945*^9, 
   3.6939779046261806`*^9}, {3.693977945351219*^9, 3.6939779461567297`*^9}, {
   3.693978077751615*^9, 3.693978100060848*^9}, {3.693978141644712*^9, 
   3.693978143531848*^9}, {3.69397821697943*^9, 3.693978259251548*^9}, {
   3.693978668491989*^9, 3.693978731013607*^9}, {3.69397882016125*^9, 
   3.6939788618769913`*^9}, {3.6939788929393187`*^9, 3.693978915073555*^9}, {
   3.693978979511043*^9, 3.693979038808416*^9}, {3.6939799016738377`*^9, 
   3.693980000381442*^9}, {3.69398004667912*^9, 3.6939801303255157`*^9}, {
   3.693980161732036*^9, 3.6939801703001347`*^9}, {3.693980230219596*^9, 
   3.693980241859041*^9}, {3.693980336122053*^9, 3.69398033639881*^9}, {
   3.6939803779132643`*^9, 3.693980459082007*^9}, 3.6939804965818872`*^9, {
   3.69398059881861*^9, 3.6939807779926443`*^9}, {3.6939809115413847`*^9, 
   3.693980933808037*^9}, {3.693981000742989*^9, 3.693981003006218*^9}, {
   3.6939812681573353`*^9, 3.693981439348465*^9}, {3.693983343866193*^9, 
   3.693983413889756*^9}, {3.693983466922658*^9, 3.693983486573926*^9}, {
   3.693983545542686*^9, 3.693983570200832*^9}, {3.693983868719879*^9, 
   3.693983909747013*^9}, {3.6939840072415123`*^9, 3.6939840987853603`*^9}, {
   3.6939841529210587`*^9, 3.693984195399267*^9}, {3.69398423663503*^9, 
   3.693984256599395*^9}, {3.693984382831408*^9, 3.693984385592795*^9}, {
   3.6939847051474*^9, 3.693984717471217*^9}, {3.693984823192234*^9, 
   3.6939849732806787`*^9}, {3.693985042203094*^9, 3.693985053260561*^9}, {
   3.693985111415991*^9, 3.693985162582983*^9}, {3.69398535808278*^9, 
   3.6939854636932697`*^9}, {3.693985514873477*^9, 3.693985521207226*^9}, {
   3.693985563866208*^9, 3.693985566693655*^9}, {3.693987570821754*^9, 
   3.6939876050054827`*^9}, {3.693987694492592*^9, 3.693987707933291*^9}, {
   3.693987755373755*^9, 3.693987815199482*^9}, {3.6939878810570593`*^9, 
   3.69398789244911*^9}, {3.6939879449389753`*^9, 3.6939881597562017`*^9}, {
   3.693988200279223*^9, 3.693988246779509*^9}, {3.693988463006537*^9, 
   3.6939885151958733`*^9}, {3.6939885524666147`*^9, 3.693988562292509*^9}, {
   3.6939886042356977`*^9, 3.693988666582842*^9}, {3.6939887022374563`*^9, 
   3.693988747131502*^9}, {3.69398883384663*^9, 3.693988881797797*^9}, 
   3.69398891564596*^9, {3.693989003124386*^9, 3.693989068680291*^9}, {
   3.693989203764189*^9, 3.693989231129445*^9}, {3.693989489526743*^9, 
   3.693989581428734*^9}, {3.6939902637924337`*^9, 3.6939902712665653`*^9}, {
   3.693990718544091*^9, 3.693990834861787*^9}, {3.693990867884963*^9, 
   3.693990871169868*^9}, 3.6939909503306503`*^9, {3.693993043536017*^9, 
   3.693993115477641*^9}, {3.693993223037902*^9, 3.693993248474049*^9}, {
   3.694044423058827*^9, 3.69404448380991*^9}, {3.6940448532070427`*^9, 
   3.694044910668569*^9}, {3.694045141315886*^9, 3.694045167291123*^9}, {
   3.6940451989627323`*^9, 3.694045201825283*^9}, {3.694045285867445*^9, 
   3.694045300611261*^9}, {3.6940458817292747`*^9, 3.694045882239437*^9}, {
   3.694046060296946*^9, 3.69404607964361*^9}, {3.6940472918111763`*^9, 
   3.694047316917019*^9}, {3.6940480029359303`*^9, 3.694048027623458*^9}, {
   3.6940480928535833`*^9, 3.694048213963035*^9}, {3.694048871581986*^9, 
   3.6940488767976027`*^9}, {3.694052755054338*^9, 3.694052782223178*^9}, {
   3.694052892097679*^9, 3.694052899623674*^9}, 3.694053043992044*^9, {
   3.694053160807706*^9, 3.6940531783152657`*^9}, {3.694053477851254*^9, 
   3.694053478315391*^9}, {3.694053790190097*^9, 3.694053853300943*^9}, 
   3.694054562523162*^9, {3.6940549055782633`*^9, 3.694054912820854*^9}, {
   3.694054956708785*^9, 3.694054958076342*^9}, {3.694055213630928*^9, 
   3.6940552352590923`*^9}, {3.694055521757182*^9, 3.6940555270595217`*^9}, {
   3.694055561570554*^9, 3.694055590502226*^9}, {3.6940558471879587`*^9, 
   3.69405586479368*^9}, {3.6940559018964033`*^9, 3.694055904968936*^9}, 
   3.694146430738748*^9, {3.6941468249468393`*^9, 3.694146839509886*^9}, {
   3.694146883965906*^9, 3.694146930619228*^9}, {3.694147071216497*^9, 
   3.6941470726826277`*^9}, {3.694147170177507*^9, 3.694147301760141*^9}, {
   3.694147422004445*^9, 3.694147451416057*^9}, 3.694147770530078*^9, {
   3.694148079408101*^9, 3.6941481310561447`*^9}, {3.694148425013472*^9, 
   3.694148439088563*^9}, {3.694246378304667*^9, 3.6942463930921297`*^9}, {
   3.694246524104504*^9, 3.694246532660062*^9}, {3.694301955591709*^9, 
   3.6943019611136312`*^9}, {3.6943020007762947`*^9, 3.694302009003631*^9}, {
   3.694302063255402*^9, 3.694302164553391*^9}, {3.6943022063404627`*^9, 
   3.6943022064995203`*^9}, {3.694302263908622*^9, 3.694302283902327*^9}, {
   3.69430435643839*^9, 3.694304360813567*^9}, 3.714812162930257*^9, 
   3.714818252515809*^9, {3.714819925023842*^9, 3.714819959033437*^9}, 
   3.714820211930187*^9, {3.7148202809285603`*^9, 3.7148202895110598`*^9}, 
   3.714820339436099*^9, {3.7148209684414263`*^9, 3.714820981985826*^9}, {
   3.714821486573571*^9, 3.7148215152893867`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Demonstrative examples", "Section",
 CellChangeTimes->{3.725591654647478*^9}],

Cell[CellGroupData[{

Cell["Exmp. 1", "Subsection",
 CellChangeTimes->{{3.725591769015128*^9, 3.725591796271072*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"game", " ", "graph"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"Graph", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1", "\[Rule]", "2"}], ",", 
         RowBox[{"1", "\[Rule]", "4"}], ",", 
         RowBox[{"2", "\[Rule]", "3"}], ",", 
         RowBox[{"4", "\[Rule]", "3"}], ",", 
         RowBox[{"3", "\[Rule]", "6"}], ",", 
         RowBox[{"3", "\[Rule]", "8"}], ",", 
         RowBox[{"6", "\[Rule]", "5"}], ",", 
         RowBox[{"8", "\[Rule]", "5"}], ",", 
         RowBox[{"7", "\[Rule]", "10"}], ",", 
         RowBox[{"7", "\[Rule]", "12"}], ",", 
         RowBox[{"10", "\[Rule]", "9"}], ",", 
         RowBox[{"12", "\[Rule]", "9"}], ",", 
         RowBox[{"9", "\[Rule]", "14"}], ",", 
         RowBox[{"9", "\[Rule]", "16"}], ",", 
         RowBox[{"14", "\[Rule]", "11"}], ",", 
         RowBox[{"16", "\[Rule]", "11"}], ",", 
         RowBox[{"5", "\[Rule]", "4"}], ",", 
         RowBox[{"5", "\[Rule]", "12"}], ",", 
         RowBox[{"11", "\[Rule]", "4"}], ",", 
         RowBox[{"11", "\[Rule]", "12"}]}], "}"}], ",", 
       RowBox[{"EdgeWeight", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "a", ",", "b", ",", "u", ",", "u", ",", "a", ",", "b", ",", "u", ",",
           "u", ",", "b", ",", "a", ",", "u", ",", "u", ",", "b", ",", "a", 
          ",", "u", ",", "u", ",", "b", ",", "a", ",", "a", ",", "b"}], 
         "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"initial", " ", "state"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"init1", "=", 
     RowBox[{"{", "1", "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"unsafe", " ", "states"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"bad1", "=", 
     RowBox[{"{", 
      RowBox[{"2", ",", "6", ",", "10", ",", "14"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", "delay", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lag1", "=", "5"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"graphical", " ", "mode"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"graphical1", "=", "1"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.679290280863879*^9, 3.679290334241673*^9}, {
   3.679290504696708*^9, 3.67929051929695*^9}, {3.679290627540678*^9, 
   3.679290646162645*^9}, {3.679290676691043*^9, 3.679290749174502*^9}, {
   3.67929089973089*^9, 3.679290911059611*^9}, {3.679290948233796*^9, 
   3.679290990883844*^9}, {3.679291164264686*^9, 3.679291210405404*^9}, {
   3.679296297585969*^9, 3.679296312880332*^9}, {3.679297255110785*^9, 
   3.67929728224135*^9}, {3.679298728331581*^9, 3.679298875905641*^9}, 
   3.679298940274908*^9, {3.679299134034567*^9, 3.679299184389367*^9}, {
   3.679303531395106*^9, 3.679303544554354*^9}, {3.679303608922887*^9, 
   3.679303639506028*^9}, {3.679303980910127*^9, 3.679303986325524*^9}, {
   3.679335615401274*^9, 3.679335623430876*^9}, {3.679335744327502*^9, 
   3.679335766784133*^9}, 3.679335823213298*^9, {3.679335983824042*^9, 
   3.679335984261932*^9}, 3.679345060627506*^9, {3.679345101558879*^9, 
   3.679345112772768*^9}, 3.679345479078967*^9, 3.679349498904059*^9, 
   3.679349536594214*^9, {3.679349600050577*^9, 3.67934962905582*^9}, 
   3.679349661608243*^9, {3.679351400809895*^9, 3.679351401467813*^9}, {
   3.679351450028281*^9, 3.679351451046861*^9}, {3.679351510988296*^9, 
   3.679351511620798*^9}, {3.679351634514476*^9, 3.679351635015629*^9}, 
   3.683091811391354*^9, {3.683092894743585*^9, 3.683092894834948*^9}, {
   3.68603364313111*^9, 3.686033643305373*^9}, {3.686033963132012*^9, 
   3.686033963385147*^9}, {3.686038456625434*^9, 3.686038457152603*^9}, 
   3.686039476145979*^9, {3.686039765194613*^9, 3.686039765777108*^9}, {
   3.6860400079460697`*^9, 3.686040011873623*^9}, {3.6860456182789392`*^9, 
   3.6860456186205263`*^9}, {3.686046033270814*^9, 3.68604603343496*^9}, 
   3.686068229925735*^9, 3.686068578190002*^9, {3.6930354502060337`*^9, 
   3.693035455589672*^9}, {3.693035680711351*^9, 3.693035683406238*^9}, {
   3.693035735036788*^9, 3.693035830541695*^9}, {3.69303629913402*^9, 
   3.693036299316936*^9}, 3.6930368977904654`*^9, {3.693036958021305*^9, 
   3.693036958205016*^9}, {3.693096257624858*^9, 3.6930962579203043`*^9}, 
   3.693096438641191*^9, {3.6933825750532618`*^9, 3.6933826039006233`*^9}, {
   3.6934422003517*^9, 3.693442215314032*^9}, {3.693442393675651*^9, 
   3.6934423937437553`*^9}, {3.6939897617128468`*^9, 3.693989782814885*^9}, {
   3.69398990337007*^9, 3.6939899038807993`*^9}, {3.6939906167708406`*^9, 
   3.693990618409132*^9}, {3.693990685826254*^9, 3.6939906886417093`*^9}, {
   3.694055767846568*^9, 3.694055780360199*^9}, 3.6941469635489264`*^9, 
   3.694147620094555*^9, 3.69414768506192*^9, 3.694147785742654*^9, 
   3.714820027417634*^9, 3.7148200625305243`*^9, 3.714820345310217*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"synthesize", " ", "the", " ", "strategy"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"main", "[", 
   RowBox[{"g1", ",", "init1", ",", "bad1", ",", "lag1", ",", "graphical1"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.679223865677226*^9, 3.679223877308047*^9}, {
  3.679223948966332*^9, 3.679223952257859*^9}, {3.679224829422299*^9, 
  3.679224842926139*^9}, {3.679225385070814*^9, 3.679225388900379*^9}, {
  3.679226561934965*^9, 3.679226582765519*^9}, {3.67922688451364*^9, 
  3.679226886812034*^9}, {3.679290582191699*^9, 3.679290588477742*^9}, {
  3.679291707467694*^9, 3.679291709084998*^9}, {3.679296205829566*^9, 
  3.679296205956924*^9}, {3.67929627826369*^9, 3.679296282866345*^9}, {
  3.679296323611739*^9, 3.679296324755156*^9}, {3.679299162275336*^9, 
  3.679299190372951*^9}, {3.686033072949698*^9, 3.686033074275885*^9}, {
  3.6930354614304457`*^9, 3.693035463013753*^9}, {3.6930356921493187`*^9, 
  3.6930356940860233`*^9}, {3.693035833924752*^9, 3.693035847231703*^9}}],

Cell[CellGroupData[{

Cell[BoxData["\<\"Original graph:\"\>"], "Print",
 CellChangeTimes->{
  3.693990625514318*^9, 3.6939906913568077`*^9, {3.6940557483423243`*^9, 
   3.6940557829222183`*^9}, 3.694146965728603*^9, 3.694147108954781*^9, 
   3.694147623537088*^9, 3.6941477883636417`*^9, {3.714820224261772*^9, 
   3.714820246716757*^9}, 3.714820296161806*^9, 3.714820348701954*^9}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 4, 3, 6, 8, 5, 7, 10, 12, 9, 14, 16, 
      11}, {{{1, 2}, {1, 3}, {2, 4}, {3, 4}, {4, 5}, {4, 6}, {5, 7}, {6, 7}, {
       8, 9}, {8, 10}, {9, 11}, {10, 11}, {11, 12}, {11, 13}, {12, 14}, {13, 
       14}, {7, 3}, {7, 10}, {14, 3}, {14, 10}}, Null}, {
      BaselinePosition -> Axis, 
       EdgeLabels -> {
        DirectedEdge[4, 3] -> $CellContext`u, 
         DirectedEdge[7, 12] -> $CellContext`a, 
         DirectedEdge[16, 11] -> $CellContext`u, 
         DirectedEdge[8, 5] -> $CellContext`u, 
         DirectedEdge[9, 14] -> $CellContext`b, 
         DirectedEdge[2, 3] -> $CellContext`u, 
         DirectedEdge[1, 2] -> $CellContext`a, 
         DirectedEdge[5, 4] -> $CellContext`b, 
         DirectedEdge[6, 5] -> $CellContext`u, 
         DirectedEdge[7, 10] -> $CellContext`b, 
         DirectedEdge[11, 12] -> $CellContext`b, 
         DirectedEdge[1, 4] -> $CellContext`b, 
         DirectedEdge[3, 8] -> $CellContext`b, 
         DirectedEdge[3, 6] -> $CellContext`a, 
         DirectedEdge[12, 9] -> $CellContext`u, 
         DirectedEdge[10, 9] -> $CellContext`u, 
         DirectedEdge[9, 16] -> $CellContext`a, 
         DirectedEdge[5, 12] -> $CellContext`a, 
         DirectedEdge[11, 4] -> $CellContext`a, 
         DirectedEdge[14, 11] -> $CellContext`u}, ImageSize -> 600, 
       VertexLabels -> {9 -> Placed[9, {
            Rational[1, 2], 
            Rational[1, 2]}], 14 -> Placed[14, {
            Rational[1, 2], 
            Rational[1, 2]}], 5 -> Placed[5, {
            Rational[1, 2], 
            Rational[1, 2]}], 6 -> Placed[6, {
            Rational[1, 2], 
            Rational[1, 2]}], 16 -> Placed[16, {
            Rational[1, 2], 
            Rational[1, 2]}], 4 -> Placed[4, {
            Rational[1, 2], 
            Rational[1, 2]}], 12 -> Placed[12, {
            Rational[1, 2], 
            Rational[1, 2]}], 1 -> Placed[1, {
            Rational[1, 2], 
            Rational[1, 2]}], 7 -> Placed[7, {
            Rational[1, 2], 
            Rational[1, 2]}], 8 -> Placed[8, {
            Rational[1, 2], 
            Rational[1, 2]}], 2 -> Placed[2, {
            Rational[1, 2], 
            Rational[1, 2]}], 10 -> Placed[10, {
            Rational[1, 2], 
            Rational[1, 2]}], 3 -> Placed[3, {
            Rational[1, 2], 
            Rational[1, 2]}], 11 -> Placed[11, {
            Rational[1, 2], 
            Rational[1, 2]}]}, 
       VertexShapeFunction -> {
        11 -> "Circle", 2 -> "ConcaveSquare", 3 -> "Circle", 12 -> "Square", 
         4 -> "Square", 16 -> "Square", 10 -> "ConcaveSquare", 8 -> "Square", 
         14 -> "ConcaveSquare", 7 -> "Circle", 9 -> "Circle", 6 -> 
         "ConcaveSquare", 5 -> "Circle", 1 -> "RoundedTriangle"}, 
       VertexSize -> {0.6}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
        0.02242705952402108], {
         ArrowBox[{{0.7336436193189988, 0.0005263210581032407}, {0., 
          0.33082239801112445`}}, 0.04478413401536528], 
         InsetBox["a", {0.3668218096594994, 0.16567435953461385`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.7336436193189988, 0.0005263210581032407}, {
          1.7317361791237305`, 0.6051721159030028}}, 0.04478413401536528], 
         InsetBox["b", {1.2326898992213646`, 0.302849218480553}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0., 0.33082239801112445`}, {0.7371071984704958, 
          0.952289735631657}}, 0.04478413401536528], 
         InsetBox["u", {0.3685535992352479, 0.6415560668213907}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1.7317361791237305`, 0.6051721159030028}, {
          0.7371071984704958, 0.952289735631657}}, 0.04478413401536528], 
         InsetBox["u", {1.2344216887971131`, 0.7787309257673298}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.7371071984704958, 0.952289735631657}, {
          1.3016329414017271`, 1.2321487844354264`}}, 0.04478413401536528], 
         InsetBox["a", {1.0193700699361115`, 1.0922192600335416`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.7371071984704958, 0.952289735631657}, {
          1.2470068462032655`, 1.7161299273155883`}}, 0.04478413401536528], 
         InsetBox["b", {0.9920570223368806, 1.3342098314736226`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1.3016329414017271`, 1.2321487844354264`}, {
          2.192457909587141, 1.1120341050020808`}}, 0.04478413401536528], 
         InsetBox["u", {1.7470454254944339`, 1.1720914447187536`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1.2470068462032655`, 1.7161299273155883`}, {
          2.192457909587141, 1.1120341050020808`}}, 0.04478413401536528], 
         InsetBox["u", {1.7197323778952032`, 1.4140820161588346`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{2.192457909587141, 1.1120341050020808`}, {
          1.7317361791237305`, 0.6051721159030028}}, 0.04478413401536528], 
         InsetBox["b", {1.9620970443554357`, 0.8586031104525418}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{2.192457909587141, 1.1120341050020808`}, {
          3.5784422473825823`, 0.6051001161342785}}, 0.04478413401536528], 
         InsetBox["a", {2.885450078484862, 0.8585671105681796}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.576262019539324, 0.}, {5.3085400265780445`, 
          0.3311339834888576}}, 0.04478413401536528], 
         InsetBox["b", {4.942401023058684, 0.1655669917444288}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.576262019539324, 0.}, {3.5784422473825823`, 
          0.6051001161342785}}, 0.04478413401536528], 
         InsetBox["a", {4.077352133460953, 0.30255005806713925`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{5.3085400265780445`, 0.3311339834888576}, {
          4.573654077851123, 0.9526457590640012}}, 0.04478413401536528], 
         InsetBox["u", {4.941097052214584, 0.6418898712764294}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{3.5784422473825823`, 0.6051001161342785}, {
          4.573654077851123, 0.9526457590640012}}, 0.04478413401536528], 
         InsetBox["u", {4.0760481626168525`, 0.7788729375991399}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.573654077851123, 0.9526457590640012}, {
          4.062573341805022, 1.7156253139309623`}}, 0.04478413401536528], 
         InsetBox["b", {4.318113709828072, 1.3341355364974818`}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.573654077851123, 0.9526457590640012}, {
          4.007293509227982, 1.2321210265891542`}}, 0.04478413401536528], 
         InsetBox["a", {4.290473793539553, 1.0923833928265778`}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.062573341805022, 1.7156253139309623`}, {
          3.117915680441285, 1.112292255349694}}, 0.04478413401536528], 
         InsetBox["u", {3.590244511123154, 1.413958784640328}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.007293509227982, 1.2321210265891542`}, {
          3.117915680441285, 1.112292255349694}}, 0.04478413401536528], 
         InsetBox["u", {3.5626045948346334`, 1.172206640969424}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{3.117915680441285, 1.112292255349694}, {
          1.7317361791237305`, 0.6051721159030028}}, 0.04478413401536528], 
         InsetBox["a", {2.4248259297825077`, 0.8587321856263483}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{3.117915680441285, 1.112292255349694}, {
          3.5784422473825823`, 0.6051001161342785}}, 0.04478413401536528], 
         InsetBox["b", {3.3481789639119337`, 0.8586961857419861}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
        0.7]}], {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}}}, {{{0.6907034962709944, 0.09871959831039152}, {
          0.6048233961712287, -0.05002911202977279}, {
          0.5618834191194675, -0.12440354019797652`}, {
          0.6477635192192331, -0.12440354019797652`}, {
          0.8195237194187645, -0.12440354019797652`}, {
          0.9054038195185301, -0.12440354019797652`}, {
          0.8624638424667689, -0.05002911202977279}, {0.7765837423670032, 
          0.09871959831039152}, {0.7336436193189988, 0.17309388048235208`}, {
          0.6907034962709944, 0.09871959831039152}}}], 
         InsetBox["1", {0.7336436193189988, 0.0005263210581032407},
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 
          2}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4gVP/B4ycuyx3xbw/G1//l17Uef7DowbFtnv
3rRdztvttj2zxtL2M+phNvsey29fYXgLJr8fJg/Vvx9V/6H9m+TrQ41a7tlL
LV1fuKftwP4A82RdI7079j6XFixLzdixvztN+65h03X7sGmOHHdEt+zXqOPf
aqhzFS5/bOrnHsNrl+ylofr/d5ZXJoWcgZtvvdNeM2nFcbj9ZuH5P5ZdPGkv
DnWf9uRz0wxUztkz3dudenNuwZ7JEv837VK7YC8I9Z8OVB7mf5h+qPn2MPOh
9tszdEHsh7rP/ijUfVD326O5374L6j+o/+1h/oeZDwsf9PAHAF5uwkc=
          "]], 
         InsetBox["2", {0., 0.33082239801112445`},
          BaseStyle->"Graphics"]}, {
         RectangleBox[{1.6029159559759605`, 0.4763518927552327}, \
{1.8605564022715004`, 0.7339923390507729}], 
         InsetBox["4", {1.7317361791237305`, 0.6051721159030028},
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.7371071984704958, 0.952289735631657}, 
          0.14599624316772322`], 
         InsetBox["3", {0.7371071984704958, 0.952289735631657},
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 
          2}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4uepDnp/J3+zX+/Iarzz+Ff7bYVGUn8zvtob
Rln+T7f9aj+3XFug9vIX+8K04FT7H1/sW2pV2P7afoHLB3eKffoj9Bmu36qf
/0VN7Sf7fNPXZx7yfLP/1fS1cemhT/Zh1k8OJZZ/ta/IOrj1m89ne1X3a+sS
fb7YW8Qt95ef9Nmex/f8kofbPsPlPwedmJWo+Bmu/1DcrrbEbx/h5q9M2Vzz
MOEj3P7MiJliXMs+wt333D7VK9rgE9z9y429nzSXfoL7DyYP8z9MP0OCu0Wt
5ne4+Q45ifNCnnyD23+oZWoWc9Q3uPuYJq6/cEvkG9z9MHmY/2D6Yf6HmQ8L
H/TwBwA2oM7R
          "]], 
         InsetBox["6", {1.3016329414017271`, 1.2321487844354264`},
          BaseStyle->"Graphics"]}, {
         RectangleBox[{1.1181866230554953`, 1.5873097041678181`}, \
{1.3758270693510357`, 1.8449501504633585`}], 
         InsetBox["8", {1.2470068462032655`, 1.7161299273155883`},
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.192457909587141, 1.1120341050020808`}, 
          0.14599624316772322`], 
         InsetBox["5", {2.192457909587141, 1.1120341050020808`},
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.576262019539324, 0.}, 0.14599624316772322`], 
         InsetBox["7", {4.576262019539324, 0.},
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 
          2}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYpH7xp8E14g6nHJxvrCq5K49e5LB28BEUYfz
y4QZ07xv2zcuXvfqo7Wow6Xr1TMPm92y//1E58VEMYT8u3TNxxdPi8D1Z6xc
/qBwmYjDMeHb5r6d9+wj1BTZ92wXcUjR3s/va3zH3kJBJCTglojD/Kj2/T7t
1+015vZWzXot4mBTlD3dx/AqXP5Wp3++z+1LcP3qRfp2M+LOwM1PXvj97fRN
x+H2x9mr771z+yTcfcHVbdFpeufg7l/OEz31qvYFuP9CoPIw/8P0z5q79Uvh
RVG4+asUbM6pHxB10IDaf0rNs3HyXFGHm1D33Vp5PsqzRxTufpj8PKj/YPph
/oeZDwsf9PAHAM5CuMQ=
          "]], 
         InsetBox["10", {5.3085400265780445`, 0.3311339834888576},
          BaseStyle->"Graphics"]}, {
         RectangleBox[{3.449622024234812, 0.4762798929865084}, \
{3.7072624705303525`, 0.7339203392820486}], 
         InsetBox["12", {3.5784422473825823`, 0.6051001161342785},
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.573654077851123, 0.9526457590640012}, 
          0.14599624316772322`], 
         InsetBox["9", {4.573654077851123, 0.9526457590640012},
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 
          2}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYpeb6Y7GGwQcdgevE+Vu+WtvEZNiU5wq4GCb
8+jhzp9/7DfNfWQp7CDgUFvxx33ilj/2OvcTzDdLIeTtj+xKeTafH67f2H17
vFoov0O1+5T1xif/2gs5rlqzq5zfIcm3d+lm47/2l0wmuD3ew+9gGFk/cTPH
H/uNes2Ty+/zO0jEV7QbF/+Gy/9PKazdfPcXXP+5guTMzZt+ws3fWhYTbyz7
E25/aZbTz+ikn3D3fQ7k01375ifc/Ztdvxy7avgL7j+YPMz/MP2np790nnxV
AG7+bakCWc8jAnD7fyvUXtiyUADuPu4lzKuyJgjA3Q+Th/kPph/mf5j5sPBB
D38AjS26wA==
          "]], 
         InsetBox["14", {4.062573341805022, 1.7156253139309623`},
          BaseStyle->"Graphics"]}, {
         RectangleBox[{3.878473286080212, 1.103300803441384}, \
{4.136113732375752, 1.3609412497369244`}], 
         InsetBox["16", {4.007293509227982, 1.2321210265891542`},
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.117915680441285, 1.112292255349694}, 
          0.14599624316772322`], 
         InsetBox["11", {3.117915680441285, 1.112292255349694},
          BaseStyle->"Graphics"]}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  BaselinePosition->Axis,
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->15,
  ImageSize->600]], "Print",
 CellChangeTimes->{
  3.693990625514318*^9, 3.6939906913568077`*^9, {3.6940557483423243`*^9, 
   3.6940557829222183`*^9}, 3.694146965728603*^9, 3.694147108954781*^9, 
   3.694147623537088*^9, 3.6941477883636417`*^9, {3.714820224261772*^9, 
   3.714820246716757*^9}, 3.714820296161806*^9, 3.714820348800148*^9}],

Cell[BoxData["\<\"Under delay = 0 :\"\>"], "Print",
 CellChangeTimes->{
  3.693990625514318*^9, 3.6939906913568077`*^9, {3.6940557483423243`*^9, 
   3.6940557829222183`*^9}, 3.694146965728603*^9, 3.694147108954781*^9, 
   3.694147623537088*^9, 3.6941477883636417`*^9, {3.714820224261772*^9, 
   3.714820246716757*^9}, 3.714820296161806*^9, 3.714820348804162*^9}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 4, 3, 6, 8, 5, 7, 10, 12, 9, 14, 16, 
      11}, {{{1, 2}, {1, 3}, {2, 4}, {3, 4}, {4, 5}, {4, 6}, {5, 7}, {6, 7}, {
       8, 9}, {8, 10}, {9, 11}, {10, 11}, {11, 12}, {11, 13}, {12, 14}, {13, 
       14}, {7, 3}, {7, 10}, {14, 3}, {14, 10}}, Null}, {
      BaselinePosition -> Axis, 
       EdgeLabels -> {
        DirectedEdge[4, 3] -> $CellContext`u, 
         DirectedEdge[7, 12] -> $CellContext`a, 
         DirectedEdge[16, 11] -> $CellContext`u, 
         DirectedEdge[8, 5] -> $CellContext`u, 
         DirectedEdge[9, 14] -> $CellContext`b, 
         DirectedEdge[2, 3] -> $CellContext`u, 
         DirectedEdge[1, 2] -> $CellContext`a, 
         DirectedEdge[5, 4] -> $CellContext`b, 
         DirectedEdge[6, 5] -> $CellContext`u, 
         DirectedEdge[7, 10] -> $CellContext`b, 
         DirectedEdge[11, 12] -> $CellContext`b, 
         DirectedEdge[1, 4] -> $CellContext`b, 
         DirectedEdge[3, 8] -> $CellContext`b, 
         DirectedEdge[3, 6] -> $CellContext`a, 
         DirectedEdge[12, 9] -> $CellContext`u, 
         DirectedEdge[10, 9] -> $CellContext`u, 
         DirectedEdge[9, 16] -> $CellContext`a, 
         DirectedEdge[5, 12] -> $CellContext`a, 
         DirectedEdge[11, 4] -> $CellContext`a, 
         DirectedEdge[14, 11] -> $CellContext`u}, ImageSize -> 600, 
       VertexLabels -> {9 -> Placed[{9, 
            Style[
             Row[{InputForm[""] -> {$CellContext`a}}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 14 -> Placed[{14, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 5 -> Placed[{5, 
            Style[
             Row[{InputForm[""] -> {$CellContext`b, $CellContext`a}}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 6 -> Placed[{6, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 16 -> Placed[{16, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 4 -> Placed[{4, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 12 -> Placed[{12, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 1 -> Placed[{1, 
            Style[
             Row[{InputForm[""] -> {$CellContext`b}}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 7 -> Placed[{7, 
            Style[
             Row[{InputForm[""] -> {$CellContext`a}}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 8 -> Placed[{8, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 2 -> Placed[{2, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 10 -> Placed[{10, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 3 -> Placed[{3, 
            Style[
             Row[{InputForm[""] -> {$CellContext`b}}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 11 -> Placed[{11, 
            Style[
             Row[{InputForm[""] -> {$CellContext`a, $CellContext`b}}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}]}, 
       VertexShapeFunction -> {
        11 -> "Circle", 2 -> "ConcaveSquare", 3 -> "Circle", 12 -> "Square", 
         4 -> "Square", 16 -> "Square", 10 -> "ConcaveSquare", 8 -> "Square", 
         14 -> "ConcaveSquare", 7 -> "Circle", 9 -> "Circle", 6 -> 
         "ConcaveSquare", 5 -> "Circle", 1 -> "RoundedTriangle"}, 
       VertexSize -> {0.6}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
        0.02242705952402108], {
         ArrowBox[{{0.7336436193189988, 0.0005263210581032407}, {0., 
          0.33082239801112445`}}, 0.04478413401536528], 
         InsetBox["a", {0.3668218096594994, 0.16567435953461385`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.7336436193189988, 0.0005263210581032407}, {
          1.7317361791237305`, 0.6051721159030028}}, 0.04478413401536528], 
         InsetBox["b", {1.2326898992213646`, 0.302849218480553}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0., 0.33082239801112445`}, {0.7371071984704958, 
          0.952289735631657}}, 0.04478413401536528], 
         InsetBox["u", {0.3685535992352479, 0.6415560668213907}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1.7317361791237305`, 0.6051721159030028}, {
          0.7371071984704958, 0.952289735631657}}, 0.04478413401536528], 
         InsetBox["u", {1.2344216887971131`, 0.7787309257673298}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.7371071984704958, 0.952289735631657}, {
          1.3016329414017271`, 1.2321487844354264`}}, 0.04478413401536528], 
         InsetBox["a", {1.0193700699361115`, 1.0922192600335416`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.7371071984704958, 0.952289735631657}, {
          1.2470068462032655`, 1.7161299273155883`}}, 0.04478413401536528], 
         InsetBox["b", {0.9920570223368806, 1.3342098314736226`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1.3016329414017271`, 1.2321487844354264`}, {
          2.192457909587141, 1.1120341050020808`}}, 0.04478413401536528], 
         InsetBox["u", {1.7470454254944339`, 1.1720914447187536`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1.2470068462032655`, 1.7161299273155883`}, {
          2.192457909587141, 1.1120341050020808`}}, 0.04478413401536528], 
         InsetBox["u", {1.7197323778952032`, 1.4140820161588346`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{2.192457909587141, 1.1120341050020808`}, {
          1.7317361791237305`, 0.6051721159030028}}, 0.04478413401536528], 
         InsetBox["b", {1.9620970443554357`, 0.8586031104525418}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{2.192457909587141, 1.1120341050020808`}, {
          3.5784422473825823`, 0.6051001161342785}}, 0.04478413401536528], 
         InsetBox["a", {2.885450078484862, 0.8585671105681796}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.576262019539324, 0.}, {5.3085400265780445`, 
          0.3311339834888576}}, 0.04478413401536528], 
         InsetBox["b", {4.942401023058684, 0.1655669917444288}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.576262019539324, 0.}, {3.5784422473825823`, 
          0.6051001161342785}}, 0.04478413401536528], 
         InsetBox["a", {4.077352133460953, 0.30255005806713925`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{5.3085400265780445`, 0.3311339834888576}, {
          4.573654077851123, 0.9526457590640012}}, 0.04478413401536528], 
         InsetBox["u", {4.941097052214584, 0.6418898712764294}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{3.5784422473825823`, 0.6051001161342785}, {
          4.573654077851123, 0.9526457590640012}}, 0.04478413401536528], 
         InsetBox["u", {4.0760481626168525`, 0.7788729375991399}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.573654077851123, 0.9526457590640012}, {
          4.062573341805022, 1.7156253139309623`}}, 0.04478413401536528], 
         InsetBox["b", {4.318113709828072, 1.3341355364974818`}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.573654077851123, 0.9526457590640012}, {
          4.007293509227982, 1.2321210265891542`}}, 0.04478413401536528], 
         InsetBox["a", {4.290473793539553, 1.0923833928265778`}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.062573341805022, 1.7156253139309623`}, {
          3.117915680441285, 1.112292255349694}}, 0.04478413401536528], 
         InsetBox["u", {3.590244511123154, 1.413958784640328}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.007293509227982, 1.2321210265891542`}, {
          3.117915680441285, 1.112292255349694}}, 0.04478413401536528], 
         InsetBox["u", {3.5626045948346334`, 1.172206640969424}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{3.117915680441285, 1.112292255349694}, {
          1.7317361791237305`, 0.6051721159030028}}, 0.04478413401536528], 
         InsetBox["a", {2.4248259297825077`, 0.8587321856263483}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{3.117915680441285, 1.112292255349694}, {
          3.5784422473825823`, 0.6051001161342785}}, 0.04478413401536528], 
         InsetBox["b", {3.3481789639119337`, 0.8586961857419861}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
        0.7]}], {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}}}, {{{0.6907034962709944, 0.09871959831039152}, {
          0.6048233961712287, -0.05002911202977279}, {
          0.5618834191194675, -0.12440354019797652`}, {
          0.6477635192192331, -0.12440354019797652`}, {
          0.8195237194187645, -0.12440354019797652`}, {
          0.9054038195185301, -0.12440354019797652`}, {
          0.8624638424667689, -0.05002911202977279}, {0.7765837423670032, 
          0.09871959831039152}, {0.7336436193189988, 0.17309388048235208`}, {
          0.6907034962709944, 0.09871959831039152}}}], 
         InsetBox["1", {0.7336436193189988, 0.0005263210581032407},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", "b", "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {0.7336436193189988, 0.14652256422582646`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 
          2}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4gVP/B4ycuyx3xbw/G1//l17Uef7DowbFtnv
3rRdztvttj2zxtL2M+phNvsey29fYXgLJr8fJg/Vvx9V/6H9m+TrQ41a7tlL
LV1fuKftwP4A82RdI7079j6XFixLzdixvztN+65h03X7sGmOHHdEt+zXqOPf
aqhzFS5/bOrnHsNrl+ylofr/d5ZXJoWcgZtvvdNeM2nFcbj9ZuH5P5ZdPGkv
DnWf9uRz0wxUztkz3dudenNuwZ7JEv837VK7YC8I9Z8OVB7mf5h+qPn2MPOh
9tszdEHsh7rP/ijUfVD326O5374L6j+o/+1h/oeZDwsf9PAHAF5uwkc=
          "]], 
         InsetBox["2", {0., 0.33082239801112445`},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {0., 0.47681864117884765`}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         RectangleBox[{1.6029159559759605`, 0.4763518927552327}, \
{1.8605564022715004`, 0.7339923390507729}], 
         InsetBox["4", {1.7317361791237305`, 0.6051721159030028},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {1.7317361791237305`, 0.751168359070726}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.7371071984704958, 0.952289735631657}, 
          0.14599624316772322`], 
         InsetBox["3", {0.7371071984704958, 0.952289735631657},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", "b", "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {0.7371071984704958, 1.0982859787993802`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 
          2}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4uepDnp/J3+zX+/Iarzz+Ff7bYVGUn8zvtob
Rln+T7f9aj+3XFug9vIX+8K04FT7H1/sW2pV2P7afoHLB3eKffoj9Bmu36qf
/0VN7Sf7fNPXZx7yfLP/1fS1cemhT/Zh1k8OJZZ/ta/IOrj1m89ne1X3a+sS
fb7YW8Qt95ef9Nmex/f8kofbPsPlPwedmJWo+Bmu/1DcrrbEbx/h5q9M2Vzz
MOEj3P7MiJliXMs+wt333D7VK9rgE9z9y429nzSXfoL7DyYP8z9MP0OCu0Wt
5ne4+Q45ifNCnnyD23+oZWoWc9Q3uPuYJq6/cEvkG9z9MHmY/2D6Yf6HmQ8L
H/TwBwA2oM7R
          "]], 
         InsetBox["6", {1.3016329414017271`, 1.2321487844354264`},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {1.3016329414017271`, 1.3781450276031497`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         RectangleBox[{1.1181866230554953`, 1.5873097041678181`}, \
{1.3758270693510357`, 1.8449501504633585`}], 
         InsetBox["8", {1.2470068462032655`, 1.7161299273155883`},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {1.2470068462032655`, 1.8621261704833116`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.192457909587141, 1.1120341050020808`}, 
          0.14599624316772322`], 
         InsetBox["5", {2.192457909587141, 1.1120341050020808`},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", 
                 RowBox[{"b", ",", "a"}], "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {2.192457909587141, 1.258030348169804}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.576262019539324, 0.}, 0.14599624316772322`], 
         InsetBox["7", {4.576262019539324, 0.},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", "a", "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {4.576262019539324, 0.14599624316772322`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 
          2}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYpH7xp8E14g6nHJxvrCq5K49e5LB28BEUYfz
y4QZ07xv2zcuXvfqo7Wow6Xr1TMPm92y//1E58VEMYT8u3TNxxdPi8D1Z6xc
/qBwmYjDMeHb5r6d9+wj1BTZ92wXcUjR3s/va3zH3kJBJCTglojD/Kj2/T7t
1+015vZWzXot4mBTlD3dx/AqXP5Wp3++z+1LcP3qRfp2M+LOwM1PXvj97fRN
x+H2x9mr771z+yTcfcHVbdFpeufg7l/OEz31qvYFuP9CoPIw/8P0z5q79Uvh
RVG4+asUbM6pHxB10IDaf0rNs3HyXFGHm1D33Vp5PsqzRxTufpj8PKj/YPph
/oeZDwsf9PAHAM5CuMQ=
          "]], 
         InsetBox["10", {5.3085400265780445`, 0.3311339834888576},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {5.3085400265780445`, 0.4771302266565808}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         RectangleBox[{3.449622024234812, 0.4762798929865084}, \
{3.7072624705303525`, 0.7339203392820486}], 
         InsetBox["12", {3.5784422473825823`, 0.6051001161342785},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {3.5784422473825823`, 0.7510963593020017}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.573654077851123, 0.9526457590640012}, 
          0.14599624316772322`], 
         InsetBox["9", {4.573654077851123, 0.9526457590640012},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", "a", "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {4.573654077851123, 1.0986420022317245`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 
          2}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYpeb6Y7GGwQcdgevE+Vu+WtvEZNiU5wq4GCb
8+jhzp9/7DfNfWQp7CDgUFvxx33ilj/2OvcTzDdLIeTtj+xKeTafH67f2H17
vFoov0O1+5T1xif/2gs5rlqzq5zfIcm3d+lm47/2l0wmuD3ew+9gGFk/cTPH
H/uNes2Ty+/zO0jEV7QbF/+Gy/9PKazdfPcXXP+5guTMzZt+ws3fWhYTbyz7
E25/aZbTz+ikn3D3fQ7k01375ifc/Ztdvxy7avgL7j+YPMz/MP2np790nnxV
AG7+bakCWc8jAnD7fyvUXtiyUADuPu4lzKuyJgjA3Q+Th/kPph/mf5j5sPBB
D38AjS26wA==
          "]], 
         InsetBox["14", {4.062573341805022, 1.7156253139309623`},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {4.062573341805022, 1.8616215570986856`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         RectangleBox[{3.878473286080212, 1.103300803441384}, \
{4.136113732375752, 1.3609412497369244`}], 
         InsetBox["16", {4.007293509227982, 1.2321210265891542`},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {4.007293509227982, 1.3781172697568775`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.117915680441285, 1.112292255349694}, 
          0.14599624316772322`], 
         InsetBox["11", {3.117915680441285, 1.112292255349694},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", 
                 RowBox[{"a", ",", "b"}], "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {3.117915680441285, 1.2582884985174172`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  BaselinePosition->Axis,
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->15,
  ImageSize->600]], "Print",
 CellChangeTimes->{
  3.693990625514318*^9, 3.6939906913568077`*^9, {3.6940557483423243`*^9, 
   3.6940557829222183`*^9}, 3.694146965728603*^9, 3.694147108954781*^9, 
   3.694147623537088*^9, 3.6941477883636417`*^9, {3.714820224261772*^9, 
   3.714820246716757*^9}, 3.714820296161806*^9, 3.714820348909442*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Under delay = \"\>", "\[InvisibleSpace]", "1", 
   "\[InvisibleSpace]", "\<\" :\"\>"}],
  SequenceForm["Under delay = ", 1, " :"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.693990625514318*^9, 3.6939906913568077`*^9, {3.6940557483423243`*^9, 
   3.6940557829222183`*^9}, 3.694146965728603*^9, 3.694147108954781*^9, 
   3.694147623537088*^9, 3.6941477883636417`*^9, {3.714820224261772*^9, 
   3.714820246716757*^9}, 3.714820296161806*^9, 3.714820348913807*^9}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 4, 3, 6, 8, 5, 7, 10, 12, 9, 14, 16, 
      11}, {{{1, 2}, {1, 3}, {2, 4}, {3, 4}, {4, 5}, {4, 6}, {5, 7}, {6, 7}, {
       8, 9}, {8, 10}, {9, 11}, {10, 11}, {11, 12}, {11, 13}, {12, 14}, {13, 
       14}, {7, 3}, {7, 10}, {14, 3}, {14, 10}}, Null}, {
      BaselinePosition -> Axis, 
       EdgeLabels -> {
        DirectedEdge[4, 3] -> $CellContext`u, 
         DirectedEdge[7, 12] -> $CellContext`a, 
         DirectedEdge[16, 11] -> $CellContext`u, 
         DirectedEdge[8, 5] -> $CellContext`u, 
         DirectedEdge[9, 14] -> $CellContext`b, 
         DirectedEdge[2, 3] -> $CellContext`u, 
         DirectedEdge[1, 2] -> $CellContext`a, 
         DirectedEdge[5, 4] -> $CellContext`b, 
         DirectedEdge[6, 5] -> $CellContext`u, 
         DirectedEdge[7, 10] -> $CellContext`b, 
         DirectedEdge[11, 12] -> $CellContext`b, 
         DirectedEdge[1, 4] -> $CellContext`b, 
         DirectedEdge[3, 8] -> $CellContext`b, 
         DirectedEdge[3, 6] -> $CellContext`a, 
         DirectedEdge[12, 9] -> $CellContext`u, 
         DirectedEdge[10, 9] -> $CellContext`u, 
         DirectedEdge[9, 16] -> $CellContext`a, 
         DirectedEdge[5, 12] -> $CellContext`a, 
         DirectedEdge[11, 4] -> $CellContext`a, 
         DirectedEdge[14, 11] -> $CellContext`u}, ImageSize -> 600, 
       VertexLabels -> {9 -> Placed[{9, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 14 -> Placed[{14, 
            Style[
             Row[{InputForm[""] -> {}}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 5 -> Placed[{5, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 6 -> Placed[{6, 
            Style[
             Row[{InputForm[""] -> {}}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 16 -> Placed[{16, 
            Style[
             Row[{InputForm[""] -> {$CellContext`a, $CellContext`b}}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 4 -> Placed[{4, 
            Style[
             Row[{InputForm[""] -> {$CellContext`b}}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 12 -> Placed[{12, 
            Style[
             Row[{InputForm[""] -> {$CellContext`a}}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 1 -> Placed[{1, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 7 -> Placed[{7, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 8 -> Placed[{8, 
            Style[
             Row[{InputForm[""] -> {$CellContext`b, $CellContext`a}}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 2 -> Placed[{2, 
            Style[
             Row[{InputForm[""] -> {}}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 10 -> Placed[{10, 
            Style[
             Row[{InputForm[""] -> {}}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 3 -> Placed[{3, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 11 -> Placed[{11, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}]}, 
       VertexShapeFunction -> {
        11 -> "Circle", 2 -> "ConcaveSquare", 3 -> "Circle", 12 -> "Square", 
         4 -> "Square", 16 -> "Square", 10 -> "ConcaveSquare", 8 -> "Square", 
         14 -> "ConcaveSquare", 7 -> "Circle", 9 -> "Circle", 6 -> 
         "ConcaveSquare", 5 -> "Circle", 1 -> "RoundedTriangle"}, 
       VertexSize -> {0.6}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
        0.02242705952402108], {
         ArrowBox[{{0.7336436193189988, 0.0005263210581032407}, {0., 
          0.33082239801112445`}}, 0.04478413401536528], 
         InsetBox["a", {0.3668218096594994, 0.16567435953461385`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.7336436193189988, 0.0005263210581032407}, {
          1.7317361791237305`, 0.6051721159030028}}, 0.04478413401536528], 
         InsetBox["b", {1.2326898992213646`, 0.302849218480553}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0., 0.33082239801112445`}, {0.7371071984704958, 
          0.952289735631657}}, 0.04478413401536528], 
         InsetBox["u", {0.3685535992352479, 0.6415560668213907}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1.7317361791237305`, 0.6051721159030028}, {
          0.7371071984704958, 0.952289735631657}}, 0.04478413401536528], 
         InsetBox["u", {1.2344216887971131`, 0.7787309257673298}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.7371071984704958, 0.952289735631657}, {
          1.3016329414017271`, 1.2321487844354264`}}, 0.04478413401536528], 
         InsetBox["a", {1.0193700699361115`, 1.0922192600335416`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.7371071984704958, 0.952289735631657}, {
          1.2470068462032655`, 1.7161299273155883`}}, 0.04478413401536528], 
         InsetBox["b", {0.9920570223368806, 1.3342098314736226`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1.3016329414017271`, 1.2321487844354264`}, {
          2.192457909587141, 1.1120341050020808`}}, 0.04478413401536528], 
         InsetBox["u", {1.7470454254944339`, 1.1720914447187536`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1.2470068462032655`, 1.7161299273155883`}, {
          2.192457909587141, 1.1120341050020808`}}, 0.04478413401536528], 
         InsetBox["u", {1.7197323778952032`, 1.4140820161588346`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{2.192457909587141, 1.1120341050020808`}, {
          1.7317361791237305`, 0.6051721159030028}}, 0.04478413401536528], 
         InsetBox["b", {1.9620970443554357`, 0.8586031104525418}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{2.192457909587141, 1.1120341050020808`}, {
          3.5784422473825823`, 0.6051001161342785}}, 0.04478413401536528], 
         InsetBox["a", {2.885450078484862, 0.8585671105681796}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.576262019539324, 0.}, {5.3085400265780445`, 
          0.3311339834888576}}, 0.04478413401536528], 
         InsetBox["b", {4.942401023058684, 0.1655669917444288}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.576262019539324, 0.}, {3.5784422473825823`, 
          0.6051001161342785}}, 0.04478413401536528], 
         InsetBox["a", {4.077352133460953, 0.30255005806713925`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{5.3085400265780445`, 0.3311339834888576}, {
          4.573654077851123, 0.9526457590640012}}, 0.04478413401536528], 
         InsetBox["u", {4.941097052214584, 0.6418898712764294}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{3.5784422473825823`, 0.6051001161342785}, {
          4.573654077851123, 0.9526457590640012}}, 0.04478413401536528], 
         InsetBox["u", {4.0760481626168525`, 0.7788729375991399}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.573654077851123, 0.9526457590640012}, {
          4.062573341805022, 1.7156253139309623`}}, 0.04478413401536528], 
         InsetBox["b", {4.318113709828072, 1.3341355364974818`}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.573654077851123, 0.9526457590640012}, {
          4.007293509227982, 1.2321210265891542`}}, 0.04478413401536528], 
         InsetBox["a", {4.290473793539553, 1.0923833928265778`}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.062573341805022, 1.7156253139309623`}, {
          3.117915680441285, 1.112292255349694}}, 0.04478413401536528], 
         InsetBox["u", {3.590244511123154, 1.413958784640328}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.007293509227982, 1.2321210265891542`}, {
          3.117915680441285, 1.112292255349694}}, 0.04478413401536528], 
         InsetBox["u", {3.5626045948346334`, 1.172206640969424}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{3.117915680441285, 1.112292255349694}, {
          1.7317361791237305`, 0.6051721159030028}}, 0.04478413401536528], 
         InsetBox["a", {2.4248259297825077`, 0.8587321856263483}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{3.117915680441285, 1.112292255349694}, {
          3.5784422473825823`, 0.6051001161342785}}, 0.04478413401536528], 
         InsetBox["b", {3.3481789639119337`, 0.8586961857419861}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
        0.7]}], {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}}}, {{{0.6907034962709944, 0.09871959831039152}, {
          0.6048233961712287, -0.05002911202977279}, {
          0.5618834191194675, -0.12440354019797652`}, {
          0.6477635192192331, -0.12440354019797652`}, {
          0.8195237194187645, -0.12440354019797652`}, {
          0.9054038195185301, -0.12440354019797652`}, {
          0.8624638424667689, -0.05002911202977279}, {0.7765837423670032, 
          0.09871959831039152}, {0.7336436193189988, 0.17309388048235208`}, {
          0.6907034962709944, 0.09871959831039152}}}], 
         InsetBox["1", {0.7336436193189988, 0.0005263210581032407},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {0.7336436193189988, 0.14652256422582646`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 
          2}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4gVP/B4ycuyx3xbw/G1//l17Uef7DowbFtnv
3rRdztvttj2zxtL2M+phNvsey29fYXgLJr8fJg/Vvx9V/6H9m+TrQ41a7tlL
LV1fuKftwP4A82RdI7079j6XFixLzdixvztN+65h03X7sGmOHHdEt+zXqOPf
aqhzFS5/bOrnHsNrl+ylofr/d5ZXJoWcgZtvvdNeM2nFcbj9ZuH5P5ZdPGkv
DnWf9uRz0wxUztkz3dudenNuwZ7JEv837VK7YC8I9Z8OVB7mf5h+qPn2MPOh
9tszdEHsh7rP/ijUfVD326O5374L6j+o/+1h/oeZDwsf9PAHAF5uwkc=
          "]], 
         InsetBox["2", {0., 0.33082239801112445`},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {0., 0.47681864117884765`}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         RectangleBox[{1.6029159559759605`, 0.4763518927552327}, \
{1.8605564022715004`, 0.7339923390507729}], 
         InsetBox["4", {1.7317361791237305`, 0.6051721159030028},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", "b", "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {1.7317361791237305`, 0.751168359070726}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.7371071984704958, 0.952289735631657}, 
          0.14599624316772322`], 
         InsetBox["3", {0.7371071984704958, 0.952289735631657},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {0.7371071984704958, 1.0982859787993802`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 
          2}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4uepDnp/J3+zX+/Iarzz+Ff7bYVGUn8zvtob
Rln+T7f9aj+3XFug9vIX+8K04FT7H1/sW2pV2P7afoHLB3eKffoj9Bmu36qf
/0VN7Sf7fNPXZx7yfLP/1fS1cemhT/Zh1k8OJZZ/ta/IOrj1m89ne1X3a+sS
fb7YW8Qt95ef9Nmex/f8kofbPsPlPwedmJWo+Bmu/1DcrrbEbx/h5q9M2Vzz
MOEj3P7MiJliXMs+wt333D7VK9rgE9z9y429nzSXfoL7DyYP8z9MP0OCu0Wt
5ne4+Q45ifNCnnyD23+oZWoWc9Q3uPuYJq6/cEvkG9z9MHmY/2D6Yf6HmQ8L
H/TwBwA2oM7R
          "]], 
         InsetBox["6", {1.3016329414017271`, 1.2321487844354264`},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {1.3016329414017271`, 1.3781450276031497`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         RectangleBox[{1.1181866230554953`, 1.5873097041678181`}, \
{1.3758270693510357`, 1.8449501504633585`}], 
         InsetBox["8", {1.2470068462032655`, 1.7161299273155883`},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", 
                 RowBox[{"b", ",", "a"}], "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {1.2470068462032655`, 1.8621261704833116`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.192457909587141, 1.1120341050020808`}, 
          0.14599624316772322`], 
         InsetBox["5", {2.192457909587141, 1.1120341050020808`},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {2.192457909587141, 1.258030348169804}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.576262019539324, 0.}, 0.14599624316772322`], 
         InsetBox["7", {4.576262019539324, 0.},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {4.576262019539324, 0.14599624316772322`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 
          2}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYpH7xp8E14g6nHJxvrCq5K49e5LB28BEUYfz
y4QZ07xv2zcuXvfqo7Wow6Xr1TMPm92y//1E58VEMYT8u3TNxxdPi8D1Z6xc
/qBwmYjDMeHb5r6d9+wj1BTZ92wXcUjR3s/va3zH3kJBJCTglojD/Kj2/T7t
1+015vZWzXot4mBTlD3dx/AqXP5Wp3++z+1LcP3qRfp2M+LOwM1PXvj97fRN
x+H2x9mr771z+yTcfcHVbdFpeufg7l/OEz31qvYFuP9CoPIw/8P0z5q79Uvh
RVG4+asUbM6pHxB10IDaf0rNs3HyXFGHm1D33Vp5PsqzRxTufpj8PKj/YPph
/oeZDwsf9PAHAM5CuMQ=
          "]], 
         InsetBox["10", {5.3085400265780445`, 0.3311339834888576},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {5.3085400265780445`, 0.4771302266565808}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         RectangleBox[{3.449622024234812, 0.4762798929865084}, \
{3.7072624705303525`, 0.7339203392820486}], 
         InsetBox["12", {3.5784422473825823`, 0.6051001161342785},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", "a", "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {3.5784422473825823`, 0.7510963593020017}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.573654077851123, 0.9526457590640012}, 
          0.14599624316772322`], 
         InsetBox["9", {4.573654077851123, 0.9526457590640012},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {4.573654077851123, 1.0986420022317245`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 
          2}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYpeb6Y7GGwQcdgevE+Vu+WtvEZNiU5wq4GCb
8+jhzp9/7DfNfWQp7CDgUFvxx33ilj/2OvcTzDdLIeTtj+xKeTafH67f2H17
vFoov0O1+5T1xif/2gs5rlqzq5zfIcm3d+lm47/2l0wmuD3ew+9gGFk/cTPH
H/uNes2Ty+/zO0jEV7QbF/+Gy/9PKazdfPcXXP+5guTMzZt+ws3fWhYTbyz7
E25/aZbTz+ikn3D3fQ7k01375ifc/Ztdvxy7avgL7j+YPMz/MP2np790nnxV
AG7+bakCWc8jAnD7fyvUXtiyUADuPu4lzKuyJgjA3Q+Th/kPph/mf5j5sPBB
D38AjS26wA==
          "]], 
         InsetBox["14", {4.062573341805022, 1.7156253139309623`},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {4.062573341805022, 1.8616215570986856`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         RectangleBox[{3.878473286080212, 1.103300803441384}, \
{4.136113732375752, 1.3609412497369244`}], 
         InsetBox["16", {4.007293509227982, 1.2321210265891542`},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", 
                 RowBox[{"a", ",", "b"}], "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {4.007293509227982, 1.3781172697568775`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.117915680441285, 1.112292255349694}, 
          0.14599624316772322`], 
         InsetBox["11", {3.117915680441285, 1.112292255349694},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {3.117915680441285, 1.2582884985174172`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  BaselinePosition->Axis,
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->15,
  ImageSize->600]], "Print",
 CellChangeTimes->{
  3.693990625514318*^9, 3.6939906913568077`*^9, {3.6940557483423243`*^9, 
   3.6940557829222183`*^9}, 3.694146965728603*^9, 3.694147108954781*^9, 
   3.694147623537088*^9, 3.6941477883636417`*^9, {3.714820224261772*^9, 
   3.714820246716757*^9}, 3.714820296161806*^9, 3.714820349000719*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Under delay = \"\>", "\[InvisibleSpace]", "2", 
   "\[InvisibleSpace]", "\<\" :\"\>"}],
  SequenceForm["Under delay = ", 2, " :"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.693990625514318*^9, 3.6939906913568077`*^9, {3.6940557483423243`*^9, 
   3.6940557829222183`*^9}, 3.694146965728603*^9, 3.694147108954781*^9, 
   3.694147623537088*^9, 3.6941477883636417`*^9, {3.714820224261772*^9, 
   3.714820246716757*^9}, 3.714820296161806*^9, 3.7148203490051394`*^9}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 4, 3, 6, 8, 5, 7, 10, 12, 9, 14, 16, 
      11}, {{{1, 2}, {1, 3}, {2, 4}, {3, 4}, {4, 5}, {4, 6}, {5, 7}, {6, 7}, {
       8, 9}, {8, 10}, {9, 11}, {10, 11}, {11, 12}, {11, 13}, {12, 14}, {13, 
       14}, {7, 3}, {7, 10}, {14, 3}, {14, 10}}, Null}, {
      BaselinePosition -> Axis, 
       EdgeLabels -> {
        DirectedEdge[4, 3] -> $CellContext`u, 
         DirectedEdge[7, 12] -> $CellContext`a, 
         DirectedEdge[16, 11] -> $CellContext`u, 
         DirectedEdge[8, 5] -> $CellContext`u, 
         DirectedEdge[9, 14] -> $CellContext`b, 
         DirectedEdge[2, 3] -> $CellContext`u, 
         DirectedEdge[1, 2] -> $CellContext`a, 
         DirectedEdge[5, 4] -> $CellContext`b, 
         DirectedEdge[6, 5] -> $CellContext`u, 
         DirectedEdge[7, 10] -> $CellContext`b, 
         DirectedEdge[11, 12] -> $CellContext`b, 
         DirectedEdge[1, 4] -> $CellContext`b, 
         DirectedEdge[3, 8] -> $CellContext`b, 
         DirectedEdge[3, 6] -> $CellContext`a, 
         DirectedEdge[12, 9] -> $CellContext`u, 
         DirectedEdge[10, 9] -> $CellContext`u, 
         DirectedEdge[9, 16] -> $CellContext`a, 
         DirectedEdge[5, 12] -> $CellContext`a, 
         DirectedEdge[11, 4] -> $CellContext`a, 
         DirectedEdge[14, 11] -> $CellContext`u}, ImageSize -> 600, 
       VertexLabels -> {9 -> Placed[{9, 
            Style[
             
             Row[{InputForm["{b}"] -> {}, 
               InputForm["{a}"] -> {$CellContext`a, $CellContext`b}}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 14 -> Placed[{14, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 5 -> Placed[{5, 
            Style[
             
             Row[{InputForm["{b}"] -> {$CellContext`b}, 
               InputForm["{a}"] -> {$CellContext`a}}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 6 -> Placed[{6, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 16 -> Placed[{16, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 4 -> Placed[{4, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 12 -> Placed[{12, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 1 -> Placed[{1, 
            Style[
             
             Row[{InputForm["{a}"] -> {}, 
               InputForm["{b}"] -> {$CellContext`b}}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 7 -> Placed[{7, 
            Style[
             
             Row[{InputForm["{b}"] -> {}, 
               InputForm["{a}"] -> {$CellContext`a}}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 8 -> Placed[{8, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 2 -> Placed[{2, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 10 -> Placed[{10, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 3 -> Placed[{3, 
            Style[
             
             Row[{InputForm["{a}"] -> {}, 
               InputForm["{b}"] -> {$CellContext`b, $CellContext`a}}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 11 -> Placed[{11, 
            Style[
             
             Row[{InputForm["{a}"] -> {$CellContext`b}, 
               InputForm["{b}"] -> {$CellContext`a}}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}]}, 
       VertexShapeFunction -> {
        11 -> "Circle", 2 -> "ConcaveSquare", 3 -> "Circle", 12 -> "Square", 
         4 -> "Square", 16 -> "Square", 10 -> "ConcaveSquare", 8 -> "Square", 
         14 -> "ConcaveSquare", 7 -> "Circle", 9 -> "Circle", 6 -> 
         "ConcaveSquare", 5 -> "Circle", 1 -> "RoundedTriangle"}, 
       VertexSize -> {0.6}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
        0.02242705952402108], {
         ArrowBox[{{0.7336436193189988, 0.0005263210581032407}, {0., 
          0.33082239801112445`}}, 0.04478413401536528], 
         InsetBox["a", {0.3668218096594994, 0.16567435953461385`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.7336436193189988, 0.0005263210581032407}, {
          1.7317361791237305`, 0.6051721159030028}}, 0.04478413401536528], 
         InsetBox["b", {1.2326898992213646`, 0.302849218480553}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0., 0.33082239801112445`}, {0.7371071984704958, 
          0.952289735631657}}, 0.04478413401536528], 
         InsetBox["u", {0.3685535992352479, 0.6415560668213907}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1.7317361791237305`, 0.6051721159030028}, {
          0.7371071984704958, 0.952289735631657}}, 0.04478413401536528], 
         InsetBox["u", {1.2344216887971131`, 0.7787309257673298}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.7371071984704958, 0.952289735631657}, {
          1.3016329414017271`, 1.2321487844354264`}}, 0.04478413401536528], 
         InsetBox["a", {1.0193700699361115`, 1.0922192600335416`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.7371071984704958, 0.952289735631657}, {
          1.2470068462032655`, 1.7161299273155883`}}, 0.04478413401536528], 
         InsetBox["b", {0.9920570223368806, 1.3342098314736226`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1.3016329414017271`, 1.2321487844354264`}, {
          2.192457909587141, 1.1120341050020808`}}, 0.04478413401536528], 
         InsetBox["u", {1.7470454254944339`, 1.1720914447187536`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1.2470068462032655`, 1.7161299273155883`}, {
          2.192457909587141, 1.1120341050020808`}}, 0.04478413401536528], 
         InsetBox["u", {1.7197323778952032`, 1.4140820161588346`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{2.192457909587141, 1.1120341050020808`}, {
          1.7317361791237305`, 0.6051721159030028}}, 0.04478413401536528], 
         InsetBox["b", {1.9620970443554357`, 0.8586031104525418}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{2.192457909587141, 1.1120341050020808`}, {
          3.5784422473825823`, 0.6051001161342785}}, 0.04478413401536528], 
         InsetBox["a", {2.885450078484862, 0.8585671105681796}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.576262019539324, 0.}, {5.3085400265780445`, 
          0.3311339834888576}}, 0.04478413401536528], 
         InsetBox["b", {4.942401023058684, 0.1655669917444288}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.576262019539324, 0.}, {3.5784422473825823`, 
          0.6051001161342785}}, 0.04478413401536528], 
         InsetBox["a", {4.077352133460953, 0.30255005806713925`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{5.3085400265780445`, 0.3311339834888576}, {
          4.573654077851123, 0.9526457590640012}}, 0.04478413401536528], 
         InsetBox["u", {4.941097052214584, 0.6418898712764294}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{3.5784422473825823`, 0.6051001161342785}, {
          4.573654077851123, 0.9526457590640012}}, 0.04478413401536528], 
         InsetBox["u", {4.0760481626168525`, 0.7788729375991399}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.573654077851123, 0.9526457590640012}, {
          4.062573341805022, 1.7156253139309623`}}, 0.04478413401536528], 
         InsetBox["b", {4.318113709828072, 1.3341355364974818`}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.573654077851123, 0.9526457590640012}, {
          4.007293509227982, 1.2321210265891542`}}, 0.04478413401536528], 
         InsetBox["a", {4.290473793539553, 1.0923833928265778`}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.062573341805022, 1.7156253139309623`}, {
          3.117915680441285, 1.112292255349694}}, 0.04478413401536528], 
         InsetBox["u", {3.590244511123154, 1.413958784640328}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.007293509227982, 1.2321210265891542`}, {
          3.117915680441285, 1.112292255349694}}, 0.04478413401536528], 
         InsetBox["u", {3.5626045948346334`, 1.172206640969424}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{3.117915680441285, 1.112292255349694}, {
          1.7317361791237305`, 0.6051721159030028}}, 0.04478413401536528], 
         InsetBox["a", {2.4248259297825077`, 0.8587321856263483}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{3.117915680441285, 1.112292255349694}, {
          3.5784422473825823`, 0.6051001161342785}}, 0.04478413401536528], 
         InsetBox["b", {3.3481789639119337`, 0.8586961857419861}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
        0.7]}], {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}}}, {{{0.6907034962709944, 0.09871959831039152}, {
          0.6048233961712287, -0.05002911202977279}, {
          0.5618834191194675, -0.12440354019797652`}, {
          0.6477635192192331, -0.12440354019797652`}, {
          0.8195237194187645, -0.12440354019797652`}, {
          0.9054038195185301, -0.12440354019797652`}, {
          0.8624638424667689, -0.05002911202977279}, {0.7765837423670032, 
          0.09871959831039152}, {0.7336436193189988, 0.17309388048235208`}, {
          0.6907034962709944, 0.09871959831039152}}}], 
         InsetBox["1", {0.7336436193189988, 0.0005263210581032407},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"{a}\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{b}\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", "b", "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {0.7336436193189988, 0.14652256422582646`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 
          2}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4gVP/B4ycuyx3xbw/G1//l17Uef7DowbFtnv
3rRdztvttj2zxtL2M+phNvsey29fYXgLJr8fJg/Vvx9V/6H9m+TrQ41a7tlL
LV1fuKftwP4A82RdI7079j6XFixLzdixvztN+65h03X7sGmOHHdEt+zXqOPf
aqhzFS5/bOrnHsNrl+ylofr/d5ZXJoWcgZtvvdNeM2nFcbj9ZuH5P5ZdPGkv
DnWf9uRz0wxUztkz3dudenNuwZ7JEv837VK7YC8I9Z8OVB7mf5h+qPn2MPOh
9tszdEHsh7rP/ijUfVD326O5374L6j+o/+1h/oeZDwsf9PAHAF5uwkc=
          "]], 
         InsetBox["2", {0., 0.33082239801112445`},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {0., 0.47681864117884765`}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         RectangleBox[{1.6029159559759605`, 0.4763518927552327}, \
{1.8605564022715004`, 0.7339923390507729}], 
         InsetBox["4", {1.7317361791237305`, 0.6051721159030028},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {1.7317361791237305`, 0.751168359070726}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.7371071984704958, 0.952289735631657}, 
          0.14599624316772322`], 
         InsetBox["3", {0.7371071984704958, 0.952289735631657},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"{a}\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{b}\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", 
                 RowBox[{"b", ",", "a"}], "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {0.7371071984704958, 1.0982859787993802`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 
          2}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4uepDnp/J3+zX+/Iarzz+Ff7bYVGUn8zvtob
Rln+T7f9aj+3XFug9vIX+8K04FT7H1/sW2pV2P7afoHLB3eKffoj9Bmu36qf
/0VN7Sf7fNPXZx7yfLP/1fS1cemhT/Zh1k8OJZZ/ta/IOrj1m89ne1X3a+sS
fb7YW8Qt95ef9Nmex/f8kofbPsPlPwedmJWo+Bmu/1DcrrbEbx/h5q9M2Vzz
MOEj3P7MiJliXMs+wt333D7VK9rgE9z9y429nzSXfoL7DyYP8z9MP0OCu0Wt
5ne4+Q45ifNCnnyD23+oZWoWc9Q3uPuYJq6/cEvkG9z9MHmY/2D6Yf6HmQ8L
H/TwBwA2oM7R
          "]], 
         InsetBox["6", {1.3016329414017271`, 1.2321487844354264`},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {1.3016329414017271`, 1.3781450276031497`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         RectangleBox[{1.1181866230554953`, 1.5873097041678181`}, \
{1.3758270693510357`, 1.8449501504633585`}], 
         InsetBox["8", {1.2470068462032655`, 1.7161299273155883`},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {1.2470068462032655`, 1.8621261704833116`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.192457909587141, 1.1120341050020808`}, 
          0.14599624316772322`], 
         InsetBox["5", {2.192457909587141, 1.1120341050020808`},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"{b}\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", "b", "}"}]}],RowBox[{
               StyleBox[
               "\"{a}\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", "a", "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {2.192457909587141, 1.258030348169804}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.576262019539324, 0.}, 0.14599624316772322`], 
         InsetBox["7", {4.576262019539324, 0.},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"{b}\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{a}\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", "a", "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], Offset[{0, 2}, 
          {4.576262019539324, 0.14599624316772322`}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 
          2}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYpH7xp8E14g6nHJxvrCq5K49e5LB28BEUYfz
y4QZ07xv2zcuXvfqo7Wow6Xr1TMPm92y//1E58VEMYT8u3TNxxdPi8D1Z6xc
/qBwmYjDMeHb5r6d9+wj1BTZ92wXcUjR3s/va3zH3kJBJCTglojD/Kj2/T7t
1+015vZWzXot4mBTlD3dx/AqXP5Wp3++z+1LcP3qRfp2M+LOwM1PXvj97fRN
x+H2x9mr771z+yTcfcHVbdFpeufg7l/OEz31qvYFuP9CoPIw/8P0z5q79Uvh
RVG4+asUbM6pHxB10IDaf0rNs3HyXFGHm1D33Vp5PsqzRxTufpj8PKj/YPph
/oeZDwsf9PAHAM5CuMQ=
          "]], 
         InsetBox["10", {5.3085400265780445`, 0.3311339834888576},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {5.3085400265780445`, 0.4771302266565808}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         RectangleBox[{3.449622024234812, 0.4762798929865084}, \
{3.7072624705303525`, 0.7339203392820486}], 
         InsetBox["12", {3.5784422473825823`, 0.6051001161342785},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {3.5784422473825823`, 0.7510963593020017}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.573654077851123, 0.9526457590640012}, 
          0.14599624316772322`], 
         InsetBox["9", {4.573654077851123, 0.9526457590640012},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"{b}\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{a}\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", 
                 RowBox[{"a", ",", "b"}], "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {4.573654077851123, 1.0986420022317245`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 
          2}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYpeb6Y7GGwQcdgevE+Vu+WtvEZNiU5wq4GCb
8+jhzp9/7DfNfWQp7CDgUFvxx33ilj/2OvcTzDdLIeTtj+xKeTafH67f2H17
vFoov0O1+5T1xif/2gs5rlqzq5zfIcm3d+lm47/2l0wmuD3ew+9gGFk/cTPH
H/uNes2Ty+/zO0jEV7QbF/+Gy/9PKazdfPcXXP+5guTMzZt+ws3fWhYTbyz7
E25/aZbTz+ikn3D3fQ7k01375ifc/Ztdvxy7avgL7j+YPMz/MP2np790nnxV
AG7+bakCWc8jAnD7fyvUXtiyUADuPu4lzKuyJgjA3Q+Th/kPph/mf5j5sPBB
D38AjS26wA==
          "]], 
         InsetBox["14", {4.062573341805022, 1.7156253139309623`},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {4.062573341805022, 1.8616215570986856`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         RectangleBox[{3.878473286080212, 1.103300803441384}, \
{4.136113732375752, 1.3609412497369244`}], 
         InsetBox["16", {4.007293509227982, 1.2321210265891542`},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {4.007293509227982, 1.3781172697568775`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.117915680441285, 1.112292255349694}, 
          0.14599624316772322`], 
         InsetBox["11", {3.117915680441285, 1.112292255349694},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"{a}\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", "b", "}"}]}],RowBox[{
               StyleBox[
               "\"{b}\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", "a", "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {3.117915680441285, 1.2582884985174172`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  BaselinePosition->Axis,
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->15,
  ImageSize->600]], "Print",
 CellChangeTimes->{
  3.693990625514318*^9, 3.6939906913568077`*^9, {3.6940557483423243`*^9, 
   3.6940557829222183`*^9}, 3.694146965728603*^9, 3.694147108954781*^9, 
   3.694147623537088*^9, 3.6941477883636417`*^9, {3.714820224261772*^9, 
   3.714820246716757*^9}, 3.714820296161806*^9, 3.714820349096884*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Under delay = \"\>", "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\" :\"\>"}],
  SequenceForm["Under delay = ", 3, " :"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.693990625514318*^9, 3.6939906913568077`*^9, {3.6940557483423243`*^9, 
   3.6940557829222183`*^9}, 3.694146965728603*^9, 3.694147108954781*^9, 
   3.694147623537088*^9, 3.6941477883636417`*^9, {3.714820224261772*^9, 
   3.714820246716757*^9}, 3.714820296161806*^9, 3.714820349101519*^9}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 4, 3, 6, 8, 5, 7, 10, 12, 9, 14, 16, 
      11}, {{{1, 2}, {1, 3}, {2, 4}, {3, 4}, {4, 5}, {4, 6}, {5, 7}, {6, 7}, {
       8, 9}, {8, 10}, {9, 11}, {10, 11}, {11, 12}, {11, 13}, {12, 14}, {13, 
       14}, {7, 3}, {7, 10}, {14, 3}, {14, 10}}, Null}, {
      BaselinePosition -> Axis, 
       EdgeLabels -> {
        DirectedEdge[4, 3] -> $CellContext`u, 
         DirectedEdge[7, 12] -> $CellContext`a, 
         DirectedEdge[16, 11] -> $CellContext`u, 
         DirectedEdge[8, 5] -> $CellContext`u, 
         DirectedEdge[9, 14] -> $CellContext`b, 
         DirectedEdge[2, 3] -> $CellContext`u, 
         DirectedEdge[1, 2] -> $CellContext`a, 
         DirectedEdge[5, 4] -> $CellContext`b, 
         DirectedEdge[6, 5] -> $CellContext`u, 
         DirectedEdge[7, 10] -> $CellContext`b, 
         DirectedEdge[11, 12] -> $CellContext`b, 
         DirectedEdge[1, 4] -> $CellContext`b, 
         DirectedEdge[3, 8] -> $CellContext`b, 
         DirectedEdge[3, 6] -> $CellContext`a, 
         DirectedEdge[12, 9] -> $CellContext`u, 
         DirectedEdge[10, 9] -> $CellContext`u, 
         DirectedEdge[9, 16] -> $CellContext`a, 
         DirectedEdge[5, 12] -> $CellContext`a, 
         DirectedEdge[11, 4] -> $CellContext`a, 
         DirectedEdge[14, 11] -> $CellContext`u}, ImageSize -> 600, 
       VertexLabels -> {9 -> Placed[{9, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 14 -> Placed[{14, 
            Style[
             Row[{InputForm["{a}"] -> {}, InputForm["{b}"] -> {}}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 5 -> Placed[{5, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 6 -> Placed[{6, 
            Style[
             Row[{InputForm["{b}"] -> {}, InputForm["{a}"] -> {}}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 16 -> Placed[{16, 
            Style[
             
             Row[{InputForm["{a}"] -> {$CellContext`b}, 
               InputForm["{b}"] -> {$CellContext`a}}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 4 -> Placed[{4, 
            Style[
             
             Row[{InputForm["{a}"] -> {}, 
               InputForm["{b}"] -> {$CellContext`a, $CellContext`b}}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 12 -> Placed[{12, 
            Style[
             
             Row[{InputForm["{b}"] -> {}, 
               InputForm["{a}"] -> {$CellContext`a, $CellContext`b}}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 1 -> Placed[{1, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 7 -> Placed[{7, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 8 -> Placed[{8, 
            Style[
             
             Row[{InputForm["{b}"] -> {$CellContext`b}, 
               InputForm["{a}"] -> {$CellContext`a}}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 2 -> Placed[{2, 
            Style[
             Row[{InputForm["{a}"] -> {}, InputForm["{b}"] -> {}}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 10 -> Placed[{10, 
            Style[
             Row[{InputForm["{b}"] -> {}, InputForm["{a}"] -> {}}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 3 -> Placed[{3, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 11 -> Placed[{11, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}]}, 
       VertexShapeFunction -> {
        11 -> "Circle", 2 -> "ConcaveSquare", 3 -> "Circle", 12 -> "Square", 
         4 -> "Square", 16 -> "Square", 10 -> "ConcaveSquare", 8 -> "Square", 
         14 -> "ConcaveSquare", 7 -> "Circle", 9 -> "Circle", 6 -> 
         "ConcaveSquare", 5 -> "Circle", 1 -> "RoundedTriangle"}, 
       VertexSize -> {0.6}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
        0.02242705952402108], {
         ArrowBox[{{0.7336436193189988, 0.0005263210581032407}, {0., 
          0.33082239801112445`}}, 0.04478413401536528], 
         InsetBox["a", {0.3668218096594994, 0.16567435953461385`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.7336436193189988, 0.0005263210581032407}, {
          1.7317361791237305`, 0.6051721159030028}}, 0.04478413401536528], 
         InsetBox["b", {1.2326898992213646`, 0.302849218480553}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0., 0.33082239801112445`}, {0.7371071984704958, 
          0.952289735631657}}, 0.04478413401536528], 
         InsetBox["u", {0.3685535992352479, 0.6415560668213907}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1.7317361791237305`, 0.6051721159030028}, {
          0.7371071984704958, 0.952289735631657}}, 0.04478413401536528], 
         InsetBox["u", {1.2344216887971131`, 0.7787309257673298}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.7371071984704958, 0.952289735631657}, {
          1.3016329414017271`, 1.2321487844354264`}}, 0.04478413401536528], 
         InsetBox["a", {1.0193700699361115`, 1.0922192600335416`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.7371071984704958, 0.952289735631657}, {
          1.2470068462032655`, 1.7161299273155883`}}, 0.04478413401536528], 
         InsetBox["b", {0.9920570223368806, 1.3342098314736226`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1.3016329414017271`, 1.2321487844354264`}, {
          2.192457909587141, 1.1120341050020808`}}, 0.04478413401536528], 
         InsetBox["u", {1.7470454254944339`, 1.1720914447187536`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1.2470068462032655`, 1.7161299273155883`}, {
          2.192457909587141, 1.1120341050020808`}}, 0.04478413401536528], 
         InsetBox["u", {1.7197323778952032`, 1.4140820161588346`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{2.192457909587141, 1.1120341050020808`}, {
          1.7317361791237305`, 0.6051721159030028}}, 0.04478413401536528], 
         InsetBox["b", {1.9620970443554357`, 0.8586031104525418}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{2.192457909587141, 1.1120341050020808`}, {
          3.5784422473825823`, 0.6051001161342785}}, 0.04478413401536528], 
         InsetBox["a", {2.885450078484862, 0.8585671105681796}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.576262019539324, 0.}, {5.3085400265780445`, 
          0.3311339834888576}}, 0.04478413401536528], 
         InsetBox["b", {4.942401023058684, 0.1655669917444288}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.576262019539324, 0.}, {3.5784422473825823`, 
          0.6051001161342785}}, 0.04478413401536528], 
         InsetBox["a", {4.077352133460953, 0.30255005806713925`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{5.3085400265780445`, 0.3311339834888576}, {
          4.573654077851123, 0.9526457590640012}}, 0.04478413401536528], 
         InsetBox["u", {4.941097052214584, 0.6418898712764294}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{3.5784422473825823`, 0.6051001161342785}, {
          4.573654077851123, 0.9526457590640012}}, 0.04478413401536528], 
         InsetBox["u", {4.0760481626168525`, 0.7788729375991399}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.573654077851123, 0.9526457590640012}, {
          4.062573341805022, 1.7156253139309623`}}, 0.04478413401536528], 
         InsetBox["b", {4.318113709828072, 1.3341355364974818`}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.573654077851123, 0.9526457590640012}, {
          4.007293509227982, 1.2321210265891542`}}, 0.04478413401536528], 
         InsetBox["a", {4.290473793539553, 1.0923833928265778`}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.062573341805022, 1.7156253139309623`}, {
          3.117915680441285, 1.112292255349694}}, 0.04478413401536528], 
         InsetBox["u", {3.590244511123154, 1.413958784640328}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.007293509227982, 1.2321210265891542`}, {
          3.117915680441285, 1.112292255349694}}, 0.04478413401536528], 
         InsetBox["u", {3.5626045948346334`, 1.172206640969424}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{3.117915680441285, 1.112292255349694}, {
          1.7317361791237305`, 0.6051721159030028}}, 0.04478413401536528], 
         InsetBox["a", {2.4248259297825077`, 0.8587321856263483}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{3.117915680441285, 1.112292255349694}, {
          3.5784422473825823`, 0.6051001161342785}}, 0.04478413401536528], 
         InsetBox["b", {3.3481789639119337`, 0.8586961857419861}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
        0.7]}], {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}}}, {{{0.6907034962709944, 0.09871959831039152}, {
          0.6048233961712287, -0.05002911202977279}, {
          0.5618834191194675, -0.12440354019797652`}, {
          0.6477635192192331, -0.12440354019797652`}, {
          0.8195237194187645, -0.12440354019797652`}, {
          0.9054038195185301, -0.12440354019797652`}, {
          0.8624638424667689, -0.05002911202977279}, {0.7765837423670032, 
          0.09871959831039152}, {0.7336436193189988, 0.17309388048235208`}, {
          0.6907034962709944, 0.09871959831039152}}}], 
         InsetBox["1", {0.7336436193189988, 0.0005263210581032407},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {0.7336436193189988, 0.14652256422582646`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 
          2}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4gVP/B4ycuyx3xbw/G1//l17Uef7DowbFtnv
3rRdztvttj2zxtL2M+phNvsey29fYXgLJr8fJg/Vvx9V/6H9m+TrQ41a7tlL
LV1fuKftwP4A82RdI7079j6XFixLzdixvztN+65h03X7sGmOHHdEt+zXqOPf
aqhzFS5/bOrnHsNrl+ylofr/d5ZXJoWcgZtvvdNeM2nFcbj9ZuH5P5ZdPGkv
DnWf9uRz0wxUztkz3dudenNuwZ7JEv837VK7YC8I9Z8OVB7mf5h+qPn2MPOh
9tszdEHsh7rP/ijUfVD326O5374L6j+o/+1h/oeZDwsf9PAHAF5uwkc=
          "]], 
         InsetBox["2", {0., 0.33082239801112445`},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"{a}\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{b}\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {0., 0.47681864117884765`}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         RectangleBox[{1.6029159559759605`, 0.4763518927552327}, \
{1.8605564022715004`, 0.7339923390507729}], 
         InsetBox["4", {1.7317361791237305`, 0.6051721159030028},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"{a}\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{b}\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", 
                 RowBox[{"a", ",", "b"}], "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {1.7317361791237305`, 0.751168359070726}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.7371071984704958, 0.952289735631657}, 
          0.14599624316772322`], 
         InsetBox["3", {0.7371071984704958, 0.952289735631657},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {0.7371071984704958, 1.0982859787993802`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 
          2}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4uepDnp/J3+zX+/Iarzz+Ff7bYVGUn8zvtob
Rln+T7f9aj+3XFug9vIX+8K04FT7H1/sW2pV2P7afoHLB3eKffoj9Bmu36qf
/0VN7Sf7fNPXZx7yfLP/1fS1cemhT/Zh1k8OJZZ/ta/IOrj1m89ne1X3a+sS
fb7YW8Qt95ef9Nmex/f8kofbPsPlPwedmJWo+Bmu/1DcrrbEbx/h5q9M2Vzz
MOEj3P7MiJliXMs+wt333D7VK9rgE9z9y429nzSXfoL7DyYP8z9MP0OCu0Wt
5ne4+Q45ifNCnnyD23+oZWoWc9Q3uPuYJq6/cEvkG9z9MHmY/2D6Yf6HmQ8L
H/TwBwA2oM7R
          "]], 
         InsetBox["6", {1.3016329414017271`, 1.2321487844354264`},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"{b}\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{a}\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {1.3016329414017271`, 1.3781450276031497`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         RectangleBox[{1.1181866230554953`, 1.5873097041678181`}, \
{1.3758270693510357`, 1.8449501504633585`}], 
         InsetBox["8", {1.2470068462032655`, 1.7161299273155883`},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"{b}\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", "b", "}"}]}],RowBox[{
               StyleBox[
               "\"{a}\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", "a", "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {1.2470068462032655`, 1.8621261704833116`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.192457909587141, 1.1120341050020808`}, 
          0.14599624316772322`], 
         InsetBox["5", {2.192457909587141, 1.1120341050020808`},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {2.192457909587141, 1.258030348169804}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.576262019539324, 0.}, 0.14599624316772322`], 
         InsetBox["7", {4.576262019539324, 0.},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {4.576262019539324, 0.14599624316772322`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 
          2}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYpH7xp8E14g6nHJxvrCq5K49e5LB28BEUYfz
y4QZ07xv2zcuXvfqo7Wow6Xr1TMPm92y//1E58VEMYT8u3TNxxdPi8D1Z6xc
/qBwmYjDMeHb5r6d9+wj1BTZ92wXcUjR3s/va3zH3kJBJCTglojD/Kj2/T7t
1+015vZWzXot4mBTlD3dx/AqXP5Wp3++z+1LcP3qRfp2M+LOwM1PXvj97fRN
x+H2x9mr771z+yTcfcHVbdFpeufg7l/OEz31qvYFuP9CoPIw/8P0z5q79Uvh
RVG4+asUbM6pHxB10IDaf0rNs3HyXFGHm1D33Vp5PsqzRxTufpj8PKj/YPph
/oeZDwsf9PAHAM5CuMQ=
          "]], 
         InsetBox["10", {5.3085400265780445`, 0.3311339834888576},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"{b}\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{a}\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {5.3085400265780445`, 0.4771302266565808}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         RectangleBox[{3.449622024234812, 0.4762798929865084}, \
{3.7072624705303525`, 0.7339203392820486}], 
         InsetBox["12", {3.5784422473825823`, 0.6051001161342785},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"{b}\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{a}\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", 
                 RowBox[{"a", ",", "b"}], "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {3.5784422473825823`, 0.7510963593020017}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.573654077851123, 0.9526457590640012}, 
          0.14599624316772322`], 
         InsetBox["9", {4.573654077851123, 0.9526457590640012},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {4.573654077851123, 1.0986420022317245`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 
          2}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYpeb6Y7GGwQcdgevE+Vu+WtvEZNiU5wq4GCb
8+jhzp9/7DfNfWQp7CDgUFvxx33ilj/2OvcTzDdLIeTtj+xKeTafH67f2H17
vFoov0O1+5T1xif/2gs5rlqzq5zfIcm3d+lm47/2l0wmuD3ew+9gGFk/cTPH
H/uNes2Ty+/zO0jEV7QbF/+Gy/9PKazdfPcXXP+5guTMzZt+ws3fWhYTbyz7
E25/aZbTz+ikn3D3fQ7k01375ifc/Ztdvxy7avgL7j+YPMz/MP2np790nnxV
AG7+bakCWc8jAnD7fyvUXtiyUADuPu4lzKuyJgjA3Q+Th/kPph/mf5j5sPBB
D38AjS26wA==
          "]], 
         InsetBox["14", {4.062573341805022, 1.7156253139309623`},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"{a}\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{b}\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {4.062573341805022, 1.8616215570986856`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         RectangleBox[{3.878473286080212, 1.103300803441384}, \
{4.136113732375752, 1.3609412497369244`}], 
         InsetBox["16", {4.007293509227982, 1.2321210265891542`},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"{a}\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", "b", "}"}]}],RowBox[{
               StyleBox[
               "\"{b}\"", ShowStringCharacters -> True, NumberMarks -> True], 
               "\[Rule]", 
               RowBox[{"{", "a", "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {4.007293509227982, 1.3781172697568775`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.117915680441285, 1.112292255349694}, 
          0.14599624316772322`], 
         InsetBox["11", {3.117915680441285, 1.112292255349694},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {3.117915680441285, 1.2582884985174172`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  BaselinePosition->Axis,
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->15,
  ImageSize->600]], "Print",
 CellChangeTimes->{
  3.693990625514318*^9, 3.6939906913568077`*^9, {3.6940557483423243`*^9, 
   3.6940557829222183`*^9}, 3.694146965728603*^9, 3.694147108954781*^9, 
   3.694147623537088*^9, 3.6941477883636417`*^9, {3.714820224261772*^9, 
   3.714820246716757*^9}, 3.714820296161806*^9, 3.71482034920002*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Under delay = \"\>", "\[InvisibleSpace]", "4", 
   "\[InvisibleSpace]", "\<\" :\"\>"}],
  SequenceForm["Under delay = ", 4, " :"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.693990625514318*^9, 3.6939906913568077`*^9, {3.6940557483423243`*^9, 
   3.6940557829222183`*^9}, 3.694146965728603*^9, 3.694147108954781*^9, 
   3.694147623537088*^9, 3.6941477883636417`*^9, {3.714820224261772*^9, 
   3.714820246716757*^9}, 3.714820296161806*^9, 3.7148203492092*^9}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 4, 3, 6, 8, 5, 7, 10, 12, 9, 14, 16, 
      11}, {{{1, 2}, {1, 3}, {2, 4}, {3, 4}, {4, 5}, {4, 6}, {5, 7}, {6, 7}, {
       8, 9}, {8, 10}, {9, 11}, {10, 11}, {11, 12}, {11, 13}, {12, 14}, {13, 
       14}, {7, 3}, {7, 10}, {14, 3}, {14, 10}}, Null}, {
      BaselinePosition -> Axis, 
       EdgeLabels -> {
        DirectedEdge[4, 3] -> $CellContext`u, 
         DirectedEdge[7, 12] -> $CellContext`a, 
         DirectedEdge[16, 11] -> $CellContext`u, 
         DirectedEdge[8, 5] -> $CellContext`u, 
         DirectedEdge[9, 14] -> $CellContext`b, 
         DirectedEdge[2, 3] -> $CellContext`u, 
         DirectedEdge[1, 2] -> $CellContext`a, 
         DirectedEdge[5, 4] -> $CellContext`b, 
         DirectedEdge[6, 5] -> $CellContext`u, 
         DirectedEdge[7, 10] -> $CellContext`b, 
         DirectedEdge[11, 12] -> $CellContext`b, 
         DirectedEdge[1, 4] -> $CellContext`b, 
         DirectedEdge[3, 8] -> $CellContext`b, 
         DirectedEdge[3, 6] -> $CellContext`a, 
         DirectedEdge[12, 9] -> $CellContext`u, 
         DirectedEdge[10, 9] -> $CellContext`u, 
         DirectedEdge[9, 16] -> $CellContext`a, 
         DirectedEdge[5, 12] -> $CellContext`a, 
         DirectedEdge[11, 4] -> $CellContext`a, 
         DirectedEdge[14, 11] -> $CellContext`u}, ImageSize -> 600, 
       VertexLabels -> {9 -> Placed[{9, 
            Style[
             
             Row[{InputForm["{b}{a}"] -> {}, InputForm["{b}{b}"] -> {}, 
               InputForm["{a}{a}"] -> {$CellContext`b}, 
               InputForm["{a}{b}"] -> {$CellContext`a}}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 14 -> Placed[{14, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 5 -> Placed[{5, 
            Style[
             
             Row[{InputForm["{b}{a}"] -> {}, 
               InputForm["{b}{b}"] -> {$CellContext`a, $CellContext`b}, 
               InputForm["{a}{b}"] -> {}, 
               InputForm["{a}{a}"] -> {$CellContext`a, $CellContext`b}}, 
              "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 6 -> Placed[{6, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 16 -> Placed[{16, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 4 -> Placed[{4, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 12 -> Placed[{12, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 1 -> Placed[{1, 
            Style[
             
             Row[{InputForm["{a}{a}"] -> {}, InputForm["{a}{b}"] -> {}, 
               InputForm["{b}{a}"] -> {}, 
               InputForm["{b}{b}"] -> {$CellContext`a, $CellContext`b}}, 
              "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 7 -> Placed[{7, 
            Style[
             
             Row[{InputForm["{b}{b}"] -> {}, InputForm["{b}{a}"] -> {}, 
               InputForm["{a}{b}"] -> {}, 
               InputForm["{a}{a}"] -> {$CellContext`a, $CellContext`b}}, 
              "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 8 -> Placed[{8, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 2 -> Placed[{2, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 10 -> Placed[{10, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 3 -> Placed[{3, 
            Style[
             
             Row[{InputForm["{a}{b}"] -> {}, InputForm["{a}{a}"] -> {}, 
               InputForm["{b}{b}"] -> {$CellContext`b}, 
               InputForm["{b}{a}"] -> {$CellContext`a}}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 11 -> Placed[{11, 
            Style[
             
             Row[{InputForm["{a}{a}"] -> {}, 
               InputForm["{a}{b}"] -> {$CellContext`a, $CellContext`b}, 
               InputForm["{b}{b}"] -> {}, 
               InputForm["{b}{a}"] -> {$CellContext`a, $CellContext`b}}, 
              "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}]}, 
       VertexShapeFunction -> {
        11 -> "Circle", 2 -> "ConcaveSquare", 3 -> "Circle", 12 -> "Square", 
         4 -> "Square", 16 -> "Square", 10 -> "ConcaveSquare", 8 -> "Square", 
         14 -> "ConcaveSquare", 7 -> "Circle", 9 -> "Circle", 6 -> 
         "ConcaveSquare", 5 -> "Circle", 1 -> "RoundedTriangle"}, 
       VertexSize -> {0.6}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
        0.02242705952402108], {
         ArrowBox[{{0.7336436193189988, 0.0005263210581032407}, {0., 
          0.33082239801112445`}}, 0.04478413401536528], 
         InsetBox["a", {0.3668218096594994, 0.16567435953461385`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.7336436193189988, 0.0005263210581032407}, {
          1.7317361791237305`, 0.6051721159030028}}, 0.04478413401536528], 
         InsetBox["b", {1.2326898992213646`, 0.302849218480553}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0., 0.33082239801112445`}, {0.7371071984704958, 
          0.952289735631657}}, 0.04478413401536528], 
         InsetBox["u", {0.3685535992352479, 0.6415560668213907}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1.7317361791237305`, 0.6051721159030028}, {
          0.7371071984704958, 0.952289735631657}}, 0.04478413401536528], 
         InsetBox["u", {1.2344216887971131`, 0.7787309257673298}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.7371071984704958, 0.952289735631657}, {
          1.3016329414017271`, 1.2321487844354264`}}, 0.04478413401536528], 
         InsetBox["a", {1.0193700699361115`, 1.0922192600335416`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.7371071984704958, 0.952289735631657}, {
          1.2470068462032655`, 1.7161299273155883`}}, 0.04478413401536528], 
         InsetBox["b", {0.9920570223368806, 1.3342098314736226`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1.3016329414017271`, 1.2321487844354264`}, {
          2.192457909587141, 1.1120341050020808`}}, 0.04478413401536528], 
         InsetBox["u", {1.7470454254944339`, 1.1720914447187536`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1.2470068462032655`, 1.7161299273155883`}, {
          2.192457909587141, 1.1120341050020808`}}, 0.04478413401536528], 
         InsetBox["u", {1.7197323778952032`, 1.4140820161588346`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{2.192457909587141, 1.1120341050020808`}, {
          1.7317361791237305`, 0.6051721159030028}}, 0.04478413401536528], 
         InsetBox["b", {1.9620970443554357`, 0.8586031104525418}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{2.192457909587141, 1.1120341050020808`}, {
          3.5784422473825823`, 0.6051001161342785}}, 0.04478413401536528], 
         InsetBox["a", {2.885450078484862, 0.8585671105681796}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.576262019539324, 0.}, {5.3085400265780445`, 
          0.3311339834888576}}, 0.04478413401536528], 
         InsetBox["b", {4.942401023058684, 0.1655669917444288}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.576262019539324, 0.}, {3.5784422473825823`, 
          0.6051001161342785}}, 0.04478413401536528], 
         InsetBox["a", {4.077352133460953, 0.30255005806713925`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{5.3085400265780445`, 0.3311339834888576}, {
          4.573654077851123, 0.9526457590640012}}, 0.04478413401536528], 
         InsetBox["u", {4.941097052214584, 0.6418898712764294}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{3.5784422473825823`, 0.6051001161342785}, {
          4.573654077851123, 0.9526457590640012}}, 0.04478413401536528], 
         InsetBox["u", {4.0760481626168525`, 0.7788729375991399}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.573654077851123, 0.9526457590640012}, {
          4.062573341805022, 1.7156253139309623`}}, 0.04478413401536528], 
         InsetBox["b", {4.318113709828072, 1.3341355364974818`}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.573654077851123, 0.9526457590640012}, {
          4.007293509227982, 1.2321210265891542`}}, 0.04478413401536528], 
         InsetBox["a", {4.290473793539553, 1.0923833928265778`}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.062573341805022, 1.7156253139309623`}, {
          3.117915680441285, 1.112292255349694}}, 0.04478413401536528], 
         InsetBox["u", {3.590244511123154, 1.413958784640328}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.007293509227982, 1.2321210265891542`}, {
          3.117915680441285, 1.112292255349694}}, 0.04478413401536528], 
         InsetBox["u", {3.5626045948346334`, 1.172206640969424}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{3.117915680441285, 1.112292255349694}, {
          1.7317361791237305`, 0.6051721159030028}}, 0.04478413401536528], 
         InsetBox["a", {2.4248259297825077`, 0.8587321856263483}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{3.117915680441285, 1.112292255349694}, {
          3.5784422473825823`, 0.6051001161342785}}, 0.04478413401536528], 
         InsetBox["b", {3.3481789639119337`, 0.8586961857419861}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
        0.7]}], {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}}}, {{{0.6907034962709944, 0.09871959831039152}, {
          0.6048233961712287, -0.05002911202977279}, {
          0.5618834191194675, -0.12440354019797652`}, {
          0.6477635192192331, -0.12440354019797652`}, {
          0.8195237194187645, -0.12440354019797652`}, {
          0.9054038195185301, -0.12440354019797652`}, {
          0.8624638424667689, -0.05002911202977279}, {0.7765837423670032, 
          0.09871959831039152}, {0.7336436193189988, 0.17309388048235208`}, {
          0.6907034962709944, 0.09871959831039152}}}], 
         InsetBox["1", {0.7336436193189988, 0.0005263210581032407},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"{a}{a}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{a}{b}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{b}{a}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{b}{b}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", 
                 RowBox[{"a", ",", "b"}], "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {0.7336436193189988, 0.14652256422582646`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 
          2}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4gVP/B4ycuyx3xbw/G1//l17Uef7DowbFtnv
3rRdztvttj2zxtL2M+phNvsey29fYXgLJr8fJg/Vvx9V/6H9m+TrQ41a7tlL
LV1fuKftwP4A82RdI7079j6XFixLzdixvztN+65h03X7sGmOHHdEt+zXqOPf
aqhzFS5/bOrnHsNrl+ylofr/d5ZXJoWcgZtvvdNeM2nFcbj9ZuH5P5ZdPGkv
DnWf9uRz0wxUztkz3dudenNuwZ7JEv837VK7YC8I9Z8OVB7mf5h+qPn2MPOh
9tszdEHsh7rP/ijUfVD326O5374L6j+o/+1h/oeZDwsf9PAHAF5uwkc=
          "]], 
         InsetBox["2", {0., 0.33082239801112445`},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {0., 0.47681864117884765`}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         RectangleBox[{1.6029159559759605`, 0.4763518927552327}, \
{1.8605564022715004`, 0.7339923390507729}], 
         InsetBox["4", {1.7317361791237305`, 0.6051721159030028},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {1.7317361791237305`, 0.751168359070726}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.7371071984704958, 0.952289735631657}, 
          0.14599624316772322`], 
         InsetBox["3", {0.7371071984704958, 0.952289735631657},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"{a}{b}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{a}{a}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{b}{b}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "b", "}"}]}],RowBox[{
               StyleBox[
               "\"{b}{a}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "a", "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {0.7371071984704958, 1.0982859787993802`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 
          2}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4uepDnp/J3+zX+/Iarzz+Ff7bYVGUn8zvtob
Rln+T7f9aj+3XFug9vIX+8K04FT7H1/sW2pV2P7afoHLB3eKffoj9Bmu36qf
/0VN7Sf7fNPXZx7yfLP/1fS1cemhT/Zh1k8OJZZ/ta/IOrj1m89ne1X3a+sS
fb7YW8Qt95ef9Nmex/f8kofbPsPlPwedmJWo+Bmu/1DcrrbEbx/h5q9M2Vzz
MOEj3P7MiJliXMs+wt333D7VK9rgE9z9y429nzSXfoL7DyYP8z9MP0OCu0Wt
5ne4+Q45ifNCnnyD23+oZWoWc9Q3uPuYJq6/cEvkG9z9MHmY/2D6Yf6HmQ8L
H/TwBwA2oM7R
          "]], 
         InsetBox["6", {1.3016329414017271`, 1.2321487844354264`},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {1.3016329414017271`, 1.3781450276031497`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         RectangleBox[{1.1181866230554953`, 1.5873097041678181`}, \
{1.3758270693510357`, 1.8449501504633585`}], 
         InsetBox["8", {1.2470068462032655`, 1.7161299273155883`},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {1.2470068462032655`, 1.8621261704833116`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.192457909587141, 1.1120341050020808`}, 
          0.14599624316772322`], 
         InsetBox["5", {2.192457909587141, 1.1120341050020808`},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"{b}{a}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{b}{b}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", 
                 RowBox[{"a", ",", "b"}], "}"}]}],RowBox[{
               StyleBox[
               "\"{a}{b}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{a}{a}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", 
                 RowBox[{"a", ",", "b"}], "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {2.192457909587141, 1.258030348169804}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.576262019539324, 0.}, 0.14599624316772322`], 
         InsetBox["7", {4.576262019539324, 0.},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"{b}{b}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{b}{a}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{a}{b}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{a}{a}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", 
                 RowBox[{"a", ",", "b"}], "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {4.576262019539324, 0.14599624316772322`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 
          2}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYpH7xp8E14g6nHJxvrCq5K49e5LB28BEUYfz
y4QZ07xv2zcuXvfqo7Wow6Xr1TMPm92y//1E58VEMYT8u3TNxxdPi8D1Z6xc
/qBwmYjDMeHb5r6d9+wj1BTZ92wXcUjR3s/va3zH3kJBJCTglojD/Kj2/T7t
1+015vZWzXot4mBTlD3dx/AqXP5Wp3++z+1LcP3qRfp2M+LOwM1PXvj97fRN
x+H2x9mr771z+yTcfcHVbdFpeufg7l/OEz31qvYFuP9CoPIw/8P0z5q79Uvh
RVG4+asUbM6pHxB10IDaf0rNs3HyXFGHm1D33Vp5PsqzRxTufpj8PKj/YPph
/oeZDwsf9PAHAM5CuMQ=
          "]], 
         InsetBox["10", {5.3085400265780445`, 0.3311339834888576},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {5.3085400265780445`, 0.4771302266565808}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         RectangleBox[{3.449622024234812, 0.4762798929865084}, \
{3.7072624705303525`, 0.7339203392820486}], 
         InsetBox["12", {3.5784422473825823`, 0.6051001161342785},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {3.5784422473825823`, 0.7510963593020017}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.573654077851123, 0.9526457590640012}, 
          0.14599624316772322`], 
         InsetBox["9", {4.573654077851123, 0.9526457590640012},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"{b}{a}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{b}{b}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{a}{a}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "b", "}"}]}],RowBox[{
               StyleBox[
               "\"{a}{b}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "a", "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {4.573654077851123, 1.0986420022317245`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 
          2}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYpeb6Y7GGwQcdgevE+Vu+WtvEZNiU5wq4GCb
8+jhzp9/7DfNfWQp7CDgUFvxx33ilj/2OvcTzDdLIeTtj+xKeTafH67f2H17
vFoov0O1+5T1xif/2gs5rlqzq5zfIcm3d+lm47/2l0wmuD3ew+9gGFk/cTPH
H/uNes2Ty+/zO0jEV7QbF/+Gy/9PKazdfPcXXP+5guTMzZt+ws3fWhYTbyz7
E25/aZbTz+ikn3D3fQ7k01375ifc/Ztdvxy7avgL7j+YPMz/MP2np790nnxV
AG7+bakCWc8jAnD7fyvUXtiyUADuPu4lzKuyJgjA3Q+Th/kPph/mf5j5sPBB
D38AjS26wA==
          "]], 
         InsetBox["14", {4.062573341805022, 1.7156253139309623`},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {4.062573341805022, 1.8616215570986856`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         RectangleBox[{3.878473286080212, 1.103300803441384}, \
{4.136113732375752, 1.3609412497369244`}], 
         InsetBox["16", {4.007293509227982, 1.2321210265891542`},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {4.007293509227982, 1.3781172697568775`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.117915680441285, 1.112292255349694}, 
          0.14599624316772322`], 
         InsetBox["11", {3.117915680441285, 1.112292255349694},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"{a}{a}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{a}{b}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", 
                 RowBox[{"a", ",", "b"}], "}"}]}],RowBox[{
               StyleBox[
               "\"{b}{b}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{b}{a}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", 
                 RowBox[{"a", ",", "b"}], "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {3.117915680441285, 1.2582884985174172`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  BaselinePosition->Axis,
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->15,
  ImageSize->600]], "Print",
 CellChangeTimes->{
  3.693990625514318*^9, 3.6939906913568077`*^9, {3.6940557483423243`*^9, 
   3.6940557829222183`*^9}, 3.694146965728603*^9, 3.694147108954781*^9, 
   3.694147623537088*^9, 3.6941477883636417`*^9, {3.714820224261772*^9, 
   3.714820246716757*^9}, 3.714820296161806*^9, 3.714820349302087*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Under delay = \"\>", "\[InvisibleSpace]", "5", 
   "\[InvisibleSpace]", "\<\" :\"\>"}],
  SequenceForm["Under delay = ", 5, " :"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.693990625514318*^9, 3.6939906913568077`*^9, {3.6940557483423243`*^9, 
   3.6940557829222183`*^9}, 3.694146965728603*^9, 3.694147108954781*^9, 
   3.694147623537088*^9, 3.6941477883636417`*^9, {3.714820224261772*^9, 
   3.714820246716757*^9}, 3.714820296161806*^9, 3.714820349314232*^9}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 4, 3, 6, 8, 5, 7, 10, 12, 9, 14, 16, 
      11}, {{{1, 2}, {1, 3}, {2, 4}, {3, 4}, {4, 5}, {4, 6}, {5, 7}, {6, 7}, {
       8, 9}, {8, 10}, {9, 11}, {10, 11}, {11, 12}, {11, 13}, {12, 14}, {13, 
       14}, {7, 3}, {7, 10}, {14, 3}, {14, 10}}, Null}, {
      BaselinePosition -> Axis, 
       EdgeLabels -> {
        DirectedEdge[4, 3] -> $CellContext`u, 
         DirectedEdge[7, 12] -> $CellContext`a, 
         DirectedEdge[16, 11] -> $CellContext`u, 
         DirectedEdge[8, 5] -> $CellContext`u, 
         DirectedEdge[9, 14] -> $CellContext`b, 
         DirectedEdge[2, 3] -> $CellContext`u, 
         DirectedEdge[1, 2] -> $CellContext`a, 
         DirectedEdge[5, 4] -> $CellContext`b, 
         DirectedEdge[6, 5] -> $CellContext`u, 
         DirectedEdge[7, 10] -> $CellContext`b, 
         DirectedEdge[11, 12] -> $CellContext`b, 
         DirectedEdge[1, 4] -> $CellContext`b, 
         DirectedEdge[3, 8] -> $CellContext`b, 
         DirectedEdge[3, 6] -> $CellContext`a, 
         DirectedEdge[12, 9] -> $CellContext`u, 
         DirectedEdge[10, 9] -> $CellContext`u, 
         DirectedEdge[9, 16] -> $CellContext`a, 
         DirectedEdge[5, 12] -> $CellContext`a, 
         DirectedEdge[11, 4] -> $CellContext`a, 
         DirectedEdge[14, 11] -> $CellContext`u}, ImageSize -> 600, 
       VertexLabels -> {9 -> Placed[{9, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 14 -> Placed[{14, 
            Style[
             
             Row[{InputForm["{a}{a}"] -> {}, InputForm["{a}{b}"] -> {}, 
               InputForm["{b}{b}"] -> {}, InputForm["{b}{a}"] -> {}}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 5 -> Placed[{5, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 6 -> Placed[{6, 
            Style[
             
             Row[{InputForm["{b}{a}"] -> {}, InputForm["{b}{b}"] -> {}, 
               InputForm["{a}{b}"] -> {}, InputForm["{a}{a}"] -> {}}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 16 -> Placed[{16, 
            Style[
             
             Row[{InputForm["{a}{a}"] -> {}, 
               InputForm["{a}{b}"] -> {$CellContext`a, $CellContext`b}, 
               InputForm["{b}{b}"] -> {}, 
               InputForm["{b}{a}"] -> {$CellContext`a, $CellContext`b}}, 
              "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 4 -> Placed[{4, 
            Style[
             
             Row[{InputForm["{a}{b}"] -> {}, InputForm["{a}{a}"] -> {}, 
               InputForm["{b}{b}"] -> {$CellContext`b}, 
               InputForm["{b}{a}"] -> {$CellContext`a}}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 12 -> Placed[{12, 
            Style[
             
             Row[{InputForm["{b}{a}"] -> {}, InputForm["{b}{b}"] -> {}, 
               InputForm["{a}{a}"] -> {$CellContext`b}, 
               InputForm["{a}{b}"] -> {$CellContext`a}}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 1 -> Placed[{1, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 7 -> Placed[{7, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 8 -> Placed[{8, 
            Style[
             
             Row[{InputForm["{b}{a}"] -> {}, 
               InputForm["{b}{b}"] -> {$CellContext`a, $CellContext`b}, 
               InputForm["{a}{b}"] -> {}, 
               InputForm["{a}{a}"] -> {$CellContext`a, $CellContext`b}}, 
              "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 2 -> Placed[{2, 
            Style[
             
             Row[{InputForm["{a}{b}"] -> {}, InputForm["{a}{a}"] -> {}, 
               InputForm["{b}{b}"] -> {}, InputForm["{b}{a}"] -> {}}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 10 -> Placed[{10, 
            Style[
             
             Row[{InputForm["{b}{a}"] -> {}, InputForm["{b}{b}"] -> {}, 
               InputForm["{a}{a}"] -> {}, InputForm["{a}{b}"] -> {}}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 3 -> Placed[{3, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}], 11 -> Placed[{11, 
            Style[
             Row[{}, "\n"], 
             RGBColor[1, 0, 0]]}, {{
             Rational[1, 2], 
             Rational[1, 2]}, Above}]}, 
       VertexShapeFunction -> {
        11 -> "Circle", 2 -> "ConcaveSquare", 3 -> "Circle", 12 -> "Square", 
         4 -> "Square", 16 -> "Square", 10 -> "ConcaveSquare", 8 -> "Square", 
         14 -> "ConcaveSquare", 7 -> "Circle", 9 -> "Circle", 6 -> 
         "ConcaveSquare", 5 -> "Circle", 1 -> "RoundedTriangle"}, 
       VertexSize -> {0.6}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
        0.02242705952402108], {
         ArrowBox[{{0.7336436193189988, 0.0005263210581032407}, {0., 
          0.33082239801112445`}}, 0.04478413401536528], 
         InsetBox["a", {0.3668218096594994, 0.16567435953461385`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.7336436193189988, 0.0005263210581032407}, {
          1.7317361791237305`, 0.6051721159030028}}, 0.04478413401536528], 
         InsetBox["b", {1.2326898992213646`, 0.302849218480553}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0., 0.33082239801112445`}, {0.7371071984704958, 
          0.952289735631657}}, 0.04478413401536528], 
         InsetBox["u", {0.3685535992352479, 0.6415560668213907}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1.7317361791237305`, 0.6051721159030028}, {
          0.7371071984704958, 0.952289735631657}}, 0.04478413401536528], 
         InsetBox["u", {1.2344216887971131`, 0.7787309257673298}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.7371071984704958, 0.952289735631657}, {
          1.3016329414017271`, 1.2321487844354264`}}, 0.04478413401536528], 
         InsetBox["a", {1.0193700699361115`, 1.0922192600335416`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.7371071984704958, 0.952289735631657}, {
          1.2470068462032655`, 1.7161299273155883`}}, 0.04478413401536528], 
         InsetBox["b", {0.9920570223368806, 1.3342098314736226`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1.3016329414017271`, 1.2321487844354264`}, {
          2.192457909587141, 1.1120341050020808`}}, 0.04478413401536528], 
         InsetBox["u", {1.7470454254944339`, 1.1720914447187536`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1.2470068462032655`, 1.7161299273155883`}, {
          2.192457909587141, 1.1120341050020808`}}, 0.04478413401536528], 
         InsetBox["u", {1.7197323778952032`, 1.4140820161588346`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{2.192457909587141, 1.1120341050020808`}, {
          1.7317361791237305`, 0.6051721159030028}}, 0.04478413401536528], 
         InsetBox["b", {1.9620970443554357`, 0.8586031104525418}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{2.192457909587141, 1.1120341050020808`}, {
          3.5784422473825823`, 0.6051001161342785}}, 0.04478413401536528], 
         InsetBox["a", {2.885450078484862, 0.8585671105681796}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.576262019539324, 0.}, {5.3085400265780445`, 
          0.3311339834888576}}, 0.04478413401536528], 
         InsetBox["b", {4.942401023058684, 0.1655669917444288}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.576262019539324, 0.}, {3.5784422473825823`, 
          0.6051001161342785}}, 0.04478413401536528], 
         InsetBox["a", {4.077352133460953, 0.30255005806713925`}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{5.3085400265780445`, 0.3311339834888576}, {
          4.573654077851123, 0.9526457590640012}}, 0.04478413401536528], 
         InsetBox["u", {4.941097052214584, 0.6418898712764294}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{3.5784422473825823`, 0.6051001161342785}, {
          4.573654077851123, 0.9526457590640012}}, 0.04478413401536528], 
         InsetBox["u", {4.0760481626168525`, 0.7788729375991399}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.573654077851123, 0.9526457590640012}, {
          4.062573341805022, 1.7156253139309623`}}, 0.04478413401536528], 
         InsetBox["b", {4.318113709828072, 1.3341355364974818`}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.573654077851123, 0.9526457590640012}, {
          4.007293509227982, 1.2321210265891542`}}, 0.04478413401536528], 
         InsetBox["a", {4.290473793539553, 1.0923833928265778`}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.062573341805022, 1.7156253139309623`}, {
          3.117915680441285, 1.112292255349694}}, 0.04478413401536528], 
         InsetBox["u", {3.590244511123154, 1.413958784640328}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.007293509227982, 1.2321210265891542`}, {
          3.117915680441285, 1.112292255349694}}, 0.04478413401536528], 
         InsetBox["u", {3.5626045948346334`, 1.172206640969424}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{3.117915680441285, 1.112292255349694}, {
          1.7317361791237305`, 0.6051721159030028}}, 0.04478413401536528], 
         InsetBox["a", {2.4248259297825077`, 0.8587321856263483}, ImageScaled[
          {0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{3.117915680441285, 1.112292255349694}, {
          3.5784422473825823`, 0.6051001161342785}}, 0.04478413401536528], 
         InsetBox["b", {3.3481789639119337`, 0.8586961857419861}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
        0.7]}], {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}}}, {{{0.6907034962709944, 0.09871959831039152}, {
          0.6048233961712287, -0.05002911202977279}, {
          0.5618834191194675, -0.12440354019797652`}, {
          0.6477635192192331, -0.12440354019797652`}, {
          0.8195237194187645, -0.12440354019797652`}, {
          0.9054038195185301, -0.12440354019797652`}, {
          0.8624638424667689, -0.05002911202977279}, {0.7765837423670032, 
          0.09871959831039152}, {0.7336436193189988, 0.17309388048235208`}, {
          0.6907034962709944, 0.09871959831039152}}}], 
         InsetBox["1", {0.7336436193189988, 0.0005263210581032407},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {0.7336436193189988, 0.14652256422582646`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 
          2}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4gVP/B4ycuyx3xbw/G1//l17Uef7DowbFtnv
3rRdztvttj2zxtL2M+phNvsey29fYXgLJr8fJg/Vvx9V/6H9m+TrQ41a7tlL
LV1fuKftwP4A82RdI7079j6XFixLzdixvztN+65h03X7sGmOHHdEt+zXqOPf
aqhzFS5/bOrnHsNrl+ylofr/d5ZXJoWcgZtvvdNeM2nFcbj9ZuH5P5ZdPGkv
DnWf9uRz0wxUztkz3dudenNuwZ7JEv837VK7YC8I9Z8OVB7mf5h+qPn2MPOh
9tszdEHsh7rP/ijUfVD326O5374L6j+o/+1h/oeZDwsf9PAHAF5uwkc=
          "]], 
         InsetBox["2", {0., 0.33082239801112445`},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"{a}{b}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{a}{a}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{b}{b}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{b}{a}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {0., 0.47681864117884765`}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         RectangleBox[{1.6029159559759605`, 0.4763518927552327}, \
{1.8605564022715004`, 0.7339923390507729}], 
         InsetBox["4", {1.7317361791237305`, 0.6051721159030028},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"{a}{b}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{a}{a}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{b}{b}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "b", "}"}]}],RowBox[{
               StyleBox[
               "\"{b}{a}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "a", "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {1.7317361791237305`, 0.751168359070726}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.7371071984704958, 0.952289735631657}, 
          0.14599624316772322`], 
         InsetBox["3", {0.7371071984704958, 0.952289735631657},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {0.7371071984704958, 1.0982859787993802`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 
          2}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYC4uepDnp/J3+zX+/Iarzz+Ff7bYVGUn8zvtob
Rln+T7f9aj+3XFug9vIX+8K04FT7H1/sW2pV2P7afoHLB3eKffoj9Bmu36qf
/0VN7Sf7fNPXZx7yfLP/1fS1cemhT/Zh1k8OJZZ/ta/IOrj1m89ne1X3a+sS
fb7YW8Qt95ef9Nmex/f8kofbPsPlPwedmJWo+Bmu/1DcrrbEbx/h5q9M2Vzz
MOEj3P7MiJliXMs+wt333D7VK9rgE9z9y429nzSXfoL7DyYP8z9MP0OCu0Wt
5ne4+Q45ifNCnnyD23+oZWoWc9Q3uPuYJq6/cEvkG9z9MHmY/2D6Yf6HmQ8L
H/TwBwA2oM7R
          "]], 
         InsetBox["6", {1.3016329414017271`, 1.2321487844354264`},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"{b}{a}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{b}{b}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{a}{b}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{a}{a}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {1.3016329414017271`, 1.3781450276031497`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         RectangleBox[{1.1181866230554953`, 1.5873097041678181`}, \
{1.3758270693510357`, 1.8449501504633585`}], 
         InsetBox["8", {1.2470068462032655`, 1.7161299273155883`},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"{b}{a}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{b}{b}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", 
                 RowBox[{"a", ",", "b"}], "}"}]}],RowBox[{
               StyleBox[
               "\"{a}{b}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{a}{a}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", 
                 RowBox[{"a", ",", "b"}], "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {1.2470068462032655`, 1.8621261704833116`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.192457909587141, 1.1120341050020808`}, 
          0.14599624316772322`], 
         InsetBox["5", {2.192457909587141, 1.1120341050020808`},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {2.192457909587141, 1.258030348169804}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.576262019539324, 0.}, 0.14599624316772322`], 
         InsetBox["7", {4.576262019539324, 0.},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {4.576262019539324, 0.14599624316772322`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 
          2}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYpH7xp8E14g6nHJxvrCq5K49e5LB28BEUYfz
y4QZ07xv2zcuXvfqo7Wow6Xr1TMPm92y//1E58VEMYT8u3TNxxdPi8D1Z6xc
/qBwmYjDMeHb5r6d9+wj1BTZ92wXcUjR3s/va3zH3kJBJCTglojD/Kj2/T7t
1+015vZWzXot4mBTlD3dx/AqXP5Wp3++z+1LcP3qRfp2M+LOwM1PXvj97fRN
x+H2x9mr771z+yTcfcHVbdFpeufg7l/OEz31qvYFuP9CoPIw/8P0z5q79Uvh
RVG4+asUbM6pHxB10IDaf0rNs3HyXFGHm1D33Vp5PsqzRxTufpj8PKj/YPph
/oeZDwsf9PAHAM5CuMQ=
          "]], 
         InsetBox["10", {5.3085400265780445`, 0.3311339834888576},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"{b}{a}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{b}{b}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{a}{a}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{a}{b}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {5.3085400265780445`, 0.4771302266565808}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         RectangleBox[{3.449622024234812, 0.4762798929865084}, 
          {3.7072624705303525`, 0.7339203392820486}], 
         InsetBox["12", {3.5784422473825823`, 0.6051001161342785},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"{b}{a}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{b}{b}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{a}{a}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "b", "}"}]}],RowBox[{
               StyleBox[
               "\"{a}{b}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "a", "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {3.5784422473825823`, 0.7510963593020017}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.573654077851123, 0.9526457590640012}, 
          0.14599624316772322`], 
         InsetBox["9", {4.573654077851123, 0.9526457590640012},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {4.573654077851123, 1.0986420022317245`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         FilledCurveBox[{{{0, 2, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 
          1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 2}, {0, 1, 1}, {1, 2, 
          2}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJJIGYCYpeb6Y7GGwQcdgevE+Vu+WtvEZNiU5wq4GCb
8+jhzp9/7DfNfWQp7CDgUFvxx33ilj/2OvcTzDdLIeTtj+xKeTafH67f2H17
vFoov0O1+5T1xif/2gs5rlqzq5zfIcm3d+lm47/2l0wmuD3ew+9gGFk/cTPH
H/uNes2Ty+/zO0jEV7QbF/+Gy/9PKazdfPcXXP+5guTMzZt+ws3fWhYTbyz7
E25/aZbTz+ikn3D3fQ7k01375ifc/Ztdvxy7avgL7j+YPMz/MP2np790nnxV
AG7+bakCWc8jAnD7fyvUXtiyUADuPu4lzKuyJgjA3Q+Th/kPph/mf5j5sPBB
D38AjS26wA==
          "]], 
         InsetBox["14", {4.062573341805022, 1.7156253139309623`},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"{a}{a}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{a}{b}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{b}{b}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{b}{a}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {4.062573341805022, 1.8616215570986856`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         RectangleBox[{3.878473286080212, 1.103300803441384}, \
{4.136113732375752, 1.3609412497369244`}], 
         InsetBox["16", {4.007293509227982, 1.2321210265891542`},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\"",RowBox[{
               StyleBox[
               "\"{a}{a}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{a}{b}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", 
                 RowBox[{"a", ",", "b"}], "}"}]}],RowBox[{
               StyleBox[
               "\"{b}{b}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", "}"}]}],RowBox[{
               StyleBox[
               "\"{b}{a}\"", ShowStringCharacters -> True, NumberMarks -> 
                True], "\[Rule]", 
               RowBox[{"{", 
                 RowBox[{"a", ",", "b"}], "}"}]}]},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {4.007293509227982, 1.3781172697568775`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.117915680441285, 1.112292255349694}, 
          0.14599624316772322`], 
         InsetBox["11", {3.117915680441285, 1.112292255349694},
          BaseStyle->"Graphics"], InsetBox[
          StyleBox[
           TemplateBox[{"\n","\"\\n\""},
            "RowWithSeparators"],
           StripOnInput->False,
           LineColor->RGBColor[1, 0, 0],
           FrontFaceColor->RGBColor[1, 0, 0],
           BackFaceColor->RGBColor[1, 0, 0],
           GraphicsColor->RGBColor[1, 0, 0],
           FontColor->RGBColor[1, 0, 0]], 
          Offset[{0, 2}, {3.117915680441285, 1.2582884985174172`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  BaselinePosition->Axis,
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->15,
  ImageSize->600]], "Print",
 CellChangeTimes->{
  3.693990625514318*^9, 3.6939906913568077`*^9, {3.6940557483423243`*^9, 
   3.6940557829222183`*^9}, 3.694146965728603*^9, 3.694147108954781*^9, 
   3.694147623537088*^9, 3.6941477883636417`*^9, {3.714820224261772*^9, 
   3.714820246716757*^9}, 3.714820296161806*^9, 3.7148203494162827`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{
   "Computation", " ", "time", " ", "is", " ", "got", " ", "under", " ", 
    "the", " ", "text", " ", "mode"}], ",", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"i", ".", "e", ".", " ", "with"}], " ", "graphical1"}], " ", "=",
     " ", "0"}], ",", " ", 
   RowBox[{
   "as", " ", "rendering", " ", "the", " ", "graphs", " ", "needs", " ", 
    "much", " ", "more", " ", "extra", " ", "time"}], ",", " ", 
   RowBox[{
   "which", " ", "though", " ", "falls", " ", "beyond", " ", "the", " ", 
    RowBox[{"algorithm", "."}]}]}], "*)"}]], "Input",
 CellChangeTimes->{{3.71482037432442*^9, 3.714820460071546*^9}, {
  3.7148205654944277`*^9, 3.714820709454123*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Computation time under increasing delays : \\n\"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "0.0040000000000048885`", ",", "0.0040000000000048885`", ",", 
     "0.0040000000000048885`", ",", "0.008000000000009777`", ",", 
     "0.008000000000009777`", ",", "0.012000000000000455`"}], "}"}]}],
  SequenceForm[
  "Computation time under increasing delays : \n", {0.0040000000000048885`, 
   0.0040000000000048885`, 0.0040000000000048885`, 0.008000000000009777, 
   0.008000000000009777, 0.012000000000000455`}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.693990625514318*^9, 3.6939906913568077`*^9, {3.6940557483423243`*^9, 
   3.6940557829222183`*^9}, 3.694146965728603*^9, 3.694147108954781*^9, 
   3.694147623537088*^9, 3.6941477883636417`*^9, {3.714820224261772*^9, 
   3.714820246716757*^9}, 3.714820296188712*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exmp. 2", "Subsection",
 CellChangeTimes->{{3.725591824510847*^9, 3.7255918270870247`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"g2", "=", 
   RowBox[{"Graph", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"1", "\[Rule]", "2"}], ",", 
       RowBox[{"1", "\[Rule]", "4"}], ",", 
       RowBox[{"2", "\[Rule]", "3"}], ",", 
       RowBox[{"4", "\[Rule]", "3"}], ",", 
       RowBox[{"3", "\[Rule]", "6"}], ",", 
       RowBox[{"3", "\[Rule]", "8"}], ",", 
       RowBox[{"6", "\[Rule]", "5"}], ",", 
       RowBox[{"8", "\[Rule]", "5"}], ",", 
       RowBox[{"7", "\[Rule]", "10"}], ",", 
       RowBox[{"7", "\[Rule]", "12"}], ",", 
       RowBox[{"10", "\[Rule]", "9"}], ",", 
       RowBox[{"12", "\[Rule]", "9"}], ",", 
       RowBox[{"9", "\[Rule]", "14"}], ",", 
       RowBox[{"9", "\[Rule]", "16"}], ",", 
       RowBox[{"14", "\[Rule]", "11"}], ",", 
       RowBox[{"16", "\[Rule]", "11"}], ",", 
       RowBox[{"5", "\[Rule]", "4"}], ",", 
       RowBox[{"5", "\[Rule]", "12"}], ",", 
       RowBox[{"11", "\[Rule]", "4"}], ",", 
       RowBox[{"11", "\[Rule]", "12"}], ",", 
       RowBox[{"8", "\[Rule]", "3"}], ",", 
       RowBox[{"8", "\[Rule]", "11"}]}], "}"}], ",", 
     RowBox[{"EdgeWeight", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "a", ",", "b", ",", "u", ",", "u", ",", "a", ",", "b", ",", "u", ",", 
        "u", ",", "b", ",", "a", ",", "u", ",", "u", ",", "b", ",", "a", ",", 
        "u", ",", "u", ",", "b", ",", "a", ",", "a", ",", "b", ",", "u", ",", 
        "u"}], "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"init2", "=", 
   RowBox[{"{", "1", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bad2", "=", 
   RowBox[{"{", 
    RowBox[{"2", ",", "6", ",", "10", ",", "14"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lag2", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"graphical2", "=", "0"}], ";"}]}], "Input",
 CellChangeTimes->{{3.679290280863879*^9, 3.679290334241673*^9}, {
   3.679290504696708*^9, 3.67929051929695*^9}, {3.679290627540678*^9, 
   3.679290646162645*^9}, {3.679290676691043*^9, 3.679290749174502*^9}, {
   3.67929089973089*^9, 3.679290911059611*^9}, {3.679290948233796*^9, 
   3.679290990883844*^9}, {3.679291164264686*^9, 3.679291210405404*^9}, {
   3.679296297585969*^9, 3.679296312880332*^9}, {3.679297255110785*^9, 
   3.67929728224135*^9}, {3.679298728331581*^9, 3.679298875905641*^9}, 
   3.679298940274908*^9, {3.679299134034567*^9, 3.679299184389367*^9}, {
   3.679303531395106*^9, 3.679303544554354*^9}, {3.679303608922887*^9, 
   3.679303639506028*^9}, {3.679303980910127*^9, 3.679303986325524*^9}, {
   3.679335615401274*^9, 3.679335623430876*^9}, {3.679335744327502*^9, 
   3.679335766784133*^9}, 3.679335823213298*^9, {3.679335983824042*^9, 
   3.679335984261932*^9}, 3.679345060627506*^9, {3.679345101558879*^9, 
   3.679345112772768*^9}, 3.679345479078967*^9, 3.679349498904059*^9, 
   3.679349536594214*^9, {3.679349600050577*^9, 3.67934962905582*^9}, 
   3.679349661608243*^9, {3.679351400809895*^9, 3.679351401467813*^9}, {
   3.679351450028281*^9, 3.679351451046861*^9}, {3.679351510988296*^9, 
   3.679351511620798*^9}, {3.679351634514476*^9, 3.679351635015629*^9}, {
   3.679386630980524*^9, 3.679386698696404*^9}, {3.679386811408715*^9, 
   3.679386822593432*^9}, {3.6860384746966476`*^9, 3.686038475079864*^9}, 
   3.686045416325849*^9, {3.686068277527047*^9, 3.686068277702538*^9}, 
   3.686068564576255*^9, {3.686068654843511*^9, 3.686068661601185*^9}, {
   3.69303726939705*^9, 3.693037272820078*^9}, {3.693382630180463*^9, 
   3.6933826455199547`*^9}, 3.6939682691038027`*^9, 3.693968757628357*^9, 
   3.6939894303952217`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"main", "[", 
  RowBox[{"g2", ",", "init2", ",", "bad2", ",", "lag2", ",", "graphical2"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.679223865677226*^9, 3.679223877308047*^9}, {
   3.679223948966332*^9, 3.679223952257859*^9}, {3.679224829422299*^9, 
   3.679224842926139*^9}, {3.679225385070814*^9, 3.679225388900379*^9}, {
   3.679226561934965*^9, 3.679226582765519*^9}, {3.67922688451364*^9, 
   3.679226886812034*^9}, {3.679290582191699*^9, 3.679290588477742*^9}, {
   3.679291707467694*^9, 3.679291709084998*^9}, {3.679296205829566*^9, 
   3.679296205956924*^9}, {3.67929627826369*^9, 3.679296282866345*^9}, {
   3.679296323611739*^9, 3.679296324755156*^9}, {3.679299162275336*^9, 
   3.679299190372951*^9}, {3.679386825476536*^9, 3.679386831871003*^9}, 
   3.686033432931532*^9, {3.693037278645743*^9, 3.693037283782069*^9}}],

Cell[CellGroupData[{

Cell[BoxData["\<\"Under delay = 0 :\"\>"], "Print",
 CellChangeTimes->{{3.7148208404337587`*^9, 3.714820866033989*^9}}],

Cell[BoxData[
 RowBox[{"\[LeftAssociation]", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "b", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "b", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"b", ",", "a"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"7", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "a", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"9", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "a", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"11", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}]}]}], "\[RightAssociation]"}]], "Print",
 CellChangeTimes->{{3.7148208404337587`*^9, 3.714820866035116*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Under delay = \"\>", "\[InvisibleSpace]", "1", 
   "\[InvisibleSpace]", "\<\" :\"\>"}],
  SequenceForm["Under delay = ", 1, " :"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.7148208404337587`*^9, 3.7148208660361013`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "b", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"8", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "b", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"10", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"12", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "a", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"14", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"16", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}]}]}], "}"}]], "Print",
 CellChangeTimes->{{3.7148208404337587`*^9, 3.7148208660372143`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Under delay = \"\>", "\[InvisibleSpace]", "2", 
   "\[InvisibleSpace]", "\<\" :\"\>"}],
  SequenceForm["Under delay = ", 2, " :"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.7148208404337587`*^9, 3.714820866038124*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"{", 
       RowBox[{"{", "a", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"{", 
       RowBox[{"{", "b", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "b", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", 
      RowBox[{"{", 
       RowBox[{"{", "a", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", 
      RowBox[{"{", 
       RowBox[{"{", "b", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "b", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", 
      RowBox[{"{", 
       RowBox[{"{", "b", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "b", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", 
      RowBox[{"{", 
       RowBox[{"{", "a", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "a", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"7", ",", 
      RowBox[{"{", 
       RowBox[{"{", "b", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"7", ",", 
      RowBox[{"{", 
       RowBox[{"{", "a", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "a", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"9", ",", 
      RowBox[{"{", 
       RowBox[{"{", "b", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"9", ",", 
      RowBox[{"{", 
       RowBox[{"{", "a", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"11", ",", 
      RowBox[{"{", 
       RowBox[{"{", "a", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "b", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"11", ",", 
      RowBox[{"{", 
       RowBox[{"{", "b", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "a", "}"}]}]}], "}"}]], "Print",
 CellChangeTimes->{{3.7148208404337587`*^9, 3.714820866039494*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Under delay = \"\>", "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\" :\"\>"}],
  SequenceForm["Under delay = ", 3, " :"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.7148208404337587`*^9, 3.714820866045369*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", 
      RowBox[{"{", 
       RowBox[{"{", "a", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", 
      RowBox[{"{", 
       RowBox[{"{", "b", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", 
      RowBox[{"{", 
       RowBox[{"{", "a", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", 
      RowBox[{"{", 
       RowBox[{"{", "b", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6", ",", 
      RowBox[{"{", 
       RowBox[{"{", "b", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6", ",", 
      RowBox[{"{", 
       RowBox[{"{", "a", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"8", ",", 
      RowBox[{"{", 
       RowBox[{"{", "a", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"8", ",", 
      RowBox[{"{", 
       RowBox[{"{", "b", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}]}], "}"}]], "Print",
 CellChangeTimes->{{3.7148208404337587`*^9, 3.714820866046767*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Not possible for sure-winning anymore under delay=\"\>", 
   "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\" with uncontrollable states \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"4", ",", "8", ",", "1"}], "}"}], 
   "\[InvisibleSpace]", "\<\".\\n\"\>"}],
  SequenceForm[
  "Not possible for sure-winning anymore under delay=", 3, 
   " with uncontrollable states ", {4, 8, 1}, ".\n"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.7148208404337587`*^9, 3.714820866047934*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Computation time under increasing delays : \\n\"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "0.`", ",", "0.0040000000000048885`", ",", "0.0040000000000048885`", ",", 
     "0.007999999999995566`"}], "}"}]}],
  SequenceForm[
  "Computation time under increasing delays : \n", {0., 
   0.0040000000000048885`, 0.0040000000000048885`, 0.007999999999995566}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.7148208404337587`*^9, 3.7148208660489388`*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Escp. 4 x 4", "Subsection",
 CellChangeTimes->{{3.725591847431138*^9, 3.7255918586953697`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"g3", " ", "=", " ", 
   RowBox[{"Graph", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"27", "\[Rule]", "84"}], ",", 
       RowBox[{"27", "\[Rule]", "84"}], ",", 
       RowBox[{"27", "\[Rule]", "28"}], ",", 
       RowBox[{"84", "\[Rule]", "77"}], ",", 
       RowBox[{"84", "\[Rule]", "81"}], ",", 
       RowBox[{"28", "\[Rule]", "21"}], ",", 
       RowBox[{"28", "\[Rule]", "25"}], ",", 
       RowBox[{"77", "\[Rule]", "50"}], ",", 
       RowBox[{"77", "\[Rule]", "162"}], ",", 
       RowBox[{"77", "\[Rule]", "22"}], ",", 
       RowBox[{"77", "\[Rule]", "22"}], ",", 
       RowBox[{"77", "\[Rule]", "134"}], ",", 
       RowBox[{"77", "\[Rule]", "134"}], ",", 
       RowBox[{"77", "\[Rule]", "78"}], ",", 
       RowBox[{"81", "\[Rule]", "54"}], ",", 
       RowBox[{"81", "\[Rule]", "166"}], ",", 
       RowBox[{"81", "\[Rule]", "26"}], ",", 
       RowBox[{"81", "\[Rule]", "26"}], ",", 
       RowBox[{"81", "\[Rule]", "138"}], ",", 
       RowBox[{"81", "\[Rule]", "138"}], ",", 
       RowBox[{"81", "\[Rule]", "82"}], ",", 
       RowBox[{"21", "\[Rule]", "78"}], ",", 
       RowBox[{"21", "\[Rule]", "78"}], ",", 
       RowBox[{"21", "\[Rule]", "22"}], ",", 
       RowBox[{"25", "\[Rule]", "82"}], ",", 
       RowBox[{"25", "\[Rule]", "82"}], ",", 
       RowBox[{"25", "\[Rule]", "26"}], ",", 
       RowBox[{"50", "\[Rule]", "41"}], ",", 
       RowBox[{"50", "\[Rule]", "55"}], ",", 
       RowBox[{"50", "\[Rule]", "47"}], ",", 
       RowBox[{"162", "\[Rule]", "153"}], ",", 
       RowBox[{"162", "\[Rule]", "167"}], ",", 
       RowBox[{"162", "\[Rule]", "159"}], ",", 
       RowBox[{"22", "\[Rule]", "13"}], ",", 
       RowBox[{"22", "\[Rule]", "27"}], ",", 
       RowBox[{"22", "\[Rule]", "19"}], ",", 
       RowBox[{"134", "\[Rule]", "125"}], ",", 
       RowBox[{"134", "\[Rule]", "139"}], ",", 
       RowBox[{"134", "\[Rule]", "131"}], ",", 
       RowBox[{"78", "\[Rule]", "69"}], ",", 
       RowBox[{"78", "\[Rule]", "83"}], ",", 
       RowBox[{"78", "\[Rule]", "75"}], ",", 
       RowBox[{"54", "\[Rule]", "47"}], ",", 
       RowBox[{"54", "\[Rule]", "55"}], ",", 
       RowBox[{"54", "\[Rule]", "51"}], ",", 
       RowBox[{"166", "\[Rule]", "159"}], ",", 
       RowBox[{"166", "\[Rule]", "167"}], ",", 
       RowBox[{"166", "\[Rule]", "163"}], ",", 
       RowBox[{"26", "\[Rule]", "19"}], ",", 
       RowBox[{"26", "\[Rule]", "27"}], ",", 
       RowBox[{"26", "\[Rule]", "23"}], ",", 
       RowBox[{"138", "\[Rule]", "131"}], ",", 
       RowBox[{"138", "\[Rule]", "139"}], ",", 
       RowBox[{"138", "\[Rule]", "135"}], ",", 
       RowBox[{"82", "\[Rule]", "75"}], ",", 
       RowBox[{"82", "\[Rule]", "83"}], ",", 
       RowBox[{"82", "\[Rule]", "79"}], ",", 
       RowBox[{"41", "\[Rule]", "98"}], ",", 
       RowBox[{"41", "\[Rule]", "70"}], ",", 
       RowBox[{"41", "\[Rule]", "42"}], ",", 
       RowBox[{"55", "\[Rule]", "112"}], ",", 
       RowBox[{"55", "\[Rule]", "84"}], ",", 
       RowBox[{"55", "\[Rule]", "56"}], ",", 
       RowBox[{"47", "\[Rule]", "104"}], ",", 
       RowBox[{"47", "\[Rule]", "76"}], ",", 
       RowBox[{"47", "\[Rule]", "48"}], ",", 
       RowBox[{"153", "\[Rule]", "98"}], ",", 
       RowBox[{"153", "\[Rule]", "210"}], ",", 
       RowBox[{"153", "\[Rule]", "210"}], ",", 
       RowBox[{"153", "\[Rule]", "70"}], ",", 
       RowBox[{"153", "\[Rule]", "182"}], ",", 
       RowBox[{"153", "\[Rule]", "182"}], ",", 
       RowBox[{"153", "\[Rule]", "154"}], ",", 
       RowBox[{"167", "\[Rule]", "112"}], ",", 
       RowBox[{"167", "\[Rule]", "224"}], ",", 
       RowBox[{"167", "\[Rule]", "224"}], ",", 
       RowBox[{"167", "\[Rule]", "84"}], ",", 
       RowBox[{"167", "\[Rule]", "196"}], ",", 
       RowBox[{"167", "\[Rule]", "196"}], ",", 
       RowBox[{"167", "\[Rule]", "168"}], ",", 
       RowBox[{"159", "\[Rule]", "104"}], ",", 
       RowBox[{"159", "\[Rule]", "216"}], ",", 
       RowBox[{"159", "\[Rule]", "216"}], ",", 
       RowBox[{"159", "\[Rule]", "76"}], ",", 
       RowBox[{"159", "\[Rule]", "188"}], ",", 
       RowBox[{"159", "\[Rule]", "188"}], ",", 
       RowBox[{"159", "\[Rule]", "160"}], ",", 
       RowBox[{"13", "\[Rule]", "70"}], ",", 
       RowBox[{"13", "\[Rule]", "70"}], ",", 
       RowBox[{"13", "\[Rule]", "14"}], ",", 
       RowBox[{"19", "\[Rule]", "76"}], ",", 
       RowBox[{"19", "\[Rule]", "76"}], ",", 
       RowBox[{"19", "\[Rule]", "20"}], ",", 
       RowBox[{"125", "\[Rule]", "70"}], ",", 
       RowBox[{"125", "\[Rule]", "70"}], ",", 
       RowBox[{"125", "\[Rule]", "182"}], ",", 
       RowBox[{"125", "\[Rule]", "126"}], ",", 
       RowBox[{"139", "\[Rule]", "84"}], ",", 
       RowBox[{"139", "\[Rule]", "84"}], ",", 
       RowBox[{"139", "\[Rule]", "196"}], ",", 
       RowBox[{"139", "\[Rule]", "140"}], ",", 
       RowBox[{"131", "\[Rule]", "76"}], ",", 
       RowBox[{"131", "\[Rule]", "76"}], ",", 
       RowBox[{"131", "\[Rule]", "188"}], ",", 
       RowBox[{"131", "\[Rule]", "132"}], ",", 
       RowBox[{"69", "\[Rule]", "42"}], ",", 
       RowBox[{"69", "\[Rule]", "154"}], ",", 
       RowBox[{"69", "\[Rule]", "14"}], ",", 
       RowBox[{"69", "\[Rule]", "14"}], ",", 
       RowBox[{"69", "\[Rule]", "126"}], ",", 
       RowBox[{"69", "\[Rule]", "126"}], ",", 
       RowBox[{"69", "\[Rule]", "70"}], ",", 
       RowBox[{"83", "\[Rule]", "56"}], ",", 
       RowBox[{"83", "\[Rule]", "168"}], ",", 
       RowBox[{"83", "\[Rule]", "28"}], ",", 
       RowBox[{"83", "\[Rule]", "28"}], ",", 
       RowBox[{"83", "\[Rule]", "140"}], ",", 
       RowBox[{"83", "\[Rule]", "140"}], ",", 
       RowBox[{"83", "\[Rule]", "84"}], ",", 
       RowBox[{"75", "\[Rule]", "48"}], ",", 
       RowBox[{"75", "\[Rule]", "160"}], ",", 
       RowBox[{"75", "\[Rule]", "20"}], ",", 
       RowBox[{"75", "\[Rule]", "20"}], ",", 
       RowBox[{"75", "\[Rule]", "132"}], ",", 
       RowBox[{"75", "\[Rule]", "132"}], ",", 
       RowBox[{"75", "\[Rule]", "76"}], ",", 
       RowBox[{"51", "\[Rule]", "108"}], ",", 
       RowBox[{"51", "\[Rule]", "80"}], ",", 
       RowBox[{"51", "\[Rule]", "52"}], ",", 
       RowBox[{"163", "\[Rule]", "108"}], ",", 
       RowBox[{"163", "\[Rule]", "220"}], ",", 
       RowBox[{"163", "\[Rule]", "220"}], ",", 
       RowBox[{"163", "\[Rule]", "80"}], ",", 
       RowBox[{"163", "\[Rule]", "192"}], ",", 
       RowBox[{"163", "\[Rule]", "192"}], ",", 
       RowBox[{"163", "\[Rule]", "164"}], ",", 
       RowBox[{"23", "\[Rule]", "80"}], ",", 
       RowBox[{"23", "\[Rule]", "80"}], ",", 
       RowBox[{"23", "\[Rule]", "24"}], ",", 
       RowBox[{"135", "\[Rule]", "80"}], ",", 
       RowBox[{"135", "\[Rule]", "80"}], ",", 
       RowBox[{"135", "\[Rule]", "192"}], ",", 
       RowBox[{"135", "\[Rule]", "136"}], ",", 
       RowBox[{"79", "\[Rule]", "52"}], ",", 
       RowBox[{"79", "\[Rule]", "164"}], ",", 
       RowBox[{"79", "\[Rule]", "24"}], ",", 
       RowBox[{"79", "\[Rule]", "24"}], ",", 
       RowBox[{"79", "\[Rule]", "136"}], ",", 
       RowBox[{"79", "\[Rule]", "136"}], ",", 
       RowBox[{"79", "\[Rule]", "80"}], ",", 
       RowBox[{"98", "\[Rule]", "91"}], ",", 
       RowBox[{"98", "\[Rule]", "105"}], ",", 
       RowBox[{"70", "\[Rule]", "63"}], ",", 
       RowBox[{"70", "\[Rule]", "77"}], ",", 
       RowBox[{"42", "\[Rule]", "35"}], ",", 
       RowBox[{"42", "\[Rule]", "49"}], ",", 
       RowBox[{"112", "\[Rule]", "105"}], ",", 
       RowBox[{"112", "\[Rule]", "109"}], ",", 
       RowBox[{"56", "\[Rule]", "49"}], ",", 
       RowBox[{"56", "\[Rule]", "53"}], ",", 
       RowBox[{"104", "\[Rule]", "109"}], ",", 
       RowBox[{"104", "\[Rule]", "105"}], ",", 
       RowBox[{"104", "\[Rule]", "101"}], ",", 
       RowBox[{"76", "\[Rule]", "81"}], ",", 
       RowBox[{"76", "\[Rule]", "77"}], ",", 
       RowBox[{"76", "\[Rule]", "73"}], ",", 
       RowBox[{"48", "\[Rule]", "53"}], ",", 
       RowBox[{"48", "\[Rule]", "49"}], ",", 
       RowBox[{"48", "\[Rule]", "45"}], ",", 
       RowBox[{"210", "\[Rule]", "203"}], ",", 
       RowBox[{"210", "\[Rule]", "217"}], ",", 
       RowBox[{"182", "\[Rule]", "175"}], ",", 
       RowBox[{"182", "\[Rule]", "189"}], ",", 
       RowBox[{"154", "\[Rule]", "147"}], ",", 
       RowBox[{"154", "\[Rule]", "161"}], ",", 
       RowBox[{"224", "\[Rule]", "217"}], ",", 
       RowBox[{"224", "\[Rule]", "221"}], ",", 
       RowBox[{"196", "\[Rule]", "189"}], ",", 
       RowBox[{"196", "\[Rule]", "193"}], ",", 
       RowBox[{"168", "\[Rule]", "161"}], ",", 
       RowBox[{"168", "\[Rule]", "165"}], ",", 
       RowBox[{"216", "\[Rule]", "221"}], ",", 
       RowBox[{"216", "\[Rule]", "217"}], ",", 
       RowBox[{"216", "\[Rule]", "213"}], ",", 
       RowBox[{"188", "\[Rule]", "193"}], ",", 
       RowBox[{"188", "\[Rule]", "189"}], ",", 
       RowBox[{"188", "\[Rule]", "185"}], ",", 
       RowBox[{"160", "\[Rule]", "165"}], ",", 
       RowBox[{"160", "\[Rule]", "161"}], ",", 
       RowBox[{"160", "\[Rule]", "157"}], ",", 
       RowBox[{"14", "\[Rule]", "7"}], ",", 
       RowBox[{"14", "\[Rule]", "21"}], ",", 
       RowBox[{"20", "\[Rule]", "25"}], ",", 
       RowBox[{"20", "\[Rule]", "21"}], ",", 
       RowBox[{"20", "\[Rule]", "17"}], ",", 
       RowBox[{"126", "\[Rule]", "119"}], ",", 
       RowBox[{"126", "\[Rule]", "133"}], ",", 
       RowBox[{"140", "\[Rule]", "133"}], ",", 
       RowBox[{"140", "\[Rule]", "137"}], ",", 
       RowBox[{"132", "\[Rule]", "137"}], ",", 
       RowBox[{"132", "\[Rule]", "133"}], ",", 
       RowBox[{"132", "\[Rule]", "129"}], ",", 
       RowBox[{"108", "\[Rule]", "101"}], ",", 
       RowBox[{"108", "\[Rule]", "109"}], ",", 
       RowBox[{"80", "\[Rule]", "73"}], ",", 
       RowBox[{"80", "\[Rule]", "81"}], ",", 
       RowBox[{"52", "\[Rule]", "45"}], ",", 
       RowBox[{"52", "\[Rule]", "53"}], ",", 
       RowBox[{"220", "\[Rule]", "213"}], ",", 
       RowBox[{"220", "\[Rule]", "221"}], ",", 
       RowBox[{"192", "\[Rule]", "185"}], ",", 
       RowBox[{"192", "\[Rule]", "193"}], ",", 
       RowBox[{"164", "\[Rule]", "157"}], ",", 
       RowBox[{"164", "\[Rule]", "165"}], ",", 
       RowBox[{"24", "\[Rule]", "17"}], ",", 
       RowBox[{"24", "\[Rule]", "25"}], ",", 
       RowBox[{"136", "\[Rule]", "129"}], ",", 
       RowBox[{"136", "\[Rule]", "137"}], ",", 
       RowBox[{"91", "\[Rule]", "148"}], ",", 
       RowBox[{"91", "\[Rule]", "92"}], ",", 
       RowBox[{"105", "\[Rule]", "50"}], ",", 
       RowBox[{"105", "\[Rule]", "106"}], ",", 
       RowBox[{"63", "\[Rule]", "36"}], ",", 
       RowBox[{"63", "\[Rule]", "148"}], ",", 
       RowBox[{"63", "\[Rule]", "8"}], ",", 
       RowBox[{"63", "\[Rule]", "8"}], ",", 
       RowBox[{"63", "\[Rule]", "120"}], ",", 
       RowBox[{"63", "\[Rule]", "120"}], ",", 
       RowBox[{"63", "\[Rule]", "64"}], ",", 
       RowBox[{"35", "\[Rule]", "64"}], ",", 
       RowBox[{"35", "\[Rule]", "36"}], ",", 
       RowBox[{"49", "\[Rule]", "106"}], ",", 
       RowBox[{"49", "\[Rule]", "78"}], ",", 
       RowBox[{"49", "\[Rule]", "50"}], ",", 
       RowBox[{"109", "\[Rule]", "54"}], ",", 
       RowBox[{"109", "\[Rule]", "166"}], ",", 
       RowBox[{"109", "\[Rule]", "110"}], ",", 
       RowBox[{"53", "\[Rule]", "110"}], ",", 
       RowBox[{"53", "\[Rule]", "82"}], ",", 
       RowBox[{"53", "\[Rule]", "54"}], ",", 
       RowBox[{"101", "\[Rule]", "46"}], ",", 
       RowBox[{"101", "\[Rule]", "158"}], ",", 
       RowBox[{"101", "\[Rule]", "102"}], ",", 
       RowBox[{"73", "\[Rule]", "46"}], ",", 
       RowBox[{"73", "\[Rule]", "18"}], ",", 
       RowBox[{"73", "\[Rule]", "18"}], ",", 
       RowBox[{"73", "\[Rule]", "130"}], ",", 
       RowBox[{"73", "\[Rule]", "74"}], ",", 
       RowBox[{"45", "\[Rule]", "102"}], ",", 
       RowBox[{"45", "\[Rule]", "74"}], ",", 
       RowBox[{"45", "\[Rule]", "46"}], ",", 
       RowBox[{"203", "\[Rule]", "148"}], ",", 
       RowBox[{"203", "\[Rule]", "148"}], ",", 
       RowBox[{"203", "\[Rule]", "204"}], ",", 
       RowBox[{"217", "\[Rule]", "162"}], ",", 
       RowBox[{"217", "\[Rule]", "218"}], ",", 
       RowBox[{"175", "\[Rule]", "148"}], ",", 
       RowBox[{"175", "\[Rule]", "148"}], ",", 
       RowBox[{"175", "\[Rule]", "120"}], ",", 
       RowBox[{"175", "\[Rule]", "176"}], ",", 
       RowBox[{"189", "\[Rule]", "162"}], ",", 
       RowBox[{"189", "\[Rule]", "162"}], ",", 
       RowBox[{"189", "\[Rule]", "134"}], ",", 
       RowBox[{"189", "\[Rule]", "190"}], ",", 
       RowBox[{"147", "\[Rule]", "92"}], ",", 
       RowBox[{"147", "\[Rule]", "204"}], ",", 
       RowBox[{"147", "\[Rule]", "204"}], ",", 
       RowBox[{"147", "\[Rule]", "64"}], ",", 
       RowBox[{"147", "\[Rule]", "176"}], ",", 
       RowBox[{"147", "\[Rule]", "176"}], ",", 
       RowBox[{"147", "\[Rule]", "148"}], ",", 
       RowBox[{"161", "\[Rule]", "218"}], ",", 
       RowBox[{"161", "\[Rule]", "78"}], ",", 
       RowBox[{"161", "\[Rule]", "190"}], ",", 
       RowBox[{"161", "\[Rule]", "190"}], ",", 
       RowBox[{"161", "\[Rule]", "162"}], ",", 
       RowBox[{"221", "\[Rule]", "166"}], ",", 
       RowBox[{"221", "\[Rule]", "222"}], ",", 
       RowBox[{"193", "\[Rule]", "166"}], ",", 
       RowBox[{"193", "\[Rule]", "138"}], ",", 
       RowBox[{"193", "\[Rule]", "194"}], ",", 
       RowBox[{"165", "\[Rule]", "110"}], ",", 
       RowBox[{"165", "\[Rule]", "222"}], ",", 
       RowBox[{"165", "\[Rule]", "82"}], ",", 
       RowBox[{"165", "\[Rule]", "194"}], ",", 
       RowBox[{"165", "\[Rule]", "166"}], ",", 
       RowBox[{"213", "\[Rule]", "158"}], ",", 
       RowBox[{"213", "\[Rule]", "158"}], ",", 
       RowBox[{"213", "\[Rule]", "214"}], ",", 
       RowBox[{"185", "\[Rule]", "158"}], ",", 
       RowBox[{"185", "\[Rule]", "186"}], ",", 
       RowBox[{"157", "\[Rule]", "102"}], ",", 
       RowBox[{"157", "\[Rule]", "214"}], ",", 
       RowBox[{"157", "\[Rule]", "214"}], ",", 
       RowBox[{"157", "\[Rule]", "186"}], ",", 
       RowBox[{"157", "\[Rule]", "158"}], ",", 
       RowBox[{"7", "\[Rule]", "64"}], ",", 
       RowBox[{"7", "\[Rule]", "64"}], ",", 
       RowBox[{"7", "\[Rule]", "8"}], ",", 
       RowBox[{"17", "\[Rule]", "74"}], ",", 
       RowBox[{"17", "\[Rule]", "74"}], ",", 
       RowBox[{"17", "\[Rule]", "18"}], ",", 
       RowBox[{"119", "\[Rule]", "64"}], ",", 
       RowBox[{"119", "\[Rule]", "64"}], ",", 
       RowBox[{"119", "\[Rule]", "176"}], ",", 
       RowBox[{"119", "\[Rule]", "120"}], ",", 
       RowBox[{"133", "\[Rule]", "78"}], ",", 
       RowBox[{"133", "\[Rule]", "78"}], ",", 
       RowBox[{"133", "\[Rule]", "190"}], ",", 
       RowBox[{"133", "\[Rule]", "134"}], ",", 
       RowBox[{"137", "\[Rule]", "82"}], ",", 
       RowBox[{"137", "\[Rule]", "82"}], ",", 
       RowBox[{"137", "\[Rule]", "194"}], ",", 
       RowBox[{"137", "\[Rule]", "138"}], ",", 
       RowBox[{"129", "\[Rule]", "74"}], ",", 
       RowBox[{"129", "\[Rule]", "130"}], ",", 
       RowBox[{"148", "\[Rule]", "153"}], ",", 
       RowBox[{"148", "\[Rule]", "145"}], ",", 
       RowBox[{"92", "\[Rule]", "97"}], ",", 
       RowBox[{"92", "\[Rule]", "89"}], ",", 
       RowBox[{"106", "\[Rule]", "97"}], ",", 
       RowBox[{"106", "\[Rule]", "111"}], ",", 
       RowBox[{"106", "\[Rule]", "103"}], ",", 
       RowBox[{"36", "\[Rule]", "41"}], ",", 
       RowBox[{"36", "\[Rule]", "33"}], ",", 
       RowBox[{"8", "\[Rule]", "13"}], ",", 
       RowBox[{"8", "\[Rule]", "5"}], ",", 
       RowBox[{"120", "\[Rule]", "125"}], ",", 
       RowBox[{"120", "\[Rule]", "117"}], ",", 
       RowBox[{"64", "\[Rule]", "69"}], ",", 
       RowBox[{"64", "\[Rule]", "61"}], ",", 
       RowBox[{"110", "\[Rule]", "103"}], ",", 
       RowBox[{"110", "\[Rule]", "111"}], ",", 
       RowBox[{"110", "\[Rule]", "107"}], ",", 
       RowBox[{"46", "\[Rule]", "39"}], ",", 
       RowBox[{"46", "\[Rule]", "51"}], ",", 
       RowBox[{"46", "\[Rule]", "47"}], ",", 
       RowBox[{"46", "\[Rule]", "43"}], ",", 
       RowBox[{"158", "\[Rule]", "151"}], ",", 
       RowBox[{"158", "\[Rule]", "163"}], ",", 
       RowBox[{"158", "\[Rule]", "159"}], ",", 
       RowBox[{"158", "\[Rule]", "155"}], ",", 
       RowBox[{"102", "\[Rule]", "95"}], ",", 
       RowBox[{"102", "\[Rule]", "107"}], ",", 
       RowBox[{"102", "\[Rule]", "103"}], ",", 
       RowBox[{"102", "\[Rule]", "99"}], ",", 
       RowBox[{"18", "\[Rule]", "11"}], ",", 
       RowBox[{"18", "\[Rule]", "23"}], ",", 
       RowBox[{"18", "\[Rule]", "19"}], ",", 
       RowBox[{"18", "\[Rule]", "15"}], ",", 
       RowBox[{"130", "\[Rule]", "123"}], ",", 
       RowBox[{"130", "\[Rule]", "135"}], ",", 
       RowBox[{"130", "\[Rule]", "131"}], ",", 
       RowBox[{"130", "\[Rule]", "127"}], ",", 
       RowBox[{"74", "\[Rule]", "67"}], ",", 
       RowBox[{"74", "\[Rule]", "79"}], ",", 
       RowBox[{"74", "\[Rule]", "75"}], ",", 
       RowBox[{"74", "\[Rule]", "71"}], ",", 
       RowBox[{"204", "\[Rule]", "209"}], ",", 
       RowBox[{"204", "\[Rule]", "201"}], ",", 
       RowBox[{"218", "\[Rule]", "209"}], ",", 
       RowBox[{"218", "\[Rule]", "223"}], ",", 
       RowBox[{"218", "\[Rule]", "215"}], ",", 
       RowBox[{"176", "\[Rule]", "181"}], ",", 
       RowBox[{"176", "\[Rule]", "173"}], ",", 
       RowBox[{"190", "\[Rule]", "181"}], ",", 
       RowBox[{"190", "\[Rule]", "195"}], ",", 
       RowBox[{"190", "\[Rule]", "187"}], ",", 
       RowBox[{"222", "\[Rule]", "215"}], ",", 
       RowBox[{"222", "\[Rule]", "223"}], ",", 
       RowBox[{"222", "\[Rule]", "219"}], ",", 
       RowBox[{"194", "\[Rule]", "187"}], ",", 
       RowBox[{"194", "\[Rule]", "195"}], ",", 
       RowBox[{"194", "\[Rule]", "191"}], ",", 
       RowBox[{"214", "\[Rule]", "207"}], ",", 
       RowBox[{"214", "\[Rule]", "219"}], ",", 
       RowBox[{"214", "\[Rule]", "215"}], ",", 
       RowBox[{"214", "\[Rule]", "211"}], ",", 
       RowBox[{"186", "\[Rule]", "179"}], ",", 
       RowBox[{"186", "\[Rule]", "191"}], ",", 
       RowBox[{"186", "\[Rule]", "187"}], ",", 
       RowBox[{"186", "\[Rule]", "183"}], ",", 
       RowBox[{"145", "\[Rule]", "90"}], ",", 
       RowBox[{"145", "\[Rule]", "202"}], ",", 
       RowBox[{"145", "\[Rule]", "202"}], ",", 
       RowBox[{"145", "\[Rule]", "62"}], ",", 
       RowBox[{"145", "\[Rule]", "174"}], ",", 
       RowBox[{"145", "\[Rule]", "174"}], ",", 
       RowBox[{"145", "\[Rule]", "146"}], ",", 
       RowBox[{"97", "\[Rule]", "42"}], ",", 
       RowBox[{"97", "\[Rule]", "154"}], ",", 
       RowBox[{"97", "\[Rule]", "98"}], ",", 
       RowBox[{"89", "\[Rule]", "34"}], ",", 
       RowBox[{"89", "\[Rule]", "146"}], ",", 
       RowBox[{"89", "\[Rule]", "90"}], ",", 
       RowBox[{"111", "\[Rule]", "56"}], ",", 
       RowBox[{"111", "\[Rule]", "168"}], ",", 
       RowBox[{"111", "\[Rule]", "112"}], ",", 
       RowBox[{"103", "\[Rule]", "48"}], ",", 
       RowBox[{"103", "\[Rule]", "160"}], ",", 
       RowBox[{"103", "\[Rule]", "104"}], ",", 
       RowBox[{"33", "\[Rule]", "90"}], ",", 
       RowBox[{"33", "\[Rule]", "62"}], ",", 
       RowBox[{"33", "\[Rule]", "34"}], ",", 
       RowBox[{"5", "\[Rule]", "62"}], ",", 
       RowBox[{"5", "\[Rule]", "62"}], ",", 
       RowBox[{"5", "\[Rule]", "6"}], ",", 
       RowBox[{"117", "\[Rule]", "62"}], ",", 
       RowBox[{"117", "\[Rule]", "62"}], ",", 
       RowBox[{"117", "\[Rule]", "174"}], ",", 
       RowBox[{"117", "\[Rule]", "118"}], ",", 
       RowBox[{"61", "\[Rule]", "34"}], ",", 
       RowBox[{"61", "\[Rule]", "146"}], ",", 
       RowBox[{"61", "\[Rule]", "6"}], ",", 
       RowBox[{"61", "\[Rule]", "6"}], ",", 
       RowBox[{"61", "\[Rule]", "118"}], ",", 
       RowBox[{"61", "\[Rule]", "118"}], ",", 
       RowBox[{"61", "\[Rule]", "62"}], ",", 
       RowBox[{"107", "\[Rule]", "52"}], ",", 
       RowBox[{"107", "\[Rule]", "164"}], ",", 
       RowBox[{"107", "\[Rule]", "108"}], ",", 
       RowBox[{"39", "\[Rule]", "96"}], ",", 
       RowBox[{"39", "\[Rule]", "68"}], ",", 
       RowBox[{"39", "\[Rule]", "40"}], ",", 
       RowBox[{"43", "\[Rule]", "100"}], ",", 
       RowBox[{"43", "\[Rule]", "72"}], ",", 
       RowBox[{"43", "\[Rule]", "44"}], ",", 
       RowBox[{"151", "\[Rule]", "96"}], ",", 
       RowBox[{"151", "\[Rule]", "208"}], ",", 
       RowBox[{"151", "\[Rule]", "208"}], ",", 
       RowBox[{"151", "\[Rule]", "68"}], ",", 
       RowBox[{"151", "\[Rule]", "180"}], ",", 
       RowBox[{"151", "\[Rule]", "180"}], ",", 
       RowBox[{"151", "\[Rule]", "152"}], ",", 
       RowBox[{"155", "\[Rule]", "100"}], ",", 
       RowBox[{"155", "\[Rule]", "212"}], ",", 
       RowBox[{"155", "\[Rule]", "212"}], ",", 
       RowBox[{"155", "\[Rule]", "72"}], ",", 
       RowBox[{"155", "\[Rule]", "184"}], ",", 
       RowBox[{"155", "\[Rule]", "184"}], ",", 
       RowBox[{"155", "\[Rule]", "156"}], ",", 
       RowBox[{"95", "\[Rule]", "40"}], ",", 
       RowBox[{"95", "\[Rule]", "152"}], ",", 
       RowBox[{"95", "\[Rule]", "96"}], ",", 
       RowBox[{"99", "\[Rule]", "44"}], ",", 
       RowBox[{"99", "\[Rule]", "156"}], ",", 
       RowBox[{"99", "\[Rule]", "100"}], ",", 
       RowBox[{"11", "\[Rule]", "68"}], ",", 
       RowBox[{"11", "\[Rule]", "68"}], ",", 
       RowBox[{"11", "\[Rule]", "12"}], ",", 
       RowBox[{"15", "\[Rule]", "72"}], ",", 
       RowBox[{"15", "\[Rule]", "72"}], ",", 
       RowBox[{"15", "\[Rule]", "16"}], ",", 
       RowBox[{"123", "\[Rule]", "68"}], ",", 
       RowBox[{"123", "\[Rule]", "68"}], ",", 
       RowBox[{"123", "\[Rule]", "180"}], ",", 
       RowBox[{"123", "\[Rule]", "124"}], ",", 
       RowBox[{"127", "\[Rule]", "72"}], ",", 
       RowBox[{"127", "\[Rule]", "72"}], ",", 
       RowBox[{"127", "\[Rule]", "184"}], ",", 
       RowBox[{"127", "\[Rule]", "128"}], ",", 
       RowBox[{"67", "\[Rule]", "40"}], ",", 
       RowBox[{"67", "\[Rule]", "152"}], ",", 
       RowBox[{"67", "\[Rule]", "12"}], ",", 
       RowBox[{"67", "\[Rule]", "12"}], ",", 
       RowBox[{"67", "\[Rule]", "124"}], ",", 
       RowBox[{"67", "\[Rule]", "124"}], ",", 
       RowBox[{"67", "\[Rule]", "68"}], ",", 
       RowBox[{"71", "\[Rule]", "44"}], ",", 
       RowBox[{"71", "\[Rule]", "156"}], ",", 
       RowBox[{"71", "\[Rule]", "16"}], ",", 
       RowBox[{"71", "\[Rule]", "16"}], ",", 
       RowBox[{"71", "\[Rule]", "128"}], ",", 
       RowBox[{"71", "\[Rule]", "128"}], ",", 
       RowBox[{"71", "\[Rule]", "72"}], ",", 
       RowBox[{"209", "\[Rule]", "154"}], ",", 
       RowBox[{"209", "\[Rule]", "154"}], ",", 
       RowBox[{"209", "\[Rule]", "210"}], ",", 
       RowBox[{"201", "\[Rule]", "146"}], ",", 
       RowBox[{"201", "\[Rule]", "146"}], ",", 
       RowBox[{"201", "\[Rule]", "202"}], ",", 
       RowBox[{"223", "\[Rule]", "168"}], ",", 
       RowBox[{"223", "\[Rule]", "168"}], ",", 
       RowBox[{"223", "\[Rule]", "224"}], ",", 
       RowBox[{"215", "\[Rule]", "160"}], ",", 
       RowBox[{"215", "\[Rule]", "160"}], ",", 
       RowBox[{"215", "\[Rule]", "216"}], ",", 
       RowBox[{"181", "\[Rule]", "154"}], ",", 
       RowBox[{"181", "\[Rule]", "154"}], ",", 
       RowBox[{"181", "\[Rule]", "126"}], ",", 
       RowBox[{"181", "\[Rule]", "182"}], ",", 
       RowBox[{"173", "\[Rule]", "146"}], ",", 
       RowBox[{"173", "\[Rule]", "146"}], ",", 
       RowBox[{"173", "\[Rule]", "118"}], ",", 
       RowBox[{"173", "\[Rule]", "174"}], ",", 
       RowBox[{"195", "\[Rule]", "168"}], ",", 
       RowBox[{"195", "\[Rule]", "168"}], ",", 
       RowBox[{"195", "\[Rule]", "140"}], ",", 
       RowBox[{"195", "\[Rule]", "196"}], ",", 
       RowBox[{"187", "\[Rule]", "160"}], ",", 
       RowBox[{"187", "\[Rule]", "160"}], ",", 
       RowBox[{"187", "\[Rule]", "132"}], ",", 
       RowBox[{"187", "\[Rule]", "188"}], ",", 
       RowBox[{"219", "\[Rule]", "164"}], ",", 
       RowBox[{"219", "\[Rule]", "164"}], ",", 
       RowBox[{"219", "\[Rule]", "220"}], ",", 
       RowBox[{"191", "\[Rule]", "164"}], ",", 
       RowBox[{"191", "\[Rule]", "164"}], ",", 
       RowBox[{"191", "\[Rule]", "136"}], ",", 
       RowBox[{"191", "\[Rule]", "192"}], ",", 
       RowBox[{"207", "\[Rule]", "152"}], ",", 
       RowBox[{"207", "\[Rule]", "152"}], ",", 
       RowBox[{"207", "\[Rule]", "208"}], ",", 
       RowBox[{"211", "\[Rule]", "156"}], ",", 
       RowBox[{"211", "\[Rule]", "156"}], ",", 
       RowBox[{"211", "\[Rule]", "212"}], ",", 
       RowBox[{"179", "\[Rule]", "152"}], ",", 
       RowBox[{"179", "\[Rule]", "152"}], ",", 
       RowBox[{"179", "\[Rule]", "124"}], ",", 
       RowBox[{"179", "\[Rule]", "180"}], ",", 
       RowBox[{"183", "\[Rule]", "156"}], ",", 
       RowBox[{"183", "\[Rule]", "156"}], ",", 
       RowBox[{"183", "\[Rule]", "128"}], ",", 
       RowBox[{"183", "\[Rule]", "184"}], ",", 
       RowBox[{"90", "\[Rule]", "91"}], ",", 
       RowBox[{"90", "\[Rule]", "87"}], ",", 
       RowBox[{"202", "\[Rule]", "203"}], ",", 
       RowBox[{"202", "\[Rule]", "199"}], ",", 
       RowBox[{"62", "\[Rule]", "63"}], ",", 
       RowBox[{"62", "\[Rule]", "59"}], ",", 
       RowBox[{"174", "\[Rule]", "175"}], ",", 
       RowBox[{"174", "\[Rule]", "171"}], ",", 
       RowBox[{"146", "\[Rule]", "147"}], ",", 
       RowBox[{"146", "\[Rule]", "143"}], ",", 
       RowBox[{"34", "\[Rule]", "35"}], ",", 
       RowBox[{"34", "\[Rule]", "31"}], ",", 
       RowBox[{"6", "\[Rule]", "7"}], ",", 
       RowBox[{"6", "\[Rule]", "3"}], ",", 
       RowBox[{"118", "\[Rule]", "119"}], ",", 
       RowBox[{"118", "\[Rule]", "115"}], ",", 
       RowBox[{"96", "\[Rule]", "87"}], ",", 
       RowBox[{"96", "\[Rule]", "101"}], ",", 
       RowBox[{"96", "\[Rule]", "93"}], ",", 
       RowBox[{"68", "\[Rule]", "59"}], ",", 
       RowBox[{"68", "\[Rule]", "73"}], ",", 
       RowBox[{"68", "\[Rule]", "65"}], ",", 
       RowBox[{"40", "\[Rule]", "31"}], ",", 
       RowBox[{"40", "\[Rule]", "45"}], ",", 
       RowBox[{"40", "\[Rule]", "37"}], ",", 
       RowBox[{"100", "\[Rule]", "93"}], ",", 
       RowBox[{"100", "\[Rule]", "101"}], ",", 
       RowBox[{"72", "\[Rule]", "65"}], ",", 
       RowBox[{"72", "\[Rule]", "73"}], ",", 
       RowBox[{"44", "\[Rule]", "37"}], ",", 
       RowBox[{"44", "\[Rule]", "45"}], ",", 
       RowBox[{"208", "\[Rule]", "199"}], ",", 
       RowBox[{"208", "\[Rule]", "213"}], ",", 
       RowBox[{"208", "\[Rule]", "205"}], ",", 
       RowBox[{"180", "\[Rule]", "171"}], ",", 
       RowBox[{"180", "\[Rule]", "185"}], ",", 
       RowBox[{"180", "\[Rule]", "177"}], ",", 
       RowBox[{"152", "\[Rule]", "143"}], ",", 
       RowBox[{"152", "\[Rule]", "157"}], ",", 
       RowBox[{"152", "\[Rule]", "149"}], ",", 
       RowBox[{"212", "\[Rule]", "205"}], ",", 
       RowBox[{"212", "\[Rule]", "213"}], ",", 
       RowBox[{"184", "\[Rule]", "177"}], ",", 
       RowBox[{"184", "\[Rule]", "185"}], ",", 
       RowBox[{"156", "\[Rule]", "149"}], ",", 
       RowBox[{"156", "\[Rule]", "157"}], ",", 
       RowBox[{"12", "\[Rule]", "3"}], ",", 
       RowBox[{"12", "\[Rule]", "17"}], ",", 
       RowBox[{"12", "\[Rule]", "9"}], ",", 
       RowBox[{"16", "\[Rule]", "9"}], ",", 
       RowBox[{"16", "\[Rule]", "17"}], ",", 
       RowBox[{"124", "\[Rule]", "115"}], ",", 
       RowBox[{"124", "\[Rule]", "129"}], ",", 
       RowBox[{"124", "\[Rule]", "121"}], ",", 
       RowBox[{"128", "\[Rule]", "121"}], ",", 
       RowBox[{"128", "\[Rule]", "129"}], ",", 
       RowBox[{"87", "\[Rule]", "32"}], ",", 
       RowBox[{"87", "\[Rule]", "144"}], ",", 
       RowBox[{"87", "\[Rule]", "88"}], ",", 
       RowBox[{"199", "\[Rule]", "144"}], ",", 
       RowBox[{"199", "\[Rule]", "144"}], ",", 
       RowBox[{"199", "\[Rule]", "200"}], ",", 
       RowBox[{"59", "\[Rule]", "144"}], ",", 
       RowBox[{"59", "\[Rule]", "4"}], ",", 
       RowBox[{"59", "\[Rule]", "116"}], ",", 
       RowBox[{"59", "\[Rule]", "116"}], ",", 
       RowBox[{"59", "\[Rule]", "60"}], ",", 
       RowBox[{"171", "\[Rule]", "144"}], ",", 
       RowBox[{"171", "\[Rule]", "144"}], ",", 
       RowBox[{"171", "\[Rule]", "116"}], ",", 
       RowBox[{"171", "\[Rule]", "172"}], ",", 
       RowBox[{"143", "\[Rule]", "88"}], ",", 
       RowBox[{"143", "\[Rule]", "200"}], ",", 
       RowBox[{"143", "\[Rule]", "200"}], ",", 
       RowBox[{"143", "\[Rule]", "60"}], ",", 
       RowBox[{"143", "\[Rule]", "172"}], ",", 
       RowBox[{"143", "\[Rule]", "172"}], ",", 
       RowBox[{"143", "\[Rule]", "144"}], ",", 
       RowBox[{"31", "\[Rule]", "88"}], ",", 
       RowBox[{"31", "\[Rule]", "32"}], ",", 
       RowBox[{"3", "\[Rule]", "60"}], ",", 
       RowBox[{"3", "\[Rule]", "4"}], ",", 
       RowBox[{"115", "\[Rule]", "60"}], ",", 
       RowBox[{"115", "\[Rule]", "60"}], ",", 
       RowBox[{"115", "\[Rule]", "172"}], ",", 
       RowBox[{"115", "\[Rule]", "116"}], ",", 
       RowBox[{"93", "\[Rule]", "38"}], ",", 
       RowBox[{"93", "\[Rule]", "150"}], ",", 
       RowBox[{"93", "\[Rule]", "94"}], ",", 
       RowBox[{"65", "\[Rule]", "38"}], ",", 
       RowBox[{"65", "\[Rule]", "150"}], ",", 
       RowBox[{"65", "\[Rule]", "10"}], ",", 
       RowBox[{"65", "\[Rule]", "122"}], ",", 
       RowBox[{"65", "\[Rule]", "66"}], ",", 
       RowBox[{"37", "\[Rule]", "94"}], ",", 
       RowBox[{"37", "\[Rule]", "66"}], ",", 
       RowBox[{"37", "\[Rule]", "38"}], ",", 
       RowBox[{"205", "\[Rule]", "150"}], ",", 
       RowBox[{"205", "\[Rule]", "150"}], ",", 
       RowBox[{"205", "\[Rule]", "206"}], ",", 
       RowBox[{"177", "\[Rule]", "150"}], ",", 
       RowBox[{"177", "\[Rule]", "150"}], ",", 
       RowBox[{"177", "\[Rule]", "122"}], ",", 
       RowBox[{"177", "\[Rule]", "178"}], ",", 
       RowBox[{"149", "\[Rule]", "94"}], ",", 
       RowBox[{"149", "\[Rule]", "206"}], ",", 
       RowBox[{"149", "\[Rule]", "206"}], ",", 
       RowBox[{"149", "\[Rule]", "66"}], ",", 
       RowBox[{"149", "\[Rule]", "178"}], ",", 
       RowBox[{"149", "\[Rule]", "178"}], ",", 
       RowBox[{"149", "\[Rule]", "150"}], ",", 
       RowBox[{"9", "\[Rule]", "66"}], ",", 
       RowBox[{"9", "\[Rule]", "10"}], ",", 
       RowBox[{"121", "\[Rule]", "66"}], ",", 
       RowBox[{"121", "\[Rule]", "178"}], ",", 
       RowBox[{"121", "\[Rule]", "122"}], ",", 
       RowBox[{"32", "\[Rule]", "39"}], ",", 
       RowBox[{"32", "\[Rule]", "33"}], ",", 
       RowBox[{"32", "\[Rule]", "29"}], ",", 
       RowBox[{"144", "\[Rule]", "151"}], ",", 
       RowBox[{"144", "\[Rule]", "145"}], ",", 
       RowBox[{"144", "\[Rule]", "141"}], ",", 
       RowBox[{"88", "\[Rule]", "95"}], ",", 
       RowBox[{"88", "\[Rule]", "89"}], ",", 
       RowBox[{"88", "\[Rule]", "85"}], ",", 
       RowBox[{"200", "\[Rule]", "207"}], ",", 
       RowBox[{"200", "\[Rule]", "201"}], ",", 
       RowBox[{"200", "\[Rule]", "197"}], ",", 
       RowBox[{"4", "\[Rule]", "11"}], ",", 
       RowBox[{"4", "\[Rule]", "5"}], ",", 
       RowBox[{"4", "\[Rule]", "1"}], ",", 
       RowBox[{"116", "\[Rule]", "123"}], ",", 
       RowBox[{"116", "\[Rule]", "117"}], ",", 
       RowBox[{"116", "\[Rule]", "113"}], ",", 
       RowBox[{"60", "\[Rule]", "67"}], ",", 
       RowBox[{"60", "\[Rule]", "61"}], ",", 
       RowBox[{"60", "\[Rule]", "57"}], ",", 
       RowBox[{"172", "\[Rule]", "179"}], ",", 
       RowBox[{"172", "\[Rule]", "173"}], ",", 
       RowBox[{"172", "\[Rule]", "169"}], ",", 
       RowBox[{"38", "\[Rule]", "29"}], ",", 
       RowBox[{"38", "\[Rule]", "43"}], ",", 
       RowBox[{"38", "\[Rule]", "39"}], ",", 
       RowBox[{"150", "\[Rule]", "141"}], ",", 
       RowBox[{"150", "\[Rule]", "155"}], ",", 
       RowBox[{"150", "\[Rule]", "151"}], ",", 
       RowBox[{"94", "\[Rule]", "85"}], ",", 
       RowBox[{"94", "\[Rule]", "99"}], ",", 
       RowBox[{"94", "\[Rule]", "95"}], ",", 
       RowBox[{"10", "\[Rule]", "1"}], ",", 
       RowBox[{"10", "\[Rule]", "15"}], ",", 
       RowBox[{"10", "\[Rule]", "11"}], ",", 
       RowBox[{"122", "\[Rule]", "113"}], ",", 
       RowBox[{"122", "\[Rule]", "127"}], ",", 
       RowBox[{"122", "\[Rule]", "123"}], ",", 
       RowBox[{"66", "\[Rule]", "57"}], ",", 
       RowBox[{"66", "\[Rule]", "71"}], ",", 
       RowBox[{"66", "\[Rule]", "67"}], ",", 
       RowBox[{"206", "\[Rule]", "197"}], ",", 
       RowBox[{"206", "\[Rule]", "211"}], ",", 
       RowBox[{"206", "\[Rule]", "207"}], ",", 
       RowBox[{"178", "\[Rule]", "169"}], ",", 
       RowBox[{"178", "\[Rule]", "183"}], ",", 
       RowBox[{"178", "\[Rule]", "179"}], ",", 
       RowBox[{"29", "\[Rule]", "86"}], ",", 
       RowBox[{"29", "\[Rule]", "58"}], ",", 
       RowBox[{"29", "\[Rule]", "30"}], ",", 
       RowBox[{"141", "\[Rule]", "86"}], ",", 
       RowBox[{"141", "\[Rule]", "198"}], ",", 
       RowBox[{"141", "\[Rule]", "198"}], ",", 
       RowBox[{"141", "\[Rule]", "58"}], ",", 
       RowBox[{"141", "\[Rule]", "170"}], ",", 
       RowBox[{"141", "\[Rule]", "170"}], ",", 
       RowBox[{"141", "\[Rule]", "142"}], ",", 
       RowBox[{"85", "\[Rule]", "30"}], ",", 
       RowBox[{"85", "\[Rule]", "142"}], ",", 
       RowBox[{"85", "\[Rule]", "86"}], ",", 
       RowBox[{"197", "\[Rule]", "142"}], ",", 
       RowBox[{"197", "\[Rule]", "142"}], ",", 
       RowBox[{"197", "\[Rule]", "198"}], ",", 
       RowBox[{"1", "\[Rule]", "58"}], ",", 
       RowBox[{"1", "\[Rule]", "58"}], ",", 
       RowBox[{"1", "\[Rule]", "2"}], ",", 
       RowBox[{"113", "\[Rule]", "58"}], ",", 
       RowBox[{"113", "\[Rule]", "58"}], ",", 
       RowBox[{"113", "\[Rule]", "170"}], ",", 
       RowBox[{"113", "\[Rule]", "114"}], ",", 
       RowBox[{"57", "\[Rule]", "30"}], ",", 
       RowBox[{"57", "\[Rule]", "142"}], ",", 
       RowBox[{"57", "\[Rule]", "2"}], ",", 
       RowBox[{"57", "\[Rule]", "2"}], ",", 
       RowBox[{"57", "\[Rule]", "114"}], ",", 
       RowBox[{"57", "\[Rule]", "114"}], ",", 
       RowBox[{"57", "\[Rule]", "58"}], ",", 
       RowBox[{"169", "\[Rule]", "142"}], ",", 
       RowBox[{"169", "\[Rule]", "142"}], ",", 
       RowBox[{"169", "\[Rule]", "114"}], ",", 
       RowBox[{"169", "\[Rule]", "170"}], ",", 
       RowBox[{"86", "\[Rule]", "93"}], ",", 
       RowBox[{"86", "\[Rule]", "87"}], ",", 
       RowBox[{"58", "\[Rule]", "65"}], ",", 
       RowBox[{"58", "\[Rule]", "59"}], ",", 
       RowBox[{"30", "\[Rule]", "37"}], ",", 
       RowBox[{"30", "\[Rule]", "31"}], ",", 
       RowBox[{"198", "\[Rule]", "205"}], ",", 
       RowBox[{"198", "\[Rule]", "199"}], ",", 
       RowBox[{"170", "\[Rule]", "177"}], ",", 
       RowBox[{"170", "\[Rule]", "171"}], ",", 
       RowBox[{"142", "\[Rule]", "149"}], ",", 
       RowBox[{"142", "\[Rule]", "143"}], ",", 
       RowBox[{"2", "\[Rule]", "9"}], ",", 
       RowBox[{"2", "\[Rule]", "3"}], ",", 
       RowBox[{"114", "\[Rule]", "121"}], ",", 
       RowBox[{"114", "\[Rule]", "115"}]}], "}"}], ",", 
     RowBox[{"EdgeWeight", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "c", ",", "d", ",", "i", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "i", ",", "c", ",", "d", ",", "i", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "c", ",", "g", ",", "i", ",", "c", ",", "g", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "h", ",", "i", ",", "f", ",", "i", ",", "b", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "g", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "f", ",", "h", ",", "i", ",", "c", ",", 
        "g", ",", "i", ",", "f", ",", "h", ",", "i", ",", "b", ",", "e", ",", 
        "f", ",", "g", ",", "i", ",", "c", ",", "g", ",", "i", ",", "e", ",", 
        "f", ",", "i", ",", "e", ",", "i", ",", "a", ",", "b", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "f", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "f", ",", "i", ",", "b", ",", "f", ",", 
        "i", ",", "a", ",", "c", ",", "e", ",", "g", ",", "i", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "b", ",", 
        "i", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "a", ",", "c", ",", "d", ",", 
        "e", ",", "g", ",", "h", ",", "i", ",", "f", ",", "h", ",", "i", ",", 
        "f", ",", "h", ",", "i", ",", "f", ",", "h", ",", "i", ",", "f", ",", 
        "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "b", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "f", ",", "h", ",", 
        "i", ",", "c", ",", "g", ",", "i", ",", "c", ",", "g", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", 
        "f", ",", "h", ",", "i", ",", "f", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "b", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "i", ",", "e", ",", "f", ",", "i", ",", "e", ",", "f", ",", 
        "i", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "f", ",", "i", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "f", ",", "i", ",", "e", ",", 
        "f", ",", "i", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "f", ",", "i", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "f", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "i", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "f", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "i", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "i", ",", "f", ",", "h", ",", "i", ",", "b", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "f", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "c", ",", "i", ",", 
        "a", ",", "c", ",", "i", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "c", ",", "g", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "f", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "i", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "i", ",", "b", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "f", ",", 
        "i", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u"}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"init3", "=", 
   RowBox[{"{", "27", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bad3", "=", 
   RowBox[{"{", 
    RowBox[{
    "2", ",", "34", ",", "68", ",", "98", ",", "128", ",", "160", ",", "192", 
     ",", "224", ",", "1", ",", "33", ",", "67", ",", "97", ",", "127", ",", 
     "159", ",", "191", ",", "223"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lag3", "=", "8"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"graphical3", "=", "0"}], ";"}]}], "Input",
 CellChangeTimes->{{3.686025994957309*^9, 3.686026099831461*^9}, {
   3.6860261438122177`*^9, 3.686026176931148*^9}, 3.686026214223475*^9, {
   3.6860262647459717`*^9, 3.686026264982861*^9}, {3.686034622552107*^9, 
   3.686034628125643*^9}, {3.686046104270862*^9, 3.686046104850851*^9}, {
   3.686046154719606*^9, 3.686046158030952*^9}, 3.686047550621757*^9, {
   3.6930373931279917`*^9, 3.693037399556898*^9}, 3.693037472771635*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"main", "[", 
  RowBox[{"g3", ",", "init3", ",", "bad3", ",", "lag3", ",", "graphical3"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6860260905272207`*^9, 3.6860260975512857`*^9}, 
   3.686033496996408*^9, {3.693037404157632*^9, 3.693037406101569*^9}}],

Cell[CellGroupData[{

Cell[BoxData["\<\"Under delay = 0 :\"\>"], "Print",
 CellChangeTimes->{3.714820891968945*^9}],

Cell[BoxData[
 RowBox[{"\[LeftAssociation]", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"27", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "d", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"77", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"b", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i"}], "}"}]}],
    ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"81", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"b", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i"}], "}"}]}],
    ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"21", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"i", ",", "c", ",", "d"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"25", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"i", ",", "c", ",", "d"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"41", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"g", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"55", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"g", ",", "c", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"47", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "g", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"153", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"e", ",", "g", ",", "h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"167", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "e", ",", "g", ",", "h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"159", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"13", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "d", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"19", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "d"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"125", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"139", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"131", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"69", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h"}], 
     "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"83", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "i", ",", "e", ",", "f", ",", "b", ",", "d", ",", "g", ",", "h"}], 
     "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"75", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"b", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"51", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "g", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"163", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "e", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"23", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "d"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"135", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"79", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"b", ",", "d", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"91", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "h", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"105", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "f", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"63", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i"}], "}"}]}],
    ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"35", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "g", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"49", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"g", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"109", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"f", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"53", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"i", ",", "g", ",", "c"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"101", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"f", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"73", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "b", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"45", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"203", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"e", ",", "f", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"217", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"175", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "f", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"189", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "f", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"147", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i"}], "}"}]}],
    ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"161", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "e", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"221", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"193", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "f", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"165", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "e"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"213", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"185", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"157", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "a", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"7", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"i", ",", "c", ",", "d"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"17", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"119", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"i", ",", "a", ",", "b", ",", "c"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"133", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"137", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"129", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"145", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i"}], 
     "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"97", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"89", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"111", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"i", ",", "f", ",", "h"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"103", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"f", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"33", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "d"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"117", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"61", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"d", ",", "g", ",", "h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"107", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"i", ",", "f", ",", "h"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"39", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"43", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "g", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"151", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"155", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "e", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"95", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"i", ",", "f", ",", "h"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"99", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"i", ",", "f", ",", "h"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"11", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"15", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "d"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"123", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"127", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"67", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"71", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"b", ",", "d", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"209", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"e", ",", "f"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"201", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"i", ",", "e", ",", "f"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"223", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"215", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"181", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"i", ",", "a", ",", "b", ",", "f"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"173", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"i", ",", "a", ",", "b", ",", "f"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"195", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"i", ",", "a", ",", "b", ",", "f"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"187", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"219", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"e", ",", "f"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"191", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"207", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"e", ",", "f"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"211", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"e", ",", "f"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"179", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"183", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"87", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"199", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"e", ",", "f", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"59", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "d", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"171", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"143", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i"}], "}"}]}],
    ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"31", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "c", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"115", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "c", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"93", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"f", ",", "h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"65", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"b", ",", "d"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"37", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"205", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"e", ",", "f", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"177", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"149", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i"}], "}"}]}],
    ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"9", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"121", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "c", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"29", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "g", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"141", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "a", ",", "e", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i"}], 
     "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"85", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"i", ",", "f", ",", "h"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"197", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"i", ",", "e", ",", "f"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"113", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"57", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"b", ",", "d", ",", "g", ",", "h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"169", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"i", ",", "a", ",", "b", ",", "f"}], "}"}]}]}], 
  "\[RightAssociation]"}]], "Print",
 CellChangeTimes->{3.714820892030067*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Under delay = \"\>", "\[InvisibleSpace]", "1", 
   "\[InvisibleSpace]", "\<\" :\"\>"}],
  SequenceForm["Under delay = ", 1, " :"],
  Editable->False]], "Print",
 CellChangeTimes->{3.714820892033885*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"84", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"b", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i"}], "}"}]}],
    ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"28", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "d", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"50", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"g", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"162", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"22", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "d"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"134", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"78", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"b", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"54", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "g", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"166", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"26", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "d"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"138", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"82", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"b", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"98", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"70", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"e", ",", "f", ",", "g", ",", "h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"42", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "g", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"112", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "f", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"56", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"g", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"104", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "f", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"76", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "b", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"48", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "i", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"210", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"182", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "f", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"154", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "e", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"224", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"196", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "f", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"168", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "e", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"216", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"188", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"160", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"14", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "d", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"20", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"126", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"140", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"132", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"108", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"f", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"80", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "b", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"52", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"220", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"192", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"164", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "a", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"24", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"136", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"148", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"e", ",", "g", ",", "h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"92", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"106", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"36", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"8", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "d"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"120", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"64", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"d", ",", "g", ",", "h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"110", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"f", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"46", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"158", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"102", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"f", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"18", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"130", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"74", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"204", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"e", ",", "f"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"218", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"176", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "f", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"190", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"222", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"194", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"214", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"186", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"90", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "h", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"202", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"e", ",", "f", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"62", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "d", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"174", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"146", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "d", ",", "g", ",", "h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"34", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"118", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "c", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"96", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "i", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"68", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"40", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "c", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"100", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"f", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"72", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "b", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"44", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"208", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"180", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"152", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "a", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"212", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"184", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"156", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "a", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"12", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"16", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"124", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"128", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"32", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"144", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"88", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"200", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"e", ",", "f"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"116", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"60", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"172", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"38", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"150", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"94", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"f", ",", "h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"10", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"122", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"66", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"206", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"e", ",", "f"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"178", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"86", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"58", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "d", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"30", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "c", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"198", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"e", ",", "f", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"170", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"142", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i"}], "}"}]}],
    ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"114", ",", 
      RowBox[{"{", "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "c", "}"}]}]}], "}"}]], "Print",
 CellChangeTimes->{3.714820892039554*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Under delay = \"\>", "\[InvisibleSpace]", "2", 
   "\[InvisibleSpace]", "\<\" :\"\>"}],
  SequenceForm["Under delay = ", 2, " :"],
  Editable->False]], "Print",
 CellChangeTimes->{3.714820892040132*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"27", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"c", ",", "d"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"b", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i"}], "}"}]}],
    ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"27", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "d", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"77", ",", 
      RowBox[{"{", 
       RowBox[{"{", "b", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"g", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"77", ",", 
      RowBox[{"{", 
       RowBox[{"{", "d", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"77", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"e", ",", "f"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "d"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"77", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"g", ",", "h"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"77", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"b", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"81", ",", 
      RowBox[{"{", 
       RowBox[{"{", "b", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "g", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"81", ",", 
      RowBox[{"{", 
       RowBox[{"{", "d", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"81", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"e", ",", "f"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "d"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"81", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"g", ",", "h"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"81", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"b", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"21", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "d"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"21", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"c", ",", "d"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"b", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"25", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "d"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"25", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"c", ",", "d"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"b", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"41", ",", 
      RowBox[{"{", 
       RowBox[{"{", "c", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"41", ",", 
      RowBox[{"{", 
       RowBox[{"{", "g", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"e", ",", "f", ",", "g", ",", "h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"41", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "g", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"55", ",", 
      RowBox[{"{", 
       RowBox[{"{", "g", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"b", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i"}], "}"}]}],
    ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"55", ",", 
      RowBox[{"{", 
       RowBox[{"{", "c", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "f", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"55", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"g", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"47", ",", 
      RowBox[{"{", 
       RowBox[{"{", "c", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "f", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"47", ",", 
      RowBox[{"{", 
       RowBox[{"{", "g", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "b", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"47", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "i", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"153", ",", 
      RowBox[{"{", 
       RowBox[{"{", "a", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"153", ",", 
      RowBox[{"{", 
       RowBox[{"{", "e", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"e", ",", "f", ",", "g", ",", "h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"153", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"c", ",", "d"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"153", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"g", ",", "h"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "f", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"153", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "e", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"167", ",", 
      RowBox[{"{", 
       RowBox[{"{", "e", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"b", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i"}], "}"}]}],
    ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"167", ",", 
      RowBox[{"{", 
       RowBox[{"{", "a", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "f", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"167", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"c", ",", "d"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"167", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"g", ",", "h"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "f", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"167", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "e", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"159", ",", 
      RowBox[{"{", 
       RowBox[{"{", "a", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"159", ",", 
      RowBox[{"{", 
       RowBox[{"{", "e", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"159", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"c", ",", "d"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"159", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"g", ",", "h"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"159", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"13", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"c", ",", "d"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"e", ",", "f", ",", "g", ",", "h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"13", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "d", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"19", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"c", ",", "d"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "b", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"19", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"125", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"e", ",", "f", ",", "g", ",", "h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"125", ",", 
      RowBox[{"{", 
       RowBox[{"{", "c", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "f", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"125", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"139", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"b", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i"}], "}"}]}],
    ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"139", ",", 
      RowBox[{"{", 
       RowBox[{"{", "c", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "f", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"139", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"131", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "b", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"131", ",", 
      RowBox[{"{", 
       RowBox[{"{", "c", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"131", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"69", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"e", ",", "f", ",", "g", ",", "h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"69", ",", 
      RowBox[{"{", 
       RowBox[{"{", "b", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "g", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"69", ",", 
      RowBox[{"{", 
       RowBox[{"{", "d", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "e", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"69", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"e", ",", "f"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "d", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"69", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"g", ",", "h"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"83", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"b", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i"}], "}"}]}],
    ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"83", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"e", ",", "f"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "d", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"83", ",", 
      RowBox[{"{", 
       RowBox[{"{", "b", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"g", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"83", ",", 
      RowBox[{"{", 
       RowBox[{"{", "d", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "e", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"83", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"g", ",", "h"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"75", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "b", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"75", ",", 
      RowBox[{"{", 
       RowBox[{"{", "b", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "i", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"75", ",", 
      RowBox[{"{", 
       RowBox[{"{", "d", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"75", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"e", ",", "f"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"75", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"g", ",", "h"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"51", ",", 
      RowBox[{"{", 
       RowBox[{"{", "c", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"f", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"51", ",", 
      RowBox[{"{", 
       RowBox[{"{", "g", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "b", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"51", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"163", ",", 
      RowBox[{"{", 
       RowBox[{"{", "a", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"f", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"163", ",", 
      RowBox[{"{", 
       RowBox[{"{", "e", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "b", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"163", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"c", ",", "d"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"163", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"g", ",", "h"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"163", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "a", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"23", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"c", ",", "d"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "b", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"23", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"135", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "b", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"135", ",", 
      RowBox[{"{", 
       RowBox[{"{", "c", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"135", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"79", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "b", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"79", ",", 
      RowBox[{"{", 
       RowBox[{"{", "b", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"79", ",", 
      RowBox[{"{", 
       RowBox[{"{", "d", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "a", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"79", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"e", ",", "f"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"79", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"g", ",", "h"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"91", ",", 
      RowBox[{"{", 
       RowBox[{"{", "h", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"e", ",", "g", ",", "h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"91", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"105", ",", 
      RowBox[{"{", 
       RowBox[{"{", "f", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"g", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"105", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"63", ",", 
      RowBox[{"{", 
       RowBox[{"{", "d", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"e", ",", "g", ",", "h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"63", ",", 
      RowBox[{"{", 
       RowBox[{"{", "b", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"63", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"e", ",", "f"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "d"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"63", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"g", ",", "h"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"63", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"d", ",", "g", ",", "h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"35", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"35", ",", 
      RowBox[{"{", 
       RowBox[{"{", "g", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"d", ",", "g", ",", "h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"49", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"g", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"49", ",", 
      RowBox[{"{", 
       RowBox[{"{", "g", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"b", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"49", ",", 
      RowBox[{"{", 
       RowBox[{"{", "c", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"109", ",", 
      RowBox[{"{", 
       RowBox[{"{", "f", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "g", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"109", ",", 
      RowBox[{"{", 
       RowBox[{"{", "h", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"109", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"f", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"53", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "g", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"53", ",", 
      RowBox[{"{", 
       RowBox[{"{", "g", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"b", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"53", ",", 
      RowBox[{"{", 
       RowBox[{"{", "c", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"f", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"101", ",", 
      RowBox[{"{", 
       RowBox[{"{", "f", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"101", ",", 
      RowBox[{"{", 
       RowBox[{"{", "h", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"101", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"f", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"73", ",", 
      RowBox[{"{", 
       RowBox[{"{", "b", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"73", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"e", ",", "f"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"73", ",", 
      RowBox[{"{", 
       RowBox[{"{", "g", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"73", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"45", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"45", ",", 
      RowBox[{"{", 
       RowBox[{"{", "c", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"f", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"45", ",", 
      RowBox[{"{", 
       RowBox[{"{", "g", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"203", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"e", ",", "f"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"e", ",", "g", ",", "h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"203", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"e", ",", "f"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"217", ",", 
      RowBox[{"{", 
       RowBox[{"{", "e", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"217", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"175", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"e", ",", "g", ",", "h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"175", ",", 
      RowBox[{"{", 
       RowBox[{"{", "f", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"175", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "f", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"189", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"189", ",", 
      RowBox[{"{", 
       RowBox[{"{", "f", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"189", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"147", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"e", ",", "g", ",", "h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"147", ",", 
      RowBox[{"{", 
       RowBox[{"{", "a", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"147", ",", 
      RowBox[{"{", 
       RowBox[{"{", "e", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"d", ",", "g", ",", "h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"147", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"c", ",", "d"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"e", ",", "f"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"147", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"g", ",", "h"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "f", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"161", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"161", ",", 
      RowBox[{"{", 
       RowBox[{"{", "e", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"b", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"161", ",", 
      RowBox[{"{", 
       RowBox[{"{", "d", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"161", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"g", ",", "h"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"221", ",", 
      RowBox[{"{", 
       RowBox[{"{", "f", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"221", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"193", ",", 
      RowBox[{"{", 
       RowBox[{"{", "b", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"193", ",", 
      RowBox[{"{", 
       RowBox[{"{", "f", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"193", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"165", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"165", ",", 
      RowBox[{"{", 
       RowBox[{"{", "e", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"b", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"165", ",", 
      RowBox[{"{", 
       RowBox[{"{", "a", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"f", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"165", ",", 
      RowBox[{"{", 
       RowBox[{"{", "c", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"165", ",", 
      RowBox[{"{", 
       RowBox[{"{", "g", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"213", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"e", ",", "f"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"213", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"185", ",", 
      RowBox[{"{", 
       RowBox[{"{", "a", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"185", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"157", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"157", ",", 
      RowBox[{"{", 
       RowBox[{"{", "a", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"f", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"157", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"c", ",", "d"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"157", ",", 
      RowBox[{"{", 
       RowBox[{"{", "h", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"7", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "d"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"7", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"c", ",", "d"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"d", ",", "g", ",", "h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"17", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"17", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"c", ",", "d"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"119", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"119", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"d", ",", "g", ",", "h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"119", ",", 
      RowBox[{"{", 
       RowBox[{"{", "c", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "f", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"133", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"133", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"b", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"133", ",", 
      RowBox[{"{", 
       RowBox[{"{", "c", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"137", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"137", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"b", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"137", ",", 
      RowBox[{"{", 
       RowBox[{"{", "c", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"129", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"129", ",", 
      RowBox[{"{", 
       RowBox[{"{", "b", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"145", ",", 
      RowBox[{"{", 
       RowBox[{"{", "a", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "h", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"145", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"c", ",", "d"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"e", ",", "f", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"145", ",", 
      RowBox[{"{", 
       RowBox[{"{", "e", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "d", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"145", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"g", ",", "h"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"145", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "d", ",", "g", ",", "h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"97", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"97", ",", 
      RowBox[{"{", 
       RowBox[{"{", "f", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"97", ",", 
      RowBox[{"{", 
       RowBox[{"{", "h", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"89", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "h", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"89", ",", 
      RowBox[{"{", 
       RowBox[{"{", "h", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "d", ",", "g", ",", "h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"89", ",", 
      RowBox[{"{", 
       RowBox[{"{", "f", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"111", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "f", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"111", ",", 
      RowBox[{"{", 
       RowBox[{"{", "f", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"g", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"111", ",", 
      RowBox[{"{", 
       RowBox[{"{", "h", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "e", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"103", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "f", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"103", ",", 
      RowBox[{"{", 
       RowBox[{"{", "f", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "i", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"103", ",", 
      RowBox[{"{", 
       RowBox[{"{", "h", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"33", ",", 
      RowBox[{"{", 
       RowBox[{"{", "c", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"33", ",", 
      RowBox[{"{", 
       RowBox[{"{", "g", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"33", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"c", ",", "d"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "d", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"117", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "d", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"117", ",", 
      RowBox[{"{", 
       RowBox[{"{", "c", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"117", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "c", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"61", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "d", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"61", ",", 
      RowBox[{"{", 
       RowBox[{"{", "d", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "d", ",", "g", ",", "h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"61", ",", 
      RowBox[{"{", 
       RowBox[{"{", "b", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"61", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"e", ",", "f"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"61", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"g", ",", "h"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "c", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"107", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"f", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"107", ",", 
      RowBox[{"{", 
       RowBox[{"{", "f", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"107", ",", 
      RowBox[{"{", 
       RowBox[{"{", "h", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "a", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"39", ",", 
      RowBox[{"{", 
       RowBox[{"{", "c", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "i", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"39", ",", 
      RowBox[{"{", 
       RowBox[{"{", "g", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"39", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "c", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"43", ",", 
      RowBox[{"{", 
       RowBox[{"{", "c", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"f", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"43", ",", 
      RowBox[{"{", 
       RowBox[{"{", "g", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "b", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"43", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"151", ",", 
      RowBox[{"{", 
       RowBox[{"{", "a", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "i", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"151", ",", 
      RowBox[{"{", 
       RowBox[{"{", "e", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"151", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"c", ",", "d"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"151", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"g", ",", "h"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"151", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "a", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"155", ",", 
      RowBox[{"{", 
       RowBox[{"{", "a", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"f", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"155", ",", 
      RowBox[{"{", 
       RowBox[{"{", "e", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "b", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"155", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"c", ",", "d"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"155", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"g", ",", "h"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"155", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "a", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"95", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "i", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"95", ",", 
      RowBox[{"{", 
       RowBox[{"{", "f", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "c", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"95", ",", 
      RowBox[{"{", 
       RowBox[{"{", "h", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "a", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"99", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"f", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"99", ",", 
      RowBox[{"{", 
       RowBox[{"{", "f", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"99", ",", 
      RowBox[{"{", 
       RowBox[{"{", "h", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "a", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"11", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"c", ",", "d"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"11", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"15", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"c", ",", "d"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "b", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"15", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"123", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"123", ",", 
      RowBox[{"{", 
       RowBox[{"{", "c", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"123", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"127", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"127", ",", 
      RowBox[{"{", 
       RowBox[{"{", "c", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"127", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"67", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"67", ",", 
      RowBox[{"{", 
       RowBox[{"{", "b", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"67", ",", 
      RowBox[{"{", 
       RowBox[{"{", "d", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"67", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"e", ",", "f"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"67", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"g", ",", "h"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"71", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "b", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"71", ",", 
      RowBox[{"{", 
       RowBox[{"{", "b", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"71", ",", 
      RowBox[{"{", 
       RowBox[{"{", "d", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "a", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"71", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"e", ",", "f"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"71", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"g", ",", "h"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"209", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"209", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"e", ",", "f"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "e", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"201", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"e", ",", "f", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"201", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"e", ",", "f"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "d", ",", "g", ",", "h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"223", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"223", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"e", ",", "f"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"215", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"215", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"e", ",", "f"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"181", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "f", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"181", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "e", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"181", ",", 
      RowBox[{"{", 
       RowBox[{"{", "f", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"173", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"173", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "d", ",", "g", ",", "h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"173", ",", 
      RowBox[{"{", 
       RowBox[{"{", "f", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "c", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"195", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "f", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"195", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "e", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"195", ",", 
      RowBox[{"{", 
       RowBox[{"{", "f", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"187", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"187", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"187", ",", 
      RowBox[{"{", 
       RowBox[{"{", "f", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"219", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"219", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"e", ",", "f"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "a", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"191", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"191", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"191", ",", 
      RowBox[{"{", 
       RowBox[{"{", "f", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"207", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"207", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"e", ",", "f"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "a", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"211", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"211", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"e", ",", "f"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "a", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"179", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"179", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "a", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"179", ",", 
      RowBox[{"{", 
       RowBox[{"{", "f", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"183", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"183", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "a", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"183", ",", 
      RowBox[{"{", 
       RowBox[{"{", "f", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"87", ",", 
      RowBox[{"{", 
       RowBox[{"{", "f", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"87", ",", 
      RowBox[{"{", 
       RowBox[{"{", "h", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"87", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"199", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"e", ",", "f"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"199", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"e", ",", "f"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"59", ",", 
      RowBox[{"{", 
       RowBox[{"{", "d", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"59", ",", 
      RowBox[{"{", 
       RowBox[{"{", "e", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"59", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"g", ",", "h"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"59", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"171", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"171", ",", 
      RowBox[{"{", 
       RowBox[{"{", "f", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"171", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"143", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"143", ",", 
      RowBox[{"{", 
       RowBox[{"{", "a", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"143", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"c", ",", "d"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"e", ",", "f"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"143", ",", 
      RowBox[{"{", 
       RowBox[{"{", "e", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"143", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"g", ",", "h"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"31", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"31", ",", 
      RowBox[{"{", 
       RowBox[{"{", "c", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", 
      RowBox[{"{", 
       RowBox[{"{", "d", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"115", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"115", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"115", ",", 
      RowBox[{"{", 
       RowBox[{"{", "c", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"93", ",", 
      RowBox[{"{", 
       RowBox[{"{", "f", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"93", ",", 
      RowBox[{"{", 
       RowBox[{"{", "h", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"93", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"f", ",", "h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"65", ",", 
      RowBox[{"{", 
       RowBox[{"{", "b", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"65", ",", 
      RowBox[{"{", 
       RowBox[{"{", "d", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"65", ",", 
      RowBox[{"{", 
       RowBox[{"{", "f", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"65", ",", 
      RowBox[{"{", 
       RowBox[{"{", "h", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"65", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"37", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"37", ",", 
      RowBox[{"{", 
       RowBox[{"{", "c", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"f", ",", "h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"37", ",", 
      RowBox[{"{", 
       RowBox[{"{", "g", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"205", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"e", ",", "f"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"205", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"e", ",", "f"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"177", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"177", ",", 
      RowBox[{"{", 
       RowBox[{"{", "f", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"177", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"149", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"149", ",", 
      RowBox[{"{", 
       RowBox[{"{", "a", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"f", ",", "h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"149", ",", 
      RowBox[{"{", 
       RowBox[{"{", "e", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"149", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"c", ",", "d"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"e", ",", "f"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"149", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"g", ",", "h"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"9", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"9", ",", 
      RowBox[{"{", 
       RowBox[{"{", "c", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"121", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"121", ",", 
      RowBox[{"{", 
       RowBox[{"{", "a", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"121", ",", 
      RowBox[{"{", 
       RowBox[{"{", "c", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"29", ",", 
      RowBox[{"{", 
       RowBox[{"{", "c", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"29", ",", 
      RowBox[{"{", 
       RowBox[{"{", "g", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "d", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"29", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "c", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"141", ",", 
      RowBox[{"{", 
       RowBox[{"{", "a", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"141", ",", 
      RowBox[{"{", 
       RowBox[{"{", "e", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "d", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"141", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"c", ",", "d"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"e", ",", "f", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"141", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"g", ",", "h"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"141", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i"}], "}"}]}],
    ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"85", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"h", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"85", ",", 
      RowBox[{"{", 
       RowBox[{"{", "f", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "c", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"85", ",", 
      RowBox[{"{", 
       RowBox[{"{", "h", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i"}], "}"}]}],
    ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"197", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"e", ",", "f", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"197", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"e", ",", "f"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i"}], "}"}]}],
    ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"c", ",", "d"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"113", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "d", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"113", ",", 
      RowBox[{"{", 
       RowBox[{"{", "c", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"113", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "c", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"57", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "d", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"57", ",", 
      RowBox[{"{", 
       RowBox[{"{", "b", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "c", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"57", ",", 
      RowBox[{"{", 
       RowBox[{"{", "d", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i"}], "}"}]}],
    ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"57", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"e", ",", "f"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"57", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"g", ",", "h"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "c", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"169", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "i"}], "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"169", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i"}], "}"}]}],
    ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"169", ",", 
      RowBox[{"{", 
       RowBox[{"{", "f", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "c", "}"}]}]}], "}"}]], "Print",
 CellChangeTimes->{3.714820892149105*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Under delay = \"\>", "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\" :\"\>"}],
  SequenceForm["Under delay = ", 3, " :"],
  Editable->False]], "Print",
 CellChangeTimes->{3.714820892150865*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"84", ",", 
      RowBox[{"{", 
       RowBox[{"{", "b", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"84", ",", 
      RowBox[{"{", 
       RowBox[{"{", "d", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"84", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"e", ",", "f"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"84", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"g", ",", "h"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"84", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"28", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"28", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"c", ",", "d"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"50", ",", 
      RowBox[{"{", 
       RowBox[{"{", "c", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"50", ",", 
      RowBox[{"{", 
       RowBox[{"{", "g", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"50", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"162", ",", 
      RowBox[{"{", 
       RowBox[{"{", "a", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"162", ",", 
      RowBox[{"{", 
       RowBox[{"{", "e", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"162", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"c", ",", "d"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"162", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"g", ",", "h"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"162", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"22", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"c", ",", "d"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"22", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"134", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"134", ",", 
      RowBox[{"{", 
       RowBox[{"{", "c", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"134", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"78", ",", 
      RowBox[{"{", 
       RowBox[{"{", "i", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"78", ",", 
      RowBox[{"{", 
       RowBox[{"{", "b", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"78", ",", 
      RowBox[{"{", 
       RowBox[{"{", "d", "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"78", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"e", ",", "f"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"78", ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"g", ",", "h"}], "}"}], "}"}]}], "}"}], "\[Rule]", 
    RowBox[{"{", "}"}]}]}], "}"}]], "Print",
 CellChangeTimes->{3.714820892152336*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Not possible for sure-winning anymore under delay=\"\>", 
   "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\" with uncontrollable states \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "162", ",", "166", ",", "210", ",", "216", ",", "188", ",", "20", ",", 
     "132", ",", "220", ",", "24", ",", "136", ",", "92", ",", "106", ",", 
     "36", ",", "158", ",", "18", ",", "130", ",", "74", ",", "218", ",", 
     "190", ",", "222", ",", "194", ",", "214", ",", "186", ",", "6", ",", 
     "208", ",", "180", ",", "212", ",", "184", ",", "12", ",", "16", ",", 
     "124", ",", "32", ",", "4", ",", "116", ",", "60", ",", "10", ",", "122",
      ",", "66", ",", "84", ",", "50", ",", "28", ",", "22", ",", "134", ",", 
     "78", ",", "27"}], "}"}], "\[InvisibleSpace]", "\<\".\\n\"\>"}],
  SequenceForm[
  "Not possible for sure-winning anymore under delay=", 3, 
   " with uncontrollable states ", {162, 166, 210, 216, 188, 20, 132, 220, 24,
    136, 92, 106, 36, 158, 18, 130, 74, 218, 190, 222, 194, 214, 186, 6, 208, 
   180, 212, 184, 12, 16, 124, 32, 4, 116, 60, 10, 122, 66, 84, 50, 28, 22, 
   134, 78, 27}, ".\n"],
  Editable->False]], "Print",
 CellChangeTimes->{3.714820892153536*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Computation time under increasing delays : \\n\"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "0.08400000000000318`", ",", "0.132000000000005`", ",", 
     "0.21600000000000819`", ",", "0.24799999999999045`"}], "}"}]}],
  SequenceForm[
  "Computation time under increasing delays : \n", {0.08400000000000318, 
   0.132000000000005, 0.21600000000000819`, 0.24799999999999045`}],
  Editable->False]], "Print",
 CellChangeTimes->{3.714820892154286*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Escp. 4 x 5", "Subsection",
 CellChangeTimes->{{3.7255918958480253`*^9, 3.7255918983676987`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"g4", " ", "=", " ", 
   RowBox[{"Graph", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"35", "\[Rule]", "144"}], ",", 
       RowBox[{"35", "\[Rule]", "144"}], ",", 
       RowBox[{"35", "\[Rule]", "36"}], ",", 
       RowBox[{"144", "\[Rule]", "135"}], ",", 
       RowBox[{"144", "\[Rule]", "141"}], ",", 
       RowBox[{"36", "\[Rule]", "27"}], ",", 
       RowBox[{"36", "\[Rule]", "33"}], ",", 
       RowBox[{"135", "\[Rule]", "64"}], ",", 
       RowBox[{"135", "\[Rule]", "244"}], ",", 
       RowBox[{"135", "\[Rule]", "28"}], ",", 
       RowBox[{"135", "\[Rule]", "28"}], ",", 
       RowBox[{"135", "\[Rule]", "208"}], ",", 
       RowBox[{"135", "\[Rule]", "208"}], ",", 
       RowBox[{"135", "\[Rule]", "136"}], ",", 
       RowBox[{"141", "\[Rule]", "70"}], ",", 
       RowBox[{"141", "\[Rule]", "250"}], ",", 
       RowBox[{"141", "\[Rule]", "34"}], ",", 
       RowBox[{"141", "\[Rule]", "34"}], ",", 
       RowBox[{"141", "\[Rule]", "214"}], ",", 
       RowBox[{"141", "\[Rule]", "214"}], ",", 
       RowBox[{"141", "\[Rule]", "142"}], ",", 
       RowBox[{"27", "\[Rule]", "136"}], ",", 
       RowBox[{"27", "\[Rule]", "136"}], ",", 
       RowBox[{"27", "\[Rule]", "28"}], ",", 
       RowBox[{"33", "\[Rule]", "142"}], ",", 
       RowBox[{"33", "\[Rule]", "142"}], ",", 
       RowBox[{"33", "\[Rule]", "34"}], ",", 
       RowBox[{"64", "\[Rule]", "53"}], ",", 
       RowBox[{"64", "\[Rule]", "71"}], ",", 
       RowBox[{"64", "\[Rule]", "61"}], ",", 
       RowBox[{"244", "\[Rule]", "233"}], ",", 
       RowBox[{"244", "\[Rule]", "251"}], ",", 
       RowBox[{"244", "\[Rule]", "241"}], ",", 
       RowBox[{"28", "\[Rule]", "17"}], ",", 
       RowBox[{"28", "\[Rule]", "35"}], ",", 
       RowBox[{"28", "\[Rule]", "25"}], ",", 
       RowBox[{"208", "\[Rule]", "197"}], ",", 
       RowBox[{"208", "\[Rule]", "215"}], ",", 
       RowBox[{"208", "\[Rule]", "205"}], ",", 
       RowBox[{"136", "\[Rule]", "125"}], ",", 
       RowBox[{"136", "\[Rule]", "143"}], ",", 
       RowBox[{"136", "\[Rule]", "133"}], ",", 
       RowBox[{"70", "\[Rule]", "61"}], ",", 
       RowBox[{"70", "\[Rule]", "71"}], ",", 
       RowBox[{"70", "\[Rule]", "67"}], ",", 
       RowBox[{"250", "\[Rule]", "241"}], ",", 
       RowBox[{"250", "\[Rule]", "251"}], ",", 
       RowBox[{"250", "\[Rule]", "247"}], ",", 
       RowBox[{"34", "\[Rule]", "25"}], ",", 
       RowBox[{"34", "\[Rule]", "35"}], ",", 
       RowBox[{"34", "\[Rule]", "31"}], ",", 
       RowBox[{"214", "\[Rule]", "205"}], ",", 
       RowBox[{"214", "\[Rule]", "215"}], ",", 
       RowBox[{"214", "\[Rule]", "211"}], ",", 
       RowBox[{"142", "\[Rule]", "133"}], ",", 
       RowBox[{"142", "\[Rule]", "143"}], ",", 
       RowBox[{"142", "\[Rule]", "139"}], ",", 
       RowBox[{"53", "\[Rule]", "162"}], ",", 
       RowBox[{"53", "\[Rule]", "126"}], ",", 
       RowBox[{"53", "\[Rule]", "54"}], ",", 
       RowBox[{"71", "\[Rule]", "180"}], ",", 
       RowBox[{"71", "\[Rule]", "144"}], ",", 
       RowBox[{"71", "\[Rule]", "72"}], ",", 
       RowBox[{"61", "\[Rule]", "170"}], ",", 
       RowBox[{"61", "\[Rule]", "134"}], ",", 
       RowBox[{"61", "\[Rule]", "62"}], ",", 
       RowBox[{"233", "\[Rule]", "162"}], ",", 
       RowBox[{"233", "\[Rule]", "342"}], ",", 
       RowBox[{"233", "\[Rule]", "342"}], ",", 
       RowBox[{"233", "\[Rule]", "126"}], ",", 
       RowBox[{"233", "\[Rule]", "306"}], ",", 
       RowBox[{"233", "\[Rule]", "306"}], ",", 
       RowBox[{"233", "\[Rule]", "234"}], ",", 
       RowBox[{"251", "\[Rule]", "180"}], ",", 
       RowBox[{"251", "\[Rule]", "360"}], ",", 
       RowBox[{"251", "\[Rule]", "360"}], ",", 
       RowBox[{"251", "\[Rule]", "144"}], ",", 
       RowBox[{"251", "\[Rule]", "324"}], ",", 
       RowBox[{"251", "\[Rule]", "324"}], ",", 
       RowBox[{"251", "\[Rule]", "252"}], ",", 
       RowBox[{"241", "\[Rule]", "350"}], ",", 
       RowBox[{"241", "\[Rule]", "134"}], ",", 
       RowBox[{"241", "\[Rule]", "314"}], ",", 
       RowBox[{"241", "\[Rule]", "314"}], ",", 
       RowBox[{"241", "\[Rule]", "242"}], ",", 
       RowBox[{"17", "\[Rule]", "126"}], ",", 
       RowBox[{"17", "\[Rule]", "126"}], ",", 
       RowBox[{"17", "\[Rule]", "18"}], ",", 
       RowBox[{"25", "\[Rule]", "134"}], ",", 
       RowBox[{"25", "\[Rule]", "134"}], ",", 
       RowBox[{"25", "\[Rule]", "26"}], ",", 
       RowBox[{"197", "\[Rule]", "126"}], ",", 
       RowBox[{"197", "\[Rule]", "126"}], ",", 
       RowBox[{"197", "\[Rule]", "306"}], ",", 
       RowBox[{"197", "\[Rule]", "198"}], ",", 
       RowBox[{"215", "\[Rule]", "144"}], ",", 
       RowBox[{"215", "\[Rule]", "144"}], ",", 
       RowBox[{"215", "\[Rule]", "324"}], ",", 
       RowBox[{"215", "\[Rule]", "216"}], ",", 
       RowBox[{"205", "\[Rule]", "134"}], ",", 
       RowBox[{"205", "\[Rule]", "134"}], ",", 
       RowBox[{"205", "\[Rule]", "314"}], ",", 
       RowBox[{"205", "\[Rule]", "206"}], ",", 
       RowBox[{"125", "\[Rule]", "54"}], ",", 
       RowBox[{"125", "\[Rule]", "234"}], ",", 
       RowBox[{"125", "\[Rule]", "18"}], ",", 
       RowBox[{"125", "\[Rule]", "18"}], ",", 
       RowBox[{"125", "\[Rule]", "198"}], ",", 
       RowBox[{"125", "\[Rule]", "198"}], ",", 
       RowBox[{"125", "\[Rule]", "126"}], ",", 
       RowBox[{"143", "\[Rule]", "72"}], ",", 
       RowBox[{"143", "\[Rule]", "252"}], ",", 
       RowBox[{"143", "\[Rule]", "36"}], ",", 
       RowBox[{"143", "\[Rule]", "36"}], ",", 
       RowBox[{"143", "\[Rule]", "216"}], ",", 
       RowBox[{"143", "\[Rule]", "216"}], ",", 
       RowBox[{"143", "\[Rule]", "144"}], ",", 
       RowBox[{"133", "\[Rule]", "62"}], ",", 
       RowBox[{"133", "\[Rule]", "242"}], ",", 
       RowBox[{"133", "\[Rule]", "26"}], ",", 
       RowBox[{"133", "\[Rule]", "26"}], ",", 
       RowBox[{"133", "\[Rule]", "206"}], ",", 
       RowBox[{"133", "\[Rule]", "206"}], ",", 
       RowBox[{"133", "\[Rule]", "134"}], ",", 
       RowBox[{"67", "\[Rule]", "176"}], ",", 
       RowBox[{"67", "\[Rule]", "140"}], ",", 
       RowBox[{"67", "\[Rule]", "68"}], ",", 
       RowBox[{"247", "\[Rule]", "176"}], ",", 
       RowBox[{"247", "\[Rule]", "356"}], ",", 
       RowBox[{"247", "\[Rule]", "140"}], ",", 
       RowBox[{"247", "\[Rule]", "320"}], ",", 
       RowBox[{"247", "\[Rule]", "248"}], ",", 
       RowBox[{"31", "\[Rule]", "140"}], ",", 
       RowBox[{"31", "\[Rule]", "140"}], ",", 
       RowBox[{"31", "\[Rule]", "32"}], ",", 
       RowBox[{"211", "\[Rule]", "140"}], ",", 
       RowBox[{"211", "\[Rule]", "140"}], ",", 
       RowBox[{"211", "\[Rule]", "320"}], ",", 
       RowBox[{"211", "\[Rule]", "212"}], ",", 
       RowBox[{"139", "\[Rule]", "68"}], ",", 
       RowBox[{"139", "\[Rule]", "248"}], ",", 
       RowBox[{"139", "\[Rule]", "32"}], ",", 
       RowBox[{"139", "\[Rule]", "32"}], ",", 
       RowBox[{"139", "\[Rule]", "212"}], ",", 
       RowBox[{"139", "\[Rule]", "212"}], ",", 
       RowBox[{"139", "\[Rule]", "140"}], ",", 
       RowBox[{"162", "\[Rule]", "153"}], ",", 
       RowBox[{"162", "\[Rule]", "171"}], ",", 
       RowBox[{"162", "\[Rule]", "159"}], ",", 
       RowBox[{"126", "\[Rule]", "117"}], ",", 
       RowBox[{"126", "\[Rule]", "135"}], ",", 
       RowBox[{"126", "\[Rule]", "123"}], ",", 
       RowBox[{"54", "\[Rule]", "45"}], ",", 
       RowBox[{"54", "\[Rule]", "63"}], ",", 
       RowBox[{"54", "\[Rule]", "51"}], ",", 
       RowBox[{"180", "\[Rule]", "171"}], ",", 
       RowBox[{"180", "\[Rule]", "177"}], ",", 
       RowBox[{"72", "\[Rule]", "63"}], ",", 
       RowBox[{"72", "\[Rule]", "69"}], ",", 
       RowBox[{"170", "\[Rule]", "159"}], ",", 
       RowBox[{"170", "\[Rule]", "177"}], ",", 
       RowBox[{"170", "\[Rule]", "171"}], ",", 
       RowBox[{"170", "\[Rule]", "167"}], ",", 
       RowBox[{"134", "\[Rule]", "123"}], ",", 
       RowBox[{"134", "\[Rule]", "141"}], ",", 
       RowBox[{"134", "\[Rule]", "135"}], ",", 
       RowBox[{"134", "\[Rule]", "131"}], ",", 
       RowBox[{"62", "\[Rule]", "51"}], ",", 
       RowBox[{"62", "\[Rule]", "69"}], ",", 
       RowBox[{"62", "\[Rule]", "63"}], ",", 
       RowBox[{"62", "\[Rule]", "59"}], ",", 
       RowBox[{"342", "\[Rule]", "333"}], ",", 
       RowBox[{"342", "\[Rule]", "351"}], ",", 
       RowBox[{"342", "\[Rule]", "339"}], ",", 
       RowBox[{"306", "\[Rule]", "297"}], ",", 
       RowBox[{"306", "\[Rule]", "315"}], ",", 
       RowBox[{"306", "\[Rule]", "303"}], ",", 
       RowBox[{"234", "\[Rule]", "225"}], ",", 
       RowBox[{"234", "\[Rule]", "243"}], ",", 
       RowBox[{"234", "\[Rule]", "231"}], ",", 
       RowBox[{"360", "\[Rule]", "351"}], ",", 
       RowBox[{"360", "\[Rule]", "357"}], ",", 
       RowBox[{"324", "\[Rule]", "315"}], ",", 
       RowBox[{"324", "\[Rule]", "321"}], ",", 
       RowBox[{"252", "\[Rule]", "243"}], ",", 
       RowBox[{"252", "\[Rule]", "249"}], ",", 
       RowBox[{"350", "\[Rule]", "339"}], ",", 
       RowBox[{"350", "\[Rule]", "357"}], ",", 
       RowBox[{"350", "\[Rule]", "351"}], ",", 
       RowBox[{"350", "\[Rule]", "347"}], ",", 
       RowBox[{"314", "\[Rule]", "303"}], ",", 
       RowBox[{"314", "\[Rule]", "321"}], ",", 
       RowBox[{"314", "\[Rule]", "315"}], ",", 
       RowBox[{"314", "\[Rule]", "311"}], ",", 
       RowBox[{"242", "\[Rule]", "231"}], ",", 
       RowBox[{"242", "\[Rule]", "249"}], ",", 
       RowBox[{"242", "\[Rule]", "243"}], ",", 
       RowBox[{"242", "\[Rule]", "239"}], ",", 
       RowBox[{"18", "\[Rule]", "9"}], ",", 
       RowBox[{"18", "\[Rule]", "27"}], ",", 
       RowBox[{"18", "\[Rule]", "15"}], ",", 
       RowBox[{"26", "\[Rule]", "15"}], ",", 
       RowBox[{"26", "\[Rule]", "33"}], ",", 
       RowBox[{"26", "\[Rule]", "27"}], ",", 
       RowBox[{"26", "\[Rule]", "23"}], ",", 
       RowBox[{"198", "\[Rule]", "189"}], ",", 
       RowBox[{"198", "\[Rule]", "207"}], ",", 
       RowBox[{"198", "\[Rule]", "195"}], ",", 
       RowBox[{"216", "\[Rule]", "207"}], ",", 
       RowBox[{"216", "\[Rule]", "213"}], ",", 
       RowBox[{"206", "\[Rule]", "195"}], ",", 
       RowBox[{"206", "\[Rule]", "213"}], ",", 
       RowBox[{"206", "\[Rule]", "207"}], ",", 
       RowBox[{"206", "\[Rule]", "203"}], ",", 
       RowBox[{"176", "\[Rule]", "167"}], ",", 
       RowBox[{"176", "\[Rule]", "177"}], ",", 
       RowBox[{"176", "\[Rule]", "173"}], ",", 
       RowBox[{"140", "\[Rule]", "131"}], ",", 
       RowBox[{"140", "\[Rule]", "141"}], ",", 
       RowBox[{"140", "\[Rule]", "137"}], ",", 
       RowBox[{"68", "\[Rule]", "59"}], ",", 
       RowBox[{"68", "\[Rule]", "69"}], ",", 
       RowBox[{"68", "\[Rule]", "65"}], ",", 
       RowBox[{"356", "\[Rule]", "347"}], ",", 
       RowBox[{"356", "\[Rule]", "357"}], ",", 
       RowBox[{"356", "\[Rule]", "353"}], ",", 
       RowBox[{"320", "\[Rule]", "311"}], ",", 
       RowBox[{"320", "\[Rule]", "321"}], ",", 
       RowBox[{"320", "\[Rule]", "317"}], ",", 
       RowBox[{"248", "\[Rule]", "239"}], ",", 
       RowBox[{"248", "\[Rule]", "249"}], ",", 
       RowBox[{"248", "\[Rule]", "245"}], ",", 
       RowBox[{"32", "\[Rule]", "23"}], ",", 
       RowBox[{"32", "\[Rule]", "33"}], ",", 
       RowBox[{"32", "\[Rule]", "29"}], ",", 
       RowBox[{"212", "\[Rule]", "203"}], ",", 
       RowBox[{"212", "\[Rule]", "213"}], ",", 
       RowBox[{"212", "\[Rule]", "209"}], ",", 
       RowBox[{"153", "\[Rule]", "82"}], ",", 
       RowBox[{"153", "\[Rule]", "82"}], ",", 
       RowBox[{"153", "\[Rule]", "262"}], ",", 
       RowBox[{"153", "\[Rule]", "262"}], ",", 
       RowBox[{"153", "\[Rule]", "46"}], ",", 
       RowBox[{"153", "\[Rule]", "226"}], ",", 
       RowBox[{"153", "\[Rule]", "154"}], ",", 
       RowBox[{"171", "\[Rule]", "100"}], ",", 
       RowBox[{"171", "\[Rule]", "100"}], ",", 
       RowBox[{"171", "\[Rule]", "280"}], ",", 
       RowBox[{"171", "\[Rule]", "280"}], ",", 
       RowBox[{"171", "\[Rule]", "64"}], ",", 
       RowBox[{"171", "\[Rule]", "244"}], ",", 
       RowBox[{"171", "\[Rule]", "172"}], ",", 
       RowBox[{"159", "\[Rule]", "88"}], ",", 
       RowBox[{"159", "\[Rule]", "88"}], ",", 
       RowBox[{"159", "\[Rule]", "268"}], ",", 
       RowBox[{"159", "\[Rule]", "268"}], ",", 
       RowBox[{"159", "\[Rule]", "52"}], ",", 
       RowBox[{"159", "\[Rule]", "232"}], ",", 
       RowBox[{"159", "\[Rule]", "160"}], ",", 
       RowBox[{"117", "\[Rule]", "46"}], ",", 
       RowBox[{"117", "\[Rule]", "226"}], ",", 
       RowBox[{"117", "\[Rule]", "10"}], ",", 
       RowBox[{"117", "\[Rule]", "10"}], ",", 
       RowBox[{"117", "\[Rule]", "190"}], ",", 
       RowBox[{"117", "\[Rule]", "190"}], ",", 
       RowBox[{"117", "\[Rule]", "118"}], ",", 
       RowBox[{"123", "\[Rule]", "52"}], ",", 
       RowBox[{"123", "\[Rule]", "232"}], ",", 
       RowBox[{"123", "\[Rule]", "16"}], ",", 
       RowBox[{"123", "\[Rule]", "16"}], ",", 
       RowBox[{"123", "\[Rule]", "196"}], ",", 
       RowBox[{"123", "\[Rule]", "196"}], ",", 
       RowBox[{"123", "\[Rule]", "124"}], ",", 
       RowBox[{"45", "\[Rule]", "154"}], ",", 
       RowBox[{"45", "\[Rule]", "118"}], ",", 
       RowBox[{"45", "\[Rule]", "46"}], ",", 
       RowBox[{"63", "\[Rule]", "172"}], ",", 
       RowBox[{"63", "\[Rule]", "136"}], ",", 
       RowBox[{"63", "\[Rule]", "64"}], ",", 
       RowBox[{"51", "\[Rule]", "160"}], ",", 
       RowBox[{"51", "\[Rule]", "124"}], ",", 
       RowBox[{"51", "\[Rule]", "52"}], ",", 
       RowBox[{"177", "\[Rule]", "106"}], ",", 
       RowBox[{"177", "\[Rule]", "106"}], ",", 
       RowBox[{"177", "\[Rule]", "286"}], ",", 
       RowBox[{"177", "\[Rule]", "286"}], ",", 
       RowBox[{"177", "\[Rule]", "70"}], ",", 
       RowBox[{"177", "\[Rule]", "250"}], ",", 
       RowBox[{"177", "\[Rule]", "178"}], ",", 
       RowBox[{"69", "\[Rule]", "178"}], ",", 
       RowBox[{"69", "\[Rule]", "142"}], ",", 
       RowBox[{"69", "\[Rule]", "70"}], ",", 
       RowBox[{"167", "\[Rule]", "96"}], ",", 
       RowBox[{"167", "\[Rule]", "96"}], ",", 
       RowBox[{"167", "\[Rule]", "276"}], ",", 
       RowBox[{"167", "\[Rule]", "276"}], ",", 
       RowBox[{"167", "\[Rule]", "60"}], ",", 
       RowBox[{"167", "\[Rule]", "240"}], ",", 
       RowBox[{"167", "\[Rule]", "168"}], ",", 
       RowBox[{"131", "\[Rule]", "60"}], ",", 
       RowBox[{"131", "\[Rule]", "240"}], ",", 
       RowBox[{"131", "\[Rule]", "24"}], ",", 
       RowBox[{"131", "\[Rule]", "24"}], ",", 
       RowBox[{"131", "\[Rule]", "204"}], ",", 
       RowBox[{"131", "\[Rule]", "204"}], ",", 
       RowBox[{"131", "\[Rule]", "132"}], ",", 
       RowBox[{"59", "\[Rule]", "168"}], ",", 
       RowBox[{"59", "\[Rule]", "132"}], ",", 
       RowBox[{"59", "\[Rule]", "60"}], ",", 
       RowBox[{"333", "\[Rule]", "262"}], ",", 
       RowBox[{"333", "\[Rule]", "262"}], ",", 
       RowBox[{"333", "\[Rule]", "226"}], ",", 
       RowBox[{"333", "\[Rule]", "226"}], ",", 
       RowBox[{"333", "\[Rule]", "334"}], ",", 
       RowBox[{"351", "\[Rule]", "280"}], ",", 
       RowBox[{"351", "\[Rule]", "280"}], ",", 
       RowBox[{"351", "\[Rule]", "244"}], ",", 
       RowBox[{"351", "\[Rule]", "244"}], ",", 
       RowBox[{"351", "\[Rule]", "352"}], ",", 
       RowBox[{"339", "\[Rule]", "268"}], ",", 
       RowBox[{"339", "\[Rule]", "268"}], ",", 
       RowBox[{"339", "\[Rule]", "232"}], ",", 
       RowBox[{"339", "\[Rule]", "232"}], ",", 
       RowBox[{"339", "\[Rule]", "340"}], ",", 
       RowBox[{"297", "\[Rule]", "226"}], ",", 
       RowBox[{"297", "\[Rule]", "226"}], ",", 
       RowBox[{"297", "\[Rule]", "190"}], ",", 
       RowBox[{"297", "\[Rule]", "298"}], ",", 
       RowBox[{"315", "\[Rule]", "244"}], ",", 
       RowBox[{"315", "\[Rule]", "244"}], ",", 
       RowBox[{"315", "\[Rule]", "208"}], ",", 
       RowBox[{"315", "\[Rule]", "316"}], ",", 
       RowBox[{"303", "\[Rule]", "232"}], ",", 
       RowBox[{"303", "\[Rule]", "232"}], ",", 
       RowBox[{"303", "\[Rule]", "196"}], ",", 
       RowBox[{"303", "\[Rule]", "304"}], ",", 
       RowBox[{"225", "\[Rule]", "154"}], ",", 
       RowBox[{"225", "\[Rule]", "334"}], ",", 
       RowBox[{"225", "\[Rule]", "334"}], ",", 
       RowBox[{"225", "\[Rule]", "118"}], ",", 
       RowBox[{"225", "\[Rule]", "298"}], ",", 
       RowBox[{"225", "\[Rule]", "298"}], ",", 
       RowBox[{"225", "\[Rule]", "226"}], ",", 
       RowBox[{"243", "\[Rule]", "172"}], ",", 
       RowBox[{"243", "\[Rule]", "352"}], ",", 
       RowBox[{"243", "\[Rule]", "352"}], ",", 
       RowBox[{"243", "\[Rule]", "136"}], ",", 
       RowBox[{"243", "\[Rule]", "316"}], ",", 
       RowBox[{"243", "\[Rule]", "316"}], ",", 
       RowBox[{"243", "\[Rule]", "244"}], ",", 
       RowBox[{"231", "\[Rule]", "160"}], ",", 
       RowBox[{"231", "\[Rule]", "340"}], ",", 
       RowBox[{"231", "\[Rule]", "340"}], ",", 
       RowBox[{"231", "\[Rule]", "124"}], ",", 
       RowBox[{"231", "\[Rule]", "304"}], ",", 
       RowBox[{"231", "\[Rule]", "304"}], ",", 
       RowBox[{"231", "\[Rule]", "232"}], ",", 
       RowBox[{"357", "\[Rule]", "286"}], ",", 
       RowBox[{"357", "\[Rule]", "286"}], ",", 
       RowBox[{"357", "\[Rule]", "250"}], ",", 
       RowBox[{"357", "\[Rule]", "250"}], ",", 
       RowBox[{"357", "\[Rule]", "358"}], ",", 
       RowBox[{"321", "\[Rule]", "250"}], ",", 
       RowBox[{"321", "\[Rule]", "250"}], ",", 
       RowBox[{"321", "\[Rule]", "214"}], ",", 
       RowBox[{"321", "\[Rule]", "322"}], ",", 
       RowBox[{"249", "\[Rule]", "178"}], ",", 
       RowBox[{"249", "\[Rule]", "358"}], ",", 
       RowBox[{"249", "\[Rule]", "358"}], ",", 
       RowBox[{"249", "\[Rule]", "142"}], ",", 
       RowBox[{"249", "\[Rule]", "322"}], ",", 
       RowBox[{"249", "\[Rule]", "322"}], ",", 
       RowBox[{"249", "\[Rule]", "250"}], ",", 
       RowBox[{"347", "\[Rule]", "276"}], ",", 
       RowBox[{"347", "\[Rule]", "276"}], ",", 
       RowBox[{"347", "\[Rule]", "240"}], ",", 
       RowBox[{"347", "\[Rule]", "240"}], ",", 
       RowBox[{"347", "\[Rule]", "348"}], ",", 
       RowBox[{"311", "\[Rule]", "240"}], ",", 
       RowBox[{"311", "\[Rule]", "240"}], ",", 
       RowBox[{"311", "\[Rule]", "204"}], ",", 
       RowBox[{"311", "\[Rule]", "312"}], ",", 
       RowBox[{"239", "\[Rule]", "168"}], ",", 
       RowBox[{"239", "\[Rule]", "348"}], ",", 
       RowBox[{"239", "\[Rule]", "348"}], ",", 
       RowBox[{"239", "\[Rule]", "132"}], ",", 
       RowBox[{"239", "\[Rule]", "312"}], ",", 
       RowBox[{"239", "\[Rule]", "312"}], ",", 
       RowBox[{"239", "\[Rule]", "240"}], ",", 
       RowBox[{"9", "\[Rule]", "118"}], ",", 
       RowBox[{"9", "\[Rule]", "118"}], ",", 
       RowBox[{"9", "\[Rule]", "10"}], ",", 
       RowBox[{"15", "\[Rule]", "124"}], ",", 
       RowBox[{"15", "\[Rule]", "124"}], ",", 
       RowBox[{"15", "\[Rule]", "16"}], ",", 
       RowBox[{"23", "\[Rule]", "132"}], ",", 
       RowBox[{"23", "\[Rule]", "132"}], ",", 
       RowBox[{"23", "\[Rule]", "24"}], ",", 
       RowBox[{"189", "\[Rule]", "118"}], ",", 
       RowBox[{"189", "\[Rule]", "118"}], ",", 
       RowBox[{"189", "\[Rule]", "298"}], ",", 
       RowBox[{"189", "\[Rule]", "190"}], ",", 
       RowBox[{"207", "\[Rule]", "136"}], ",", 
       RowBox[{"207", "\[Rule]", "136"}], ",", 
       RowBox[{"207", "\[Rule]", "316"}], ",", 
       RowBox[{"207", "\[Rule]", "208"}], ",", 
       RowBox[{"195", "\[Rule]", "124"}], ",", 
       RowBox[{"195", "\[Rule]", "124"}], ",", 
       RowBox[{"195", "\[Rule]", "304"}], ",", 
       RowBox[{"195", "\[Rule]", "196"}], ",", 
       RowBox[{"213", "\[Rule]", "142"}], ",", 
       RowBox[{"213", "\[Rule]", "142"}], ",", 
       RowBox[{"213", "\[Rule]", "322"}], ",", 
       RowBox[{"213", "\[Rule]", "214"}], ",", 
       RowBox[{"203", "\[Rule]", "132"}], ",", 
       RowBox[{"203", "\[Rule]", "132"}], ",", 
       RowBox[{"203", "\[Rule]", "312"}], ",", 
       RowBox[{"203", "\[Rule]", "204"}], ",", 
       RowBox[{"173", "\[Rule]", "102"}], ",", 
       RowBox[{"173", "\[Rule]", "102"}], ",", 
       RowBox[{"173", "\[Rule]", "282"}], ",", 
       RowBox[{"173", "\[Rule]", "282"}], ",", 
       RowBox[{"173", "\[Rule]", "66"}], ",", 
       RowBox[{"173", "\[Rule]", "246"}], ",", 
       RowBox[{"173", "\[Rule]", "174"}], ",", 
       RowBox[{"137", "\[Rule]", "66"}], ",", 
       RowBox[{"137", "\[Rule]", "246"}], ",", 
       RowBox[{"137", "\[Rule]", "30"}], ",", 
       RowBox[{"137", "\[Rule]", "30"}], ",", 
       RowBox[{"137", "\[Rule]", "210"}], ",", 
       RowBox[{"137", "\[Rule]", "210"}], ",", 
       RowBox[{"137", "\[Rule]", "138"}], ",", 
       RowBox[{"65", "\[Rule]", "174"}], ",", 
       RowBox[{"65", "\[Rule]", "138"}], ",", 
       RowBox[{"65", "\[Rule]", "66"}], ",", 
       RowBox[{"353", "\[Rule]", "282"}], ",", 
       RowBox[{"353", "\[Rule]", "282"}], ",", 
       RowBox[{"353", "\[Rule]", "246"}], ",", 
       RowBox[{"353", "\[Rule]", "246"}], ",", 
       RowBox[{"353", "\[Rule]", "354"}], ",", 
       RowBox[{"317", "\[Rule]", "246"}], ",", 
       RowBox[{"317", "\[Rule]", "246"}], ",", 
       RowBox[{"317", "\[Rule]", "210"}], ",", 
       RowBox[{"317", "\[Rule]", "318"}], ",", 
       RowBox[{"245", "\[Rule]", "174"}], ",", 
       RowBox[{"245", "\[Rule]", "354"}], ",", 
       RowBox[{"245", "\[Rule]", "354"}], ",", 
       RowBox[{"245", "\[Rule]", "138"}], ",", 
       RowBox[{"245", "\[Rule]", "318"}], ",", 
       RowBox[{"245", "\[Rule]", "318"}], ",", 
       RowBox[{"245", "\[Rule]", "246"}], ",", 
       RowBox[{"29", "\[Rule]", "138"}], ",", 
       RowBox[{"29", "\[Rule]", "138"}], ",", 
       RowBox[{"29", "\[Rule]", "30"}], ",", 
       RowBox[{"209", "\[Rule]", "138"}], ",", 
       RowBox[{"209", "\[Rule]", "138"}], ",", 
       RowBox[{"209", "\[Rule]", "318"}], ",", 
       RowBox[{"209", "\[Rule]", "210"}], ",", 
       RowBox[{"82", "\[Rule]", "89"}], ",", 
       RowBox[{"82", "\[Rule]", "79"}], ",", 
       RowBox[{"262", "\[Rule]", "269"}], ",", 
       RowBox[{"262", "\[Rule]", "259"}], ",", 
       RowBox[{"46", "\[Rule]", "53"}], ",", 
       RowBox[{"46", "\[Rule]", "43"}], ",", 
       RowBox[{"226", "\[Rule]", "233"}], ",", 
       RowBox[{"226", "\[Rule]", "223"}], ",", 
       RowBox[{"154", "\[Rule]", "161"}], ",", 
       RowBox[{"154", "\[Rule]", "151"}], ",", 
       RowBox[{"100", "\[Rule]", "89"}], ",", 
       RowBox[{"100", "\[Rule]", "107"}], ",", 
       RowBox[{"100", "\[Rule]", "97"}], ",", 
       RowBox[{"280", "\[Rule]", "269"}], ",", 
       RowBox[{"280", "\[Rule]", "287"}], ",", 
       RowBox[{"280", "\[Rule]", "277"}], ",", 
       RowBox[{"172", "\[Rule]", "161"}], ",", 
       RowBox[{"172", "\[Rule]", "179"}], ",", 
       RowBox[{"172", "\[Rule]", "169"}], ",", 
       RowBox[{"88", "\[Rule]", "79"}], ",", 
       RowBox[{"88", "\[Rule]", "97"}], ",", 
       RowBox[{"88", "\[Rule]", "89"}], ",", 
       RowBox[{"268", "\[Rule]", "259"}], ",", 
       RowBox[{"268", "\[Rule]", "277"}], ",", 
       RowBox[{"268", "\[Rule]", "269"}], ",", 
       RowBox[{"52", "\[Rule]", "43"}], ",", 
       RowBox[{"52", "\[Rule]", "61"}], ",", 
       RowBox[{"52", "\[Rule]", "53"}], ",", 
       RowBox[{"232", "\[Rule]", "223"}], ",", 
       RowBox[{"232", "\[Rule]", "241"}], ",", 
       RowBox[{"232", "\[Rule]", "233"}], ",", 
       RowBox[{"160", "\[Rule]", "151"}], ",", 
       RowBox[{"160", "\[Rule]", "169"}], ",", 
       RowBox[{"160", "\[Rule]", "161"}], ",", 
       RowBox[{"10", "\[Rule]", "17"}], ",", 
       RowBox[{"10", "\[Rule]", "7"}], ",", 
       RowBox[{"190", "\[Rule]", "197"}], ",", 
       RowBox[{"190", "\[Rule]", "187"}], ",", 
       RowBox[{"118", "\[Rule]", "125"}], ",", 
       RowBox[{"118", "\[Rule]", "115"}], ",", 
       RowBox[{"16", "\[Rule]", "7"}], ",", 
       RowBox[{"16", "\[Rule]", "25"}], ",", 
       RowBox[{"16", "\[Rule]", "17"}], ",", 
       RowBox[{"196", "\[Rule]", "187"}], ",", 
       RowBox[{"196", "\[Rule]", "205"}], ",", 
       RowBox[{"196", "\[Rule]", "197"}], ",", 
       RowBox[{"124", "\[Rule]", "115"}], ",", 
       RowBox[{"124", "\[Rule]", "133"}], ",", 
       RowBox[{"124", "\[Rule]", "125"}], ",", 
       RowBox[{"106", "\[Rule]", "97"}], ",", 
       RowBox[{"106", "\[Rule]", "107"}], ",", 
       RowBox[{"106", "\[Rule]", "103"}], ",", 
       RowBox[{"286", "\[Rule]", "277"}], ",", 
       RowBox[{"286", "\[Rule]", "287"}], ",", 
       RowBox[{"286", "\[Rule]", "283"}], ",", 
       RowBox[{"178", "\[Rule]", "169"}], ",", 
       RowBox[{"178", "\[Rule]", "179"}], ",", 
       RowBox[{"178", "\[Rule]", "175"}], ",", 
       RowBox[{"96", "\[Rule]", "103"}], ",", 
       RowBox[{"96", "\[Rule]", "97"}], ",", 
       RowBox[{"96", "\[Rule]", "93"}], ",", 
       RowBox[{"276", "\[Rule]", "283"}], ",", 
       RowBox[{"276", "\[Rule]", "277"}], ",", 
       RowBox[{"276", "\[Rule]", "273"}], ",", 
       RowBox[{"60", "\[Rule]", "67"}], ",", 
       RowBox[{"60", "\[Rule]", "61"}], ",", 
       RowBox[{"60", "\[Rule]", "57"}], ",", 
       RowBox[{"240", "\[Rule]", "247"}], ",", 
       RowBox[{"240", "\[Rule]", "241"}], ",", 
       RowBox[{"240", "\[Rule]", "237"}], ",", 
       RowBox[{"168", "\[Rule]", "175"}], ",", 
       RowBox[{"168", "\[Rule]", "169"}], ",", 
       RowBox[{"168", "\[Rule]", "165"}], ",", 
       RowBox[{"24", "\[Rule]", "31"}], ",", 
       RowBox[{"24", "\[Rule]", "25"}], ",", 
       RowBox[{"24", "\[Rule]", "21"}], ",", 
       RowBox[{"204", "\[Rule]", "211"}], ",", 
       RowBox[{"204", "\[Rule]", "205"}], ",", 
       RowBox[{"204", "\[Rule]", "201"}], ",", 
       RowBox[{"132", "\[Rule]", "139"}], ",", 
       RowBox[{"132", "\[Rule]", "133"}], ",", 
       RowBox[{"132", "\[Rule]", "129"}], ",", 
       RowBox[{"334", "\[Rule]", "341"}], ",", 
       RowBox[{"334", "\[Rule]", "331"}], ",", 
       RowBox[{"352", "\[Rule]", "341"}], ",", 
       RowBox[{"352", "\[Rule]", "359"}], ",", 
       RowBox[{"352", "\[Rule]", "349"}], ",", 
       RowBox[{"340", "\[Rule]", "331"}], ",", 
       RowBox[{"340", "\[Rule]", "349"}], ",", 
       RowBox[{"340", "\[Rule]", "341"}], ",", 
       RowBox[{"298", "\[Rule]", "305"}], ",", 
       RowBox[{"298", "\[Rule]", "295"}], ",", 
       RowBox[{"316", "\[Rule]", "305"}], ",", 
       RowBox[{"316", "\[Rule]", "323"}], ",", 
       RowBox[{"316", "\[Rule]", "313"}], ",", 
       RowBox[{"304", "\[Rule]", "295"}], ",", 
       RowBox[{"304", "\[Rule]", "313"}], ",", 
       RowBox[{"304", "\[Rule]", "305"}], ",", 
       RowBox[{"358", "\[Rule]", "349"}], ",", 
       RowBox[{"358", "\[Rule]", "359"}], ",", 
       RowBox[{"358", "\[Rule]", "355"}], ",", 
       RowBox[{"322", "\[Rule]", "313"}], ",", 
       RowBox[{"322", "\[Rule]", "323"}], ",", 
       RowBox[{"322", "\[Rule]", "319"}], ",", 
       RowBox[{"348", "\[Rule]", "355"}], ",", 
       RowBox[{"348", "\[Rule]", "349"}], ",", 
       RowBox[{"348", "\[Rule]", "345"}], ",", 
       RowBox[{"312", "\[Rule]", "319"}], ",", 
       RowBox[{"312", "\[Rule]", "313"}], ",", 
       RowBox[{"312", "\[Rule]", "309"}], ",", 
       RowBox[{"102", "\[Rule]", "93"}], ",", 
       RowBox[{"102", "\[Rule]", "103"}], ",", 
       RowBox[{"282", "\[Rule]", "273"}], ",", 
       RowBox[{"282", "\[Rule]", "283"}], ",", 
       RowBox[{"66", "\[Rule]", "57"}], ",", 
       RowBox[{"66", "\[Rule]", "67"}], ",", 
       RowBox[{"246", "\[Rule]", "237"}], ",", 
       RowBox[{"246", "\[Rule]", "247"}], ",", 
       RowBox[{"174", "\[Rule]", "165"}], ",", 
       RowBox[{"174", "\[Rule]", "175"}], ",", 
       RowBox[{"30", "\[Rule]", "21"}], ",", 
       RowBox[{"30", "\[Rule]", "31"}], ",", 
       RowBox[{"210", "\[Rule]", "201"}], ",", 
       RowBox[{"210", "\[Rule]", "211"}], ",", 
       RowBox[{"138", "\[Rule]", "129"}], ",", 
       RowBox[{"138", "\[Rule]", "139"}], ",", 
       RowBox[{"354", "\[Rule]", "345"}], ",", 
       RowBox[{"354", "\[Rule]", "355"}], ",", 
       RowBox[{"318", "\[Rule]", "309"}], ",", 
       RowBox[{"318", "\[Rule]", "319"}], ",", 
       RowBox[{"89", "\[Rule]", "162"}], ",", 
       RowBox[{"89", "\[Rule]", "90"}], ",", 
       RowBox[{"79", "\[Rule]", "152"}], ",", 
       RowBox[{"79", "\[Rule]", "80"}], ",", 
       RowBox[{"269", "\[Rule]", "162"}], ",", 
       RowBox[{"269", "\[Rule]", "342"}], ",", 
       RowBox[{"269", "\[Rule]", "342"}], ",", 
       RowBox[{"269", "\[Rule]", "270"}], ",", 
       RowBox[{"259", "\[Rule]", "152"}], ",", 
       RowBox[{"259", "\[Rule]", "152"}], ",", 
       RowBox[{"259", "\[Rule]", "332"}], ",", 
       RowBox[{"259", "\[Rule]", "332"}], ",", 
       RowBox[{"259", "\[Rule]", "260"}], ",", 
       RowBox[{"43", "\[Rule]", "116"}], ",", 
       RowBox[{"43", "\[Rule]", "44"}], ",", 
       RowBox[{"223", "\[Rule]", "152"}], ",", 
       RowBox[{"223", "\[Rule]", "332"}], ",", 
       RowBox[{"223", "\[Rule]", "332"}], ",", 
       RowBox[{"223", "\[Rule]", "116"}], ",", 
       RowBox[{"223", "\[Rule]", "296"}], ",", 
       RowBox[{"223", "\[Rule]", "296"}], ",", 
       RowBox[{"223", "\[Rule]", "224"}], ",", 
       RowBox[{"161", "\[Rule]", "90"}], ",", 
       RowBox[{"161", "\[Rule]", "270"}], ",", 
       RowBox[{"161", "\[Rule]", "54"}], ",", 
       RowBox[{"161", "\[Rule]", "234"}], ",", 
       RowBox[{"161", "\[Rule]", "162"}], ",", 
       RowBox[{"151", "\[Rule]", "80"}], ",", 
       RowBox[{"151", "\[Rule]", "260"}], ",", 
       RowBox[{"151", "\[Rule]", "260"}], ",", 
       RowBox[{"151", "\[Rule]", "224"}], ",", 
       RowBox[{"151", "\[Rule]", "152"}], ",", 
       RowBox[{"107", "\[Rule]", "180"}], ",", 
       RowBox[{"107", "\[Rule]", "180"}], ",", 
       RowBox[{"107", "\[Rule]", "108"}], ",", 
       RowBox[{"97", "\[Rule]", "170"}], ",", 
       RowBox[{"97", "\[Rule]", "170"}], ",", 
       RowBox[{"97", "\[Rule]", "98"}], ",", 
       RowBox[{"287", "\[Rule]", "180"}], ",", 
       RowBox[{"287", "\[Rule]", "180"}], ",", 
       RowBox[{"287", "\[Rule]", "360"}], ",", 
       RowBox[{"287", "\[Rule]", "288"}], ",", 
       RowBox[{"277", "\[Rule]", "170"}], ",", 
       RowBox[{"277", "\[Rule]", "350"}], ",", 
       RowBox[{"277", "\[Rule]", "278"}], ",", 
       RowBox[{"179", "\[Rule]", "108"}], ",", 
       RowBox[{"179", "\[Rule]", "108"}], ",", 
       RowBox[{"179", "\[Rule]", "288"}], ",", 
       RowBox[{"179", "\[Rule]", "288"}], ",", 
       RowBox[{"179", "\[Rule]", "72"}], ",", 
       RowBox[{"179", "\[Rule]", "252"}], ",", 
       RowBox[{"179", "\[Rule]", "180"}], ",", 
       RowBox[{"169", "\[Rule]", "98"}], ",", 
       RowBox[{"169", "\[Rule]", "98"}], ",", 
       RowBox[{"169", "\[Rule]", "278"}], ",", 
       RowBox[{"169", "\[Rule]", "62"}], ",", 
       RowBox[{"169", "\[Rule]", "170"}], ",", 
       RowBox[{"7", "\[Rule]", "116"}], ",", 
       RowBox[{"7", "\[Rule]", "116"}], ",", 
       RowBox[{"7", "\[Rule]", "8"}], ",", 
       RowBox[{"187", "\[Rule]", "116"}], ",", 
       RowBox[{"187", "\[Rule]", "116"}], ",", 
       RowBox[{"187", "\[Rule]", "296"}], ",", 
       RowBox[{"187", "\[Rule]", "188"}], ",", 
       RowBox[{"115", "\[Rule]", "44"}], ",", 
       RowBox[{"115", "\[Rule]", "224"}], ",", 
       RowBox[{"115", "\[Rule]", "8"}], ",", 
       RowBox[{"115", "\[Rule]", "8"}], ",", 
       RowBox[{"115", "\[Rule]", "188"}], ",", 
       RowBox[{"115", "\[Rule]", "188"}], ",", 
       RowBox[{"115", "\[Rule]", "116"}], ",", 
       RowBox[{"103", "\[Rule]", "176"}], ",", 
       RowBox[{"103", "\[Rule]", "176"}], ",", 
       RowBox[{"103", "\[Rule]", "104"}], ",", 
       RowBox[{"283", "\[Rule]", "176"}], ",", 
       RowBox[{"283", "\[Rule]", "176"}], ",", 
       RowBox[{"283", "\[Rule]", "356"}], ",", 
       RowBox[{"283", "\[Rule]", "356"}], ",", 
       RowBox[{"283", "\[Rule]", "284"}], ",", 
       RowBox[{"175", "\[Rule]", "104"}], ",", 
       RowBox[{"175", "\[Rule]", "104"}], ",", 
       RowBox[{"175", "\[Rule]", "284"}], ",", 
       RowBox[{"175", "\[Rule]", "284"}], ",", 
       RowBox[{"175", "\[Rule]", "68"}], ",", 
       RowBox[{"175", "\[Rule]", "248"}], ",", 
       RowBox[{"175", "\[Rule]", "176"}], ",", 
       RowBox[{"93", "\[Rule]", "166"}], ",", 
       RowBox[{"93", "\[Rule]", "166"}], ",", 
       RowBox[{"93", "\[Rule]", "94"}], ",", 
       RowBox[{"273", "\[Rule]", "166"}], ",", 
       RowBox[{"273", "\[Rule]", "166"}], ",", 
       RowBox[{"273", "\[Rule]", "346"}], ",", 
       RowBox[{"273", "\[Rule]", "346"}], ",", 
       RowBox[{"273", "\[Rule]", "274"}], ",", 
       RowBox[{"57", "\[Rule]", "166"}], ",", 
       RowBox[{"57", "\[Rule]", "130"}], ",", 
       RowBox[{"57", "\[Rule]", "58"}], ",", 
       RowBox[{"237", "\[Rule]", "166"}], ",", 
       RowBox[{"237", "\[Rule]", "346"}], ",", 
       RowBox[{"237", "\[Rule]", "346"}], ",", 
       RowBox[{"237", "\[Rule]", "310"}], ",", 
       RowBox[{"237", "\[Rule]", "238"}], ",", 
       RowBox[{"165", "\[Rule]", "94"}], ",", 
       RowBox[{"165", "\[Rule]", "94"}], ",", 
       RowBox[{"165", "\[Rule]", "274"}], ",", 
       RowBox[{"165", "\[Rule]", "274"}], ",", 
       RowBox[{"165", "\[Rule]", "58"}], ",", 
       RowBox[{"165", "\[Rule]", "238"}], ",", 
       RowBox[{"165", "\[Rule]", "166"}], ",", 
       RowBox[{"21", "\[Rule]", "130"}], ",", 
       RowBox[{"21", "\[Rule]", "130"}], ",", 
       RowBox[{"21", "\[Rule]", "22"}], ",", 
       RowBox[{"201", "\[Rule]", "130"}], ",", 
       RowBox[{"201", "\[Rule]", "202"}], ",", 
       RowBox[{"129", "\[Rule]", "58"}], ",", 
       RowBox[{"129", "\[Rule]", "22"}], ",", 
       RowBox[{"129", "\[Rule]", "22"}], ",", 
       RowBox[{"129", "\[Rule]", "202"}], ",", 
       RowBox[{"129", "\[Rule]", "130"}], ",", 
       RowBox[{"341", "\[Rule]", "270"}], ",", 
       RowBox[{"341", "\[Rule]", "270"}], ",", 
       RowBox[{"341", "\[Rule]", "234"}], ",", 
       RowBox[{"341", "\[Rule]", "234"}], ",", 
       RowBox[{"341", "\[Rule]", "342"}], ",", 
       RowBox[{"331", "\[Rule]", "260"}], ",", 
       RowBox[{"331", "\[Rule]", "260"}], ",", 
       RowBox[{"331", "\[Rule]", "224"}], ",", 
       RowBox[{"331", "\[Rule]", "224"}], ",", 
       RowBox[{"331", "\[Rule]", "332"}], ",", 
       RowBox[{"359", "\[Rule]", "288"}], ",", 
       RowBox[{"359", "\[Rule]", "252"}], ",", 
       RowBox[{"359", "\[Rule]", "252"}], ",", 
       RowBox[{"359", "\[Rule]", "360"}], ",", 
       RowBox[{"349", "\[Rule]", "278"}], ",", 
       RowBox[{"349", "\[Rule]", "242"}], ",", 
       RowBox[{"349", "\[Rule]", "350"}], ",", 
       RowBox[{"305", "\[Rule]", "234"}], ",", 
       RowBox[{"305", "\[Rule]", "234"}], ",", 
       RowBox[{"305", "\[Rule]", "198"}], ",", 
       RowBox[{"305", "\[Rule]", "306"}], ",", 
       RowBox[{"295", "\[Rule]", "224"}], ",", 
       RowBox[{"295", "\[Rule]", "224"}], ",", 
       RowBox[{"295", "\[Rule]", "188"}], ",", 
       RowBox[{"295", "\[Rule]", "296"}], ",", 
       RowBox[{"323", "\[Rule]", "252"}], ",", 
       RowBox[{"323", "\[Rule]", "252"}], ",", 
       RowBox[{"323", "\[Rule]", "216"}], ",", 
       RowBox[{"323", "\[Rule]", "324"}], ",", 
       RowBox[{"313", "\[Rule]", "242"}], ",", 
       RowBox[{"313", "\[Rule]", "242"}], ",", 
       RowBox[{"313", "\[Rule]", "206"}], ",", 
       RowBox[{"313", "\[Rule]", "314"}], ",", 
       RowBox[{"355", "\[Rule]", "284"}], ",", 
       RowBox[{"355", "\[Rule]", "284"}], ",", 
       RowBox[{"355", "\[Rule]", "248"}], ",", 
       RowBox[{"355", "\[Rule]", "356"}], ",", 
       RowBox[{"319", "\[Rule]", "248"}], ",", 
       RowBox[{"319", "\[Rule]", "212"}], ",", 
       RowBox[{"319", "\[Rule]", "320"}], ",", 
       RowBox[{"345", "\[Rule]", "274"}], ",", 
       RowBox[{"345", "\[Rule]", "274"}], ",", 
       RowBox[{"345", "\[Rule]", "238"}], ",", 
       RowBox[{"345", "\[Rule]", "238"}], ",", 
       RowBox[{"345", "\[Rule]", "346"}], ",", 
       RowBox[{"309", "\[Rule]", "238"}], ",", 
       RowBox[{"309", "\[Rule]", "310"}], ",", 
       RowBox[{"90", "\[Rule]", "81"}], ",", 
       RowBox[{"90", "\[Rule]", "99"}], ",", 
       RowBox[{"90", "\[Rule]", "87"}], ",", 
       RowBox[{"152", "\[Rule]", "159"}], ",", 
       RowBox[{"152", "\[Rule]", "153"}], ",", 
       RowBox[{"152", "\[Rule]", "149"}], ",", 
       RowBox[{"80", "\[Rule]", "87"}], ",", 
       RowBox[{"80", "\[Rule]", "81"}], ",", 
       RowBox[{"80", "\[Rule]", "77"}], ",", 
       RowBox[{"270", "\[Rule]", "261"}], ",", 
       RowBox[{"270", "\[Rule]", "279"}], ",", 
       RowBox[{"270", "\[Rule]", "267"}], ",", 
       RowBox[{"332", "\[Rule]", "339"}], ",", 
       RowBox[{"332", "\[Rule]", "333"}], ",", 
       RowBox[{"332", "\[Rule]", "329"}], ",", 
       RowBox[{"260", "\[Rule]", "267"}], ",", 
       RowBox[{"260", "\[Rule]", "261"}], ",", 
       RowBox[{"260", "\[Rule]", "257"}], ",", 
       RowBox[{"116", "\[Rule]", "123"}], ",", 
       RowBox[{"116", "\[Rule]", "117"}], ",", 
       RowBox[{"116", "\[Rule]", "113"}], ",", 
       RowBox[{"44", "\[Rule]", "51"}], ",", 
       RowBox[{"44", "\[Rule]", "45"}], ",", 
       RowBox[{"44", "\[Rule]", "41"}], ",", 
       RowBox[{"296", "\[Rule]", "303"}], ",", 
       RowBox[{"296", "\[Rule]", "297"}], ",", 
       RowBox[{"296", "\[Rule]", "293"}], ",", 
       RowBox[{"224", "\[Rule]", "231"}], ",", 
       RowBox[{"224", "\[Rule]", "225"}], ",", 
       RowBox[{"224", "\[Rule]", "221"}], ",", 
       RowBox[{"108", "\[Rule]", "99"}], ",", 
       RowBox[{"108", "\[Rule]", "105"}], ",", 
       RowBox[{"98", "\[Rule]", "87"}], ",", 
       RowBox[{"98", "\[Rule]", "105"}], ",", 
       RowBox[{"98", "\[Rule]", "99"}], ",", 
       RowBox[{"98", "\[Rule]", "95"}], ",", 
       RowBox[{"288", "\[Rule]", "279"}], ",", 
       RowBox[{"288", "\[Rule]", "285"}], ",", 
       RowBox[{"278", "\[Rule]", "267"}], ",", 
       RowBox[{"278", "\[Rule]", "285"}], ",", 
       RowBox[{"278", "\[Rule]", "279"}], ",", 
       RowBox[{"278", "\[Rule]", "275"}], ",", 
       RowBox[{"8", "\[Rule]", "15"}], ",", 
       RowBox[{"8", "\[Rule]", "9"}], ",", 
       RowBox[{"8", "\[Rule]", "5"}], ",", 
       RowBox[{"188", "\[Rule]", "195"}], ",", 
       RowBox[{"188", "\[Rule]", "189"}], ",", 
       RowBox[{"188", "\[Rule]", "185"}], ",", 
       RowBox[{"104", "\[Rule]", "95"}], ",", 
       RowBox[{"104", "\[Rule]", "105"}], ",", 
       RowBox[{"104", "\[Rule]", "101"}], ",", 
       RowBox[{"284", "\[Rule]", "275"}], ",", 
       RowBox[{"284", "\[Rule]", "285"}], ",", 
       RowBox[{"284", "\[Rule]", "281"}], ",", 
       RowBox[{"166", "\[Rule]", "157"}], ",", 
       RowBox[{"166", "\[Rule]", "173"}], ",", 
       RowBox[{"166", "\[Rule]", "167"}], ",", 
       RowBox[{"166", "\[Rule]", "163"}], ",", 
       RowBox[{"94", "\[Rule]", "85"}], ",", 
       RowBox[{"94", "\[Rule]", "101"}], ",", 
       RowBox[{"94", "\[Rule]", "95"}], ",", 
       RowBox[{"94", "\[Rule]", "91"}], ",", 
       RowBox[{"346", "\[Rule]", "337"}], ",", 
       RowBox[{"346", "\[Rule]", "353"}], ",", 
       RowBox[{"346", "\[Rule]", "347"}], ",", 
       RowBox[{"346", "\[Rule]", "343"}], ",", 
       RowBox[{"274", "\[Rule]", "265"}], ",", 
       RowBox[{"274", "\[Rule]", "281"}], ",", 
       RowBox[{"274", "\[Rule]", "275"}], ",", 
       RowBox[{"274", "\[Rule]", "271"}], ",", 
       RowBox[{"130", "\[Rule]", "121"}], ",", 
       RowBox[{"130", "\[Rule]", "137"}], ",", 
       RowBox[{"130", "\[Rule]", "131"}], ",", 
       RowBox[{"130", "\[Rule]", "127"}], ",", 
       RowBox[{"58", "\[Rule]", "49"}], ",", 
       RowBox[{"58", "\[Rule]", "65"}], ",", 
       RowBox[{"58", "\[Rule]", "59"}], ",", 
       RowBox[{"58", "\[Rule]", "55"}], ",", 
       RowBox[{"310", "\[Rule]", "301"}], ",", 
       RowBox[{"310", "\[Rule]", "317"}], ",", 
       RowBox[{"310", "\[Rule]", "311"}], ",", 
       RowBox[{"310", "\[Rule]", "307"}], ",", 
       RowBox[{"238", "\[Rule]", "229"}], ",", 
       RowBox[{"238", "\[Rule]", "245"}], ",", 
       RowBox[{"238", "\[Rule]", "239"}], ",", 
       RowBox[{"238", "\[Rule]", "235"}], ",", 
       RowBox[{"22", "\[Rule]", "13"}], ",", 
       RowBox[{"22", "\[Rule]", "29"}], ",", 
       RowBox[{"22", "\[Rule]", "23"}], ",", 
       RowBox[{"22", "\[Rule]", "19"}], ",", 
       RowBox[{"202", "\[Rule]", "193"}], ",", 
       RowBox[{"202", "\[Rule]", "209"}], ",", 
       RowBox[{"202", "\[Rule]", "203"}], ",", 
       RowBox[{"202", "\[Rule]", "199"}], ",", 
       RowBox[{"81", "\[Rule]", "154"}], ",", 
       RowBox[{"81", "\[Rule]", "154"}], ",", 
       RowBox[{"81", "\[Rule]", "82"}], ",", 
       RowBox[{"99", "\[Rule]", "172"}], ",", 
       RowBox[{"99", "\[Rule]", "172"}], ",", 
       RowBox[{"99", "\[Rule]", "100"}], ",", 
       RowBox[{"87", "\[Rule]", "160"}], ",", 
       RowBox[{"87", "\[Rule]", "160"}], ",", 
       RowBox[{"87", "\[Rule]", "88"}], ",", 
       RowBox[{"149", "\[Rule]", "78"}], ",", 
       RowBox[{"149", "\[Rule]", "78"}], ",", 
       RowBox[{"149", "\[Rule]", "258"}], ",", 
       RowBox[{"149", "\[Rule]", "258"}], ",", 
       RowBox[{"149", "\[Rule]", "42"}], ",", 
       RowBox[{"149", "\[Rule]", "222"}], ",", 
       RowBox[{"149", "\[Rule]", "150"}], ",", 
       RowBox[{"77", "\[Rule]", "150"}], ",", 
       RowBox[{"77", "\[Rule]", "150"}], ",", 
       RowBox[{"77", "\[Rule]", "78"}], ",", 
       RowBox[{"261", "\[Rule]", "154"}], ",", 
       RowBox[{"261", "\[Rule]", "154"}], ",", 
       RowBox[{"261", "\[Rule]", "334"}], ",", 
       RowBox[{"261", "\[Rule]", "334"}], ",", 
       RowBox[{"261", "\[Rule]", "262"}], ",", 
       RowBox[{"279", "\[Rule]", "172"}], ",", 
       RowBox[{"279", "\[Rule]", "172"}], ",", 
       RowBox[{"279", "\[Rule]", "352"}], ",", 
       RowBox[{"279", "\[Rule]", "352"}], ",", 
       RowBox[{"279", "\[Rule]", "280"}], ",", 
       RowBox[{"267", "\[Rule]", "160"}], ",", 
       RowBox[{"267", "\[Rule]", "160"}], ",", 
       RowBox[{"267", "\[Rule]", "340"}], ",", 
       RowBox[{"267", "\[Rule]", "340"}], ",", 
       RowBox[{"267", "\[Rule]", "268"}], ",", 
       RowBox[{"329", "\[Rule]", "258"}], ",", 
       RowBox[{"329", "\[Rule]", "258"}], ",", 
       RowBox[{"329", "\[Rule]", "222"}], ",", 
       RowBox[{"329", "\[Rule]", "222"}], ",", 
       RowBox[{"329", "\[Rule]", "330"}], ",", 
       RowBox[{"257", "\[Rule]", "150"}], ",", 
       RowBox[{"257", "\[Rule]", "150"}], ",", 
       RowBox[{"257", "\[Rule]", "330"}], ",", 
       RowBox[{"257", "\[Rule]", "330"}], ",", 
       RowBox[{"257", "\[Rule]", "258"}], ",", 
       RowBox[{"113", "\[Rule]", "42"}], ",", 
       RowBox[{"113", "\[Rule]", "222"}], ",", 
       RowBox[{"113", "\[Rule]", "6"}], ",", 
       RowBox[{"113", "\[Rule]", "6"}], ",", 
       RowBox[{"113", "\[Rule]", "186"}], ",", 
       RowBox[{"113", "\[Rule]", "186"}], ",", 
       RowBox[{"113", "\[Rule]", "114"}], ",", 
       RowBox[{"41", "\[Rule]", "150"}], ",", 
       RowBox[{"41", "\[Rule]", "114"}], ",", 
       RowBox[{"41", "\[Rule]", "42"}], ",", 
       RowBox[{"293", "\[Rule]", "222"}], ",", 
       RowBox[{"293", "\[Rule]", "222"}], ",", 
       RowBox[{"293", "\[Rule]", "186"}], ",", 
       RowBox[{"293", "\[Rule]", "294"}], ",", 
       RowBox[{"221", "\[Rule]", "150"}], ",", 
       RowBox[{"221", "\[Rule]", "330"}], ",", 
       RowBox[{"221", "\[Rule]", "330"}], ",", 
       RowBox[{"221", "\[Rule]", "114"}], ",", 
       RowBox[{"221", "\[Rule]", "294"}], ",", 
       RowBox[{"221", "\[Rule]", "294"}], ",", 
       RowBox[{"221", "\[Rule]", "222"}], ",", 
       RowBox[{"105", "\[Rule]", "178"}], ",", 
       RowBox[{"105", "\[Rule]", "178"}], ",", 
       RowBox[{"105", "\[Rule]", "106"}], ",", 
       RowBox[{"95", "\[Rule]", "168"}], ",", 
       RowBox[{"95", "\[Rule]", "168"}], ",", 
       RowBox[{"95", "\[Rule]", "96"}], ",", 
       RowBox[{"285", "\[Rule]", "178"}], ",", 
       RowBox[{"285", "\[Rule]", "178"}], ",", 
       RowBox[{"285", "\[Rule]", "358"}], ",", 
       RowBox[{"285", "\[Rule]", "358"}], ",", 
       RowBox[{"285", "\[Rule]", "286"}], ",", 
       RowBox[{"275", "\[Rule]", "168"}], ",", 
       RowBox[{"275", "\[Rule]", "168"}], ",", 
       RowBox[{"275", "\[Rule]", "348"}], ",", 
       RowBox[{"275", "\[Rule]", "348"}], ",", 
       RowBox[{"275", "\[Rule]", "276"}], ",", 
       RowBox[{"5", "\[Rule]", "114"}], ",", 
       RowBox[{"5", "\[Rule]", "114"}], ",", 
       RowBox[{"5", "\[Rule]", "6"}], ",", 
       RowBox[{"185", "\[Rule]", "114"}], ",", 
       RowBox[{"185", "\[Rule]", "114"}], ",", 
       RowBox[{"185", "\[Rule]", "294"}], ",", 
       RowBox[{"185", "\[Rule]", "186"}], ",", 
       RowBox[{"101", "\[Rule]", "174"}], ",", 
       RowBox[{"101", "\[Rule]", "174"}], ",", 
       RowBox[{"101", "\[Rule]", "102"}], ",", 
       RowBox[{"281", "\[Rule]", "174"}], ",", 
       RowBox[{"281", "\[Rule]", "174"}], ",", 
       RowBox[{"281", "\[Rule]", "354"}], ",", 
       RowBox[{"281", "\[Rule]", "354"}], ",", 
       RowBox[{"281", "\[Rule]", "282"}], ",", 
       RowBox[{"157", "\[Rule]", "86"}], ",", 
       RowBox[{"157", "\[Rule]", "86"}], ",", 
       RowBox[{"157", "\[Rule]", "266"}], ",", 
       RowBox[{"157", "\[Rule]", "266"}], ",", 
       RowBox[{"157", "\[Rule]", "50"}], ",", 
       RowBox[{"157", "\[Rule]", "230"}], ",", 
       RowBox[{"157", "\[Rule]", "158"}], ",", 
       RowBox[{"163", "\[Rule]", "92"}], ",", 
       RowBox[{"163", "\[Rule]", "92"}], ",", 
       RowBox[{"163", "\[Rule]", "272"}], ",", 
       RowBox[{"163", "\[Rule]", "272"}], ",", 
       RowBox[{"163", "\[Rule]", "56"}], ",", 
       RowBox[{"163", "\[Rule]", "236"}], ",", 
       RowBox[{"163", "\[Rule]", "164"}], ",", 
       RowBox[{"85", "\[Rule]", "158"}], ",", 
       RowBox[{"85", "\[Rule]", "158"}], ",", 
       RowBox[{"85", "\[Rule]", "86"}], ",", 
       RowBox[{"91", "\[Rule]", "164"}], ",", 
       RowBox[{"91", "\[Rule]", "164"}], ",", 
       RowBox[{"91", "\[Rule]", "92"}], ",", 
       RowBox[{"337", "\[Rule]", "266"}], ",", 
       RowBox[{"337", "\[Rule]", "266"}], ",", 
       RowBox[{"337", "\[Rule]", "230"}], ",", 
       RowBox[{"337", "\[Rule]", "230"}], ",", 
       RowBox[{"337", "\[Rule]", "338"}], ",", 
       RowBox[{"343", "\[Rule]", "272"}], ",", 
       RowBox[{"343", "\[Rule]", "272"}], ",", 
       RowBox[{"343", "\[Rule]", "236"}], ",", 
       RowBox[{"343", "\[Rule]", "236"}], ",", 
       RowBox[{"343", "\[Rule]", "344"}], ",", 
       RowBox[{"265", "\[Rule]", "158"}], ",", 
       RowBox[{"265", "\[Rule]", "158"}], ",", 
       RowBox[{"265", "\[Rule]", "338"}], ",", 
       RowBox[{"265", "\[Rule]", "338"}], ",", 
       RowBox[{"265", "\[Rule]", "266"}], ",", 
       RowBox[{"271", "\[Rule]", "164"}], ",", 
       RowBox[{"271", "\[Rule]", "164"}], ",", 
       RowBox[{"271", "\[Rule]", "344"}], ",", 
       RowBox[{"271", "\[Rule]", "344"}], ",", 
       RowBox[{"271", "\[Rule]", "272"}], ",", 
       RowBox[{"121", "\[Rule]", "50"}], ",", 
       RowBox[{"121", "\[Rule]", "230"}], ",", 
       RowBox[{"121", "\[Rule]", "14"}], ",", 
       RowBox[{"121", "\[Rule]", "14"}], ",", 
       RowBox[{"121", "\[Rule]", "194"}], ",", 
       RowBox[{"121", "\[Rule]", "194"}], ",", 
       RowBox[{"121", "\[Rule]", "122"}], ",", 
       RowBox[{"127", "\[Rule]", "56"}], ",", 
       RowBox[{"127", "\[Rule]", "236"}], ",", 
       RowBox[{"127", "\[Rule]", "20"}], ",", 
       RowBox[{"127", "\[Rule]", "20"}], ",", 
       RowBox[{"127", "\[Rule]", "200"}], ",", 
       RowBox[{"127", "\[Rule]", "200"}], ",", 
       RowBox[{"127", "\[Rule]", "128"}], ",", 
       RowBox[{"49", "\[Rule]", "158"}], ",", 
       RowBox[{"49", "\[Rule]", "122"}], ",", 
       RowBox[{"49", "\[Rule]", "50"}], ",", 
       RowBox[{"55", "\[Rule]", "164"}], ",", 
       RowBox[{"55", "\[Rule]", "128"}], ",", 
       RowBox[{"55", "\[Rule]", "56"}], ",", 
       RowBox[{"301", "\[Rule]", "230"}], ",", 
       RowBox[{"301", "\[Rule]", "230"}], ",", 
       RowBox[{"301", "\[Rule]", "194"}], ",", 
       RowBox[{"301", "\[Rule]", "302"}], ",", 
       RowBox[{"307", "\[Rule]", "236"}], ",", 
       RowBox[{"307", "\[Rule]", "236"}], ",", 
       RowBox[{"307", "\[Rule]", "200"}], ",", 
       RowBox[{"307", "\[Rule]", "308"}], ",", 
       RowBox[{"229", "\[Rule]", "158"}], ",", 
       RowBox[{"229", "\[Rule]", "338"}], ",", 
       RowBox[{"229", "\[Rule]", "338"}], ",", 
       RowBox[{"229", "\[Rule]", "122"}], ",", 
       RowBox[{"229", "\[Rule]", "302"}], ",", 
       RowBox[{"229", "\[Rule]", "302"}], ",", 
       RowBox[{"229", "\[Rule]", "230"}], ",", 
       RowBox[{"235", "\[Rule]", "164"}], ",", 
       RowBox[{"235", "\[Rule]", "344"}], ",", 
       RowBox[{"235", "\[Rule]", "344"}], ",", 
       RowBox[{"235", "\[Rule]", "128"}], ",", 
       RowBox[{"235", "\[Rule]", "308"}], ",", 
       RowBox[{"235", "\[Rule]", "308"}], ",", 
       RowBox[{"235", "\[Rule]", "236"}], ",", 
       RowBox[{"13", "\[Rule]", "122"}], ",", 
       RowBox[{"13", "\[Rule]", "122"}], ",", 
       RowBox[{"13", "\[Rule]", "14"}], ",", 
       RowBox[{"19", "\[Rule]", "128"}], ",", 
       RowBox[{"19", "\[Rule]", "128"}], ",", 
       RowBox[{"19", "\[Rule]", "20"}], ",", 
       RowBox[{"193", "\[Rule]", "122"}], ",", 
       RowBox[{"193", "\[Rule]", "122"}], ",", 
       RowBox[{"193", "\[Rule]", "302"}], ",", 
       RowBox[{"193", "\[Rule]", "194"}], ",", 
       RowBox[{"199", "\[Rule]", "128"}], ",", 
       RowBox[{"199", "\[Rule]", "128"}], ",", 
       RowBox[{"199", "\[Rule]", "308"}], ",", 
       RowBox[{"199", "\[Rule]", "200"}], ",", 
       RowBox[{"78", "\[Rule]", "79"}], ",", 
       RowBox[{"78", "\[Rule]", "75"}], ",", 
       RowBox[{"258", "\[Rule]", "259"}], ",", 
       RowBox[{"258", "\[Rule]", "255"}], ",", 
       RowBox[{"42", "\[Rule]", "43"}], ",", 
       RowBox[{"42", "\[Rule]", "39"}], ",", 
       RowBox[{"222", "\[Rule]", "223"}], ",", 
       RowBox[{"222", "\[Rule]", "219"}], ",", 
       RowBox[{"150", "\[Rule]", "151"}], ",", 
       RowBox[{"150", "\[Rule]", "147"}], ",", 
       RowBox[{"330", "\[Rule]", "331"}], ",", 
       RowBox[{"330", "\[Rule]", "327"}], ",", 
       RowBox[{"6", "\[Rule]", "7"}], ",", 
       RowBox[{"6", "\[Rule]", "3"}], ",", 
       RowBox[{"186", "\[Rule]", "187"}], ",", 
       RowBox[{"186", "\[Rule]", "183"}], ",", 
       RowBox[{"114", "\[Rule]", "115"}], ",", 
       RowBox[{"114", "\[Rule]", "111"}], ",", 
       RowBox[{"294", "\[Rule]", "295"}], ",", 
       RowBox[{"294", "\[Rule]", "291"}], ",", 
       RowBox[{"86", "\[Rule]", "75"}], ",", 
       RowBox[{"86", "\[Rule]", "93"}], ",", 
       RowBox[{"86", "\[Rule]", "83"}], ",", 
       RowBox[{"266", "\[Rule]", "255"}], ",", 
       RowBox[{"266", "\[Rule]", "273"}], ",", 
       RowBox[{"266", "\[Rule]", "263"}], ",", 
       RowBox[{"50", "\[Rule]", "39"}], ",", 
       RowBox[{"50", "\[Rule]", "57"}], ",", 
       RowBox[{"50", "\[Rule]", "47"}], ",", 
       RowBox[{"230", "\[Rule]", "219"}], ",", 
       RowBox[{"230", "\[Rule]", "237"}], ",", 
       RowBox[{"230", "\[Rule]", "227"}], ",", 
       RowBox[{"158", "\[Rule]", "147"}], ",", 
       RowBox[{"158", "\[Rule]", "165"}], ",", 
       RowBox[{"158", "\[Rule]", "155"}], ",", 
       RowBox[{"92", "\[Rule]", "83"}], ",", 
       RowBox[{"92", "\[Rule]", "93"}], ",", 
       RowBox[{"272", "\[Rule]", "263"}], ",", 
       RowBox[{"272", "\[Rule]", "273"}], ",", 
       RowBox[{"56", "\[Rule]", "47"}], ",", 
       RowBox[{"56", "\[Rule]", "57"}], ",", 
       RowBox[{"236", "\[Rule]", "227"}], ",", 
       RowBox[{"236", "\[Rule]", "237"}], ",", 
       RowBox[{"164", "\[Rule]", "155"}], ",", 
       RowBox[{"164", "\[Rule]", "165"}], ",", 
       RowBox[{"338", "\[Rule]", "327"}], ",", 
       RowBox[{"338", "\[Rule]", "345"}], ",", 
       RowBox[{"338", "\[Rule]", "335"}], ",", 
       RowBox[{"344", "\[Rule]", "335"}], ",", 
       RowBox[{"344", "\[Rule]", "345"}], ",", 
       RowBox[{"14", "\[Rule]", "3"}], ",", 
       RowBox[{"14", "\[Rule]", "21"}], ",", 
       RowBox[{"14", "\[Rule]", "11"}], ",", 
       RowBox[{"194", "\[Rule]", "183"}], ",", 
       RowBox[{"194", "\[Rule]", "201"}], ",", 
       RowBox[{"194", "\[Rule]", "191"}], ",", 
       RowBox[{"122", "\[Rule]", "111"}], ",", 
       RowBox[{"122", "\[Rule]", "129"}], ",", 
       RowBox[{"122", "\[Rule]", "119"}], ",", 
       RowBox[{"20", "\[Rule]", "11"}], ",", 
       RowBox[{"20", "\[Rule]", "21"}], ",", 
       RowBox[{"200", "\[Rule]", "191"}], ",", 
       RowBox[{"200", "\[Rule]", "201"}], ",", 
       RowBox[{"128", "\[Rule]", "119"}], ",", 
       RowBox[{"128", "\[Rule]", "129"}], ",", 
       RowBox[{"302", "\[Rule]", "291"}], ",", 
       RowBox[{"302", "\[Rule]", "309"}], ",", 
       RowBox[{"302", "\[Rule]", "299"}], ",", 
       RowBox[{"308", "\[Rule]", "299"}], ",", 
       RowBox[{"308", "\[Rule]", "309"}], ",", 
       RowBox[{"75", "\[Rule]", "148"}], ",", 
       RowBox[{"75", "\[Rule]", "148"}], ",", 
       RowBox[{"75", "\[Rule]", "76"}], ",", 
       RowBox[{"255", "\[Rule]", "148"}], ",", 
       RowBox[{"255", "\[Rule]", "148"}], ",", 
       RowBox[{"255", "\[Rule]", "328"}], ",", 
       RowBox[{"255", "\[Rule]", "328"}], ",", 
       RowBox[{"255", "\[Rule]", "256"}], ",", 
       RowBox[{"39", "\[Rule]", "148"}], ",", 
       RowBox[{"39", "\[Rule]", "40"}], ",", 
       RowBox[{"219", "\[Rule]", "148"}], ",", 
       RowBox[{"219", "\[Rule]", "328"}], ",", 
       RowBox[{"219", "\[Rule]", "328"}], ",", 
       RowBox[{"219", "\[Rule]", "112"}], ",", 
       RowBox[{"219", "\[Rule]", "292"}], ",", 
       RowBox[{"219", "\[Rule]", "292"}], ",", 
       RowBox[{"219", "\[Rule]", "220"}], ",", 
       RowBox[{"147", "\[Rule]", "76"}], ",", 
       RowBox[{"147", "\[Rule]", "76"}], ",", 
       RowBox[{"147", "\[Rule]", "256"}], ",", 
       RowBox[{"147", "\[Rule]", "256"}], ",", 
       RowBox[{"147", "\[Rule]", "40"}], ",", 
       RowBox[{"147", "\[Rule]", "220"}], ",", 
       RowBox[{"147", "\[Rule]", "148"}], ",", 
       RowBox[{"327", "\[Rule]", "256"}], ",", 
       RowBox[{"327", "\[Rule]", "256"}], ",", 
       RowBox[{"327", "\[Rule]", "220"}], ",", 
       RowBox[{"327", "\[Rule]", "220"}], ",", 
       RowBox[{"327", "\[Rule]", "328"}], ",", 
       RowBox[{"3", "\[Rule]", "112"}], ",", 
       RowBox[{"3", "\[Rule]", "4"}], ",", 
       RowBox[{"183", "\[Rule]", "112"}], ",", 
       RowBox[{"183", "\[Rule]", "112"}], ",", 
       RowBox[{"183", "\[Rule]", "292"}], ",", 
       RowBox[{"183", "\[Rule]", "184"}], ",", 
       RowBox[{"111", "\[Rule]", "220"}], ",", 
       RowBox[{"111", "\[Rule]", "4"}], ",", 
       RowBox[{"111", "\[Rule]", "184"}], ",", 
       RowBox[{"111", "\[Rule]", "184"}], ",", 
       RowBox[{"111", "\[Rule]", "112"}], ",", 
       RowBox[{"291", "\[Rule]", "220"}], ",", 
       RowBox[{"291", "\[Rule]", "220"}], ",", 
       RowBox[{"291", "\[Rule]", "184"}], ",", 
       RowBox[{"291", "\[Rule]", "292"}], ",", 
       RowBox[{"83", "\[Rule]", "156"}], ",", 
       RowBox[{"83", "\[Rule]", "156"}], ",", 
       RowBox[{"83", "\[Rule]", "84"}], ",", 
       RowBox[{"263", "\[Rule]", "156"}], ",", 
       RowBox[{"263", "\[Rule]", "156"}], ",", 
       RowBox[{"263", "\[Rule]", "336"}], ",", 
       RowBox[{"263", "\[Rule]", "336"}], ",", 
       RowBox[{"263", "\[Rule]", "264"}], ",", 
       RowBox[{"47", "\[Rule]", "156"}], ",", 
       RowBox[{"47", "\[Rule]", "120"}], ",", 
       RowBox[{"47", "\[Rule]", "48"}], ",", 
       RowBox[{"227", "\[Rule]", "156"}], ",", 
       RowBox[{"227", "\[Rule]", "336"}], ",", 
       RowBox[{"227", "\[Rule]", "336"}], ",", 
       RowBox[{"227", "\[Rule]", "120"}], ",", 
       RowBox[{"227", "\[Rule]", "300"}], ",", 
       RowBox[{"227", "\[Rule]", "300"}], ",", 
       RowBox[{"227", "\[Rule]", "228"}], ",", 
       RowBox[{"155", "\[Rule]", "84"}], ",", 
       RowBox[{"155", "\[Rule]", "84"}], ",", 
       RowBox[{"155", "\[Rule]", "264"}], ",", 
       RowBox[{"155", "\[Rule]", "264"}], ",", 
       RowBox[{"155", "\[Rule]", "48"}], ",", 
       RowBox[{"155", "\[Rule]", "228"}], ",", 
       RowBox[{"155", "\[Rule]", "156"}], ",", 
       RowBox[{"335", "\[Rule]", "264"}], ",", 
       RowBox[{"335", "\[Rule]", "264"}], ",", 
       RowBox[{"335", "\[Rule]", "228"}], ",", 
       RowBox[{"335", "\[Rule]", "228"}], ",", 
       RowBox[{"335", "\[Rule]", "336"}], ",", 
       RowBox[{"11", "\[Rule]", "120"}], ",", 
       RowBox[{"11", "\[Rule]", "12"}], ",", 
       RowBox[{"191", "\[Rule]", "120"}], ",", 
       RowBox[{"191", "\[Rule]", "300"}], ",", 
       RowBox[{"191", "\[Rule]", "192"}], ",", 
       RowBox[{"119", "\[Rule]", "48"}], ",", 
       RowBox[{"119", "\[Rule]", "228"}], ",", 
       RowBox[{"119", "\[Rule]", "12"}], ",", 
       RowBox[{"119", "\[Rule]", "192"}], ",", 
       RowBox[{"119", "\[Rule]", "120"}], ",", 
       RowBox[{"299", "\[Rule]", "228"}], ",", 
       RowBox[{"299", "\[Rule]", "228"}], ",", 
       RowBox[{"299", "\[Rule]", "192"}], ",", 
       RowBox[{"299", "\[Rule]", "300"}], ",", 
       RowBox[{"148", "\[Rule]", "157"}], ",", 
       RowBox[{"148", "\[Rule]", "149"}], ",", 
       RowBox[{"148", "\[Rule]", "145"}], ",", 
       RowBox[{"76", "\[Rule]", "85"}], ",", 
       RowBox[{"76", "\[Rule]", "77"}], ",", 
       RowBox[{"76", "\[Rule]", "73"}], ",", 
       RowBox[{"328", "\[Rule]", "337"}], ",", 
       RowBox[{"328", "\[Rule]", "329"}], ",", 
       RowBox[{"328", "\[Rule]", "325"}], ",", 
       RowBox[{"256", "\[Rule]", "265"}], ",", 
       RowBox[{"256", "\[Rule]", "257"}], ",", 
       RowBox[{"256", "\[Rule]", "253"}], ",", 
       RowBox[{"40", "\[Rule]", "49"}], ",", 
       RowBox[{"40", "\[Rule]", "41"}], ",", 
       RowBox[{"40", "\[Rule]", "37"}], ",", 
       RowBox[{"112", "\[Rule]", "121"}], ",", 
       RowBox[{"112", "\[Rule]", "113"}], ",", 
       RowBox[{"112", "\[Rule]", "109"}], ",", 
       RowBox[{"292", "\[Rule]", "301"}], ",", 
       RowBox[{"292", "\[Rule]", "293"}], ",", 
       RowBox[{"292", "\[Rule]", "289"}], ",", 
       RowBox[{"220", "\[Rule]", "229"}], ",", 
       RowBox[{"220", "\[Rule]", "221"}], ",", 
       RowBox[{"220", "\[Rule]", "217"}], ",", 
       RowBox[{"4", "\[Rule]", "13"}], ",", 
       RowBox[{"4", "\[Rule]", "5"}], ",", 
       RowBox[{"4", "\[Rule]", "1"}], ",", 
       RowBox[{"184", "\[Rule]", "193"}], ",", 
       RowBox[{"184", "\[Rule]", "185"}], ",", 
       RowBox[{"184", "\[Rule]", "181"}], ",", 
       RowBox[{"156", "\[Rule]", "145"}], ",", 
       RowBox[{"156", "\[Rule]", "163"}], ",", 
       RowBox[{"156", "\[Rule]", "157"}], ",", 
       RowBox[{"84", "\[Rule]", "73"}], ",", 
       RowBox[{"84", "\[Rule]", "91"}], ",", 
       RowBox[{"84", "\[Rule]", "85"}], ",", 
       RowBox[{"336", "\[Rule]", "325"}], ",", 
       RowBox[{"336", "\[Rule]", "343"}], ",", 
       RowBox[{"336", "\[Rule]", "337"}], ",", 
       RowBox[{"264", "\[Rule]", "253"}], ",", 
       RowBox[{"264", "\[Rule]", "271"}], ",", 
       RowBox[{"264", "\[Rule]", "265"}], ",", 
       RowBox[{"120", "\[Rule]", "109"}], ",", 
       RowBox[{"120", "\[Rule]", "127"}], ",", 
       RowBox[{"120", "\[Rule]", "121"}], ",", 
       RowBox[{"48", "\[Rule]", "37"}], ",", 
       RowBox[{"48", "\[Rule]", "55"}], ",", 
       RowBox[{"48", "\[Rule]", "49"}], ",", 
       RowBox[{"300", "\[Rule]", "289"}], ",", 
       RowBox[{"300", "\[Rule]", "307"}], ",", 
       RowBox[{"300", "\[Rule]", "301"}], ",", 
       RowBox[{"228", "\[Rule]", "217"}], ",", 
       RowBox[{"228", "\[Rule]", "235"}], ",", 
       RowBox[{"228", "\[Rule]", "229"}], ",", 
       RowBox[{"12", "\[Rule]", "1"}], ",", 
       RowBox[{"12", "\[Rule]", "19"}], ",", 
       RowBox[{"12", "\[Rule]", "13"}], ",", 
       RowBox[{"192", "\[Rule]", "181"}], ",", 
       RowBox[{"192", "\[Rule]", "199"}], ",", 
       RowBox[{"192", "\[Rule]", "193"}], ",", 
       RowBox[{"145", "\[Rule]", "74"}], ",", 
       RowBox[{"145", "\[Rule]", "74"}], ",", 
       RowBox[{"145", "\[Rule]", "254"}], ",", 
       RowBox[{"145", "\[Rule]", "254"}], ",", 
       RowBox[{"145", "\[Rule]", "38"}], ",", 
       RowBox[{"145", "\[Rule]", "218"}], ",", 
       RowBox[{"145", "\[Rule]", "146"}], ",", 
       RowBox[{"73", "\[Rule]", "146"}], ",", 
       RowBox[{"73", "\[Rule]", "146"}], ",", 
       RowBox[{"73", "\[Rule]", "74"}], ",", 
       RowBox[{"325", "\[Rule]", "254"}], ",", 
       RowBox[{"325", "\[Rule]", "254"}], ",", 
       RowBox[{"325", "\[Rule]", "218"}], ",", 
       RowBox[{"325", "\[Rule]", "218"}], ",", 
       RowBox[{"325", "\[Rule]", "326"}], ",", 
       RowBox[{"253", "\[Rule]", "146"}], ",", 
       RowBox[{"253", "\[Rule]", "146"}], ",", 
       RowBox[{"253", "\[Rule]", "326"}], ",", 
       RowBox[{"253", "\[Rule]", "326"}], ",", 
       RowBox[{"253", "\[Rule]", "254"}], ",", 
       RowBox[{"37", "\[Rule]", "146"}], ",", 
       RowBox[{"37", "\[Rule]", "110"}], ",", 
       RowBox[{"37", "\[Rule]", "38"}], ",", 
       RowBox[{"109", "\[Rule]", "38"}], ",", 
       RowBox[{"109", "\[Rule]", "218"}], ",", 
       RowBox[{"109", "\[Rule]", "2"}], ",", 
       RowBox[{"109", "\[Rule]", "2"}], ",", 
       RowBox[{"109", "\[Rule]", "182"}], ",", 
       RowBox[{"109", "\[Rule]", "182"}], ",", 
       RowBox[{"109", "\[Rule]", "110"}], ",", 
       RowBox[{"289", "\[Rule]", "218"}], ",", 
       RowBox[{"289", "\[Rule]", "218"}], ",", 
       RowBox[{"289", "\[Rule]", "182"}], ",", 
       RowBox[{"289", "\[Rule]", "290"}], ",", 
       RowBox[{"217", "\[Rule]", "146"}], ",", 
       RowBox[{"217", "\[Rule]", "326"}], ",", 
       RowBox[{"217", "\[Rule]", "326"}], ",", 
       RowBox[{"217", "\[Rule]", "110"}], ",", 
       RowBox[{"217", "\[Rule]", "290"}], ",", 
       RowBox[{"217", "\[Rule]", "290"}], ",", 
       RowBox[{"217", "\[Rule]", "218"}], ",", 
       RowBox[{"1", "\[Rule]", "110"}], ",", 
       RowBox[{"1", "\[Rule]", "110"}], ",", 
       RowBox[{"1", "\[Rule]", "2"}], ",", 
       RowBox[{"181", "\[Rule]", "110"}], ",", 
       RowBox[{"181", "\[Rule]", "110"}], ",", 
       RowBox[{"181", "\[Rule]", "290"}], ",", 
       RowBox[{"181", "\[Rule]", "182"}], ",", 
       RowBox[{"74", "\[Rule]", "83"}], ",", 
       RowBox[{"74", "\[Rule]", "75"}], ",", 
       RowBox[{"254", "\[Rule]", "263"}], ",", 
       RowBox[{"254", "\[Rule]", "255"}], ",", 
       RowBox[{"38", "\[Rule]", "47"}], ",", 
       RowBox[{"38", "\[Rule]", "39"}], ",", 
       RowBox[{"218", "\[Rule]", "227"}], ",", 
       RowBox[{"218", "\[Rule]", "219"}], ",", 
       RowBox[{"146", "\[Rule]", "155"}], ",", 
       RowBox[{"146", "\[Rule]", "147"}], ",", 
       RowBox[{"326", "\[Rule]", "335"}], ",", 
       RowBox[{"326", "\[Rule]", "327"}], ",", 
       RowBox[{"110", "\[Rule]", "119"}], ",", 
       RowBox[{"110", "\[Rule]", "111"}], ",", 
       RowBox[{"2", "\[Rule]", "11"}], ",", 
       RowBox[{"2", "\[Rule]", "3"}], ",", 
       RowBox[{"182", "\[Rule]", "191"}], ",", 
       RowBox[{"182", "\[Rule]", "183"}], ",", 
       RowBox[{"290", "\[Rule]", "299"}], ",", 
       RowBox[{"290", "\[Rule]", "291"}]}], "}"}], ",", 
     RowBox[{"EdgeWeight", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "c", ",", "d", ",", "i", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "i", ",", "c", ",", "d", ",", "i", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "c", ",", "g", ",", "i", ",", "c", ",", "g", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "d", ",", "e", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "i", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "b", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", 
        "i", ",", "a", ",", "c", ",", "e", ",", "g", ",", "i", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "b", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "c", ",", "g", ",", "i", ",", "c", ",", 
        "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "b", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "f", ",", "i", ",", "a", ",", "b", ",", "f", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "f", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "f", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "e", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", 
        "c", ",", "d", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "b", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "f", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "i", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "g", ",", "i", ",", "h", ",", "i", ",", "e", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "g", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", 
        "i", ",", "b", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "h", ",", "i", ",", "g", ",", "h", ",", "i", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "i", ",", 
        "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "f", ",", 
        "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", 
        "b", ",", "i", ",", "b", ",", "e", ",", "f", ",", "g", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "e", ",", "i", ",", "a", ",", "b", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "f", ",", "i", ",", "a", ",", "b", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "f", ",", "i", ",", "b", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "i", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "g", ",", "h", ",", "i", ",", "g", ",", "h", ",", "i", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", 
        "b", ",", "f", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "g", ",", "h", ",", "i", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "g", ",", 
        "h", ",", "i", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "a", ",", "b", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "f", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "e", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", 
        "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "i", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "g", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "d", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "i", ",", "d", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "f", ",", "i", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "c", ",", "i", ",", "a", ",", "c", ",", "i", ",", "b", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "f", ",", 
        "i", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "f", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "e", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "i", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"init4", "=", 
   RowBox[{"{", "35", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bad4", "=", 
   RowBox[{"{", 
    RowBox[{
    "2", ",", "42", ",", "82", ",", "122", ",", "160", ",", "200", ",", "240",
      ",", "280", ",", "318", ",", "358", ",", "1", ",", "41", ",", "81", ",",
      "121", ",", "159", ",", "199", ",", "239", ",", "279", ",", "317", ",", 
     "357"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lag4", "=", "8"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"graphical4", "=", "0"}], ";"}]}], "Input",
 CellChangeTimes->{{3.686025994957309*^9, 3.686026099831461*^9}, {
   3.6860261438122177`*^9, 3.686026176931148*^9}, 3.686026214223475*^9, {
   3.6860262647459717`*^9, 3.686026264982861*^9}, {3.686034622552107*^9, 
   3.686034628125643*^9}, {3.686046104270862*^9, 3.686046104850851*^9}, {
   3.686046154719606*^9, 3.686046158030952*^9}, 3.686047550621757*^9, {
   3.6930373931279917`*^9, 3.693037399556898*^9}, 3.693037472771635*^9, {
   3.693038158973789*^9, 3.6930381650361757`*^9}, {3.6930428123397503`*^9, 
   3.6930428231360483`*^9}, {3.693042919219357*^9, 3.6930429194085093`*^9}, {
   3.6930429516798887`*^9, 3.693042982121161*^9}, {3.693043077791449*^9, 
   3.69304309606213*^9}, 3.693043291196598*^9, 3.693043620502562*^9, {
   3.693044334417268*^9, 3.693044334984551*^9}, 3.693090945355526*^9, {
   3.693091965118734*^9, 3.693092009204561*^9}, {3.6930920757053328`*^9, 
   3.693092085073921*^9}, 3.693092154521061*^9, 3.693092208978632*^9, {
   3.693092275145597*^9, 3.6930923031680183`*^9}, {3.693093406035363*^9, 
   3.693093424747863*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"main", "[", 
  RowBox[{"g4", ",", "init4", ",", "bad4", ",", "lag4", ",", "graphical4"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6930430476106987`*^9, 3.693043058627466*^9}, {
  3.6930920447959757`*^9, 3.693092052345579*^9}, {3.69309213878589*^9, 
  3.693092147161015*^9}, {3.693093428876047*^9, 3.693093437286838*^9}}],

Cell[CellGroupData[{

Cell[BoxData["\<\"Under delay = 0 :\"\>"], "Print",
 CellChangeTimes->{3.694147496278737*^9, 3.6941478306218987`*^9, 
  3.7148210259308987`*^9}],

Cell[BoxData["\<\"(*hidden for the sake of space*)\"\>"], "Print",
 CellChangeTimes->{3.694147496278737*^9, 3.6941478306218987`*^9, 
  3.7148210259315987`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Under delay = \"\>", "\[InvisibleSpace]", "1", 
   "\[InvisibleSpace]", "\<\" :\"\>"}],
  SequenceForm["Under delay = ", 1, " :"],
  Editable->False]], "Print",
 CellChangeTimes->{3.694147496278737*^9, 3.6941478306218987`*^9, 
  3.714821025932391*^9}],

Cell[BoxData["\<\"(*hidden for the sake of space*)\"\>"], "Print",
 CellChangeTimes->{3.694147496278737*^9, 3.6941478306218987`*^9, 
  3.714821026025195*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Under delay = \"\>", "\[InvisibleSpace]", "2", 
   "\[InvisibleSpace]", "\<\" :\"\>"}],
  SequenceForm["Under delay = ", 2, " :"],
  Editable->False]], "Print",
 CellChangeTimes->{3.694147496278737*^9, 3.6941478306218987`*^9, 
  3.714821026026019*^9}],

Cell[BoxData["\<\"(*hidden for the sake of space*)\"\>"], "Print",
 CellChangeTimes->{3.694147496278737*^9, 3.6941478306218987`*^9, 
  3.714821026208843*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Under delay = \"\>", "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\" :\"\>"}],
  SequenceForm["Under delay = ", 3, " :"],
  Editable->False]], "Print",
 CellChangeTimes->{3.694147496278737*^9, 3.6941478306218987`*^9, 
  3.7148210262096043`*^9}],

Cell[BoxData["\<\"(*hidden for the sake of space*)\"\>"], "Print",
 CellChangeTimes->{3.694147496278737*^9, 3.6941478306218987`*^9, 
  3.714821026378891*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Not possible for sure-winning anymore under delay=\"\>", 
   "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\" with uncontrollable states \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "162", ",", "170", ",", "360", ",", "350", ",", "314", ",", "242", ",", 
     "356", ",", "320", ",", "248", ",", "100", ",", "88", ",", "268", ",", 
     "106", ",", "286", ",", "96", ",", "276", ",", "24", ",", "204", ",", 
     "352", ",", "340", ",", "348", ",", "312", ",", "30", ",", "210", ",", 
     "90", ",", "152", ",", "80", ",", "270", ",", "260", ",", "44", ",", 
     "98", ",", "288", ",", "278", ",", "346", ",", "130", ",", "310", ",", 
     "238", ",", "22", ",", "202", ",", "78", ",", "6", ",", "14", ",", "194",
      ",", "20", ",", "302", ",", "308", ",", "40", ",", "112", ",", "4", ",",
      "184", ",", "120", ",", "12", ",", "192", ",", "64", ",", "70", ",", 
     "244", ",", "144", ",", "250", ",", "28", ",", "34", ",", "208", ",", 
     "214", ",", "136", ",", "142", ",", "134", ",", "62", ",", "342", ",", 
     "36", ",", "26", ",", "206", ",", "35"}], "}"}], 
   "\[InvisibleSpace]", "\<\".\\n\"\>"}],
  SequenceForm[
  "Not possible for sure-winning anymore under delay=", 3, 
   " with uncontrollable states ", {162, 170, 360, 350, 314, 242, 356, 320, 
   248, 100, 88, 268, 106, 286, 96, 276, 24, 204, 352, 340, 348, 312, 30, 210,
    90, 152, 80, 270, 260, 44, 98, 288, 278, 346, 130, 310, 238, 22, 202, 78, 
   6, 14, 194, 20, 302, 308, 40, 112, 4, 184, 120, 12, 192, 64, 70, 244, 144, 
   250, 28, 34, 208, 214, 136, 142, 134, 62, 342, 36, 26, 206, 35}, ".\n"],
  Editable->False]], "Print",
 CellChangeTimes->{3.694147496278737*^9, 3.6941478306218987`*^9, 
  3.7148210263804007`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Computation time under increasing delays : \\n\"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "0.1799999999999926`", ",", "0.27199999999999136`", ",", 
     "0.45599999999998886`", ",", "0.6280000000000001`"}], "}"}]}],
  SequenceForm[
  "Computation time under increasing delays : \n", {0.1799999999999926, 
   0.27199999999999136`, 0.45599999999998886`, 0.6280000000000001}],
  Editable->False]], "Print",
 CellChangeTimes->{3.694147496278737*^9, 3.6941478306218987`*^9, 
  3.714821026381277*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Escp. 5 x 5", "Subsection",
 CellChangeTimes->{{3.725591915936283*^9, 3.725591919983073*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"g5", " ", "=", " ", 
   RowBox[{"Graph", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"45", "\[Rule]", "184"}], ",", 
       RowBox[{"45", "\[Rule]", "184"}], ",", 
       RowBox[{"45", "\[Rule]", "46"}], ",", 
       RowBox[{"184", "\[Rule]", "173"}], ",", 
       RowBox[{"184", "\[Rule]", "181"}], ",", 
       RowBox[{"46", "\[Rule]", "35"}], ",", 
       RowBox[{"46", "\[Rule]", "43"}], ",", 
       RowBox[{"173", "\[Rule]", "82"}], ",", 
       RowBox[{"173", "\[Rule]", "312"}], ",", 
       RowBox[{"173", "\[Rule]", "36"}], ",", 
       RowBox[{"173", "\[Rule]", "36"}], ",", 
       RowBox[{"173", "\[Rule]", "266"}], ",", 
       RowBox[{"173", "\[Rule]", "266"}], ",", 
       RowBox[{"173", "\[Rule]", "174"}], ",", 
       RowBox[{"181", "\[Rule]", "90"}], ",", 
       RowBox[{"181", "\[Rule]", "320"}], ",", 
       RowBox[{"181", "\[Rule]", "44"}], ",", 
       RowBox[{"181", "\[Rule]", "44"}], ",", 
       RowBox[{"181", "\[Rule]", "274"}], ",", 
       RowBox[{"181", "\[Rule]", "274"}], ",", 
       RowBox[{"181", "\[Rule]", "182"}], ",", 
       RowBox[{"35", "\[Rule]", "174"}], ",", 
       RowBox[{"35", "\[Rule]", "174"}], ",", 
       RowBox[{"35", "\[Rule]", "36"}], ",", 
       RowBox[{"43", "\[Rule]", "182"}], ",", 
       RowBox[{"43", "\[Rule]", "182"}], ",", 
       RowBox[{"43", "\[Rule]", "44"}], ",", 
       RowBox[{"82", "\[Rule]", "73"}], ",", 
       RowBox[{"82", "\[Rule]", "91"}], ",", 
       RowBox[{"82", "\[Rule]", "79"}], ",", 
       RowBox[{"312", "\[Rule]", "303"}], ",", 
       RowBox[{"312", "\[Rule]", "321"}], ",", 
       RowBox[{"312", "\[Rule]", "309"}], ",", 
       RowBox[{"36", "\[Rule]", "27"}], ",", 
       RowBox[{"36", "\[Rule]", "45"}], ",", 
       RowBox[{"36", "\[Rule]", "33"}], ",", 
       RowBox[{"266", "\[Rule]", "257"}], ",", 
       RowBox[{"266", "\[Rule]", "275"}], ",", 
       RowBox[{"266", "\[Rule]", "263"}], ",", 
       RowBox[{"174", "\[Rule]", "165"}], ",", 
       RowBox[{"174", "\[Rule]", "183"}], ",", 
       RowBox[{"174", "\[Rule]", "171"}], ",", 
       RowBox[{"90", "\[Rule]", "79"}], ",", 
       RowBox[{"90", "\[Rule]", "91"}], ",", 
       RowBox[{"90", "\[Rule]", "87"}], ",", 
       RowBox[{"320", "\[Rule]", "309"}], ",", 
       RowBox[{"320", "\[Rule]", "321"}], ",", 
       RowBox[{"320", "\[Rule]", "317"}], ",", 
       RowBox[{"44", "\[Rule]", "33"}], ",", 
       RowBox[{"44", "\[Rule]", "45"}], ",", 
       RowBox[{"44", "\[Rule]", "41"}], ",", 
       RowBox[{"274", "\[Rule]", "263"}], ",", 
       RowBox[{"274", "\[Rule]", "275"}], ",", 
       RowBox[{"274", "\[Rule]", "271"}], ",", 
       RowBox[{"182", "\[Rule]", "171"}], ",", 
       RowBox[{"182", "\[Rule]", "183"}], ",", 
       RowBox[{"182", "\[Rule]", "179"}], ",", 
       RowBox[{"73", "\[Rule]", "212"}], ",", 
       RowBox[{"73", "\[Rule]", "166"}], ",", 
       RowBox[{"73", "\[Rule]", "74"}], ",", 
       RowBox[{"91", "\[Rule]", "230"}], ",", 
       RowBox[{"91", "\[Rule]", "184"}], ",", 
       RowBox[{"91", "\[Rule]", "92"}], ",", 
       RowBox[{"79", "\[Rule]", "218"}], ",", 
       RowBox[{"79", "\[Rule]", "172"}], ",", 
       RowBox[{"79", "\[Rule]", "80"}], ",", 
       RowBox[{"303", "\[Rule]", "212"}], ",", 
       RowBox[{"303", "\[Rule]", "442"}], ",", 
       RowBox[{"303", "\[Rule]", "442"}], ",", 
       RowBox[{"303", "\[Rule]", "166"}], ",", 
       RowBox[{"303", "\[Rule]", "396"}], ",", 
       RowBox[{"303", "\[Rule]", "396"}], ",", 
       RowBox[{"303", "\[Rule]", "304"}], ",", 
       RowBox[{"321", "\[Rule]", "230"}], ",", 
       RowBox[{"321", "\[Rule]", "460"}], ",", 
       RowBox[{"321", "\[Rule]", "460"}], ",", 
       RowBox[{"321", "\[Rule]", "184"}], ",", 
       RowBox[{"321", "\[Rule]", "414"}], ",", 
       RowBox[{"321", "\[Rule]", "414"}], ",", 
       RowBox[{"321", "\[Rule]", "322"}], ",", 
       RowBox[{"309", "\[Rule]", "218"}], ",", 
       RowBox[{"309", "\[Rule]", "448"}], ",", 
       RowBox[{"309", "\[Rule]", "448"}], ",", 
       RowBox[{"309", "\[Rule]", "172"}], ",", 
       RowBox[{"309", "\[Rule]", "402"}], ",", 
       RowBox[{"309", "\[Rule]", "402"}], ",", 
       RowBox[{"309", "\[Rule]", "310"}], ",", 
       RowBox[{"27", "\[Rule]", "166"}], ",", 
       RowBox[{"27", "\[Rule]", "166"}], ",", 
       RowBox[{"27", "\[Rule]", "28"}], ",", 
       RowBox[{"33", "\[Rule]", "172"}], ",", 
       RowBox[{"33", "\[Rule]", "172"}], ",", 
       RowBox[{"33", "\[Rule]", "34"}], ",", 
       RowBox[{"257", "\[Rule]", "166"}], ",", 
       RowBox[{"257", "\[Rule]", "166"}], ",", 
       RowBox[{"257", "\[Rule]", "396"}], ",", 
       RowBox[{"257", "\[Rule]", "258"}], ",", 
       RowBox[{"275", "\[Rule]", "184"}], ",", 
       RowBox[{"275", "\[Rule]", "184"}], ",", 
       RowBox[{"275", "\[Rule]", "414"}], ",", 
       RowBox[{"275", "\[Rule]", "276"}], ",", 
       RowBox[{"263", "\[Rule]", "172"}], ",", 
       RowBox[{"263", "\[Rule]", "172"}], ",", 
       RowBox[{"263", "\[Rule]", "402"}], ",", 
       RowBox[{"263", "\[Rule]", "264"}], ",", 
       RowBox[{"165", "\[Rule]", "74"}], ",", 
       RowBox[{"165", "\[Rule]", "304"}], ",", 
       RowBox[{"165", "\[Rule]", "28"}], ",", 
       RowBox[{"165", "\[Rule]", "28"}], ",", 
       RowBox[{"165", "\[Rule]", "258"}], ",", 
       RowBox[{"165", "\[Rule]", "258"}], ",", 
       RowBox[{"165", "\[Rule]", "166"}], ",", 
       RowBox[{"183", "\[Rule]", "92"}], ",", 
       RowBox[{"183", "\[Rule]", "322"}], ",", 
       RowBox[{"183", "\[Rule]", "46"}], ",", 
       RowBox[{"183", "\[Rule]", "46"}], ",", 
       RowBox[{"183", "\[Rule]", "276"}], ",", 
       RowBox[{"183", "\[Rule]", "276"}], ",", 
       RowBox[{"183", "\[Rule]", "184"}], ",", 
       RowBox[{"171", "\[Rule]", "80"}], ",", 
       RowBox[{"171", "\[Rule]", "310"}], ",", 
       RowBox[{"171", "\[Rule]", "34"}], ",", 
       RowBox[{"171", "\[Rule]", "34"}], ",", 
       RowBox[{"171", "\[Rule]", "264"}], ",", 
       RowBox[{"171", "\[Rule]", "264"}], ",", 
       RowBox[{"171", "\[Rule]", "172"}], ",", 
       RowBox[{"87", "\[Rule]", "226"}], ",", 
       RowBox[{"87", "\[Rule]", "180"}], ",", 
       RowBox[{"87", "\[Rule]", "88"}], ",", 
       RowBox[{"317", "\[Rule]", "226"}], ",", 
       RowBox[{"317", "\[Rule]", "456"}], ",", 
       RowBox[{"317", "\[Rule]", "456"}], ",", 
       RowBox[{"317", "\[Rule]", "180"}], ",", 
       RowBox[{"317", "\[Rule]", "410"}], ",", 
       RowBox[{"317", "\[Rule]", "410"}], ",", 
       RowBox[{"317", "\[Rule]", "318"}], ",", 
       RowBox[{"41", "\[Rule]", "180"}], ",", 
       RowBox[{"41", "\[Rule]", "180"}], ",", 
       RowBox[{"41", "\[Rule]", "42"}], ",", 
       RowBox[{"271", "\[Rule]", "180"}], ",", 
       RowBox[{"271", "\[Rule]", "180"}], ",", 
       RowBox[{"271", "\[Rule]", "410"}], ",", 
       RowBox[{"271", "\[Rule]", "272"}], ",", 
       RowBox[{"179", "\[Rule]", "88"}], ",", 
       RowBox[{"179", "\[Rule]", "318"}], ",", 
       RowBox[{"179", "\[Rule]", "42"}], ",", 
       RowBox[{"179", "\[Rule]", "42"}], ",", 
       RowBox[{"179", "\[Rule]", "272"}], ",", 
       RowBox[{"179", "\[Rule]", "272"}], ",", 
       RowBox[{"179", "\[Rule]", "180"}], ",", 
       RowBox[{"212", "\[Rule]", "201"}], ",", 
       RowBox[{"212", "\[Rule]", "219"}], ",", 
       RowBox[{"212", "\[Rule]", "209"}], ",", 
       RowBox[{"166", "\[Rule]", "155"}], ",", 
       RowBox[{"166", "\[Rule]", "173"}], ",", 
       RowBox[{"166", "\[Rule]", "163"}], ",", 
       RowBox[{"74", "\[Rule]", "63"}], ",", 
       RowBox[{"74", "\[Rule]", "81"}], ",", 
       RowBox[{"74", "\[Rule]", "71"}], ",", 
       RowBox[{"230", "\[Rule]", "219"}], ",", 
       RowBox[{"230", "\[Rule]", "227"}], ",", 
       RowBox[{"92", "\[Rule]", "81"}], ",", 
       RowBox[{"92", "\[Rule]", "89"}], ",", 
       RowBox[{"218", "\[Rule]", "209"}], ",", 
       RowBox[{"218", "\[Rule]", "227"}], ",", 
       RowBox[{"218", "\[Rule]", "219"}], ",", 
       RowBox[{"218", "\[Rule]", "215"}], ",", 
       RowBox[{"172", "\[Rule]", "163"}], ",", 
       RowBox[{"172", "\[Rule]", "181"}], ",", 
       RowBox[{"172", "\[Rule]", "173"}], ",", 
       RowBox[{"172", "\[Rule]", "169"}], ",", 
       RowBox[{"80", "\[Rule]", "71"}], ",", 
       RowBox[{"80", "\[Rule]", "89"}], ",", 
       RowBox[{"80", "\[Rule]", "81"}], ",", 
       RowBox[{"80", "\[Rule]", "77"}], ",", 
       RowBox[{"442", "\[Rule]", "431"}], ",", 
       RowBox[{"442", "\[Rule]", "449"}], ",", 
       RowBox[{"442", "\[Rule]", "439"}], ",", 
       RowBox[{"396", "\[Rule]", "385"}], ",", 
       RowBox[{"396", "\[Rule]", "403"}], ",", 
       RowBox[{"396", "\[Rule]", "393"}], ",", 
       RowBox[{"304", "\[Rule]", "293"}], ",", 
       RowBox[{"304", "\[Rule]", "311"}], ",", 
       RowBox[{"304", "\[Rule]", "301"}], ",", 
       RowBox[{"460", "\[Rule]", "449"}], ",", 
       RowBox[{"460", "\[Rule]", "457"}], ",", 
       RowBox[{"414", "\[Rule]", "403"}], ",", 
       RowBox[{"414", "\[Rule]", "411"}], ",", 
       RowBox[{"322", "\[Rule]", "311"}], ",", 
       RowBox[{"322", "\[Rule]", "319"}], ",", 
       RowBox[{"448", "\[Rule]", "439"}], ",", 
       RowBox[{"448", "\[Rule]", "457"}], ",", 
       RowBox[{"448", "\[Rule]", "449"}], ",", 
       RowBox[{"448", "\[Rule]", "445"}], ",", 
       RowBox[{"402", "\[Rule]", "393"}], ",", 
       RowBox[{"402", "\[Rule]", "411"}], ",", 
       RowBox[{"402", "\[Rule]", "403"}], ",", 
       RowBox[{"402", "\[Rule]", "399"}], ",", 
       RowBox[{"310", "\[Rule]", "301"}], ",", 
       RowBox[{"310", "\[Rule]", "319"}], ",", 
       RowBox[{"310", "\[Rule]", "311"}], ",", 
       RowBox[{"310", "\[Rule]", "307"}], ",", 
       RowBox[{"28", "\[Rule]", "17"}], ",", 
       RowBox[{"28", "\[Rule]", "35"}], ",", 
       RowBox[{"28", "\[Rule]", "25"}], ",", 
       RowBox[{"34", "\[Rule]", "25"}], ",", 
       RowBox[{"34", "\[Rule]", "43"}], ",", 
       RowBox[{"34", "\[Rule]", "35"}], ",", 
       RowBox[{"34", "\[Rule]", "31"}], ",", 
       RowBox[{"258", "\[Rule]", "247"}], ",", 
       RowBox[{"258", "\[Rule]", "265"}], ",", 
       RowBox[{"258", "\[Rule]", "255"}], ",", 
       RowBox[{"276", "\[Rule]", "265"}], ",", 
       RowBox[{"276", "\[Rule]", "273"}], ",", 
       RowBox[{"264", "\[Rule]", "255"}], ",", 
       RowBox[{"264", "\[Rule]", "273"}], ",", 
       RowBox[{"264", "\[Rule]", "265"}], ",", 
       RowBox[{"264", "\[Rule]", "261"}], ",", 
       RowBox[{"226", "\[Rule]", "215"}], ",", 
       RowBox[{"226", "\[Rule]", "227"}], ",", 
       RowBox[{"226", "\[Rule]", "223"}], ",", 
       RowBox[{"180", "\[Rule]", "169"}], ",", 
       RowBox[{"180", "\[Rule]", "181"}], ",", 
       RowBox[{"180", "\[Rule]", "177"}], ",", 
       RowBox[{"88", "\[Rule]", "77"}], ",", 
       RowBox[{"88", "\[Rule]", "89"}], ",", 
       RowBox[{"88", "\[Rule]", "85"}], ",", 
       RowBox[{"456", "\[Rule]", "445"}], ",", 
       RowBox[{"456", "\[Rule]", "457"}], ",", 
       RowBox[{"456", "\[Rule]", "453"}], ",", 
       RowBox[{"410", "\[Rule]", "399"}], ",", 
       RowBox[{"410", "\[Rule]", "411"}], ",", 
       RowBox[{"410", "\[Rule]", "407"}], ",", 
       RowBox[{"318", "\[Rule]", "307"}], ",", 
       RowBox[{"318", "\[Rule]", "319"}], ",", 
       RowBox[{"318", "\[Rule]", "315"}], ",", 
       RowBox[{"42", "\[Rule]", "31"}], ",", 
       RowBox[{"42", "\[Rule]", "43"}], ",", 
       RowBox[{"42", "\[Rule]", "39"}], ",", 
       RowBox[{"272", "\[Rule]", "261"}], ",", 
       RowBox[{"272", "\[Rule]", "273"}], ",", 
       RowBox[{"272", "\[Rule]", "269"}], ",", 
       RowBox[{"201", "\[Rule]", "110"}], ",", 
       RowBox[{"201", "\[Rule]", "340"}], ",", 
       RowBox[{"201", "\[Rule]", "64"}], ",", 
       RowBox[{"201", "\[Rule]", "294"}], ",", 
       RowBox[{"201", "\[Rule]", "202"}], ",", 
       RowBox[{"219", "\[Rule]", "128"}], ",", 
       RowBox[{"219", "\[Rule]", "128"}], ",", 
       RowBox[{"219", "\[Rule]", "358"}], ",", 
       RowBox[{"219", "\[Rule]", "358"}], ",", 
       RowBox[{"219", "\[Rule]", "82"}], ",", 
       RowBox[{"219", "\[Rule]", "312"}], ",", 
       RowBox[{"219", "\[Rule]", "220"}], ",", 
       RowBox[{"209", "\[Rule]", "118"}], ",", 
       RowBox[{"209", "\[Rule]", "118"}], ",", 
       RowBox[{"209", "\[Rule]", "348"}], ",", 
       RowBox[{"209", "\[Rule]", "72"}], ",", 
       RowBox[{"209", "\[Rule]", "210"}], ",", 
       RowBox[{"155", "\[Rule]", "64"}], ",", 
       RowBox[{"155", "\[Rule]", "294"}], ",", 
       RowBox[{"155", "\[Rule]", "18"}], ",", 
       RowBox[{"155", "\[Rule]", "18"}], ",", 
       RowBox[{"155", "\[Rule]", "248"}], ",", 
       RowBox[{"155", "\[Rule]", "248"}], ",", 
       RowBox[{"155", "\[Rule]", "156"}], ",", 
       RowBox[{"163", "\[Rule]", "72"}], ",", 
       RowBox[{"163", "\[Rule]", "302"}], ",", 
       RowBox[{"163", "\[Rule]", "26"}], ",", 
       RowBox[{"163", "\[Rule]", "26"}], ",", 
       RowBox[{"163", "\[Rule]", "256"}], ",", 
       RowBox[{"163", "\[Rule]", "256"}], ",", 
       RowBox[{"163", "\[Rule]", "164"}], ",", 
       RowBox[{"63", "\[Rule]", "202"}], ",", 
       RowBox[{"63", "\[Rule]", "156"}], ",", 
       RowBox[{"63", "\[Rule]", "64"}], ",", 
       RowBox[{"81", "\[Rule]", "220"}], ",", 
       RowBox[{"81", "\[Rule]", "174"}], ",", 
       RowBox[{"81", "\[Rule]", "82"}], ",", 
       RowBox[{"71", "\[Rule]", "210"}], ",", 
       RowBox[{"71", "\[Rule]", "164"}], ",", 
       RowBox[{"71", "\[Rule]", "72"}], ",", 
       RowBox[{"227", "\[Rule]", "136"}], ",", 
       RowBox[{"227", "\[Rule]", "136"}], ",", 
       RowBox[{"227", "\[Rule]", "366"}], ",", 
       RowBox[{"227", "\[Rule]", "366"}], ",", 
       RowBox[{"227", "\[Rule]", "90"}], ",", 
       RowBox[{"227", "\[Rule]", "320"}], ",", 
       RowBox[{"227", "\[Rule]", "228"}], ",", 
       RowBox[{"89", "\[Rule]", "228"}], ",", 
       RowBox[{"89", "\[Rule]", "182"}], ",", 
       RowBox[{"89", "\[Rule]", "90"}], ",", 
       RowBox[{"215", "\[Rule]", "124"}], ",", 
       RowBox[{"215", "\[Rule]", "124"}], ",", 
       RowBox[{"215", "\[Rule]", "354"}], ",", 
       RowBox[{"215", "\[Rule]", "354"}], ",", 
       RowBox[{"215", "\[Rule]", "78"}], ",", 
       RowBox[{"215", "\[Rule]", "308"}], ",", 
       RowBox[{"215", "\[Rule]", "216"}], ",", 
       RowBox[{"169", "\[Rule]", "78"}], ",", 
       RowBox[{"169", "\[Rule]", "308"}], ",", 
       RowBox[{"169", "\[Rule]", "32"}], ",", 
       RowBox[{"169", "\[Rule]", "32"}], ",", 
       RowBox[{"169", "\[Rule]", "262"}], ",", 
       RowBox[{"169", "\[Rule]", "262"}], ",", 
       RowBox[{"169", "\[Rule]", "170"}], ",", 
       RowBox[{"77", "\[Rule]", "216"}], ",", 
       RowBox[{"77", "\[Rule]", "170"}], ",", 
       RowBox[{"77", "\[Rule]", "78"}], ",", 
       RowBox[{"431", "\[Rule]", "340"}], ",", 
       RowBox[{"431", "\[Rule]", "340"}], ",", 
       RowBox[{"431", "\[Rule]", "570"}], ",", 
       RowBox[{"431", "\[Rule]", "570"}], ",", 
       RowBox[{"431", "\[Rule]", "294"}], ",", 
       RowBox[{"431", "\[Rule]", "294"}], ",", 
       RowBox[{"431", "\[Rule]", "524"}], ",", 
       RowBox[{"431", "\[Rule]", "524"}], ",", 
       RowBox[{"431", "\[Rule]", "432"}], ",", 
       RowBox[{"449", "\[Rule]", "358"}], ",", 
       RowBox[{"449", "\[Rule]", "588"}], ",", 
       RowBox[{"449", "\[Rule]", "312"}], ",", 
       RowBox[{"449", "\[Rule]", "312"}], ",", 
       RowBox[{"449", "\[Rule]", "542"}], ",", 
       RowBox[{"449", "\[Rule]", "542"}], ",", 
       RowBox[{"449", "\[Rule]", "450"}], ",", 
       RowBox[{"439", "\[Rule]", "348"}], ",", 
       RowBox[{"439", "\[Rule]", "578"}], ",", 
       RowBox[{"439", "\[Rule]", "578"}], ",", 
       RowBox[{"439", "\[Rule]", "302"}], ",", 
       RowBox[{"439", "\[Rule]", "532"}], ",", 
       RowBox[{"439", "\[Rule]", "532"}], ",", 
       RowBox[{"439", "\[Rule]", "440"}], ",", 
       RowBox[{"385", "\[Rule]", "294"}], ",", 
       RowBox[{"385", "\[Rule]", "294"}], ",", 
       RowBox[{"385", "\[Rule]", "524"}], ",", 
       RowBox[{"385", "\[Rule]", "524"}], ",", 
       RowBox[{"385", "\[Rule]", "248"}], ",", 
       RowBox[{"385", "\[Rule]", "478"}], ",", 
       RowBox[{"385", "\[Rule]", "386"}], ",", 
       RowBox[{"403", "\[Rule]", "312"}], ",", 
       RowBox[{"403", "\[Rule]", "312"}], ",", 
       RowBox[{"403", "\[Rule]", "542"}], ",", 
       RowBox[{"403", "\[Rule]", "542"}], ",", 
       RowBox[{"403", "\[Rule]", "266"}], ",", 
       RowBox[{"403", "\[Rule]", "496"}], ",", 
       RowBox[{"403", "\[Rule]", "404"}], ",", 
       RowBox[{"393", "\[Rule]", "302"}], ",", 
       RowBox[{"393", "\[Rule]", "302"}], ",", 
       RowBox[{"393", "\[Rule]", "532"}], ",", 
       RowBox[{"393", "\[Rule]", "532"}], ",", 
       RowBox[{"393", "\[Rule]", "256"}], ",", 
       RowBox[{"393", "\[Rule]", "486"}], ",", 
       RowBox[{"393", "\[Rule]", "394"}], ",", 
       RowBox[{"293", "\[Rule]", "202"}], ",", 
       RowBox[{"293", "\[Rule]", "432"}], ",", 
       RowBox[{"293", "\[Rule]", "432"}], ",", 
       RowBox[{"293", "\[Rule]", "156"}], ",", 
       RowBox[{"293", "\[Rule]", "386"}], ",", 
       RowBox[{"293", "\[Rule]", "386"}], ",", 
       RowBox[{"293", "\[Rule]", "294"}], ",", 
       RowBox[{"311", "\[Rule]", "220"}], ",", 
       RowBox[{"311", "\[Rule]", "450"}], ",", 
       RowBox[{"311", "\[Rule]", "450"}], ",", 
       RowBox[{"311", "\[Rule]", "174"}], ",", 
       RowBox[{"311", "\[Rule]", "404"}], ",", 
       RowBox[{"311", "\[Rule]", "404"}], ",", 
       RowBox[{"311", "\[Rule]", "312"}], ",", 
       RowBox[{"301", "\[Rule]", "440"}], ",", 
       RowBox[{"301", "\[Rule]", "164"}], ",", 
       RowBox[{"301", "\[Rule]", "394"}], ",", 
       RowBox[{"301", "\[Rule]", "394"}], ",", 
       RowBox[{"301", "\[Rule]", "302"}], ",", 
       RowBox[{"457", "\[Rule]", "366"}], ",", 
       RowBox[{"457", "\[Rule]", "366"}], ",", 
       RowBox[{"457", "\[Rule]", "596"}], ",", 
       RowBox[{"457", "\[Rule]", "320"}], ",", 
       RowBox[{"457", "\[Rule]", "320"}], ",", 
       RowBox[{"457", "\[Rule]", "550"}], ",", 
       RowBox[{"457", "\[Rule]", "458"}], ",", 
       RowBox[{"411", "\[Rule]", "320"}], ",", 
       RowBox[{"411", "\[Rule]", "320"}], ",", 
       RowBox[{"411", "\[Rule]", "550"}], ",", 
       RowBox[{"411", "\[Rule]", "550"}], ",", 
       RowBox[{"411", "\[Rule]", "274"}], ",", 
       RowBox[{"411", "\[Rule]", "504"}], ",", 
       RowBox[{"411", "\[Rule]", "412"}], ",", 
       RowBox[{"319", "\[Rule]", "228"}], ",", 
       RowBox[{"319", "\[Rule]", "458"}], ",", 
       RowBox[{"319", "\[Rule]", "458"}], ",", 
       RowBox[{"319", "\[Rule]", "182"}], ",", 
       RowBox[{"319", "\[Rule]", "412"}], ",", 
       RowBox[{"319", "\[Rule]", "412"}], ",", 
       RowBox[{"319", "\[Rule]", "320"}], ",", 
       RowBox[{"445", "\[Rule]", "354"}], ",", 
       RowBox[{"445", "\[Rule]", "354"}], ",", 
       RowBox[{"445", "\[Rule]", "584"}], ",", 
       RowBox[{"445", "\[Rule]", "584"}], ",", 
       RowBox[{"445", "\[Rule]", "308"}], ",", 
       RowBox[{"445", "\[Rule]", "538"}], ",", 
       RowBox[{"445", "\[Rule]", "446"}], ",", 
       RowBox[{"399", "\[Rule]", "308"}], ",", 
       RowBox[{"399", "\[Rule]", "538"}], ",", 
       RowBox[{"399", "\[Rule]", "262"}], ",", 
       RowBox[{"399", "\[Rule]", "492"}], ",", 
       RowBox[{"399", "\[Rule]", "400"}], ",", 
       RowBox[{"307", "\[Rule]", "216"}], ",", 
       RowBox[{"307", "\[Rule]", "446"}], ",", 
       RowBox[{"307", "\[Rule]", "170"}], ",", 
       RowBox[{"307", "\[Rule]", "400"}], ",", 
       RowBox[{"307", "\[Rule]", "308"}], ",", 
       RowBox[{"17", "\[Rule]", "156"}], ",", 
       RowBox[{"17", "\[Rule]", "156"}], ",", 
       RowBox[{"17", "\[Rule]", "18"}], ",", 
       RowBox[{"25", "\[Rule]", "164"}], ",", 
       RowBox[{"25", "\[Rule]", "164"}], ",", 
       RowBox[{"25", "\[Rule]", "26"}], ",", 
       RowBox[{"31", "\[Rule]", "170"}], ",", 
       RowBox[{"31", "\[Rule]", "170"}], ",", 
       RowBox[{"31", "\[Rule]", "32"}], ",", 
       RowBox[{"247", "\[Rule]", "156"}], ",", 
       RowBox[{"247", "\[Rule]", "156"}], ",", 
       RowBox[{"247", "\[Rule]", "386"}], ",", 
       RowBox[{"247", "\[Rule]", "248"}], ",", 
       RowBox[{"265", "\[Rule]", "174"}], ",", 
       RowBox[{"265", "\[Rule]", "174"}], ",", 
       RowBox[{"265", "\[Rule]", "404"}], ",", 
       RowBox[{"265", "\[Rule]", "266"}], ",", 
       RowBox[{"255", "\[Rule]", "164"}], ",", 
       RowBox[{"255", "\[Rule]", "164"}], ",", 
       RowBox[{"255", "\[Rule]", "394"}], ",", 
       RowBox[{"255", "\[Rule]", "256"}], ",", 
       RowBox[{"273", "\[Rule]", "182"}], ",", 
       RowBox[{"273", "\[Rule]", "182"}], ",", 
       RowBox[{"273", "\[Rule]", "412"}], ",", 
       RowBox[{"273", "\[Rule]", "274"}], ",", 
       RowBox[{"261", "\[Rule]", "170"}], ",", 
       RowBox[{"261", "\[Rule]", "170"}], ",", 
       RowBox[{"261", "\[Rule]", "400"}], ",", 
       RowBox[{"261", "\[Rule]", "262"}], ",", 
       RowBox[{"223", "\[Rule]", "132"}], ",", 
       RowBox[{"223", "\[Rule]", "132"}], ",", 
       RowBox[{"223", "\[Rule]", "362"}], ",", 
       RowBox[{"223", "\[Rule]", "362"}], ",", 
       RowBox[{"223", "\[Rule]", "86"}], ",", 
       RowBox[{"223", "\[Rule]", "316"}], ",", 
       RowBox[{"223", "\[Rule]", "224"}], ",", 
       RowBox[{"177", "\[Rule]", "86"}], ",", 
       RowBox[{"177", "\[Rule]", "316"}], ",", 
       RowBox[{"177", "\[Rule]", "40"}], ",", 
       RowBox[{"177", "\[Rule]", "40"}], ",", 
       RowBox[{"177", "\[Rule]", "270"}], ",", 
       RowBox[{"177", "\[Rule]", "270"}], ",", 
       RowBox[{"177", "\[Rule]", "178"}], ",", 
       RowBox[{"85", "\[Rule]", "224"}], ",", 
       RowBox[{"85", "\[Rule]", "178"}], ",", 
       RowBox[{"85", "\[Rule]", "86"}], ",", 
       RowBox[{"453", "\[Rule]", "362"}], ",", 
       RowBox[{"453", "\[Rule]", "362"}], ",", 
       RowBox[{"453", "\[Rule]", "592"}], ",", 
       RowBox[{"453", "\[Rule]", "592"}], ",", 
       RowBox[{"453", "\[Rule]", "316"}], ",", 
       RowBox[{"453", "\[Rule]", "316"}], ",", 
       RowBox[{"453", "\[Rule]", "546"}], ",", 
       RowBox[{"453", "\[Rule]", "546"}], ",", 
       RowBox[{"453", "\[Rule]", "454"}], ",", 
       RowBox[{"407", "\[Rule]", "316"}], ",", 
       RowBox[{"407", "\[Rule]", "316"}], ",", 
       RowBox[{"407", "\[Rule]", "546"}], ",", 
       RowBox[{"407", "\[Rule]", "270"}], ",", 
       RowBox[{"407", "\[Rule]", "408"}], ",", 
       RowBox[{"315", "\[Rule]", "224"}], ",", 
       RowBox[{"315", "\[Rule]", "454"}], ",", 
       RowBox[{"315", "\[Rule]", "454"}], ",", 
       RowBox[{"315", "\[Rule]", "178"}], ",", 
       RowBox[{"315", "\[Rule]", "408"}], ",", 
       RowBox[{"315", "\[Rule]", "408"}], ",", 
       RowBox[{"315", "\[Rule]", "316"}], ",", 
       RowBox[{"39", "\[Rule]", "178"}], ",", 
       RowBox[{"39", "\[Rule]", "178"}], ",", 
       RowBox[{"39", "\[Rule]", "40"}], ",", 
       RowBox[{"269", "\[Rule]", "178"}], ",", 
       RowBox[{"269", "\[Rule]", "178"}], ",", 
       RowBox[{"269", "\[Rule]", "408"}], ",", 
       RowBox[{"269", "\[Rule]", "270"}], ",", 
       RowBox[{"110", "\[Rule]", "101"}], ",", 
       RowBox[{"110", "\[Rule]", "119"}], ",", 
       RowBox[{"110", "\[Rule]", "107"}], ",", 
       RowBox[{"340", "\[Rule]", "331"}], ",", 
       RowBox[{"340", "\[Rule]", "349"}], ",", 
       RowBox[{"340", "\[Rule]", "337"}], ",", 
       RowBox[{"64", "\[Rule]", "55"}], ",", 
       RowBox[{"64", "\[Rule]", "73"}], ",", 
       RowBox[{"64", "\[Rule]", "61"}], ",", 
       RowBox[{"294", "\[Rule]", "285"}], ",", 
       RowBox[{"294", "\[Rule]", "303"}], ",", 
       RowBox[{"294", "\[Rule]", "291"}], ",", 
       RowBox[{"202", "\[Rule]", "193"}], ",", 
       RowBox[{"202", "\[Rule]", "211"}], ",", 
       RowBox[{"202", "\[Rule]", "199"}], ",", 
       RowBox[{"128", "\[Rule]", "119"}], ",", 
       RowBox[{"128", "\[Rule]", "137"}], ",", 
       RowBox[{"128", "\[Rule]", "125"}], ",", 
       RowBox[{"358", "\[Rule]", "349"}], ",", 
       RowBox[{"358", "\[Rule]", "367"}], ",", 
       RowBox[{"358", "\[Rule]", "355"}], ",", 
       RowBox[{"220", "\[Rule]", "211"}], ",", 
       RowBox[{"220", "\[Rule]", "229"}], ",", 
       RowBox[{"220", "\[Rule]", "217"}], ",", 
       RowBox[{"118", "\[Rule]", "107"}], ",", 
       RowBox[{"118", "\[Rule]", "125"}], ",", 
       RowBox[{"118", "\[Rule]", "119"}], ",", 
       RowBox[{"118", "\[Rule]", "115"}], ",", 
       RowBox[{"348", "\[Rule]", "337"}], ",", 
       RowBox[{"348", "\[Rule]", "355"}], ",", 
       RowBox[{"348", "\[Rule]", "349"}], ",", 
       RowBox[{"348", "\[Rule]", "345"}], ",", 
       RowBox[{"72", "\[Rule]", "61"}], ",", 
       RowBox[{"72", "\[Rule]", "79"}], ",", 
       RowBox[{"72", "\[Rule]", "73"}], ",", 
       RowBox[{"72", "\[Rule]", "69"}], ",", 
       RowBox[{"210", "\[Rule]", "199"}], ",", 
       RowBox[{"210", "\[Rule]", "217"}], ",", 
       RowBox[{"210", "\[Rule]", "211"}], ",", 
       RowBox[{"210", "\[Rule]", "207"}], ",", 
       RowBox[{"18", "\[Rule]", "9"}], ",", 
       RowBox[{"18", "\[Rule]", "27"}], ",", 
       RowBox[{"18", "\[Rule]", "15"}], ",", 
       RowBox[{"248", "\[Rule]", "239"}], ",", 
       RowBox[{"248", "\[Rule]", "257"}], ",", 
       RowBox[{"248", "\[Rule]", "245"}], ",", 
       RowBox[{"156", "\[Rule]", "147"}], ",", 
       RowBox[{"156", "\[Rule]", "165"}], ",", 
       RowBox[{"156", "\[Rule]", "153"}], ",", 
       RowBox[{"302", "\[Rule]", "291"}], ",", 
       RowBox[{"302", "\[Rule]", "309"}], ",", 
       RowBox[{"302", "\[Rule]", "303"}], ",", 
       RowBox[{"302", "\[Rule]", "299"}], ",", 
       RowBox[{"26", "\[Rule]", "15"}], ",", 
       RowBox[{"26", "\[Rule]", "33"}], ",", 
       RowBox[{"26", "\[Rule]", "27"}], ",", 
       RowBox[{"26", "\[Rule]", "23"}], ",", 
       RowBox[{"256", "\[Rule]", "245"}], ",", 
       RowBox[{"256", "\[Rule]", "263"}], ",", 
       RowBox[{"256", "\[Rule]", "257"}], ",", 
       RowBox[{"256", "\[Rule]", "253"}], ",", 
       RowBox[{"164", "\[Rule]", "153"}], ",", 
       RowBox[{"164", "\[Rule]", "171"}], ",", 
       RowBox[{"164", "\[Rule]", "165"}], ",", 
       RowBox[{"164", "\[Rule]", "161"}], ",", 
       RowBox[{"136", "\[Rule]", "125"}], ",", 
       RowBox[{"136", "\[Rule]", "137"}], ",", 
       RowBox[{"136", "\[Rule]", "133"}], ",", 
       RowBox[{"366", "\[Rule]", "355"}], ",", 
       RowBox[{"366", "\[Rule]", "367"}], ",", 
       RowBox[{"366", "\[Rule]", "363"}], ",", 
       RowBox[{"228", "\[Rule]", "217"}], ",", 
       RowBox[{"228", "\[Rule]", "229"}], ",", 
       RowBox[{"228", "\[Rule]", "225"}], ",", 
       RowBox[{"124", "\[Rule]", "115"}], ",", 
       RowBox[{"124", "\[Rule]", "133"}], ",", 
       RowBox[{"124", "\[Rule]", "125"}], ",", 
       RowBox[{"124", "\[Rule]", "121"}], ",", 
       RowBox[{"354", "\[Rule]", "345"}], ",", 
       RowBox[{"354", "\[Rule]", "363"}], ",", 
       RowBox[{"354", "\[Rule]", "355"}], ",", 
       RowBox[{"354", "\[Rule]", "351"}], ",", 
       RowBox[{"78", "\[Rule]", "69"}], ",", 
       RowBox[{"78", "\[Rule]", "87"}], ",", 
       RowBox[{"78", "\[Rule]", "79"}], ",", 
       RowBox[{"78", "\[Rule]", "75"}], ",", 
       RowBox[{"308", "\[Rule]", "299"}], ",", 
       RowBox[{"308", "\[Rule]", "317"}], ",", 
       RowBox[{"308", "\[Rule]", "309"}], ",", 
       RowBox[{"308", "\[Rule]", "305"}], ",", 
       RowBox[{"216", "\[Rule]", "207"}], ",", 
       RowBox[{"216", "\[Rule]", "225"}], ",", 
       RowBox[{"216", "\[Rule]", "217"}], ",", 
       RowBox[{"216", "\[Rule]", "213"}], ",", 
       RowBox[{"32", "\[Rule]", "23"}], ",", 
       RowBox[{"32", "\[Rule]", "41"}], ",", 
       RowBox[{"32", "\[Rule]", "33"}], ",", 
       RowBox[{"32", "\[Rule]", "29"}], ",", 
       RowBox[{"262", "\[Rule]", "253"}], ",", 
       RowBox[{"262", "\[Rule]", "271"}], ",", 
       RowBox[{"262", "\[Rule]", "263"}], ",", 
       RowBox[{"262", "\[Rule]", "259"}], ",", 
       RowBox[{"170", "\[Rule]", "161"}], ",", 
       RowBox[{"170", "\[Rule]", "179"}], ",", 
       RowBox[{"170", "\[Rule]", "171"}], ",", 
       RowBox[{"170", "\[Rule]", "167"}], ",", 
       RowBox[{"570", "\[Rule]", "561"}], ",", 
       RowBox[{"570", "\[Rule]", "579"}], ",", 
       RowBox[{"570", "\[Rule]", "567"}], ",", 
       RowBox[{"524", "\[Rule]", "515"}], ",", 
       RowBox[{"524", "\[Rule]", "533"}], ",", 
       RowBox[{"524", "\[Rule]", "521"}], ",", 
       RowBox[{"432", "\[Rule]", "423"}], ",", 
       RowBox[{"432", "\[Rule]", "441"}], ",", 
       RowBox[{"432", "\[Rule]", "429"}], ",", 
       RowBox[{"588", "\[Rule]", "579"}], ",", 
       RowBox[{"588", "\[Rule]", "597"}], ",", 
       RowBox[{"588", "\[Rule]", "585"}], ",", 
       RowBox[{"542", "\[Rule]", "533"}], ",", 
       RowBox[{"542", "\[Rule]", "551"}], ",", 
       RowBox[{"542", "\[Rule]", "539"}], ",", 
       RowBox[{"450", "\[Rule]", "441"}], ",", 
       RowBox[{"450", "\[Rule]", "459"}], ",", 
       RowBox[{"450", "\[Rule]", "447"}], ",", 
       RowBox[{"578", "\[Rule]", "567"}], ",", 
       RowBox[{"578", "\[Rule]", "585"}], ",", 
       RowBox[{"578", "\[Rule]", "579"}], ",", 
       RowBox[{"578", "\[Rule]", "575"}], ",", 
       RowBox[{"532", "\[Rule]", "521"}], ",", 
       RowBox[{"532", "\[Rule]", "539"}], ",", 
       RowBox[{"532", "\[Rule]", "533"}], ",", 
       RowBox[{"532", "\[Rule]", "529"}], ",", 
       RowBox[{"440", "\[Rule]", "429"}], ",", 
       RowBox[{"440", "\[Rule]", "447"}], ",", 
       RowBox[{"440", "\[Rule]", "441"}], ",", 
       RowBox[{"440", "\[Rule]", "437"}], ",", 
       RowBox[{"478", "\[Rule]", "469"}], ",", 
       RowBox[{"478", "\[Rule]", "487"}], ",", 
       RowBox[{"478", "\[Rule]", "475"}], ",", 
       RowBox[{"386", "\[Rule]", "377"}], ",", 
       RowBox[{"386", "\[Rule]", "395"}], ",", 
       RowBox[{"386", "\[Rule]", "383"}], ",", 
       RowBox[{"496", "\[Rule]", "487"}], ",", 
       RowBox[{"496", "\[Rule]", "505"}], ",", 
       RowBox[{"496", "\[Rule]", "493"}], ",", 
       RowBox[{"404", "\[Rule]", "395"}], ",", 
       RowBox[{"404", "\[Rule]", "413"}], ",", 
       RowBox[{"404", "\[Rule]", "401"}], ",", 
       RowBox[{"486", "\[Rule]", "475"}], ",", 
       RowBox[{"486", "\[Rule]", "493"}], ",", 
       RowBox[{"486", "\[Rule]", "487"}], ",", 
       RowBox[{"486", "\[Rule]", "483"}], ",", 
       RowBox[{"394", "\[Rule]", "383"}], ",", 
       RowBox[{"394", "\[Rule]", "401"}], ",", 
       RowBox[{"394", "\[Rule]", "395"}], ",", 
       RowBox[{"394", "\[Rule]", "391"}], ",", 
       RowBox[{"596", "\[Rule]", "585"}], ",", 
       RowBox[{"596", "\[Rule]", "597"}], ",", 
       RowBox[{"596", "\[Rule]", "593"}], ",", 
       RowBox[{"550", "\[Rule]", "539"}], ",", 
       RowBox[{"550", "\[Rule]", "551"}], ",", 
       RowBox[{"550", "\[Rule]", "547"}], ",", 
       RowBox[{"458", "\[Rule]", "447"}], ",", 
       RowBox[{"458", "\[Rule]", "459"}], ",", 
       RowBox[{"458", "\[Rule]", "455"}], ",", 
       RowBox[{"504", "\[Rule]", "493"}], ",", 
       RowBox[{"504", "\[Rule]", "505"}], ",", 
       RowBox[{"504", "\[Rule]", "501"}], ",", 
       RowBox[{"412", "\[Rule]", "401"}], ",", 
       RowBox[{"412", "\[Rule]", "413"}], ",", 
       RowBox[{"412", "\[Rule]", "409"}], ",", 
       RowBox[{"584", "\[Rule]", "575"}], ",", 
       RowBox[{"584", "\[Rule]", "593"}], ",", 
       RowBox[{"584", "\[Rule]", "585"}], ",", 
       RowBox[{"584", "\[Rule]", "581"}], ",", 
       RowBox[{"538", "\[Rule]", "529"}], ",", 
       RowBox[{"538", "\[Rule]", "547"}], ",", 
       RowBox[{"538", "\[Rule]", "539"}], ",", 
       RowBox[{"538", "\[Rule]", "535"}], ",", 
       RowBox[{"446", "\[Rule]", "437"}], ",", 
       RowBox[{"446", "\[Rule]", "455"}], ",", 
       RowBox[{"446", "\[Rule]", "447"}], ",", 
       RowBox[{"446", "\[Rule]", "443"}], ",", 
       RowBox[{"492", "\[Rule]", "483"}], ",", 
       RowBox[{"492", "\[Rule]", "501"}], ",", 
       RowBox[{"492", "\[Rule]", "493"}], ",", 
       RowBox[{"492", "\[Rule]", "489"}], ",", 
       RowBox[{"400", "\[Rule]", "391"}], ",", 
       RowBox[{"400", "\[Rule]", "409"}], ",", 
       RowBox[{"400", "\[Rule]", "401"}], ",", 
       RowBox[{"400", "\[Rule]", "397"}], ",", 
       RowBox[{"132", "\[Rule]", "121"}], ",", 
       RowBox[{"132", "\[Rule]", "133"}], ",", 
       RowBox[{"132", "\[Rule]", "129"}], ",", 
       RowBox[{"362", "\[Rule]", "351"}], ",", 
       RowBox[{"362", "\[Rule]", "363"}], ",", 
       RowBox[{"362", "\[Rule]", "359"}], ",", 
       RowBox[{"86", "\[Rule]", "75"}], ",", 
       RowBox[{"86", "\[Rule]", "87"}], ",", 
       RowBox[{"86", "\[Rule]", "83"}], ",", 
       RowBox[{"316", "\[Rule]", "305"}], ",", 
       RowBox[{"316", "\[Rule]", "317"}], ",", 
       RowBox[{"316", "\[Rule]", "313"}], ",", 
       RowBox[{"224", "\[Rule]", "213"}], ",", 
       RowBox[{"224", "\[Rule]", "225"}], ",", 
       RowBox[{"224", "\[Rule]", "221"}], ",", 
       RowBox[{"40", "\[Rule]", "29"}], ",", 
       RowBox[{"40", "\[Rule]", "41"}], ",", 
       RowBox[{"40", "\[Rule]", "37"}], ",", 
       RowBox[{"270", "\[Rule]", "259"}], ",", 
       RowBox[{"270", "\[Rule]", "271"}], ",", 
       RowBox[{"270", "\[Rule]", "267"}], ",", 
       RowBox[{"178", "\[Rule]", "167"}], ",", 
       RowBox[{"178", "\[Rule]", "179"}], ",", 
       RowBox[{"178", "\[Rule]", "175"}], ",", 
       RowBox[{"592", "\[Rule]", "581"}], ",", 
       RowBox[{"592", "\[Rule]", "593"}], ",", 
       RowBox[{"592", "\[Rule]", "589"}], ",", 
       RowBox[{"546", "\[Rule]", "535"}], ",", 
       RowBox[{"546", "\[Rule]", "547"}], ",", 
       RowBox[{"546", "\[Rule]", "543"}], ",", 
       RowBox[{"454", "\[Rule]", "443"}], ",", 
       RowBox[{"454", "\[Rule]", "455"}], ",", 
       RowBox[{"454", "\[Rule]", "451"}], ",", 
       RowBox[{"408", "\[Rule]", "397"}], ",", 
       RowBox[{"408", "\[Rule]", "409"}], ",", 
       RowBox[{"408", "\[Rule]", "405"}], ",", 
       RowBox[{"101", "\[Rule]", "194"}], ",", 
       RowBox[{"101", "\[Rule]", "194"}], ",", 
       RowBox[{"101", "\[Rule]", "102"}], ",", 
       RowBox[{"119", "\[Rule]", "212"}], ",", 
       RowBox[{"119", "\[Rule]", "212"}], ",", 
       RowBox[{"119", "\[Rule]", "120"}], ",", 
       RowBox[{"107", "\[Rule]", "200"}], ",", 
       RowBox[{"107", "\[Rule]", "200"}], ",", 
       RowBox[{"107", "\[Rule]", "108"}], ",", 
       RowBox[{"331", "\[Rule]", "194"}], ",", 
       RowBox[{"331", "\[Rule]", "194"}], ",", 
       RowBox[{"331", "\[Rule]", "424"}], ",", 
       RowBox[{"331", "\[Rule]", "424"}], ",", 
       RowBox[{"331", "\[Rule]", "332"}], ",", 
       RowBox[{"349", "\[Rule]", "212"}], ",", 
       RowBox[{"349", "\[Rule]", "212"}], ",", 
       RowBox[{"349", "\[Rule]", "442"}], ",", 
       RowBox[{"349", "\[Rule]", "442"}], ",", 
       RowBox[{"349", "\[Rule]", "350"}], ",", 
       RowBox[{"337", "\[Rule]", "200"}], ",", 
       RowBox[{"337", "\[Rule]", "200"}], ",", 
       RowBox[{"337", "\[Rule]", "430"}], ",", 
       RowBox[{"337", "\[Rule]", "430"}], ",", 
       RowBox[{"337", "\[Rule]", "338"}], ",", 
       RowBox[{"55", "\[Rule]", "194"}], ",", 
       RowBox[{"55", "\[Rule]", "148"}], ",", 
       RowBox[{"55", "\[Rule]", "56"}], ",", 
       RowBox[{"61", "\[Rule]", "200"}], ",", 
       RowBox[{"61", "\[Rule]", "154"}], ",", 
       RowBox[{"61", "\[Rule]", "62"}], ",", 
       RowBox[{"285", "\[Rule]", "194"}], ",", 
       RowBox[{"285", "\[Rule]", "424"}], ",", 
       RowBox[{"285", "\[Rule]", "424"}], ",", 
       RowBox[{"285", "\[Rule]", "148"}], ",", 
       RowBox[{"285", "\[Rule]", "378"}], ",", 
       RowBox[{"285", "\[Rule]", "378"}], ",", 
       RowBox[{"285", "\[Rule]", "286"}], ",", 
       RowBox[{"291", "\[Rule]", "200"}], ",", 
       RowBox[{"291", "\[Rule]", "430"}], ",", 
       RowBox[{"291", "\[Rule]", "430"}], ",", 
       RowBox[{"291", "\[Rule]", "154"}], ",", 
       RowBox[{"291", "\[Rule]", "384"}], ",", 
       RowBox[{"291", "\[Rule]", "384"}], ",", 
       RowBox[{"291", "\[Rule]", "292"}], ",", 
       RowBox[{"193", "\[Rule]", "102"}], ",", 
       RowBox[{"193", "\[Rule]", "102"}], ",", 
       RowBox[{"193", "\[Rule]", "332"}], ",", 
       RowBox[{"193", "\[Rule]", "332"}], ",", 
       RowBox[{"193", "\[Rule]", "56"}], ",", 
       RowBox[{"193", "\[Rule]", "286"}], ",", 
       RowBox[{"193", "\[Rule]", "194"}], ",", 
       RowBox[{"211", "\[Rule]", "120"}], ",", 
       RowBox[{"211", "\[Rule]", "120"}], ",", 
       RowBox[{"211", "\[Rule]", "350"}], ",", 
       RowBox[{"211", "\[Rule]", "350"}], ",", 
       RowBox[{"211", "\[Rule]", "74"}], ",", 
       RowBox[{"211", "\[Rule]", "304"}], ",", 
       RowBox[{"211", "\[Rule]", "212"}], ",", 
       RowBox[{"199", "\[Rule]", "108"}], ",", 
       RowBox[{"199", "\[Rule]", "108"}], ",", 
       RowBox[{"199", "\[Rule]", "338"}], ",", 
       RowBox[{"199", "\[Rule]", "338"}], ",", 
       RowBox[{"199", "\[Rule]", "62"}], ",", 
       RowBox[{"199", "\[Rule]", "292"}], ",", 
       RowBox[{"199", "\[Rule]", "200"}], ",", 
       RowBox[{"137", "\[Rule]", "230"}], ",", 
       RowBox[{"137", "\[Rule]", "230"}], ",", 
       RowBox[{"137", "\[Rule]", "138"}], ",", 
       RowBox[{"125", "\[Rule]", "218"}], ",", 
       RowBox[{"125", "\[Rule]", "218"}], ",", 
       RowBox[{"125", "\[Rule]", "126"}], ",", 
       RowBox[{"367", "\[Rule]", "230"}], ",", 
       RowBox[{"367", "\[Rule]", "230"}], ",", 
       RowBox[{"367", "\[Rule]", "460"}], ",", 
       RowBox[{"367", "\[Rule]", "460"}], ",", 
       RowBox[{"367", "\[Rule]", "368"}], ",", 
       RowBox[{"355", "\[Rule]", "218"}], ",", 
       RowBox[{"355", "\[Rule]", "218"}], ",", 
       RowBox[{"355", "\[Rule]", "448"}], ",", 
       RowBox[{"355", "\[Rule]", "448"}], ",", 
       RowBox[{"355", "\[Rule]", "356"}], ",", 
       RowBox[{"229", "\[Rule]", "138"}], ",", 
       RowBox[{"229", "\[Rule]", "138"}], ",", 
       RowBox[{"229", "\[Rule]", "368"}], ",", 
       RowBox[{"229", "\[Rule]", "368"}], ",", 
       RowBox[{"229", "\[Rule]", "92"}], ",", 
       RowBox[{"229", "\[Rule]", "322"}], ",", 
       RowBox[{"229", "\[Rule]", "230"}], ",", 
       RowBox[{"217", "\[Rule]", "126"}], ",", 
       RowBox[{"217", "\[Rule]", "126"}], ",", 
       RowBox[{"217", "\[Rule]", "356"}], ",", 
       RowBox[{"217", "\[Rule]", "356"}], ",", 
       RowBox[{"217", "\[Rule]", "80"}], ",", 
       RowBox[{"217", "\[Rule]", "310"}], ",", 
       RowBox[{"217", "\[Rule]", "218"}], ",", 
       RowBox[{"115", "\[Rule]", "208"}], ",", 
       RowBox[{"115", "\[Rule]", "208"}], ",", 
       RowBox[{"115", "\[Rule]", "116"}], ",", 
       RowBox[{"345", "\[Rule]", "208"}], ",", 
       RowBox[{"345", "\[Rule]", "208"}], ",", 
       RowBox[{"345", "\[Rule]", "438"}], ",", 
       RowBox[{"345", "\[Rule]", "438"}], ",", 
       RowBox[{"345", "\[Rule]", "346"}], ",", 
       RowBox[{"69", "\[Rule]", "208"}], ",", 
       RowBox[{"69", "\[Rule]", "162"}], ",", 
       RowBox[{"69", "\[Rule]", "70"}], ",", 
       RowBox[{"207", "\[Rule]", "116"}], ",", 
       RowBox[{"207", "\[Rule]", "116"}], ",", 
       RowBox[{"207", "\[Rule]", "346"}], ",", 
       RowBox[{"207", "\[Rule]", "346"}], ",", 
       RowBox[{"207", "\[Rule]", "70"}], ",", 
       RowBox[{"207", "\[Rule]", "300"}], ",", 
       RowBox[{"207", "\[Rule]", "208"}], ",", 
       RowBox[{"9", "\[Rule]", "148"}], ",", 
       RowBox[{"9", "\[Rule]", "148"}], ",", 
       RowBox[{"9", "\[Rule]", "10"}], ",", 
       RowBox[{"15", "\[Rule]", "154"}], ",", 
       RowBox[{"15", "\[Rule]", "154"}], ",", 
       RowBox[{"15", "\[Rule]", "16"}], ",", 
       RowBox[{"239", "\[Rule]", "148"}], ",", 
       RowBox[{"239", "\[Rule]", "148"}], ",", 
       RowBox[{"239", "\[Rule]", "378"}], ",", 
       RowBox[{"239", "\[Rule]", "240"}], ",", 
       RowBox[{"245", "\[Rule]", "154"}], ",", 
       RowBox[{"245", "\[Rule]", "154"}], ",", 
       RowBox[{"245", "\[Rule]", "384"}], ",", 
       RowBox[{"245", "\[Rule]", "246"}], ",", 
       RowBox[{"147", "\[Rule]", "56"}], ",", 
       RowBox[{"147", "\[Rule]", "286"}], ",", 
       RowBox[{"147", "\[Rule]", "10"}], ",", 
       RowBox[{"147", "\[Rule]", "10"}], ",", 
       RowBox[{"147", "\[Rule]", "240"}], ",", 
       RowBox[{"147", "\[Rule]", "240"}], ",", 
       RowBox[{"147", "\[Rule]", "148"}], ",", 
       RowBox[{"153", "\[Rule]", "62"}], ",", 
       RowBox[{"153", "\[Rule]", "292"}], ",", 
       RowBox[{"153", "\[Rule]", "16"}], ",", 
       RowBox[{"153", "\[Rule]", "16"}], ",", 
       RowBox[{"153", "\[Rule]", "246"}], ",", 
       RowBox[{"153", "\[Rule]", "246"}], ",", 
       RowBox[{"153", "\[Rule]", "154"}], ",", 
       RowBox[{"299", "\[Rule]", "208"}], ",", 
       RowBox[{"299", "\[Rule]", "438"}], ",", 
       RowBox[{"299", "\[Rule]", "438"}], ",", 
       RowBox[{"299", "\[Rule]", "162"}], ",", 
       RowBox[{"299", "\[Rule]", "392"}], ",", 
       RowBox[{"299", "\[Rule]", "392"}], ",", 
       RowBox[{"299", "\[Rule]", "300"}], ",", 
       RowBox[{"23", "\[Rule]", "162"}], ",", 
       RowBox[{"23", "\[Rule]", "162"}], ",", 
       RowBox[{"23", "\[Rule]", "24"}], ",", 
       RowBox[{"253", "\[Rule]", "162"}], ",", 
       RowBox[{"253", "\[Rule]", "162"}], ",", 
       RowBox[{"253", "\[Rule]", "392"}], ",", 
       RowBox[{"253", "\[Rule]", "254"}], ",", 
       RowBox[{"161", "\[Rule]", "70"}], ",", 
       RowBox[{"161", "\[Rule]", "300"}], ",", 
       RowBox[{"161", "\[Rule]", "24"}], ",", 
       RowBox[{"161", "\[Rule]", "24"}], ",", 
       RowBox[{"161", "\[Rule]", "254"}], ",", 
       RowBox[{"161", "\[Rule]", "254"}], ",", 
       RowBox[{"161", "\[Rule]", "162"}], ",", 
       RowBox[{"133", "\[Rule]", "226"}], ",", 
       RowBox[{"133", "\[Rule]", "226"}], ",", 
       RowBox[{"133", "\[Rule]", "134"}], ",", 
       RowBox[{"363", "\[Rule]", "226"}], ",", 
       RowBox[{"363", "\[Rule]", "226"}], ",", 
       RowBox[{"363", "\[Rule]", "456"}], ",", 
       RowBox[{"363", "\[Rule]", "456"}], ",", 
       RowBox[{"363", "\[Rule]", "364"}], ",", 
       RowBox[{"225", "\[Rule]", "134"}], ",", 
       RowBox[{"225", "\[Rule]", "134"}], ",", 
       RowBox[{"225", "\[Rule]", "364"}], ",", 
       RowBox[{"225", "\[Rule]", "364"}], ",", 
       RowBox[{"225", "\[Rule]", "88"}], ",", 
       RowBox[{"225", "\[Rule]", "318"}], ",", 
       RowBox[{"225", "\[Rule]", "226"}], ",", 
       RowBox[{"121", "\[Rule]", "214"}], ",", 
       RowBox[{"121", "\[Rule]", "214"}], ",", 
       RowBox[{"121", "\[Rule]", "122"}], ",", 
       RowBox[{"351", "\[Rule]", "214"}], ",", 
       RowBox[{"351", "\[Rule]", "214"}], ",", 
       RowBox[{"351", "\[Rule]", "444"}], ",", 
       RowBox[{"351", "\[Rule]", "444"}], ",", 
       RowBox[{"351", "\[Rule]", "352"}], ",", 
       RowBox[{"75", "\[Rule]", "214"}], ",", 
       RowBox[{"75", "\[Rule]", "168"}], ",", 
       RowBox[{"75", "\[Rule]", "76"}], ",", 
       RowBox[{"305", "\[Rule]", "214"}], ",", 
       RowBox[{"305", "\[Rule]", "444"}], ",", 
       RowBox[{"305", "\[Rule]", "444"}], ",", 
       RowBox[{"305", "\[Rule]", "168"}], ",", 
       RowBox[{"305", "\[Rule]", "398"}], ",", 
       RowBox[{"305", "\[Rule]", "398"}], ",", 
       RowBox[{"305", "\[Rule]", "306"}], ",", 
       RowBox[{"213", "\[Rule]", "122"}], ",", 
       RowBox[{"213", "\[Rule]", "122"}], ",", 
       RowBox[{"213", "\[Rule]", "352"}], ",", 
       RowBox[{"213", "\[Rule]", "352"}], ",", 
       RowBox[{"213", "\[Rule]", "76"}], ",", 
       RowBox[{"213", "\[Rule]", "306"}], ",", 
       RowBox[{"213", "\[Rule]", "214"}], ",", 
       RowBox[{"29", "\[Rule]", "168"}], ",", 
       RowBox[{"29", "\[Rule]", "168"}], ",", 
       RowBox[{"29", "\[Rule]", "30"}], ",", 
       RowBox[{"259", "\[Rule]", "168"}], ",", 
       RowBox[{"259", "\[Rule]", "168"}], ",", 
       RowBox[{"259", "\[Rule]", "398"}], ",", 
       RowBox[{"259", "\[Rule]", "260"}], ",", 
       RowBox[{"167", "\[Rule]", "76"}], ",", 
       RowBox[{"167", "\[Rule]", "306"}], ",", 
       RowBox[{"167", "\[Rule]", "30"}], ",", 
       RowBox[{"167", "\[Rule]", "30"}], ",", 
       RowBox[{"167", "\[Rule]", "260"}], ",", 
       RowBox[{"167", "\[Rule]", "260"}], ",", 
       RowBox[{"167", "\[Rule]", "168"}], ",", 
       RowBox[{"561", "\[Rule]", "424"}], ",", 
       RowBox[{"561", "\[Rule]", "424"}], ",", 
       RowBox[{"561", "\[Rule]", "562"}], ",", 
       RowBox[{"579", "\[Rule]", "442"}], ",", 
       RowBox[{"579", "\[Rule]", "442"}], ",", 
       RowBox[{"579", "\[Rule]", "580"}], ",", 
       RowBox[{"567", "\[Rule]", "430"}], ",", 
       RowBox[{"567", "\[Rule]", "430"}], ",", 
       RowBox[{"567", "\[Rule]", "568"}], ",", 
       RowBox[{"515", "\[Rule]", "424"}], ",", 
       RowBox[{"515", "\[Rule]", "424"}], ",", 
       RowBox[{"515", "\[Rule]", "378"}], ",", 
       RowBox[{"515", "\[Rule]", "378"}], ",", 
       RowBox[{"515", "\[Rule]", "516"}], ",", 
       RowBox[{"533", "\[Rule]", "442"}], ",", 
       RowBox[{"533", "\[Rule]", "442"}], ",", 
       RowBox[{"533", "\[Rule]", "396"}], ",", 
       RowBox[{"533", "\[Rule]", "396"}], ",", 
       RowBox[{"533", "\[Rule]", "534"}], ",", 
       RowBox[{"521", "\[Rule]", "430"}], ",", 
       RowBox[{"521", "\[Rule]", "430"}], ",", 
       RowBox[{"521", "\[Rule]", "384"}], ",", 
       RowBox[{"521", "\[Rule]", "384"}], ",", 
       RowBox[{"521", "\[Rule]", "522"}], ",", 
       RowBox[{"423", "\[Rule]", "332"}], ",", 
       RowBox[{"423", "\[Rule]", "332"}], ",", 
       RowBox[{"423", "\[Rule]", "562"}], ",", 
       RowBox[{"423", "\[Rule]", "562"}], ",", 
       RowBox[{"423", "\[Rule]", "286"}], ",", 
       RowBox[{"423", "\[Rule]", "286"}], ",", 
       RowBox[{"423", "\[Rule]", "516"}], ",", 
       RowBox[{"423", "\[Rule]", "516"}], ",", 
       RowBox[{"423", "\[Rule]", "424"}], ",", 
       RowBox[{"441", "\[Rule]", "350"}], ",", 
       RowBox[{"441", "\[Rule]", "350"}], ",", 
       RowBox[{"441", "\[Rule]", "580"}], ",", 
       RowBox[{"441", "\[Rule]", "580"}], ",", 
       RowBox[{"441", "\[Rule]", "304"}], ",", 
       RowBox[{"441", "\[Rule]", "304"}], ",", 
       RowBox[{"441", "\[Rule]", "534"}], ",", 
       RowBox[{"441", "\[Rule]", "534"}], ",", 
       RowBox[{"441", "\[Rule]", "442"}], ",", 
       RowBox[{"429", "\[Rule]", "338"}], ",", 
       RowBox[{"429", "\[Rule]", "338"}], ",", 
       RowBox[{"429", "\[Rule]", "568"}], ",", 
       RowBox[{"429", "\[Rule]", "568"}], ",", 
       RowBox[{"429", "\[Rule]", "292"}], ",", 
       RowBox[{"429", "\[Rule]", "292"}], ",", 
       RowBox[{"429", "\[Rule]", "522"}], ",", 
       RowBox[{"429", "\[Rule]", "522"}], ",", 
       RowBox[{"429", "\[Rule]", "430"}], ",", 
       RowBox[{"597", "\[Rule]", "460"}], ",", 
       RowBox[{"597", "\[Rule]", "460"}], ",", 
       RowBox[{"597", "\[Rule]", "598"}], ",", 
       RowBox[{"585", "\[Rule]", "448"}], ",", 
       RowBox[{"585", "\[Rule]", "448"}], ",", 
       RowBox[{"585", "\[Rule]", "586"}], ",", 
       RowBox[{"551", "\[Rule]", "460"}], ",", 
       RowBox[{"551", "\[Rule]", "460"}], ",", 
       RowBox[{"551", "\[Rule]", "414"}], ",", 
       RowBox[{"551", "\[Rule]", "414"}], ",", 
       RowBox[{"551", "\[Rule]", "552"}], ",", 
       RowBox[{"539", "\[Rule]", "448"}], ",", 
       RowBox[{"539", "\[Rule]", "448"}], ",", 
       RowBox[{"539", "\[Rule]", "402"}], ",", 
       RowBox[{"539", "\[Rule]", "402"}], ",", 
       RowBox[{"539", "\[Rule]", "540"}], ",", 
       RowBox[{"459", "\[Rule]", "368"}], ",", 
       RowBox[{"459", "\[Rule]", "368"}], ",", 
       RowBox[{"459", "\[Rule]", "598"}], ",", 
       RowBox[{"459", "\[Rule]", "598"}], ",", 
       RowBox[{"459", "\[Rule]", "322"}], ",", 
       RowBox[{"459", "\[Rule]", "322"}], ",", 
       RowBox[{"459", "\[Rule]", "552"}], ",", 
       RowBox[{"459", "\[Rule]", "552"}], ",", 
       RowBox[{"459", "\[Rule]", "460"}], ",", 
       RowBox[{"447", "\[Rule]", "356"}], ",", 
       RowBox[{"447", "\[Rule]", "356"}], ",", 
       RowBox[{"447", "\[Rule]", "586"}], ",", 
       RowBox[{"447", "\[Rule]", "586"}], ",", 
       RowBox[{"447", "\[Rule]", "310"}], ",", 
       RowBox[{"447", "\[Rule]", "310"}], ",", 
       RowBox[{"447", "\[Rule]", "540"}], ",", 
       RowBox[{"447", "\[Rule]", "540"}], ",", 
       RowBox[{"447", "\[Rule]", "448"}], ",", 
       RowBox[{"575", "\[Rule]", "438"}], ",", 
       RowBox[{"575", "\[Rule]", "438"}], ",", 
       RowBox[{"575", "\[Rule]", "576"}], ",", 
       RowBox[{"529", "\[Rule]", "438"}], ",", 
       RowBox[{"529", "\[Rule]", "438"}], ",", 
       RowBox[{"529", "\[Rule]", "392"}], ",", 
       RowBox[{"529", "\[Rule]", "392"}], ",", 
       RowBox[{"529", "\[Rule]", "530"}], ",", 
       RowBox[{"437", "\[Rule]", "346"}], ",", 
       RowBox[{"437", "\[Rule]", "346"}], ",", 
       RowBox[{"437", "\[Rule]", "576"}], ",", 
       RowBox[{"437", "\[Rule]", "576"}], ",", 
       RowBox[{"437", "\[Rule]", "300"}], ",", 
       RowBox[{"437", "\[Rule]", "300"}], ",", 
       RowBox[{"437", "\[Rule]", "530"}], ",", 
       RowBox[{"437", "\[Rule]", "530"}], ",", 
       RowBox[{"437", "\[Rule]", "438"}], ",", 
       RowBox[{"469", "\[Rule]", "378"}], ",", 
       RowBox[{"469", "\[Rule]", "470"}], ",", 
       RowBox[{"487", "\[Rule]", "396"}], ",", 
       RowBox[{"487", "\[Rule]", "488"}], ",", 
       RowBox[{"475", "\[Rule]", "384"}], ",", 
       RowBox[{"475", "\[Rule]", "476"}], ",", 
       RowBox[{"377", "\[Rule]", "286"}], ",", 
       RowBox[{"377", "\[Rule]", "286"}], ",", 
       RowBox[{"377", "\[Rule]", "516"}], ",", 
       RowBox[{"377", "\[Rule]", "516"}], ",", 
       RowBox[{"377", "\[Rule]", "240"}], ",", 
       RowBox[{"377", "\[Rule]", "470"}], ",", 
       RowBox[{"377", "\[Rule]", "378"}], ",", 
       RowBox[{"395", "\[Rule]", "304"}], ",", 
       RowBox[{"395", "\[Rule]", "304"}], ",", 
       RowBox[{"395", "\[Rule]", "534"}], ",", 
       RowBox[{"395", "\[Rule]", "534"}], ",", 
       RowBox[{"395", "\[Rule]", "258"}], ",", 
       RowBox[{"395", "\[Rule]", "488"}], ",", 
       RowBox[{"395", "\[Rule]", "396"}], ",", 
       RowBox[{"383", "\[Rule]", "292"}], ",", 
       RowBox[{"383", "\[Rule]", "292"}], ",", 
       RowBox[{"383", "\[Rule]", "522"}], ",", 
       RowBox[{"383", "\[Rule]", "522"}], ",", 
       RowBox[{"383", "\[Rule]", "246"}], ",", 
       RowBox[{"383", "\[Rule]", "476"}], ",", 
       RowBox[{"383", "\[Rule]", "384"}], ",", 
       RowBox[{"505", "\[Rule]", "414"}], ",", 
       RowBox[{"505", "\[Rule]", "506"}], ",", 
       RowBox[{"493", "\[Rule]", "402"}], ",", 
       RowBox[{"493", "\[Rule]", "494"}], ",", 
       RowBox[{"413", "\[Rule]", "322"}], ",", 
       RowBox[{"413", "\[Rule]", "322"}], ",", 
       RowBox[{"413", "\[Rule]", "552"}], ",", 
       RowBox[{"413", "\[Rule]", "552"}], ",", 
       RowBox[{"413", "\[Rule]", "276"}], ",", 
       RowBox[{"413", "\[Rule]", "506"}], ",", 
       RowBox[{"413", "\[Rule]", "414"}], ",", 
       RowBox[{"401", "\[Rule]", "310"}], ",", 
       RowBox[{"401", "\[Rule]", "310"}], ",", 
       RowBox[{"401", "\[Rule]", "540"}], ",", 
       RowBox[{"401", "\[Rule]", "540"}], ",", 
       RowBox[{"401", "\[Rule]", "264"}], ",", 
       RowBox[{"401", "\[Rule]", "494"}], ",", 
       RowBox[{"401", "\[Rule]", "402"}], ",", 
       RowBox[{"483", "\[Rule]", "392"}], ",", 
       RowBox[{"483", "\[Rule]", "484"}], ",", 
       RowBox[{"391", "\[Rule]", "300"}], ",", 
       RowBox[{"391", "\[Rule]", "300"}], ",", 
       RowBox[{"391", "\[Rule]", "530"}], ",", 
       RowBox[{"391", "\[Rule]", "530"}], ",", 
       RowBox[{"391", "\[Rule]", "254"}], ",", 
       RowBox[{"391", "\[Rule]", "484"}], ",", 
       RowBox[{"391", "\[Rule]", "392"}], ",", 
       RowBox[{"593", "\[Rule]", "456"}], ",", 
       RowBox[{"593", "\[Rule]", "456"}], ",", 
       RowBox[{"593", "\[Rule]", "594"}], ",", 
       RowBox[{"547", "\[Rule]", "456"}], ",", 
       RowBox[{"547", "\[Rule]", "456"}], ",", 
       RowBox[{"547", "\[Rule]", "410"}], ",", 
       RowBox[{"547", "\[Rule]", "410"}], ",", 
       RowBox[{"547", "\[Rule]", "548"}], ",", 
       RowBox[{"455", "\[Rule]", "364"}], ",", 
       RowBox[{"455", "\[Rule]", "364"}], ",", 
       RowBox[{"455", "\[Rule]", "594"}], ",", 
       RowBox[{"455", "\[Rule]", "594"}], ",", 
       RowBox[{"455", "\[Rule]", "318"}], ",", 
       RowBox[{"455", "\[Rule]", "318"}], ",", 
       RowBox[{"455", "\[Rule]", "548"}], ",", 
       RowBox[{"455", "\[Rule]", "548"}], ",", 
       RowBox[{"455", "\[Rule]", "456"}], ",", 
       RowBox[{"501", "\[Rule]", "410"}], ",", 
       RowBox[{"501", "\[Rule]", "502"}], ",", 
       RowBox[{"409", "\[Rule]", "318"}], ",", 
       RowBox[{"409", "\[Rule]", "318"}], ",", 
       RowBox[{"409", "\[Rule]", "548"}], ",", 
       RowBox[{"409", "\[Rule]", "548"}], ",", 
       RowBox[{"409", "\[Rule]", "272"}], ",", 
       RowBox[{"409", "\[Rule]", "502"}], ",", 
       RowBox[{"409", "\[Rule]", "410"}], ",", 
       RowBox[{"581", "\[Rule]", "444"}], ",", 
       RowBox[{"581", "\[Rule]", "444"}], ",", 
       RowBox[{"581", "\[Rule]", "582"}], ",", 
       RowBox[{"535", "\[Rule]", "444"}], ",", 
       RowBox[{"535", "\[Rule]", "444"}], ",", 
       RowBox[{"535", "\[Rule]", "398"}], ",", 
       RowBox[{"535", "\[Rule]", "398"}], ",", 
       RowBox[{"535", "\[Rule]", "536"}], ",", 
       RowBox[{"443", "\[Rule]", "352"}], ",", 
       RowBox[{"443", "\[Rule]", "352"}], ",", 
       RowBox[{"443", "\[Rule]", "582"}], ",", 
       RowBox[{"443", "\[Rule]", "582"}], ",", 
       RowBox[{"443", "\[Rule]", "306"}], ",", 
       RowBox[{"443", "\[Rule]", "306"}], ",", 
       RowBox[{"443", "\[Rule]", "536"}], ",", 
       RowBox[{"443", "\[Rule]", "536"}], ",", 
       RowBox[{"443", "\[Rule]", "444"}], ",", 
       RowBox[{"489", "\[Rule]", "398"}], ",", 
       RowBox[{"489", "\[Rule]", "490"}], ",", 
       RowBox[{"397", "\[Rule]", "306"}], ",", 
       RowBox[{"397", "\[Rule]", "306"}], ",", 
       RowBox[{"397", "\[Rule]", "536"}], ",", 
       RowBox[{"397", "\[Rule]", "536"}], ",", 
       RowBox[{"397", "\[Rule]", "260"}], ",", 
       RowBox[{"397", "\[Rule]", "490"}], ",", 
       RowBox[{"397", "\[Rule]", "398"}], ",", 
       RowBox[{"129", "\[Rule]", "222"}], ",", 
       RowBox[{"129", "\[Rule]", "222"}], ",", 
       RowBox[{"129", "\[Rule]", "130"}], ",", 
       RowBox[{"359", "\[Rule]", "222"}], ",", 
       RowBox[{"359", "\[Rule]", "222"}], ",", 
       RowBox[{"359", "\[Rule]", "452"}], ",", 
       RowBox[{"359", "\[Rule]", "452"}], ",", 
       RowBox[{"359", "\[Rule]", "360"}], ",", 
       RowBox[{"83", "\[Rule]", "222"}], ",", 
       RowBox[{"83", "\[Rule]", "176"}], ",", 
       RowBox[{"83", "\[Rule]", "84"}], ",", 
       RowBox[{"313", "\[Rule]", "222"}], ",", 
       RowBox[{"313", "\[Rule]", "452"}], ",", 
       RowBox[{"313", "\[Rule]", "452"}], ",", 
       RowBox[{"313", "\[Rule]", "176"}], ",", 
       RowBox[{"313", "\[Rule]", "406"}], ",", 
       RowBox[{"313", "\[Rule]", "406"}], ",", 
       RowBox[{"313", "\[Rule]", "314"}], ",", 
       RowBox[{"221", "\[Rule]", "130"}], ",", 
       RowBox[{"221", "\[Rule]", "130"}], ",", 
       RowBox[{"221", "\[Rule]", "360"}], ",", 
       RowBox[{"221", "\[Rule]", "360"}], ",", 
       RowBox[{"221", "\[Rule]", "84"}], ",", 
       RowBox[{"221", "\[Rule]", "314"}], ",", 
       RowBox[{"221", "\[Rule]", "222"}], ",", 
       RowBox[{"37", "\[Rule]", "176"}], ",", 
       RowBox[{"37", "\[Rule]", "176"}], ",", 
       RowBox[{"37", "\[Rule]", "38"}], ",", 
       RowBox[{"267", "\[Rule]", "176"}], ",", 
       RowBox[{"267", "\[Rule]", "176"}], ",", 
       RowBox[{"267", "\[Rule]", "406"}], ",", 
       RowBox[{"267", "\[Rule]", "268"}], ",", 
       RowBox[{"175", "\[Rule]", "84"}], ",", 
       RowBox[{"175", "\[Rule]", "314"}], ",", 
       RowBox[{"175", "\[Rule]", "38"}], ",", 
       RowBox[{"175", "\[Rule]", "38"}], ",", 
       RowBox[{"175", "\[Rule]", "268"}], ",", 
       RowBox[{"175", "\[Rule]", "268"}], ",", 
       RowBox[{"175", "\[Rule]", "176"}], ",", 
       RowBox[{"589", "\[Rule]", "452"}], ",", 
       RowBox[{"589", "\[Rule]", "452"}], ",", 
       RowBox[{"589", "\[Rule]", "590"}], ",", 
       RowBox[{"543", "\[Rule]", "452"}], ",", 
       RowBox[{"543", "\[Rule]", "452"}], ",", 
       RowBox[{"543", "\[Rule]", "406"}], ",", 
       RowBox[{"543", "\[Rule]", "406"}], ",", 
       RowBox[{"543", "\[Rule]", "544"}], ",", 
       RowBox[{"451", "\[Rule]", "360"}], ",", 
       RowBox[{"451", "\[Rule]", "360"}], ",", 
       RowBox[{"451", "\[Rule]", "590"}], ",", 
       RowBox[{"451", "\[Rule]", "590"}], ",", 
       RowBox[{"451", "\[Rule]", "314"}], ",", 
       RowBox[{"451", "\[Rule]", "314"}], ",", 
       RowBox[{"451", "\[Rule]", "544"}], ",", 
       RowBox[{"451", "\[Rule]", "544"}], ",", 
       RowBox[{"451", "\[Rule]", "452"}], ",", 
       RowBox[{"405", "\[Rule]", "314"}], ",", 
       RowBox[{"405", "\[Rule]", "314"}], ",", 
       RowBox[{"405", "\[Rule]", "544"}], ",", 
       RowBox[{"405", "\[Rule]", "544"}], ",", 
       RowBox[{"405", "\[Rule]", "268"}], ",", 
       RowBox[{"405", "\[Rule]", "498"}], ",", 
       RowBox[{"405", "\[Rule]", "406"}], ",", 
       RowBox[{"194", "\[Rule]", "201"}], ",", 
       RowBox[{"194", "\[Rule]", "191"}], ",", 
       RowBox[{"102", "\[Rule]", "109"}], ",", 
       RowBox[{"102", "\[Rule]", "99"}], ",", 
       RowBox[{"120", "\[Rule]", "109"}], ",", 
       RowBox[{"120", "\[Rule]", "127"}], ",", 
       RowBox[{"120", "\[Rule]", "117"}], ",", 
       RowBox[{"200", "\[Rule]", "191"}], ",", 
       RowBox[{"200", "\[Rule]", "209"}], ",", 
       RowBox[{"200", "\[Rule]", "201"}], ",", 
       RowBox[{"108", "\[Rule]", "99"}], ",", 
       RowBox[{"108", "\[Rule]", "117"}], ",", 
       RowBox[{"108", "\[Rule]", "109"}], ",", 
       RowBox[{"424", "\[Rule]", "431"}], ",", 
       RowBox[{"424", "\[Rule]", "421"}], ",", 
       RowBox[{"332", "\[Rule]", "339"}], ",", 
       RowBox[{"332", "\[Rule]", "329"}], ",", 
       RowBox[{"350", "\[Rule]", "339"}], ",", 
       RowBox[{"350", "\[Rule]", "357"}], ",", 
       RowBox[{"350", "\[Rule]", "347"}], ",", 
       RowBox[{"430", "\[Rule]", "421"}], ",", 
       RowBox[{"430", "\[Rule]", "439"}], ",", 
       RowBox[{"430", "\[Rule]", "431"}], ",", 
       RowBox[{"338", "\[Rule]", "329"}], ",", 
       RowBox[{"338", "\[Rule]", "347"}], ",", 
       RowBox[{"338", "\[Rule]", "339"}], ",", 
       RowBox[{"148", "\[Rule]", "155"}], ",", 
       RowBox[{"148", "\[Rule]", "145"}], ",", 
       RowBox[{"56", "\[Rule]", "63"}], ",", 
       RowBox[{"56", "\[Rule]", "53"}], ",", 
       RowBox[{"154", "\[Rule]", "145"}], ",", 
       RowBox[{"154", "\[Rule]", "163"}], ",", 
       RowBox[{"154", "\[Rule]", "155"}], ",", 
       RowBox[{"62", "\[Rule]", "53"}], ",", 
       RowBox[{"62", "\[Rule]", "71"}], ",", 
       RowBox[{"62", "\[Rule]", "63"}], ",", 
       RowBox[{"378", "\[Rule]", "385"}], ",", 
       RowBox[{"378", "\[Rule]", "375"}], ",", 
       RowBox[{"286", "\[Rule]", "293"}], ",", 
       RowBox[{"286", "\[Rule]", "283"}], ",", 
       RowBox[{"384", "\[Rule]", "375"}], ",", 
       RowBox[{"384", "\[Rule]", "393"}], ",", 
       RowBox[{"384", "\[Rule]", "385"}], ",", 
       RowBox[{"292", "\[Rule]", "283"}], ",", 
       RowBox[{"292", "\[Rule]", "301"}], ",", 
       RowBox[{"292", "\[Rule]", "293"}], ",", 
       RowBox[{"138", "\[Rule]", "127"}], ",", 
       RowBox[{"138", "\[Rule]", "135"}], ",", 
       RowBox[{"126", "\[Rule]", "117"}], ",", 
       RowBox[{"126", "\[Rule]", "135"}], ",", 
       RowBox[{"126", "\[Rule]", "127"}], ",", 
       RowBox[{"126", "\[Rule]", "123"}], ",", 
       RowBox[{"368", "\[Rule]", "357"}], ",", 
       RowBox[{"368", "\[Rule]", "365"}], ",", 
       RowBox[{"356", "\[Rule]", "347"}], ",", 
       RowBox[{"356", "\[Rule]", "365"}], ",", 
       RowBox[{"356", "\[Rule]", "357"}], ",", 
       RowBox[{"356", "\[Rule]", "353"}], ",", 
       RowBox[{"208", "\[Rule]", "215"}], ",", 
       RowBox[{"208", "\[Rule]", "209"}], ",", 
       RowBox[{"208", "\[Rule]", "205"}], ",", 
       RowBox[{"116", "\[Rule]", "123"}], ",", 
       RowBox[{"116", "\[Rule]", "117"}], ",", 
       RowBox[{"116", "\[Rule]", "113"}], ",", 
       RowBox[{"438", "\[Rule]", "445"}], ",", 
       RowBox[{"438", "\[Rule]", "439"}], ",", 
       RowBox[{"438", "\[Rule]", "435"}], ",", 
       RowBox[{"346", "\[Rule]", "353"}], ",", 
       RowBox[{"346", "\[Rule]", "347"}], ",", 
       RowBox[{"346", "\[Rule]", "343"}], ",", 
       RowBox[{"162", "\[Rule]", "169"}], ",", 
       RowBox[{"162", "\[Rule]", "163"}], ",", 
       RowBox[{"162", "\[Rule]", "159"}], ",", 
       RowBox[{"70", "\[Rule]", "77"}], ",", 
       RowBox[{"70", "\[Rule]", "71"}], ",", 
       RowBox[{"70", "\[Rule]", "67"}], ",", 
       RowBox[{"300", "\[Rule]", "307"}], ",", 
       RowBox[{"300", "\[Rule]", "301"}], ",", 
       RowBox[{"300", "\[Rule]", "297"}], ",", 
       RowBox[{"10", "\[Rule]", "17"}], ",", 
       RowBox[{"10", "\[Rule]", "7"}], ",", 
       RowBox[{"16", "\[Rule]", "7"}], ",", 
       RowBox[{"16", "\[Rule]", "25"}], ",", 
       RowBox[{"16", "\[Rule]", "17"}], ",", 
       RowBox[{"240", "\[Rule]", "247"}], ",", 
       RowBox[{"240", "\[Rule]", "237"}], ",", 
       RowBox[{"246", "\[Rule]", "237"}], ",", 
       RowBox[{"246", "\[Rule]", "255"}], ",", 
       RowBox[{"246", "\[Rule]", "247"}], ",", 
       RowBox[{"392", "\[Rule]", "399"}], ",", 
       RowBox[{"392", "\[Rule]", "393"}], ",", 
       RowBox[{"392", "\[Rule]", "389"}], ",", 
       RowBox[{"24", "\[Rule]", "31"}], ",", 
       RowBox[{"24", "\[Rule]", "25"}], ",", 
       RowBox[{"24", "\[Rule]", "21"}], ",", 
       RowBox[{"254", "\[Rule]", "261"}], ",", 
       RowBox[{"254", "\[Rule]", "255"}], ",", 
       RowBox[{"254", "\[Rule]", "251"}], ",", 
       RowBox[{"134", "\[Rule]", "123"}], ",", 
       RowBox[{"134", "\[Rule]", "135"}], ",", 
       RowBox[{"134", "\[Rule]", "131"}], ",", 
       RowBox[{"364", "\[Rule]", "353"}], ",", 
       RowBox[{"364", "\[Rule]", "365"}], ",", 
       RowBox[{"364", "\[Rule]", "361"}], ",", 
       RowBox[{"214", "\[Rule]", "205"}], ",", 
       RowBox[{"214", "\[Rule]", "223"}], ",", 
       RowBox[{"214", "\[Rule]", "215"}], ",", 
       RowBox[{"122", "\[Rule]", "113"}], ",", 
       RowBox[{"122", "\[Rule]", "131"}], ",", 
       RowBox[{"122", "\[Rule]", "123"}], ",", 
       RowBox[{"444", "\[Rule]", "435"}], ",", 
       RowBox[{"444", "\[Rule]", "453"}], ",", 
       RowBox[{"444", "\[Rule]", "445"}], ",", 
       RowBox[{"352", "\[Rule]", "343"}], ",", 
       RowBox[{"352", "\[Rule]", "361"}], ",", 
       RowBox[{"352", "\[Rule]", "353"}], ",", 
       RowBox[{"168", "\[Rule]", "159"}], ",", 
       RowBox[{"168", "\[Rule]", "177"}], ",", 
       RowBox[{"168", "\[Rule]", "169"}], ",", 
       RowBox[{"76", "\[Rule]", "67"}], ",", 
       RowBox[{"76", "\[Rule]", "85"}], ",", 
       RowBox[{"76", "\[Rule]", "77"}], ",", 
       RowBox[{"398", "\[Rule]", "389"}], ",", 
       RowBox[{"398", "\[Rule]", "407"}], ",", 
       RowBox[{"398", "\[Rule]", "399"}], ",", 
       RowBox[{"306", "\[Rule]", "297"}], ",", 
       RowBox[{"306", "\[Rule]", "315"}], ",", 
       RowBox[{"306", "\[Rule]", "307"}], ",", 
       RowBox[{"30", "\[Rule]", "21"}], ",", 
       RowBox[{"30", "\[Rule]", "39"}], ",", 
       RowBox[{"30", "\[Rule]", "31"}], ",", 
       RowBox[{"260", "\[Rule]", "251"}], ",", 
       RowBox[{"260", "\[Rule]", "269"}], ",", 
       RowBox[{"260", "\[Rule]", "261"}], ",", 
       RowBox[{"562", "\[Rule]", "569"}], ",", 
       RowBox[{"562", "\[Rule]", "559"}], ",", 
       RowBox[{"580", "\[Rule]", "569"}], ",", 
       RowBox[{"580", "\[Rule]", "587"}], ",", 
       RowBox[{"580", "\[Rule]", "577"}], ",", 
       RowBox[{"568", "\[Rule]", "559"}], ",", 
       RowBox[{"568", "\[Rule]", "577"}], ",", 
       RowBox[{"568", "\[Rule]", "569"}], ",", 
       RowBox[{"516", "\[Rule]", "523"}], ",", 
       RowBox[{"516", "\[Rule]", "513"}], ",", 
       RowBox[{"534", "\[Rule]", "523"}], ",", 
       RowBox[{"534", "\[Rule]", "541"}], ",", 
       RowBox[{"534", "\[Rule]", "531"}], ",", 
       RowBox[{"522", "\[Rule]", "513"}], ",", 
       RowBox[{"522", "\[Rule]", "531"}], ",", 
       RowBox[{"522", "\[Rule]", "523"}], ",", 
       RowBox[{"598", "\[Rule]", "587"}], ",", 
       RowBox[{"598", "\[Rule]", "595"}], ",", 
       RowBox[{"586", "\[Rule]", "577"}], ",", 
       RowBox[{"586", "\[Rule]", "595"}], ",", 
       RowBox[{"586", "\[Rule]", "587"}], ",", 
       RowBox[{"586", "\[Rule]", "583"}], ",", 
       RowBox[{"552", "\[Rule]", "541"}], ",", 
       RowBox[{"552", "\[Rule]", "549"}], ",", 
       RowBox[{"540", "\[Rule]", "531"}], ",", 
       RowBox[{"540", "\[Rule]", "549"}], ",", 
       RowBox[{"540", "\[Rule]", "541"}], ",", 
       RowBox[{"540", "\[Rule]", "537"}], ",", 
       RowBox[{"576", "\[Rule]", "583"}], ",", 
       RowBox[{"576", "\[Rule]", "577"}], ",", 
       RowBox[{"576", "\[Rule]", "573"}], ",", 
       RowBox[{"530", "\[Rule]", "537"}], ",", 
       RowBox[{"530", "\[Rule]", "531"}], ",", 
       RowBox[{"530", "\[Rule]", "527"}], ",", 
       RowBox[{"470", "\[Rule]", "477"}], ",", 
       RowBox[{"470", "\[Rule]", "467"}], ",", 
       RowBox[{"488", "\[Rule]", "477"}], ",", 
       RowBox[{"488", "\[Rule]", "495"}], ",", 
       RowBox[{"488", "\[Rule]", "485"}], ",", 
       RowBox[{"476", "\[Rule]", "467"}], ",", 
       RowBox[{"476", "\[Rule]", "485"}], ",", 
       RowBox[{"476", "\[Rule]", "477"}], ",", 
       RowBox[{"506", "\[Rule]", "495"}], ",", 
       RowBox[{"506", "\[Rule]", "503"}], ",", 
       RowBox[{"494", "\[Rule]", "485"}], ",", 
       RowBox[{"494", "\[Rule]", "503"}], ",", 
       RowBox[{"494", "\[Rule]", "495"}], ",", 
       RowBox[{"494", "\[Rule]", "491"}], ",", 
       RowBox[{"484", "\[Rule]", "491"}], ",", 
       RowBox[{"484", "\[Rule]", "485"}], ",", 
       RowBox[{"484", "\[Rule]", "481"}], ",", 
       RowBox[{"594", "\[Rule]", "583"}], ",", 
       RowBox[{"594", "\[Rule]", "595"}], ",", 
       RowBox[{"594", "\[Rule]", "591"}], ",", 
       RowBox[{"548", "\[Rule]", "537"}], ",", 
       RowBox[{"548", "\[Rule]", "549"}], ",", 
       RowBox[{"548", "\[Rule]", "545"}], ",", 
       RowBox[{"502", "\[Rule]", "491"}], ",", 
       RowBox[{"502", "\[Rule]", "503"}], ",", 
       RowBox[{"502", "\[Rule]", "499"}], ",", 
       RowBox[{"582", "\[Rule]", "573"}], ",", 
       RowBox[{"582", "\[Rule]", "591"}], ",", 
       RowBox[{"582", "\[Rule]", "583"}], ",", 
       RowBox[{"536", "\[Rule]", "527"}], ",", 
       RowBox[{"536", "\[Rule]", "545"}], ",", 
       RowBox[{"536", "\[Rule]", "537"}], ",", 
       RowBox[{"490", "\[Rule]", "481"}], ",", 
       RowBox[{"490", "\[Rule]", "499"}], ",", 
       RowBox[{"490", "\[Rule]", "491"}], ",", 
       RowBox[{"222", "\[Rule]", "223"}], ",", 
       RowBox[{"130", "\[Rule]", "131"}], ",", 
       RowBox[{"452", "\[Rule]", "453"}], ",", 
       RowBox[{"360", "\[Rule]", "361"}], ",", 
       RowBox[{"176", "\[Rule]", "177"}], ",", 
       RowBox[{"84", "\[Rule]", "85"}], ",", 
       RowBox[{"406", "\[Rule]", "407"}], ",", 
       RowBox[{"314", "\[Rule]", "315"}], ",", 
       RowBox[{"38", "\[Rule]", "39"}], ",", 
       RowBox[{"268", "\[Rule]", "269"}], ",", 
       RowBox[{"590", "\[Rule]", "591"}], ",", 
       RowBox[{"544", "\[Rule]", "545"}], ",", 
       RowBox[{"498", "\[Rule]", "499"}], ",", 
       RowBox[{"191", "\[Rule]", "100"}], ",", 
       RowBox[{"191", "\[Rule]", "330"}], ",", 
       RowBox[{"191", "\[Rule]", "330"}], ",", 
       RowBox[{"191", "\[Rule]", "284"}], ",", 
       RowBox[{"191", "\[Rule]", "192"}], ",", 
       RowBox[{"109", "\[Rule]", "202"}], ",", 
       RowBox[{"109", "\[Rule]", "110"}], ",", 
       RowBox[{"99", "\[Rule]", "192"}], ",", 
       RowBox[{"99", "\[Rule]", "100"}], ",", 
       RowBox[{"127", "\[Rule]", "220"}], ",", 
       RowBox[{"127", "\[Rule]", "220"}], ",", 
       RowBox[{"127", "\[Rule]", "128"}], ",", 
       RowBox[{"117", "\[Rule]", "210"}], ",", 
       RowBox[{"117", "\[Rule]", "210"}], ",", 
       RowBox[{"117", "\[Rule]", "118"}], ",", 
       RowBox[{"421", "\[Rule]", "330"}], ",", 
       RowBox[{"421", "\[Rule]", "330"}], ",", 
       RowBox[{"421", "\[Rule]", "560"}], ",", 
       RowBox[{"421", "\[Rule]", "560"}], ",", 
       RowBox[{"421", "\[Rule]", "284"}], ",", 
       RowBox[{"421", "\[Rule]", "284"}], ",", 
       RowBox[{"421", "\[Rule]", "514"}], ",", 
       RowBox[{"421", "\[Rule]", "514"}], ",", 
       RowBox[{"421", "\[Rule]", "422"}], ",", 
       RowBox[{"339", "\[Rule]", "202"}], ",", 
       RowBox[{"339", "\[Rule]", "432"}], ",", 
       RowBox[{"339", "\[Rule]", "432"}], ",", 
       RowBox[{"339", "\[Rule]", "340"}], ",", 
       RowBox[{"329", "\[Rule]", "192"}], ",", 
       RowBox[{"329", "\[Rule]", "192"}], ",", 
       RowBox[{"329", "\[Rule]", "422"}], ",", 
       RowBox[{"329", "\[Rule]", "422"}], ",", 
       RowBox[{"329", "\[Rule]", "330"}], ",", 
       RowBox[{"357", "\[Rule]", "220"}], ",", 
       RowBox[{"357", "\[Rule]", "220"}], ",", 
       RowBox[{"357", "\[Rule]", "450"}], ",", 
       RowBox[{"357", "\[Rule]", "358"}], ",", 
       RowBox[{"347", "\[Rule]", "210"}], ",", 
       RowBox[{"347", "\[Rule]", "440"}], ",", 
       RowBox[{"347", "\[Rule]", "348"}], ",", 
       RowBox[{"145", "\[Rule]", "54"}], ",", 
       RowBox[{"145", "\[Rule]", "284"}], ",", 
       RowBox[{"145", "\[Rule]", "8"}], ",", 
       RowBox[{"145", "\[Rule]", "8"}], ",", 
       RowBox[{"145", "\[Rule]", "238"}], ",", 
       RowBox[{"145", "\[Rule]", "238"}], ",", 
       RowBox[{"145", "\[Rule]", "146"}], ",", 
       RowBox[{"53", "\[Rule]", "146"}], ",", 
       RowBox[{"53", "\[Rule]", "54"}], ",", 
       RowBox[{"375", "\[Rule]", "284"}], ",", 
       RowBox[{"375", "\[Rule]", "284"}], ",", 
       RowBox[{"375", "\[Rule]", "514"}], ",", 
       RowBox[{"375", "\[Rule]", "514"}], ",", 
       RowBox[{"375", "\[Rule]", "238"}], ",", 
       RowBox[{"375", "\[Rule]", "468"}], ",", 
       RowBox[{"375", "\[Rule]", "376"}], ",", 
       RowBox[{"283", "\[Rule]", "192"}], ",", 
       RowBox[{"283", "\[Rule]", "422"}], ",", 
       RowBox[{"283", "\[Rule]", "422"}], ",", 
       RowBox[{"283", "\[Rule]", "146"}], ",", 
       RowBox[{"283", "\[Rule]", "376"}], ",", 
       RowBox[{"283", "\[Rule]", "376"}], ",", 
       RowBox[{"283", "\[Rule]", "284"}], ",", 
       RowBox[{"135", "\[Rule]", "228"}], ",", 
       RowBox[{"135", "\[Rule]", "228"}], ",", 
       RowBox[{"135", "\[Rule]", "136"}], ",", 
       RowBox[{"123", "\[Rule]", "216"}], ",", 
       RowBox[{"123", "\[Rule]", "216"}], ",", 
       RowBox[{"123", "\[Rule]", "124"}], ",", 
       RowBox[{"365", "\[Rule]", "228"}], ",", 
       RowBox[{"365", "\[Rule]", "228"}], ",", 
       RowBox[{"365", "\[Rule]", "458"}], ",", 
       RowBox[{"365", "\[Rule]", "458"}], ",", 
       RowBox[{"365", "\[Rule]", "366"}], ",", 
       RowBox[{"353", "\[Rule]", "216"}], ",", 
       RowBox[{"353", "\[Rule]", "216"}], ",", 
       RowBox[{"353", "\[Rule]", "446"}], ",", 
       RowBox[{"353", "\[Rule]", "446"}], ",", 
       RowBox[{"353", "\[Rule]", "354"}], ",", 
       RowBox[{"205", "\[Rule]", "114"}], ",", 
       RowBox[{"205", "\[Rule]", "114"}], ",", 
       RowBox[{"205", "\[Rule]", "344"}], ",", 
       RowBox[{"205", "\[Rule]", "344"}], ",", 
       RowBox[{"205", "\[Rule]", "68"}], ",", 
       RowBox[{"205", "\[Rule]", "298"}], ",", 
       RowBox[{"205", "\[Rule]", "206"}], ",", 
       RowBox[{"113", "\[Rule]", "206"}], ",", 
       RowBox[{"113", "\[Rule]", "206"}], ",", 
       RowBox[{"113", "\[Rule]", "114"}], ",", 
       RowBox[{"435", "\[Rule]", "344"}], ",", 
       RowBox[{"435", "\[Rule]", "344"}], ",", 
       RowBox[{"435", "\[Rule]", "574"}], ",", 
       RowBox[{"435", "\[Rule]", "574"}], ",", 
       RowBox[{"435", "\[Rule]", "298"}], ",", 
       RowBox[{"435", "\[Rule]", "298"}], ",", 
       RowBox[{"435", "\[Rule]", "528"}], ",", 
       RowBox[{"435", "\[Rule]", "528"}], ",", 
       RowBox[{"435", "\[Rule]", "436"}], ",", 
       RowBox[{"343", "\[Rule]", "206"}], ",", 
       RowBox[{"343", "\[Rule]", "206"}], ",", 
       RowBox[{"343", "\[Rule]", "436"}], ",", 
       RowBox[{"343", "\[Rule]", "436"}], ",", 
       RowBox[{"343", "\[Rule]", "344"}], ",", 
       RowBox[{"159", "\[Rule]", "68"}], ",", 
       RowBox[{"159", "\[Rule]", "22"}], ",", 
       RowBox[{"159", "\[Rule]", "22"}], ",", 
       RowBox[{"159", "\[Rule]", "252"}], ",", 
       RowBox[{"159", "\[Rule]", "160"}], ",", 
       RowBox[{"67", "\[Rule]", "206"}], ",", 
       RowBox[{"67", "\[Rule]", "160"}], ",", 
       RowBox[{"67", "\[Rule]", "68"}], ",", 
       RowBox[{"297", "\[Rule]", "206"}], ",", 
       RowBox[{"297", "\[Rule]", "436"}], ",", 
       RowBox[{"297", "\[Rule]", "436"}], ",", 
       RowBox[{"297", "\[Rule]", "390"}], ",", 
       RowBox[{"297", "\[Rule]", "298"}], ",", 
       RowBox[{"7", "\[Rule]", "146"}], ",", 
       RowBox[{"7", "\[Rule]", "146"}], ",", 
       RowBox[{"7", "\[Rule]", "8"}], ",", 
       RowBox[{"237", "\[Rule]", "146"}], ",", 
       RowBox[{"237", "\[Rule]", "146"}], ",", 
       RowBox[{"237", "\[Rule]", "376"}], ",", 
       RowBox[{"237", "\[Rule]", "238"}], ",", 
       RowBox[{"389", "\[Rule]", "298"}], ",", 
       RowBox[{"389", "\[Rule]", "528"}], ",", 
       RowBox[{"389", "\[Rule]", "528"}], ",", 
       RowBox[{"389", "\[Rule]", "482"}], ",", 
       RowBox[{"389", "\[Rule]", "390"}], ",", 
       RowBox[{"21", "\[Rule]", "160"}], ",", 
       RowBox[{"21", "\[Rule]", "160"}], ",", 
       RowBox[{"21", "\[Rule]", "22"}], ",", 
       RowBox[{"251", "\[Rule]", "160"}], ",", 
       RowBox[{"251", "\[Rule]", "252"}], ",", 
       RowBox[{"131", "\[Rule]", "224"}], ",", 
       RowBox[{"131", "\[Rule]", "224"}], ",", 
       RowBox[{"131", "\[Rule]", "132"}], ",", 
       RowBox[{"361", "\[Rule]", "224"}], ",", 
       RowBox[{"361", "\[Rule]", "224"}], ",", 
       RowBox[{"361", "\[Rule]", "454"}], ",", 
       RowBox[{"361", "\[Rule]", "454"}], ",", 
       RowBox[{"361", "\[Rule]", "362"}], ",", 
       RowBox[{"569", "\[Rule]", "432"}], ",", 
       RowBox[{"569", "\[Rule]", "432"}], ",", 
       RowBox[{"569", "\[Rule]", "570"}], ",", 
       RowBox[{"559", "\[Rule]", "422"}], ",", 
       RowBox[{"559", "\[Rule]", "422"}], ",", 
       RowBox[{"559", "\[Rule]", "560"}], ",", 
       RowBox[{"587", "\[Rule]", "450"}], ",", 
       RowBox[{"587", "\[Rule]", "588"}], ",", 
       RowBox[{"577", "\[Rule]", "440"}], ",", 
       RowBox[{"577", "\[Rule]", "440"}], ",", 
       RowBox[{"577", "\[Rule]", "578"}], ",", 
       RowBox[{"523", "\[Rule]", "432"}], ",", 
       RowBox[{"523", "\[Rule]", "432"}], ",", 
       RowBox[{"523", "\[Rule]", "386"}], ",", 
       RowBox[{"523", "\[Rule]", "386"}], ",", 
       RowBox[{"523", "\[Rule]", "524"}], ",", 
       RowBox[{"513", "\[Rule]", "422"}], ",", 
       RowBox[{"513", "\[Rule]", "422"}], ",", 
       RowBox[{"513", "\[Rule]", "376"}], ",", 
       RowBox[{"513", "\[Rule]", "376"}], ",", 
       RowBox[{"513", "\[Rule]", "514"}], ",", 
       RowBox[{"541", "\[Rule]", "450"}], ",", 
       RowBox[{"541", "\[Rule]", "450"}], ",", 
       RowBox[{"541", "\[Rule]", "404"}], ",", 
       RowBox[{"541", "\[Rule]", "404"}], ",", 
       RowBox[{"541", "\[Rule]", "542"}], ",", 
       RowBox[{"531", "\[Rule]", "440"}], ",", 
       RowBox[{"531", "\[Rule]", "440"}], ",", 
       RowBox[{"531", "\[Rule]", "394"}], ",", 
       RowBox[{"531", "\[Rule]", "394"}], ",", 
       RowBox[{"531", "\[Rule]", "532"}], ",", 
       RowBox[{"595", "\[Rule]", "458"}], ",", 
       RowBox[{"595", "\[Rule]", "596"}], ",", 
       RowBox[{"583", "\[Rule]", "446"}], ",", 
       RowBox[{"583", "\[Rule]", "446"}], ",", 
       RowBox[{"583", "\[Rule]", "584"}], ",", 
       RowBox[{"549", "\[Rule]", "458"}], ",", 
       RowBox[{"549", "\[Rule]", "412"}], ",", 
       RowBox[{"549", "\[Rule]", "412"}], ",", 
       RowBox[{"549", "\[Rule]", "550"}], ",", 
       RowBox[{"537", "\[Rule]", "446"}], ",", 
       RowBox[{"537", "\[Rule]", "400"}], ",", 
       RowBox[{"537", "\[Rule]", "538"}], ",", 
       RowBox[{"573", "\[Rule]", "436"}], ",", 
       RowBox[{"573", "\[Rule]", "436"}], ",", 
       RowBox[{"573", "\[Rule]", "574"}], ",", 
       RowBox[{"527", "\[Rule]", "436"}], ",", 
       RowBox[{"527", "\[Rule]", "436"}], ",", 
       RowBox[{"527", "\[Rule]", "390"}], ",", 
       RowBox[{"527", "\[Rule]", "390"}], ",", 
       RowBox[{"527", "\[Rule]", "528"}], ",", 
       RowBox[{"477", "\[Rule]", "386"}], ",", 
       RowBox[{"477", "\[Rule]", "478"}], ",", 
       RowBox[{"467", "\[Rule]", "376"}], ",", 
       RowBox[{"467", "\[Rule]", "468"}], ",", 
       RowBox[{"495", "\[Rule]", "404"}], ",", 
       RowBox[{"495", "\[Rule]", "496"}], ",", 
       RowBox[{"485", "\[Rule]", "394"}], ",", 
       RowBox[{"485", "\[Rule]", "486"}], ",", 
       RowBox[{"503", "\[Rule]", "412"}], ",", 
       RowBox[{"503", "\[Rule]", "504"}], ",", 
       RowBox[{"491", "\[Rule]", "400"}], ",", 
       RowBox[{"491", "\[Rule]", "492"}], ",", 
       RowBox[{"481", "\[Rule]", "390"}], ",", 
       RowBox[{"481", "\[Rule]", "482"}], ",", 
       RowBox[{"591", "\[Rule]", "454"}], ",", 
       RowBox[{"591", "\[Rule]", "454"}], ",", 
       RowBox[{"591", "\[Rule]", "592"}], ",", 
       RowBox[{"545", "\[Rule]", "454"}], ",", 
       RowBox[{"545", "\[Rule]", "454"}], ",", 
       RowBox[{"545", "\[Rule]", "408"}], ",", 
       RowBox[{"545", "\[Rule]", "546"}], ",", 
       RowBox[{"499", "\[Rule]", "500"}], ",", 
       RowBox[{"100", "\[Rule]", "107"}], ",", 
       RowBox[{"100", "\[Rule]", "101"}], ",", 
       RowBox[{"100", "\[Rule]", "97"}], ",", 
       RowBox[{"330", "\[Rule]", "337"}], ",", 
       RowBox[{"330", "\[Rule]", "331"}], ",", 
       RowBox[{"330", "\[Rule]", "327"}], ",", 
       RowBox[{"284", "\[Rule]", "291"}], ",", 
       RowBox[{"284", "\[Rule]", "285"}], ",", 
       RowBox[{"284", "\[Rule]", "281"}], ",", 
       RowBox[{"192", "\[Rule]", "199"}], ",", 
       RowBox[{"192", "\[Rule]", "193"}], ",", 
       RowBox[{"192", "\[Rule]", "189"}], ",", 
       RowBox[{"560", "\[Rule]", "567"}], ",", 
       RowBox[{"560", "\[Rule]", "561"}], ",", 
       RowBox[{"560", "\[Rule]", "557"}], ",", 
       RowBox[{"514", "\[Rule]", "521"}], ",", 
       RowBox[{"514", "\[Rule]", "515"}], ",", 
       RowBox[{"514", "\[Rule]", "511"}], ",", 
       RowBox[{"422", "\[Rule]", "429"}], ",", 
       RowBox[{"422", "\[Rule]", "423"}], ",", 
       RowBox[{"422", "\[Rule]", "419"}], ",", 
       RowBox[{"54", "\[Rule]", "61"}], ",", 
       RowBox[{"54", "\[Rule]", "55"}], ",", 
       RowBox[{"54", "\[Rule]", "51"}], ",", 
       RowBox[{"8", "\[Rule]", "15"}], ",", 
       RowBox[{"8", "\[Rule]", "9"}], ",", 
       RowBox[{"8", "\[Rule]", "5"}], ",", 
       RowBox[{"238", "\[Rule]", "245"}], ",", 
       RowBox[{"238", "\[Rule]", "239"}], ",", 
       RowBox[{"238", "\[Rule]", "235"}], ",", 
       RowBox[{"146", "\[Rule]", "153"}], ",", 
       RowBox[{"146", "\[Rule]", "147"}], ",", 
       RowBox[{"146", "\[Rule]", "143"}], ",", 
       RowBox[{"468", "\[Rule]", "475"}], ",", 
       RowBox[{"468", "\[Rule]", "469"}], ",", 
       RowBox[{"468", "\[Rule]", "465"}], ",", 
       RowBox[{"376", "\[Rule]", "383"}], ",", 
       RowBox[{"376", "\[Rule]", "377"}], ",", 
       RowBox[{"376", "\[Rule]", "373"}], ",", 
       RowBox[{"114", "\[Rule]", "105"}], ",", 
       RowBox[{"114", "\[Rule]", "121"}], ",", 
       RowBox[{"114", "\[Rule]", "115"}], ",", 
       RowBox[{"114", "\[Rule]", "111"}], ",", 
       RowBox[{"344", "\[Rule]", "335"}], ",", 
       RowBox[{"344", "\[Rule]", "351"}], ",", 
       RowBox[{"344", "\[Rule]", "345"}], ",", 
       RowBox[{"344", "\[Rule]", "341"}], ",", 
       RowBox[{"68", "\[Rule]", "59"}], ",", 
       RowBox[{"68", "\[Rule]", "75"}], ",", 
       RowBox[{"68", "\[Rule]", "69"}], ",", 
       RowBox[{"68", "\[Rule]", "65"}], ",", 
       RowBox[{"298", "\[Rule]", "289"}], ",", 
       RowBox[{"298", "\[Rule]", "305"}], ",", 
       RowBox[{"298", "\[Rule]", "299"}], ",", 
       RowBox[{"298", "\[Rule]", "295"}], ",", 
       RowBox[{"206", "\[Rule]", "197"}], ",", 
       RowBox[{"206", "\[Rule]", "213"}], ",", 
       RowBox[{"206", "\[Rule]", "207"}], ",", 
       RowBox[{"206", "\[Rule]", "203"}], ",", 
       RowBox[{"574", "\[Rule]", "565"}], ",", 
       RowBox[{"574", "\[Rule]", "581"}], ",", 
       RowBox[{"574", "\[Rule]", "575"}], ",", 
       RowBox[{"574", "\[Rule]", "571"}], ",", 
       RowBox[{"528", "\[Rule]", "519"}], ",", 
       RowBox[{"528", "\[Rule]", "535"}], ",", 
       RowBox[{"528", "\[Rule]", "529"}], ",", 
       RowBox[{"528", "\[Rule]", "525"}], ",", 
       RowBox[{"436", "\[Rule]", "427"}], ",", 
       RowBox[{"436", "\[Rule]", "443"}], ",", 
       RowBox[{"436", "\[Rule]", "437"}], ",", 
       RowBox[{"436", "\[Rule]", "433"}], ",", 
       RowBox[{"22", "\[Rule]", "13"}], ",", 
       RowBox[{"22", "\[Rule]", "29"}], ",", 
       RowBox[{"22", "\[Rule]", "23"}], ",", 
       RowBox[{"22", "\[Rule]", "19"}], ",", 
       RowBox[{"252", "\[Rule]", "243"}], ",", 
       RowBox[{"252", "\[Rule]", "259"}], ",", 
       RowBox[{"252", "\[Rule]", "253"}], ",", 
       RowBox[{"252", "\[Rule]", "249"}], ",", 
       RowBox[{"160", "\[Rule]", "151"}], ",", 
       RowBox[{"160", "\[Rule]", "167"}], ",", 
       RowBox[{"160", "\[Rule]", "161"}], ",", 
       RowBox[{"160", "\[Rule]", "157"}], ",", 
       RowBox[{"390", "\[Rule]", "381"}], ",", 
       RowBox[{"390", "\[Rule]", "397"}], ",", 
       RowBox[{"390", "\[Rule]", "391"}], ",", 
       RowBox[{"390", "\[Rule]", "387"}], ",", 
       RowBox[{"482", "\[Rule]", "473"}], ",", 
       RowBox[{"482", "\[Rule]", "489"}], ",", 
       RowBox[{"482", "\[Rule]", "483"}], ",", 
       RowBox[{"482", "\[Rule]", "479"}], ",", 
       RowBox[{"500", "\[Rule]", "489"}], ",", 
       RowBox[{"500", "\[Rule]", "501"}], ",", 
       RowBox[{"500", "\[Rule]", "497"}], ",", 
       RowBox[{"97", "\[Rule]", "190"}], ",", 
       RowBox[{"97", "\[Rule]", "190"}], ",", 
       RowBox[{"97", "\[Rule]", "98"}], ",", 
       RowBox[{"327", "\[Rule]", "190"}], ",", 
       RowBox[{"327", "\[Rule]", "190"}], ",", 
       RowBox[{"327", "\[Rule]", "420"}], ",", 
       RowBox[{"327", "\[Rule]", "420"}], ",", 
       RowBox[{"327", "\[Rule]", "328"}], ",", 
       RowBox[{"281", "\[Rule]", "190"}], ",", 
       RowBox[{"281", "\[Rule]", "420"}], ",", 
       RowBox[{"281", "\[Rule]", "420"}], ",", 
       RowBox[{"281", "\[Rule]", "144"}], ",", 
       RowBox[{"281", "\[Rule]", "374"}], ",", 
       RowBox[{"281", "\[Rule]", "374"}], ",", 
       RowBox[{"281", "\[Rule]", "282"}], ",", 
       RowBox[{"189", "\[Rule]", "98"}], ",", 
       RowBox[{"189", "\[Rule]", "98"}], ",", 
       RowBox[{"189", "\[Rule]", "328"}], ",", 
       RowBox[{"189", "\[Rule]", "328"}], ",", 
       RowBox[{"189", "\[Rule]", "52"}], ",", 
       RowBox[{"189", "\[Rule]", "282"}], ",", 
       RowBox[{"189", "\[Rule]", "190"}], ",", 
       RowBox[{"557", "\[Rule]", "420"}], ",", 
       RowBox[{"557", "\[Rule]", "420"}], ",", 
       RowBox[{"557", "\[Rule]", "558"}], ",", 
       RowBox[{"511", "\[Rule]", "420"}], ",", 
       RowBox[{"511", "\[Rule]", "420"}], ",", 
       RowBox[{"511", "\[Rule]", "374"}], ",", 
       RowBox[{"511", "\[Rule]", "374"}], ",", 
       RowBox[{"511", "\[Rule]", "512"}], ",", 
       RowBox[{"419", "\[Rule]", "328"}], ",", 
       RowBox[{"419", "\[Rule]", "328"}], ",", 
       RowBox[{"419", "\[Rule]", "558"}], ",", 
       RowBox[{"419", "\[Rule]", "558"}], ",", 
       RowBox[{"419", "\[Rule]", "282"}], ",", 
       RowBox[{"419", "\[Rule]", "282"}], ",", 
       RowBox[{"419", "\[Rule]", "512"}], ",", 
       RowBox[{"419", "\[Rule]", "512"}], ",", 
       RowBox[{"419", "\[Rule]", "420"}], ",", 
       RowBox[{"51", "\[Rule]", "190"}], ",", 
       RowBox[{"51", "\[Rule]", "144"}], ",", 
       RowBox[{"51", "\[Rule]", "52"}], ",", 
       RowBox[{"5", "\[Rule]", "144"}], ",", 
       RowBox[{"5", "\[Rule]", "144"}], ",", 
       RowBox[{"5", "\[Rule]", "6"}], ",", 
       RowBox[{"235", "\[Rule]", "144"}], ",", 
       RowBox[{"235", "\[Rule]", "144"}], ",", 
       RowBox[{"235", "\[Rule]", "374"}], ",", 
       RowBox[{"235", "\[Rule]", "236"}], ",", 
       RowBox[{"143", "\[Rule]", "52"}], ",", 
       RowBox[{"143", "\[Rule]", "282"}], ",", 
       RowBox[{"143", "\[Rule]", "6"}], ",", 
       RowBox[{"143", "\[Rule]", "6"}], ",", 
       RowBox[{"143", "\[Rule]", "236"}], ",", 
       RowBox[{"143", "\[Rule]", "236"}], ",", 
       RowBox[{"143", "\[Rule]", "144"}], ",", 
       RowBox[{"465", "\[Rule]", "374"}], ",", 
       RowBox[{"465", "\[Rule]", "466"}], ",", 
       RowBox[{"373", "\[Rule]", "282"}], ",", 
       RowBox[{"373", "\[Rule]", "282"}], ",", 
       RowBox[{"373", "\[Rule]", "512"}], ",", 
       RowBox[{"373", "\[Rule]", "512"}], ",", 
       RowBox[{"373", "\[Rule]", "236"}], ",", 
       RowBox[{"373", "\[Rule]", "466"}], ",", 
       RowBox[{"373", "\[Rule]", "374"}], ",", 
       RowBox[{"105", "\[Rule]", "198"}], ",", 
       RowBox[{"105", "\[Rule]", "198"}], ",", 
       RowBox[{"105", "\[Rule]", "106"}], ",", 
       RowBox[{"111", "\[Rule]", "204"}], ",", 
       RowBox[{"111", "\[Rule]", "204"}], ",", 
       RowBox[{"111", "\[Rule]", "112"}], ",", 
       RowBox[{"335", "\[Rule]", "198"}], ",", 
       RowBox[{"335", "\[Rule]", "198"}], ",", 
       RowBox[{"335", "\[Rule]", "428"}], ",", 
       RowBox[{"335", "\[Rule]", "428"}], ",", 
       RowBox[{"335", "\[Rule]", "336"}], ",", 
       RowBox[{"341", "\[Rule]", "204"}], ",", 
       RowBox[{"341", "\[Rule]", "204"}], ",", 
       RowBox[{"341", "\[Rule]", "434"}], ",", 
       RowBox[{"341", "\[Rule]", "434"}], ",", 
       RowBox[{"341", "\[Rule]", "342"}], ",", 
       RowBox[{"59", "\[Rule]", "198"}], ",", 
       RowBox[{"59", "\[Rule]", "152"}], ",", 
       RowBox[{"59", "\[Rule]", "60"}], ",", 
       RowBox[{"65", "\[Rule]", "204"}], ",", 
       RowBox[{"65", "\[Rule]", "158"}], ",", 
       RowBox[{"65", "\[Rule]", "66"}], ",", 
       RowBox[{"289", "\[Rule]", "198"}], ",", 
       RowBox[{"289", "\[Rule]", "428"}], ",", 
       RowBox[{"289", "\[Rule]", "428"}], ",", 
       RowBox[{"289", "\[Rule]", "152"}], ",", 
       RowBox[{"289", "\[Rule]", "382"}], ",", 
       RowBox[{"289", "\[Rule]", "382"}], ",", 
       RowBox[{"289", "\[Rule]", "290"}], ",", 
       RowBox[{"295", "\[Rule]", "204"}], ",", 
       RowBox[{"295", "\[Rule]", "434"}], ",", 
       RowBox[{"295", "\[Rule]", "434"}], ",", 
       RowBox[{"295", "\[Rule]", "158"}], ",", 
       RowBox[{"295", "\[Rule]", "388"}], ",", 
       RowBox[{"295", "\[Rule]", "388"}], ",", 
       RowBox[{"295", "\[Rule]", "296"}], ",", 
       RowBox[{"197", "\[Rule]", "106"}], ",", 
       RowBox[{"197", "\[Rule]", "106"}], ",", 
       RowBox[{"197", "\[Rule]", "336"}], ",", 
       RowBox[{"197", "\[Rule]", "336"}], ",", 
       RowBox[{"197", "\[Rule]", "60"}], ",", 
       RowBox[{"197", "\[Rule]", "290"}], ",", 
       RowBox[{"197", "\[Rule]", "198"}], ",", 
       RowBox[{"203", "\[Rule]", "112"}], ",", 
       RowBox[{"203", "\[Rule]", "112"}], ",", 
       RowBox[{"203", "\[Rule]", "342"}], ",", 
       RowBox[{"203", "\[Rule]", "342"}], ",", 
       RowBox[{"203", "\[Rule]", "66"}], ",", 
       RowBox[{"203", "\[Rule]", "296"}], ",", 
       RowBox[{"203", "\[Rule]", "204"}], ",", 
       RowBox[{"565", "\[Rule]", "428"}], ",", 
       RowBox[{"565", "\[Rule]", "428"}], ",", 
       RowBox[{"565", "\[Rule]", "566"}], ",", 
       RowBox[{"571", "\[Rule]", "434"}], ",", 
       RowBox[{"571", "\[Rule]", "434"}], ",", 
       RowBox[{"571", "\[Rule]", "572"}], ",", 
       RowBox[{"519", "\[Rule]", "428"}], ",", 
       RowBox[{"519", "\[Rule]", "428"}], ",", 
       RowBox[{"519", "\[Rule]", "382"}], ",", 
       RowBox[{"519", "\[Rule]", "382"}], ",", 
       RowBox[{"519", "\[Rule]", "520"}], ",", 
       RowBox[{"525", "\[Rule]", "434"}], ",", 
       RowBox[{"525", "\[Rule]", "434"}], ",", 
       RowBox[{"525", "\[Rule]", "388"}], ",", 
       RowBox[{"525", "\[Rule]", "388"}], ",", 
       RowBox[{"525", "\[Rule]", "526"}], ",", 
       RowBox[{"427", "\[Rule]", "336"}], ",", 
       RowBox[{"427", "\[Rule]", "336"}], ",", 
       RowBox[{"427", "\[Rule]", "566"}], ",", 
       RowBox[{"427", "\[Rule]", "566"}], ",", 
       RowBox[{"427", "\[Rule]", "290"}], ",", 
       RowBox[{"427", "\[Rule]", "290"}], ",", 
       RowBox[{"427", "\[Rule]", "520"}], ",", 
       RowBox[{"427", "\[Rule]", "520"}], ",", 
       RowBox[{"427", "\[Rule]", "428"}], ",", 
       RowBox[{"433", "\[Rule]", "342"}], ",", 
       RowBox[{"433", "\[Rule]", "342"}], ",", 
       RowBox[{"433", "\[Rule]", "572"}], ",", 
       RowBox[{"433", "\[Rule]", "572"}], ",", 
       RowBox[{"433", "\[Rule]", "296"}], ",", 
       RowBox[{"433", "\[Rule]", "296"}], ",", 
       RowBox[{"433", "\[Rule]", "526"}], ",", 
       RowBox[{"433", "\[Rule]", "526"}], ",", 
       RowBox[{"433", "\[Rule]", "434"}], ",", 
       RowBox[{"13", "\[Rule]", "152"}], ",", 
       RowBox[{"13", "\[Rule]", "152"}], ",", 
       RowBox[{"13", "\[Rule]", "14"}], ",", 
       RowBox[{"19", "\[Rule]", "158"}], ",", 
       RowBox[{"19", "\[Rule]", "158"}], ",", 
       RowBox[{"19", "\[Rule]", "20"}], ",", 
       RowBox[{"243", "\[Rule]", "152"}], ",", 
       RowBox[{"243", "\[Rule]", "152"}], ",", 
       RowBox[{"243", "\[Rule]", "382"}], ",", 
       RowBox[{"243", "\[Rule]", "244"}], ",", 
       RowBox[{"249", "\[Rule]", "158"}], ",", 
       RowBox[{"249", "\[Rule]", "158"}], ",", 
       RowBox[{"249", "\[Rule]", "388"}], ",", 
       RowBox[{"249", "\[Rule]", "250"}], ",", 
       RowBox[{"151", "\[Rule]", "60"}], ",", 
       RowBox[{"151", "\[Rule]", "290"}], ",", 
       RowBox[{"151", "\[Rule]", "14"}], ",", 
       RowBox[{"151", "\[Rule]", "14"}], ",", 
       RowBox[{"151", "\[Rule]", "244"}], ",", 
       RowBox[{"151", "\[Rule]", "244"}], ",", 
       RowBox[{"151", "\[Rule]", "152"}], ",", 
       RowBox[{"157", "\[Rule]", "66"}], ",", 
       RowBox[{"157", "\[Rule]", "296"}], ",", 
       RowBox[{"157", "\[Rule]", "20"}], ",", 
       RowBox[{"157", "\[Rule]", "20"}], ",", 
       RowBox[{"157", "\[Rule]", "250"}], ",", 
       RowBox[{"157", "\[Rule]", "250"}], ",", 
       RowBox[{"157", "\[Rule]", "158"}], ",", 
       RowBox[{"381", "\[Rule]", "290"}], ",", 
       RowBox[{"381", "\[Rule]", "290"}], ",", 
       RowBox[{"381", "\[Rule]", "520"}], ",", 
       RowBox[{"381", "\[Rule]", "520"}], ",", 
       RowBox[{"381", "\[Rule]", "244"}], ",", 
       RowBox[{"381", "\[Rule]", "474"}], ",", 
       RowBox[{"381", "\[Rule]", "382"}], ",", 
       RowBox[{"387", "\[Rule]", "296"}], ",", 
       RowBox[{"387", "\[Rule]", "296"}], ",", 
       RowBox[{"387", "\[Rule]", "526"}], ",", 
       RowBox[{"387", "\[Rule]", "526"}], ",", 
       RowBox[{"387", "\[Rule]", "250"}], ",", 
       RowBox[{"387", "\[Rule]", "480"}], ",", 
       RowBox[{"387", "\[Rule]", "388"}], ",", 
       RowBox[{"473", "\[Rule]", "382"}], ",", 
       RowBox[{"473", "\[Rule]", "474"}], ",", 
       RowBox[{"479", "\[Rule]", "388"}], ",", 
       RowBox[{"479", "\[Rule]", "480"}], ",", 
       RowBox[{"497", "\[Rule]", "406"}], ",", 
       RowBox[{"497", "\[Rule]", "498"}], ",", 
       RowBox[{"190", "\[Rule]", "191"}], ",", 
       RowBox[{"190", "\[Rule]", "187"}], ",", 
       RowBox[{"98", "\[Rule]", "99"}], ",", 
       RowBox[{"98", "\[Rule]", "95"}], ",", 
       RowBox[{"420", "\[Rule]", "421"}], ",", 
       RowBox[{"420", "\[Rule]", "417"}], ",", 
       RowBox[{"328", "\[Rule]", "329"}], ",", 
       RowBox[{"328", "\[Rule]", "325"}], ",", 
       RowBox[{"144", "\[Rule]", "145"}], ",", 
       RowBox[{"144", "\[Rule]", "141"}], ",", 
       RowBox[{"374", "\[Rule]", "375"}], ",", 
       RowBox[{"374", "\[Rule]", "371"}], ",", 
       RowBox[{"282", "\[Rule]", "283"}], ",", 
       RowBox[{"282", "\[Rule]", "279"}], ",", 
       RowBox[{"52", "\[Rule]", "53"}], ",", 
       RowBox[{"52", "\[Rule]", "49"}], ",", 
       RowBox[{"558", "\[Rule]", "559"}], ",", 
       RowBox[{"558", "\[Rule]", "555"}], ",", 
       RowBox[{"512", "\[Rule]", "513"}], ",", 
       RowBox[{"512", "\[Rule]", "509"}], ",", 
       RowBox[{"6", "\[Rule]", "7"}], ",", 
       RowBox[{"6", "\[Rule]", "3"}], ",", 
       RowBox[{"236", "\[Rule]", "237"}], ",", 
       RowBox[{"236", "\[Rule]", "233"}], ",", 
       RowBox[{"466", "\[Rule]", "467"}], ",", 
       RowBox[{"466", "\[Rule]", "463"}], ",", 
       RowBox[{"198", "\[Rule]", "187"}], ",", 
       RowBox[{"198", "\[Rule]", "205"}], ",", 
       RowBox[{"198", "\[Rule]", "195"}], ",", 
       RowBox[{"106", "\[Rule]", "95"}], ",", 
       RowBox[{"106", "\[Rule]", "113"}], ",", 
       RowBox[{"106", "\[Rule]", "103"}], ",", 
       RowBox[{"204", "\[Rule]", "195"}], ",", 
       RowBox[{"204", "\[Rule]", "205"}], ",", 
       RowBox[{"112", "\[Rule]", "103"}], ",", 
       RowBox[{"112", "\[Rule]", "113"}], ",", 
       RowBox[{"428", "\[Rule]", "417"}], ",", 
       RowBox[{"428", "\[Rule]", "435"}], ",", 
       RowBox[{"428", "\[Rule]", "425"}], ",", 
       RowBox[{"336", "\[Rule]", "325"}], ",", 
       RowBox[{"336", "\[Rule]", "343"}], ",", 
       RowBox[{"336", "\[Rule]", "333"}], ",", 
       RowBox[{"434", "\[Rule]", "425"}], ",", 
       RowBox[{"434", "\[Rule]", "435"}], ",", 
       RowBox[{"342", "\[Rule]", "333"}], ",", 
       RowBox[{"342", "\[Rule]", "343"}], ",", 
       RowBox[{"152", "\[Rule]", "141"}], ",", 
       RowBox[{"152", "\[Rule]", "159"}], ",", 
       RowBox[{"152", "\[Rule]", "149"}], ",", 
       RowBox[{"60", "\[Rule]", "49"}], ",", 
       RowBox[{"60", "\[Rule]", "67"}], ",", 
       RowBox[{"60", "\[Rule]", "57"}], ",", 
       RowBox[{"158", "\[Rule]", "149"}], ",", 
       RowBox[{"158", "\[Rule]", "159"}], ",", 
       RowBox[{"66", "\[Rule]", "57"}], ",", 
       RowBox[{"66", "\[Rule]", "67"}], ",", 
       RowBox[{"382", "\[Rule]", "371"}], ",", 
       RowBox[{"382", "\[Rule]", "389"}], ",", 
       RowBox[{"382", "\[Rule]", "379"}], ",", 
       RowBox[{"290", "\[Rule]", "279"}], ",", 
       RowBox[{"290", "\[Rule]", "297"}], ",", 
       RowBox[{"290", "\[Rule]", "287"}], ",", 
       RowBox[{"388", "\[Rule]", "379"}], ",", 
       RowBox[{"388", "\[Rule]", "389"}], ",", 
       RowBox[{"296", "\[Rule]", "287"}], ",", 
       RowBox[{"296", "\[Rule]", "297"}], ",", 
       RowBox[{"566", "\[Rule]", "555"}], ",", 
       RowBox[{"566", "\[Rule]", "573"}], ",", 
       RowBox[{"566", "\[Rule]", "563"}], ",", 
       RowBox[{"572", "\[Rule]", "563"}], ",", 
       RowBox[{"572", "\[Rule]", "573"}], ",", 
       RowBox[{"520", "\[Rule]", "509"}], ",", 
       RowBox[{"520", "\[Rule]", "527"}], ",", 
       RowBox[{"520", "\[Rule]", "517"}], ",", 
       RowBox[{"526", "\[Rule]", "517"}], ",", 
       RowBox[{"526", "\[Rule]", "527"}], ",", 
       RowBox[{"14", "\[Rule]", "3"}], ",", 
       RowBox[{"14", "\[Rule]", "21"}], ",", 
       RowBox[{"14", "\[Rule]", "11"}], ",", 
       RowBox[{"20", "\[Rule]", "11"}], ",", 
       RowBox[{"20", "\[Rule]", "21"}], ",", 
       RowBox[{"244", "\[Rule]", "233"}], ",", 
       RowBox[{"244", "\[Rule]", "251"}], ",", 
       RowBox[{"244", "\[Rule]", "241"}], ",", 
       RowBox[{"250", "\[Rule]", "241"}], ",", 
       RowBox[{"250", "\[Rule]", "251"}], ",", 
       RowBox[{"474", "\[Rule]", "463"}], ",", 
       RowBox[{"474", "\[Rule]", "481"}], ",", 
       RowBox[{"474", "\[Rule]", "471"}], ",", 
       RowBox[{"480", "\[Rule]", "471"}], ",", 
       RowBox[{"480", "\[Rule]", "481"}], ",", 
       RowBox[{"187", "\[Rule]", "96"}], ",", 
       RowBox[{"187", "\[Rule]", "96"}], ",", 
       RowBox[{"187", "\[Rule]", "326"}], ",", 
       RowBox[{"187", "\[Rule]", "326"}], ",", 
       RowBox[{"187", "\[Rule]", "50"}], ",", 
       RowBox[{"187", "\[Rule]", "280"}], ",", 
       RowBox[{"187", "\[Rule]", "188"}], ",", 
       RowBox[{"95", "\[Rule]", "188"}], ",", 
       RowBox[{"95", "\[Rule]", "188"}], ",", 
       RowBox[{"95", "\[Rule]", "96"}], ",", 
       RowBox[{"417", "\[Rule]", "326"}], ",", 
       RowBox[{"417", "\[Rule]", "326"}], ",", 
       RowBox[{"417", "\[Rule]", "556"}], ",", 
       RowBox[{"417", "\[Rule]", "556"}], ",", 
       RowBox[{"417", "\[Rule]", "280"}], ",", 
       RowBox[{"417", "\[Rule]", "280"}], ",", 
       RowBox[{"417", "\[Rule]", "510"}], ",", 
       RowBox[{"417", "\[Rule]", "510"}], ",", 
       RowBox[{"417", "\[Rule]", "418"}], ",", 
       RowBox[{"325", "\[Rule]", "188"}], ",", 
       RowBox[{"325", "\[Rule]", "188"}], ",", 
       RowBox[{"325", "\[Rule]", "418"}], ",", 
       RowBox[{"325", "\[Rule]", "418"}], ",", 
       RowBox[{"325", "\[Rule]", "326"}], ",", 
       RowBox[{"141", "\[Rule]", "280"}], ",", 
       RowBox[{"141", "\[Rule]", "4"}], ",", 
       RowBox[{"141", "\[Rule]", "234"}], ",", 
       RowBox[{"141", "\[Rule]", "234"}], ",", 
       RowBox[{"141", "\[Rule]", "142"}], ",", 
       RowBox[{"371", "\[Rule]", "280"}], ",", 
       RowBox[{"371", "\[Rule]", "280"}], ",", 
       RowBox[{"371", "\[Rule]", "510"}], ",", 
       RowBox[{"371", "\[Rule]", "510"}], ",", 
       RowBox[{"371", "\[Rule]", "234"}], ",", 
       RowBox[{"371", "\[Rule]", "464"}], ",", 
       RowBox[{"371", "\[Rule]", "372"}], ",", 
       RowBox[{"279", "\[Rule]", "188"}], ",", 
       RowBox[{"279", "\[Rule]", "418"}], ",", 
       RowBox[{"279", "\[Rule]", "418"}], ",", 
       RowBox[{"279", "\[Rule]", "142"}], ",", 
       RowBox[{"279", "\[Rule]", "372"}], ",", 
       RowBox[{"279", "\[Rule]", "372"}], ",", 
       RowBox[{"279", "\[Rule]", "280"}], ",", 
       RowBox[{"49", "\[Rule]", "188"}], ",", 
       RowBox[{"49", "\[Rule]", "50"}], ",", 
       RowBox[{"555", "\[Rule]", "418"}], ",", 
       RowBox[{"555", "\[Rule]", "418"}], ",", 
       RowBox[{"555", "\[Rule]", "556"}], ",", 
       RowBox[{"509", "\[Rule]", "418"}], ",", 
       RowBox[{"509", "\[Rule]", "418"}], ",", 
       RowBox[{"509", "\[Rule]", "372"}], ",", 
       RowBox[{"509", "\[Rule]", "372"}], ",", 
       RowBox[{"509", "\[Rule]", "510"}], ",", 
       RowBox[{"3", "\[Rule]", "142"}], ",", 
       RowBox[{"3", "\[Rule]", "4"}], ",", 
       RowBox[{"233", "\[Rule]", "142"}], ",", 
       RowBox[{"233", "\[Rule]", "142"}], ",", 
       RowBox[{"233", "\[Rule]", "372"}], ",", 
       RowBox[{"233", "\[Rule]", "234"}], ",", 
       RowBox[{"463", "\[Rule]", "372"}], ",", 
       RowBox[{"463", "\[Rule]", "464"}], ",", 
       RowBox[{"195", "\[Rule]", "104"}], ",", 
       RowBox[{"195", "\[Rule]", "104"}], ",", 
       RowBox[{"195", "\[Rule]", "334"}], ",", 
       RowBox[{"195", "\[Rule]", "334"}], ",", 
       RowBox[{"195", "\[Rule]", "58"}], ",", 
       RowBox[{"195", "\[Rule]", "288"}], ",", 
       RowBox[{"195", "\[Rule]", "196"}], ",", 
       RowBox[{"103", "\[Rule]", "196"}], ",", 
       RowBox[{"103", "\[Rule]", "196"}], ",", 
       RowBox[{"103", "\[Rule]", "104"}], ",", 
       RowBox[{"425", "\[Rule]", "334"}], ",", 
       RowBox[{"425", "\[Rule]", "334"}], ",", 
       RowBox[{"425", "\[Rule]", "564"}], ",", 
       RowBox[{"425", "\[Rule]", "564"}], ",", 
       RowBox[{"425", "\[Rule]", "288"}], ",", 
       RowBox[{"425", "\[Rule]", "288"}], ",", 
       RowBox[{"425", "\[Rule]", "518"}], ",", 
       RowBox[{"425", "\[Rule]", "518"}], ",", 
       RowBox[{"425", "\[Rule]", "426"}], ",", 
       RowBox[{"333", "\[Rule]", "196"}], ",", 
       RowBox[{"333", "\[Rule]", "196"}], ",", 
       RowBox[{"333", "\[Rule]", "426"}], ",", 
       RowBox[{"333", "\[Rule]", "426"}], ",", 
       RowBox[{"333", "\[Rule]", "334"}], ",", 
       RowBox[{"149", "\[Rule]", "58"}], ",", 
       RowBox[{"149", "\[Rule]", "288"}], ",", 
       RowBox[{"149", "\[Rule]", "12"}], ",", 
       RowBox[{"149", "\[Rule]", "242"}], ",", 
       RowBox[{"149", "\[Rule]", "150"}], ",", 
       RowBox[{"57", "\[Rule]", "196"}], ",", 
       RowBox[{"57", "\[Rule]", "150"}], ",", 
       RowBox[{"57", "\[Rule]", "58"}], ",", 
       RowBox[{"379", "\[Rule]", "288"}], ",", 
       RowBox[{"379", "\[Rule]", "288"}], ",", 
       RowBox[{"379", "\[Rule]", "518"}], ",", 
       RowBox[{"379", "\[Rule]", "518"}], ",", 
       RowBox[{"379", "\[Rule]", "242"}], ",", 
       RowBox[{"379", "\[Rule]", "472"}], ",", 
       RowBox[{"379", "\[Rule]", "380"}], ",", 
       RowBox[{"287", "\[Rule]", "196"}], ",", 
       RowBox[{"287", "\[Rule]", "426"}], ",", 
       RowBox[{"287", "\[Rule]", "426"}], ",", 
       RowBox[{"287", "\[Rule]", "150"}], ",", 
       RowBox[{"287", "\[Rule]", "380"}], ",", 
       RowBox[{"287", "\[Rule]", "380"}], ",", 
       RowBox[{"287", "\[Rule]", "288"}], ",", 
       RowBox[{"563", "\[Rule]", "426"}], ",", 
       RowBox[{"563", "\[Rule]", "426"}], ",", 
       RowBox[{"563", "\[Rule]", "564"}], ",", 
       RowBox[{"517", "\[Rule]", "426"}], ",", 
       RowBox[{"517", "\[Rule]", "426"}], ",", 
       RowBox[{"517", "\[Rule]", "380"}], ",", 
       RowBox[{"517", "\[Rule]", "380"}], ",", 
       RowBox[{"517", "\[Rule]", "518"}], ",", 
       RowBox[{"11", "\[Rule]", "150"}], ",", 
       RowBox[{"11", "\[Rule]", "12"}], ",", 
       RowBox[{"241", "\[Rule]", "150"}], ",", 
       RowBox[{"241", "\[Rule]", "380"}], ",", 
       RowBox[{"241", "\[Rule]", "242"}], ",", 
       RowBox[{"471", "\[Rule]", "380"}], ",", 
       RowBox[{"471", "\[Rule]", "472"}], ",", 
       RowBox[{"96", "\[Rule]", "105"}], ",", 
       RowBox[{"96", "\[Rule]", "97"}], ",", 
       RowBox[{"96", "\[Rule]", "93"}], ",", 
       RowBox[{"326", "\[Rule]", "335"}], ",", 
       RowBox[{"326", "\[Rule]", "327"}], ",", 
       RowBox[{"326", "\[Rule]", "323"}], ",", 
       RowBox[{"50", "\[Rule]", "59"}], ",", 
       RowBox[{"50", "\[Rule]", "51"}], ",", 
       RowBox[{"50", "\[Rule]", "47"}], ",", 
       RowBox[{"280", "\[Rule]", "289"}], ",", 
       RowBox[{"280", "\[Rule]", "281"}], ",", 
       RowBox[{"280", "\[Rule]", "277"}], ",", 
       RowBox[{"188", "\[Rule]", "197"}], ",", 
       RowBox[{"188", "\[Rule]", "189"}], ",", 
       RowBox[{"188", "\[Rule]", "185"}], ",", 
       RowBox[{"556", "\[Rule]", "565"}], ",", 
       RowBox[{"556", "\[Rule]", "557"}], ",", 
       RowBox[{"556", "\[Rule]", "553"}], ",", 
       RowBox[{"510", "\[Rule]", "519"}], ",", 
       RowBox[{"510", "\[Rule]", "511"}], ",", 
       RowBox[{"510", "\[Rule]", "507"}], ",", 
       RowBox[{"418", "\[Rule]", "427"}], ",", 
       RowBox[{"418", "\[Rule]", "419"}], ",", 
       RowBox[{"418", "\[Rule]", "415"}], ",", 
       RowBox[{"4", "\[Rule]", "13"}], ",", 
       RowBox[{"4", "\[Rule]", "5"}], ",", 
       RowBox[{"4", "\[Rule]", "1"}], ",", 
       RowBox[{"234", "\[Rule]", "243"}], ",", 
       RowBox[{"234", "\[Rule]", "235"}], ",", 
       RowBox[{"234", "\[Rule]", "231"}], ",", 
       RowBox[{"142", "\[Rule]", "151"}], ",", 
       RowBox[{"142", "\[Rule]", "143"}], ",", 
       RowBox[{"142", "\[Rule]", "139"}], ",", 
       RowBox[{"464", "\[Rule]", "473"}], ",", 
       RowBox[{"464", "\[Rule]", "465"}], ",", 
       RowBox[{"464", "\[Rule]", "461"}], ",", 
       RowBox[{"372", "\[Rule]", "381"}], ",", 
       RowBox[{"372", "\[Rule]", "373"}], ",", 
       RowBox[{"372", "\[Rule]", "369"}], ",", 
       RowBox[{"104", "\[Rule]", "93"}], ",", 
       RowBox[{"104", "\[Rule]", "111"}], ",", 
       RowBox[{"104", "\[Rule]", "105"}], ",", 
       RowBox[{"334", "\[Rule]", "323"}], ",", 
       RowBox[{"334", "\[Rule]", "341"}], ",", 
       RowBox[{"334", "\[Rule]", "335"}], ",", 
       RowBox[{"58", "\[Rule]", "47"}], ",", 
       RowBox[{"58", "\[Rule]", "65"}], ",", 
       RowBox[{"58", "\[Rule]", "59"}], ",", 
       RowBox[{"288", "\[Rule]", "277"}], ",", 
       RowBox[{"288", "\[Rule]", "295"}], ",", 
       RowBox[{"288", "\[Rule]", "289"}], ",", 
       RowBox[{"196", "\[Rule]", "185"}], ",", 
       RowBox[{"196", "\[Rule]", "203"}], ",", 
       RowBox[{"196", "\[Rule]", "197"}], ",", 
       RowBox[{"564", "\[Rule]", "553"}], ",", 
       RowBox[{"564", "\[Rule]", "571"}], ",", 
       RowBox[{"564", "\[Rule]", "565"}], ",", 
       RowBox[{"518", "\[Rule]", "507"}], ",", 
       RowBox[{"518", "\[Rule]", "525"}], ",", 
       RowBox[{"518", "\[Rule]", "519"}], ",", 
       RowBox[{"426", "\[Rule]", "415"}], ",", 
       RowBox[{"426", "\[Rule]", "433"}], ",", 
       RowBox[{"426", "\[Rule]", "427"}], ",", 
       RowBox[{"12", "\[Rule]", "1"}], ",", 
       RowBox[{"12", "\[Rule]", "19"}], ",", 
       RowBox[{"12", "\[Rule]", "13"}], ",", 
       RowBox[{"242", "\[Rule]", "231"}], ",", 
       RowBox[{"242", "\[Rule]", "249"}], ",", 
       RowBox[{"242", "\[Rule]", "243"}], ",", 
       RowBox[{"150", "\[Rule]", "139"}], ",", 
       RowBox[{"150", "\[Rule]", "157"}], ",", 
       RowBox[{"150", "\[Rule]", "151"}], ",", 
       RowBox[{"472", "\[Rule]", "461"}], ",", 
       RowBox[{"472", "\[Rule]", "479"}], ",", 
       RowBox[{"472", "\[Rule]", "473"}], ",", 
       RowBox[{"380", "\[Rule]", "369"}], ",", 
       RowBox[{"380", "\[Rule]", "387"}], ",", 
       RowBox[{"380", "\[Rule]", "381"}], ",", 
       RowBox[{"93", "\[Rule]", "186"}], ",", 
       RowBox[{"93", "\[Rule]", "186"}], ",", 
       RowBox[{"93", "\[Rule]", "94"}], ",", 
       RowBox[{"323", "\[Rule]", "186"}], ",", 
       RowBox[{"323", "\[Rule]", "186"}], ",", 
       RowBox[{"323", "\[Rule]", "416"}], ",", 
       RowBox[{"323", "\[Rule]", "416"}], ",", 
       RowBox[{"323", "\[Rule]", "324"}], ",", 
       RowBox[{"47", "\[Rule]", "186"}], ",", 
       RowBox[{"47", "\[Rule]", "140"}], ",", 
       RowBox[{"47", "\[Rule]", "48"}], ",", 
       RowBox[{"277", "\[Rule]", "186"}], ",", 
       RowBox[{"277", "\[Rule]", "416"}], ",", 
       RowBox[{"277", "\[Rule]", "416"}], ",", 
       RowBox[{"277", "\[Rule]", "140"}], ",", 
       RowBox[{"277", "\[Rule]", "370"}], ",", 
       RowBox[{"277", "\[Rule]", "370"}], ",", 
       RowBox[{"277", "\[Rule]", "278"}], ",", 
       RowBox[{"185", "\[Rule]", "94"}], ",", 
       RowBox[{"185", "\[Rule]", "94"}], ",", 
       RowBox[{"185", "\[Rule]", "324"}], ",", 
       RowBox[{"185", "\[Rule]", "324"}], ",", 
       RowBox[{"185", "\[Rule]", "48"}], ",", 
       RowBox[{"185", "\[Rule]", "278"}], ",", 
       RowBox[{"185", "\[Rule]", "186"}], ",", 
       RowBox[{"553", "\[Rule]", "416"}], ",", 
       RowBox[{"553", "\[Rule]", "416"}], ",", 
       RowBox[{"553", "\[Rule]", "554"}], ",", 
       RowBox[{"507", "\[Rule]", "416"}], ",", 
       RowBox[{"507", "\[Rule]", "416"}], ",", 
       RowBox[{"507", "\[Rule]", "370"}], ",", 
       RowBox[{"507", "\[Rule]", "370"}], ",", 
       RowBox[{"507", "\[Rule]", "508"}], ",", 
       RowBox[{"415", "\[Rule]", "324"}], ",", 
       RowBox[{"415", "\[Rule]", "324"}], ",", 
       RowBox[{"415", "\[Rule]", "554"}], ",", 
       RowBox[{"415", "\[Rule]", "554"}], ",", 
       RowBox[{"415", "\[Rule]", "278"}], ",", 
       RowBox[{"415", "\[Rule]", "278"}], ",", 
       RowBox[{"415", "\[Rule]", "508"}], ",", 
       RowBox[{"415", "\[Rule]", "508"}], ",", 
       RowBox[{"415", "\[Rule]", "416"}], ",", 
       RowBox[{"1", "\[Rule]", "140"}], ",", 
       RowBox[{"1", "\[Rule]", "140"}], ",", 
       RowBox[{"1", "\[Rule]", "2"}], ",", 
       RowBox[{"231", "\[Rule]", "140"}], ",", 
       RowBox[{"231", "\[Rule]", "140"}], ",", 
       RowBox[{"231", "\[Rule]", "370"}], ",", 
       RowBox[{"231", "\[Rule]", "232"}], ",", 
       RowBox[{"139", "\[Rule]", "48"}], ",", 
       RowBox[{"139", "\[Rule]", "278"}], ",", 
       RowBox[{"139", "\[Rule]", "2"}], ",", 
       RowBox[{"139", "\[Rule]", "2"}], ",", 
       RowBox[{"139", "\[Rule]", "232"}], ",", 
       RowBox[{"139", "\[Rule]", "232"}], ",", 
       RowBox[{"139", "\[Rule]", "140"}], ",", 
       RowBox[{"461", "\[Rule]", "370"}], ",", 
       RowBox[{"461", "\[Rule]", "462"}], ",", 
       RowBox[{"369", "\[Rule]", "278"}], ",", 
       RowBox[{"369", "\[Rule]", "278"}], ",", 
       RowBox[{"369", "\[Rule]", "508"}], ",", 
       RowBox[{"369", "\[Rule]", "508"}], ",", 
       RowBox[{"369", "\[Rule]", "232"}], ",", 
       RowBox[{"369", "\[Rule]", "462"}], ",", 
       RowBox[{"369", "\[Rule]", "370"}], ",", 
       RowBox[{"186", "\[Rule]", "195"}], ",", 
       RowBox[{"186", "\[Rule]", "187"}], ",", 
       RowBox[{"94", "\[Rule]", "103"}], ",", 
       RowBox[{"94", "\[Rule]", "95"}], ",", 
       RowBox[{"416", "\[Rule]", "425"}], ",", 
       RowBox[{"416", "\[Rule]", "417"}], ",", 
       RowBox[{"324", "\[Rule]", "333"}], ",", 
       RowBox[{"324", "\[Rule]", "325"}], ",", 
       RowBox[{"140", "\[Rule]", "149"}], ",", 
       RowBox[{"140", "\[Rule]", "141"}], ",", 
       RowBox[{"48", "\[Rule]", "57"}], ",", 
       RowBox[{"48", "\[Rule]", "49"}], ",", 
       RowBox[{"370", "\[Rule]", "379"}], ",", 
       RowBox[{"370", "\[Rule]", "371"}], ",", 
       RowBox[{"278", "\[Rule]", "287"}], ",", 
       RowBox[{"278", "\[Rule]", "279"}], ",", 
       RowBox[{"554", "\[Rule]", "563"}], ",", 
       RowBox[{"554", "\[Rule]", "555"}], ",", 
       RowBox[{"508", "\[Rule]", "517"}], ",", 
       RowBox[{"508", "\[Rule]", "509"}], ",", 
       RowBox[{"2", "\[Rule]", "11"}], ",", 
       RowBox[{"2", "\[Rule]", "3"}], ",", 
       RowBox[{"232", "\[Rule]", "241"}], ",", 
       RowBox[{"232", "\[Rule]", "233"}], ",", 
       RowBox[{"462", "\[Rule]", "471"}], ",", 
       RowBox[{"462", "\[Rule]", "463"}]}], "}"}], ",", 
     RowBox[{"EdgeWeight", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "c", ",", "d", ",", "i", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "i", ",", "c", ",", "d", ",", "i", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "c", ",", "g", ",", "i", ",", "c", ",", "g", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "b", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "f", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "c", ",", "g", ",", "i", ",", "c", ",", 
        "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "b", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "d", ",", "e", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "e", ",", "f", ",", "g", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "b", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", 
        "c", ",", "e", ",", "g", ",", "i", ",", "c", ",", "d", ",", "i", ",", 
        "c", ",", "d", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "b", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "f", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "i", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "g", ",", "h", ",", "i", ",", 
        "g", ",", "h", ",", "i", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "g", ",", 
        "h", ",", "i", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "b", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "b", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "i", ",", "e", ",", 
        "f", ",", "i", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "i", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "i", ",", "a", ",", "i", ",", "a", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", 
        "i", ",", "a", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "a", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "b", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "a", ",", "c", ",", "d", ",", "h", ",", "i", ",", "g", ",", "i", ",", 
        "h", ",", "i", ",", "g", ",", "h", ",", "i", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "g", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "i", ",", "f", ",", "h", ",", "i", ",", "b", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "g", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", 
        "g", ",", "h", ",", "i", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", "e", ",", 
        "f", ",", "g", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "b", ",", "i", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "i", ",", "e", ",", "f", ",", "i", ",", 
        "e", ",", "i", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "f", ",", "i", ",", "e", ",", 
        "f", ",", "i", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "e", ",", "i", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "i", ",", "a", ",", "i", ",", 
        "a", ",", "i", ",", "a", ",", "i", ",", "a", ",", "i", ",", "a", ",", 
        "i", ",", "a", ",", "i", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "f", ",", "i", ",", "i", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", 
        "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "g", ",", "h", ",", "i", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "e", ",", "f", ",", "i", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "i", ",", "a", ",", "i", ",", "a", ",", 
        "i", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "d", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "i", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "d", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "b", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "c", ",", "i", ",", "a", ",", 
        "c", ",", "i", ",", "a", ",", "i", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "b", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u"}], "}"}]}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"init5", "=", 
   RowBox[{"{", "45", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bad5", "=", 
   RowBox[{"{", 
    RowBox[{
    "2", ",", "52", ",", "102", ",", "152", ",", "200", ",", "250", ",", 
     "300", ",", "350", ",", "398", ",", "448", ",", "498", ",", "548", ",", 
     "598", ",", "1", ",", "51", ",", "101", ",", "151", ",", "199", ",", 
     "249", ",", "299", ",", "349", ",", "397", ",", "447", ",", "497", ",", 
     "547", ",", "597"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lag5", "=", "13"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"graphical5", "=", "0"}], ";"}]}], "Input",
 CellChangeTimes->{{3.686025994957309*^9, 3.686026099831461*^9}, {
   3.6860261438122177`*^9, 3.686026176931148*^9}, 3.686026214223475*^9, {
   3.6860262647459717`*^9, 3.686026264982861*^9}, {3.686034622552107*^9, 
   3.686034628125643*^9}, {3.686046104270862*^9, 3.686046104850851*^9}, {
   3.686046154719606*^9, 3.686046158030952*^9}, 3.686047550621757*^9, {
   3.6930373931279917`*^9, 3.693037399556898*^9}, 3.693037472771635*^9, {
   3.693038158973789*^9, 3.6930381650361757`*^9}, {3.6930428123397503`*^9, 
   3.6930428231360483`*^9}, {3.693042919219357*^9, 3.6930429194085093`*^9}, {
   3.6930429516798887`*^9, 3.693042982121161*^9}, {3.693043077791449*^9, 
   3.69304309606213*^9}, 3.693043291196598*^9, 3.693043620502562*^9, {
   3.693044334417268*^9, 3.693044334984551*^9}, 3.693090945355526*^9, {
   3.69309202141042*^9, 3.6930920401067057`*^9}, {3.693093467244327*^9, 
   3.693093488693907*^9}, {3.693383056627502*^9, 3.693383056717105*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"main", "[", 
  RowBox[{"g5", ",", "init5", ",", "bad5", ",", "lag5", ",", "graphical5"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6930430476106987`*^9, 3.693043058627466*^9}, {
  3.6930920447959757`*^9, 3.693092052345579*^9}, {3.6930935011457863`*^9, 
  3.6930935089531193`*^9}}],

Cell[CellGroupData[{

Cell[BoxData["\<\"Under delay = 0 :\"\>"], "Print",
 CellChangeTimes->{3.6939935068248*^9, 3.694055986313821*^9, 
  3.69414785155029*^9, 3.71482106554044*^9}],

Cell[BoxData["\<\"(*hidden for the sake of space*)\"\>"], "Print",
 CellChangeTimes->{3.6939935068248*^9, 3.694055986313821*^9, 
  3.69414785155029*^9, 3.7148210655413218`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Under delay = \"\>", "\[InvisibleSpace]", "1", 
   "\[InvisibleSpace]", "\<\" :\"\>"}],
  SequenceForm["Under delay = ", 1, " :"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6939935068248*^9, 3.694055986313821*^9, 
  3.69414785155029*^9, 3.714821065542095*^9}],

Cell[BoxData["\<\"(*hidden for the sake of space*)\"\>"], "Print",
 CellChangeTimes->{3.6939935068248*^9, 3.694055986313821*^9, 
  3.69414785155029*^9, 3.714821065762835*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Under delay = \"\>", "\[InvisibleSpace]", "2", 
   "\[InvisibleSpace]", "\<\" :\"\>"}],
  SequenceForm["Under delay = ", 2, " :"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6939935068248*^9, 3.694055986313821*^9, 
  3.69414785155029*^9, 3.714821065764126*^9}],

Cell[BoxData["\<\"(*hidden for the sake of space*)\"\>"], "Print",
 CellChangeTimes->{3.6939935068248*^9, 3.694055986313821*^9, 
  3.69414785155029*^9, 3.714821066246976*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Under delay = \"\>", "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\" :\"\>"}],
  SequenceForm["Under delay = ", 3, " :"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6939935068248*^9, 3.694055986313821*^9, 
  3.69414785155029*^9, 3.7148210662985287`*^9}],

Cell[BoxData["\<\"(*hidden for the sake of space*)\"\>"], "Print",
 CellChangeTimes->{3.6939935068248*^9, 3.694055986313821*^9, 
  3.69414785155029*^9, 3.7148210667904577`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Not possible for sure-winning anymore under delay=\"\>", 
   "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\" with uncontrollable states \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "110", ",", "340", ",", "202", ",", "358", ",", "118", ",", "348", ",", 
     "210", ",", "302", ",", "308", ",", "588", ",", "450", ",", "578", ",", 
     "440", ",", "596", ",", "550", ",", "458", ",", "584", ",", "538", ",", 
     "446", ",", "492", ",", "400", ",", "546", ",", "408", ",", "120", ",", 
     "108", ",", "338", ",", "126", ",", "356", ",", "116", ",", "438", ",", 
     "346", ",", "392", ",", "24", ",", "254", ",", "30", ",", "260", ",", 
     "580", ",", "568", ",", "586", ",", "540", ",", "576", ",", "530", ",", 
     "494", ",", "484", ",", "594", ",", "502", ",", "582", ",", "536", ",", 
     "490", ",", "100", ",", "192", ",", "54", ",", "298", ",", "22", ",", 
     "252", ",", "160", ",", "390", ",", "482", ",", "500", ",", "98", ",", 
     "6", ",", "14", ",", "20", ",", "244", ",", "474", ",", "480", ",", "50",
      ",", "4", ",", "142", ",", "12", ",", "242", ",", "150", ",", "212", 
     ",", "82", ",", "312", ",", "218", ",", "90", ",", "320", ",", "166", 
     ",", "172", ",", "74", ",", "80", ",", "72", ",", "28", ",", "34", ",", 
     "26", ",", "402", ",", "266", ",", "274", ",", "264", ",", "396", ",", 
     "258", ",", "256", ",", "36", ",", "174", ",", "44", ",", "182", ",", 
     "184", ",", "304", ",", "310", ",", "46", ",", "164", ",", "45"}], "}"}],
    "\[InvisibleSpace]", "\<\".\\n\"\>"}],
  SequenceForm[
  "Not possible for sure-winning anymore under delay=", 3, 
   " with uncontrollable states ", CompressedData["
1:eJwV0D1IQmEUgOEviYiQBokQkUCJhiiJCHGUkBBxiIuTNInUErZENDVGQ0Q0
RGNDNEVjOIU4OkaTk0RTRENIU0TPHR7ec+4/N9c6iDoTIYQ9OjQsA93VI93R
Fy3oBvVECH3d1K42dImBuaoZns2fXJK33+ixZ+wTmU+0rYf6pE3OSNv/WGDS
XnFviRpZyqT4cu6dyPyjW5rmw9x2b48iy/Z5/eWWU/sbY1r2KWaZY8zQ8RHr
8fu5IMk317zG30/JNUNtUjbf6wM1tqmSJU+GK9fMkGKacxLxT2dRHlmJ/wVd
1hwvUjDfsco/s4Itgw==
   "], ".\n"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6939935068248*^9, 3.694055986313821*^9, 
  3.69414785155029*^9, 3.7148210667924423`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Computation time under increasing delays : \\n\"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "0.45600000000000307`", ",", "0.6799999999999926`", ",", 
     "1.1640000000000015`", ",", "1.7079999999999984`"}], "}"}]}],
  SequenceForm[
  "Computation time under increasing delays : \n", {0.45600000000000307`, 
   0.6799999999999926, 1.1640000000000015`, 1.7079999999999984`}],
  Editable->False]], "Print",
 CellChangeTimes->{3.6939935068248*^9, 3.694055986313821*^9, 
  3.69414785155029*^9, 3.714821066793213*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Escp. 5 x 6", "Subsection",
 CellChangeTimes->{{3.72559194076807*^9, 3.725591945943405*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"g6", " ", "=", " ", 
   RowBox[{"Graph", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"55", "\[Rule]", "224"}], ",", 
       RowBox[{"55", "\[Rule]", "224"}], ",", 
       RowBox[{"55", "\[Rule]", "56"}], ",", 
       RowBox[{"224", "\[Rule]", "211"}], ",", 
       RowBox[{"224", "\[Rule]", "221"}], ",", 
       RowBox[{"56", "\[Rule]", "43"}], ",", 
       RowBox[{"56", "\[Rule]", "53"}], ",", 
       RowBox[{"211", "\[Rule]", "100"}], ",", 
       RowBox[{"211", "\[Rule]", "436"}], ",", 
       RowBox[{"211", "\[Rule]", "44"}], ",", 
       RowBox[{"211", "\[Rule]", "44"}], ",", 
       RowBox[{"211", "\[Rule]", "380"}], ",", 
       RowBox[{"211", "\[Rule]", "380"}], ",", 
       RowBox[{"211", "\[Rule]", "212"}], ",", 
       RowBox[{"221", "\[Rule]", "110"}], ",", 
       RowBox[{"221", "\[Rule]", "446"}], ",", 
       RowBox[{"221", "\[Rule]", "54"}], ",", 
       RowBox[{"221", "\[Rule]", "54"}], ",", 
       RowBox[{"221", "\[Rule]", "390"}], ",", 
       RowBox[{"221", "\[Rule]", "390"}], ",", 
       RowBox[{"221", "\[Rule]", "222"}], ",", 
       RowBox[{"43", "\[Rule]", "212"}], ",", 
       RowBox[{"43", "\[Rule]", "212"}], ",", 
       RowBox[{"43", "\[Rule]", "44"}], ",", 
       RowBox[{"53", "\[Rule]", "222"}], ",", 
       RowBox[{"53", "\[Rule]", "222"}], ",", 
       RowBox[{"53", "\[Rule]", "54"}], ",", 
       RowBox[{"100", "\[Rule]", "89"}], ",", 
       RowBox[{"100", "\[Rule]", "111"}], ",", 
       RowBox[{"100", "\[Rule]", "97"}], ",", 
       RowBox[{"436", "\[Rule]", "425"}], ",", 
       RowBox[{"436", "\[Rule]", "447"}], ",", 
       RowBox[{"436", "\[Rule]", "433"}], ",", 
       RowBox[{"44", "\[Rule]", "33"}], ",", 
       RowBox[{"44", "\[Rule]", "55"}], ",", 
       RowBox[{"44", "\[Rule]", "41"}], ",", 
       RowBox[{"380", "\[Rule]", "369"}], ",", 
       RowBox[{"380", "\[Rule]", "391"}], ",", 
       RowBox[{"380", "\[Rule]", "377"}], ",", 
       RowBox[{"212", "\[Rule]", "201"}], ",", 
       RowBox[{"212", "\[Rule]", "223"}], ",", 
       RowBox[{"212", "\[Rule]", "209"}], ",", 
       RowBox[{"110", "\[Rule]", "97"}], ",", 
       RowBox[{"110", "\[Rule]", "111"}], ",", 
       RowBox[{"110", "\[Rule]", "107"}], ",", 
       RowBox[{"446", "\[Rule]", "433"}], ",", 
       RowBox[{"446", "\[Rule]", "447"}], ",", 
       RowBox[{"446", "\[Rule]", "443"}], ",", 
       RowBox[{"54", "\[Rule]", "41"}], ",", 
       RowBox[{"54", "\[Rule]", "55"}], ",", 
       RowBox[{"54", "\[Rule]", "51"}], ",", 
       RowBox[{"390", "\[Rule]", "377"}], ",", 
       RowBox[{"390", "\[Rule]", "391"}], ",", 
       RowBox[{"390", "\[Rule]", "387"}], ",", 
       RowBox[{"222", "\[Rule]", "209"}], ",", 
       RowBox[{"222", "\[Rule]", "223"}], ",", 
       RowBox[{"222", "\[Rule]", "219"}], ",", 
       RowBox[{"89", "\[Rule]", "258"}], ",", 
       RowBox[{"89", "\[Rule]", "202"}], ",", 
       RowBox[{"89", "\[Rule]", "90"}], ",", 
       RowBox[{"111", "\[Rule]", "280"}], ",", 
       RowBox[{"111", "\[Rule]", "224"}], ",", 
       RowBox[{"111", "\[Rule]", "112"}], ",", 
       RowBox[{"97", "\[Rule]", "266"}], ",", 
       RowBox[{"97", "\[Rule]", "210"}], ",", 
       RowBox[{"97", "\[Rule]", "98"}], ",", 
       RowBox[{"425", "\[Rule]", "258"}], ",", 
       RowBox[{"425", "\[Rule]", "594"}], ",", 
       RowBox[{"425", "\[Rule]", "594"}], ",", 
       RowBox[{"425", "\[Rule]", "202"}], ",", 
       RowBox[{"425", "\[Rule]", "538"}], ",", 
       RowBox[{"425", "\[Rule]", "538"}], ",", 
       RowBox[{"425", "\[Rule]", "426"}], ",", 
       RowBox[{"447", "\[Rule]", "280"}], ",", 
       RowBox[{"447", "\[Rule]", "616"}], ",", 
       RowBox[{"447", "\[Rule]", "616"}], ",", 
       RowBox[{"447", "\[Rule]", "224"}], ",", 
       RowBox[{"447", "\[Rule]", "560"}], ",", 
       RowBox[{"447", "\[Rule]", "560"}], ",", 
       RowBox[{"447", "\[Rule]", "448"}], ",", 
       RowBox[{"433", "\[Rule]", "266"}], ",", 
       RowBox[{"433", "\[Rule]", "602"}], ",", 
       RowBox[{"433", "\[Rule]", "602"}], ",", 
       RowBox[{"433", "\[Rule]", "210"}], ",", 
       RowBox[{"433", "\[Rule]", "546"}], ",", 
       RowBox[{"433", "\[Rule]", "546"}], ",", 
       RowBox[{"433", "\[Rule]", "434"}], ",", 
       RowBox[{"33", "\[Rule]", "202"}], ",", 
       RowBox[{"33", "\[Rule]", "202"}], ",", 
       RowBox[{"33", "\[Rule]", "34"}], ",", 
       RowBox[{"41", "\[Rule]", "210"}], ",", 
       RowBox[{"41", "\[Rule]", "210"}], ",", 
       RowBox[{"41", "\[Rule]", "42"}], ",", 
       RowBox[{"369", "\[Rule]", "202"}], ",", 
       RowBox[{"369", "\[Rule]", "202"}], ",", 
       RowBox[{"369", "\[Rule]", "538"}], ",", 
       RowBox[{"369", "\[Rule]", "370"}], ",", 
       RowBox[{"391", "\[Rule]", "224"}], ",", 
       RowBox[{"391", "\[Rule]", "224"}], ",", 
       RowBox[{"391", "\[Rule]", "560"}], ",", 
       RowBox[{"391", "\[Rule]", "392"}], ",", 
       RowBox[{"377", "\[Rule]", "210"}], ",", 
       RowBox[{"377", "\[Rule]", "210"}], ",", 
       RowBox[{"377", "\[Rule]", "546"}], ",", 
       RowBox[{"377", "\[Rule]", "378"}], ",", 
       RowBox[{"201", "\[Rule]", "90"}], ",", 
       RowBox[{"201", "\[Rule]", "426"}], ",", 
       RowBox[{"201", "\[Rule]", "34"}], ",", 
       RowBox[{"201", "\[Rule]", "34"}], ",", 
       RowBox[{"201", "\[Rule]", "370"}], ",", 
       RowBox[{"201", "\[Rule]", "370"}], ",", 
       RowBox[{"201", "\[Rule]", "202"}], ",", 
       RowBox[{"223", "\[Rule]", "112"}], ",", 
       RowBox[{"223", "\[Rule]", "448"}], ",", 
       RowBox[{"223", "\[Rule]", "56"}], ",", 
       RowBox[{"223", "\[Rule]", "56"}], ",", 
       RowBox[{"223", "\[Rule]", "392"}], ",", 
       RowBox[{"223", "\[Rule]", "392"}], ",", 
       RowBox[{"223", "\[Rule]", "224"}], ",", 
       RowBox[{"209", "\[Rule]", "98"}], ",", 
       RowBox[{"209", "\[Rule]", "434"}], ",", 
       RowBox[{"209", "\[Rule]", "42"}], ",", 
       RowBox[{"209", "\[Rule]", "42"}], ",", 
       RowBox[{"209", "\[Rule]", "378"}], ",", 
       RowBox[{"209", "\[Rule]", "378"}], ",", 
       RowBox[{"209", "\[Rule]", "210"}], ",", 
       RowBox[{"107", "\[Rule]", "276"}], ",", 
       RowBox[{"107", "\[Rule]", "220"}], ",", 
       RowBox[{"107", "\[Rule]", "108"}], ",", 
       RowBox[{"443", "\[Rule]", "276"}], ",", 
       RowBox[{"443", "\[Rule]", "612"}], ",", 
       RowBox[{"443", "\[Rule]", "612"}], ",", 
       RowBox[{"443", "\[Rule]", "220"}], ",", 
       RowBox[{"443", "\[Rule]", "556"}], ",", 
       RowBox[{"443", "\[Rule]", "556"}], ",", 
       RowBox[{"443", "\[Rule]", "444"}], ",", 
       RowBox[{"51", "\[Rule]", "220"}], ",", 
       RowBox[{"51", "\[Rule]", "220"}], ",", 
       RowBox[{"51", "\[Rule]", "52"}], ",", 
       RowBox[{"387", "\[Rule]", "220"}], ",", 
       RowBox[{"387", "\[Rule]", "220"}], ",", 
       RowBox[{"387", "\[Rule]", "556"}], ",", 
       RowBox[{"387", "\[Rule]", "388"}], ",", 
       RowBox[{"219", "\[Rule]", "108"}], ",", 
       RowBox[{"219", "\[Rule]", "444"}], ",", 
       RowBox[{"219", "\[Rule]", "52"}], ",", 
       RowBox[{"219", "\[Rule]", "52"}], ",", 
       RowBox[{"219", "\[Rule]", "388"}], ",", 
       RowBox[{"219", "\[Rule]", "388"}], ",", 
       RowBox[{"219", "\[Rule]", "220"}], ",", 
       RowBox[{"258", "\[Rule]", "245"}], ",", 
       RowBox[{"258", "\[Rule]", "267"}], ",", 
       RowBox[{"258", "\[Rule]", "255"}], ",", 
       RowBox[{"202", "\[Rule]", "189"}], ",", 
       RowBox[{"202", "\[Rule]", "211"}], ",", 
       RowBox[{"202", "\[Rule]", "199"}], ",", 
       RowBox[{"90", "\[Rule]", "77"}], ",", 
       RowBox[{"90", "\[Rule]", "99"}], ",", 
       RowBox[{"90", "\[Rule]", "87"}], ",", 
       RowBox[{"280", "\[Rule]", "267"}], ",", 
       RowBox[{"280", "\[Rule]", "277"}], ",", 
       RowBox[{"112", "\[Rule]", "99"}], ",", 
       RowBox[{"112", "\[Rule]", "109"}], ",", 
       RowBox[{"266", "\[Rule]", "255"}], ",", 
       RowBox[{"266", "\[Rule]", "277"}], ",", 
       RowBox[{"266", "\[Rule]", "267"}], ",", 
       RowBox[{"266", "\[Rule]", "263"}], ",", 
       RowBox[{"210", "\[Rule]", "199"}], ",", 
       RowBox[{"210", "\[Rule]", "221"}], ",", 
       RowBox[{"210", "\[Rule]", "211"}], ",", 
       RowBox[{"210", "\[Rule]", "207"}], ",", 
       RowBox[{"98", "\[Rule]", "87"}], ",", 
       RowBox[{"98", "\[Rule]", "109"}], ",", 
       RowBox[{"98", "\[Rule]", "99"}], ",", 
       RowBox[{"98", "\[Rule]", "95"}], ",", 
       RowBox[{"594", "\[Rule]", "581"}], ",", 
       RowBox[{"594", "\[Rule]", "603"}], ",", 
       RowBox[{"594", "\[Rule]", "591"}], ",", 
       RowBox[{"538", "\[Rule]", "525"}], ",", 
       RowBox[{"538", "\[Rule]", "547"}], ",", 
       RowBox[{"538", "\[Rule]", "535"}], ",", 
       RowBox[{"426", "\[Rule]", "413"}], ",", 
       RowBox[{"426", "\[Rule]", "435"}], ",", 
       RowBox[{"426", "\[Rule]", "423"}], ",", 
       RowBox[{"616", "\[Rule]", "603"}], ",", 
       RowBox[{"616", "\[Rule]", "613"}], ",", 
       RowBox[{"560", "\[Rule]", "547"}], ",", 
       RowBox[{"560", "\[Rule]", "557"}], ",", 
       RowBox[{"448", "\[Rule]", "435"}], ",", 
       RowBox[{"448", "\[Rule]", "445"}], ",", 
       RowBox[{"602", "\[Rule]", "591"}], ",", 
       RowBox[{"602", "\[Rule]", "613"}], ",", 
       RowBox[{"602", "\[Rule]", "603"}], ",", 
       RowBox[{"602", "\[Rule]", "599"}], ",", 
       RowBox[{"546", "\[Rule]", "535"}], ",", 
       RowBox[{"546", "\[Rule]", "557"}], ",", 
       RowBox[{"546", "\[Rule]", "547"}], ",", 
       RowBox[{"546", "\[Rule]", "543"}], ",", 
       RowBox[{"434", "\[Rule]", "423"}], ",", 
       RowBox[{"434", "\[Rule]", "445"}], ",", 
       RowBox[{"434", "\[Rule]", "435"}], ",", 
       RowBox[{"434", "\[Rule]", "431"}], ",", 
       RowBox[{"34", "\[Rule]", "21"}], ",", 
       RowBox[{"34", "\[Rule]", "43"}], ",", 
       RowBox[{"34", "\[Rule]", "31"}], ",", 
       RowBox[{"42", "\[Rule]", "31"}], ",", 
       RowBox[{"42", "\[Rule]", "53"}], ",", 
       RowBox[{"42", "\[Rule]", "43"}], ",", 
       RowBox[{"42", "\[Rule]", "39"}], ",", 
       RowBox[{"370", "\[Rule]", "357"}], ",", 
       RowBox[{"370", "\[Rule]", "379"}], ",", 
       RowBox[{"370", "\[Rule]", "367"}], ",", 
       RowBox[{"392", "\[Rule]", "379"}], ",", 
       RowBox[{"392", "\[Rule]", "389"}], ",", 
       RowBox[{"378", "\[Rule]", "367"}], ",", 
       RowBox[{"378", "\[Rule]", "389"}], ",", 
       RowBox[{"378", "\[Rule]", "379"}], ",", 
       RowBox[{"378", "\[Rule]", "375"}], ",", 
       RowBox[{"276", "\[Rule]", "263"}], ",", 
       RowBox[{"276", "\[Rule]", "277"}], ",", 
       RowBox[{"276", "\[Rule]", "273"}], ",", 
       RowBox[{"220", "\[Rule]", "207"}], ",", 
       RowBox[{"220", "\[Rule]", "221"}], ",", 
       RowBox[{"220", "\[Rule]", "217"}], ",", 
       RowBox[{"108", "\[Rule]", "95"}], ",", 
       RowBox[{"108", "\[Rule]", "109"}], ",", 
       RowBox[{"108", "\[Rule]", "105"}], ",", 
       RowBox[{"612", "\[Rule]", "599"}], ",", 
       RowBox[{"612", "\[Rule]", "613"}], ",", 
       RowBox[{"612", "\[Rule]", "609"}], ",", 
       RowBox[{"556", "\[Rule]", "543"}], ",", 
       RowBox[{"556", "\[Rule]", "557"}], ",", 
       RowBox[{"556", "\[Rule]", "553"}], ",", 
       RowBox[{"444", "\[Rule]", "431"}], ",", 
       RowBox[{"444", "\[Rule]", "445"}], ",", 
       RowBox[{"444", "\[Rule]", "441"}], ",", 
       RowBox[{"52", "\[Rule]", "39"}], ",", 
       RowBox[{"52", "\[Rule]", "53"}], ",", 
       RowBox[{"52", "\[Rule]", "49"}], ",", 
       RowBox[{"388", "\[Rule]", "375"}], ",", 
       RowBox[{"388", "\[Rule]", "389"}], ",", 
       RowBox[{"388", "\[Rule]", "385"}], ",", 
       RowBox[{"245", "\[Rule]", "134"}], ",", 
       RowBox[{"245", "\[Rule]", "134"}], ",", 
       RowBox[{"245", "\[Rule]", "470"}], ",", 
       RowBox[{"245", "\[Rule]", "470"}], ",", 
       RowBox[{"245", "\[Rule]", "78"}], ",", 
       RowBox[{"245", "\[Rule]", "414"}], ",", 
       RowBox[{"245", "\[Rule]", "246"}], ",", 
       RowBox[{"267", "\[Rule]", "156"}], ",", 
       RowBox[{"267", "\[Rule]", "156"}], ",", 
       RowBox[{"267", "\[Rule]", "492"}], ",", 
       RowBox[{"267", "\[Rule]", "492"}], ",", 
       RowBox[{"267", "\[Rule]", "100"}], ",", 
       RowBox[{"267", "\[Rule]", "436"}], ",", 
       RowBox[{"267", "\[Rule]", "268"}], ",", 
       RowBox[{"255", "\[Rule]", "144"}], ",", 
       RowBox[{"255", "\[Rule]", "144"}], ",", 
       RowBox[{"255", "\[Rule]", "480"}], ",", 
       RowBox[{"255", "\[Rule]", "480"}], ",", 
       RowBox[{"255", "\[Rule]", "88"}], ",", 
       RowBox[{"255", "\[Rule]", "424"}], ",", 
       RowBox[{"255", "\[Rule]", "256"}], ",", 
       RowBox[{"189", "\[Rule]", "78"}], ",", 
       RowBox[{"189", "\[Rule]", "414"}], ",", 
       RowBox[{"189", "\[Rule]", "22"}], ",", 
       RowBox[{"189", "\[Rule]", "22"}], ",", 
       RowBox[{"189", "\[Rule]", "358"}], ",", 
       RowBox[{"189", "\[Rule]", "358"}], ",", 
       RowBox[{"189", "\[Rule]", "190"}], ",", 
       RowBox[{"199", "\[Rule]", "88"}], ",", 
       RowBox[{"199", "\[Rule]", "424"}], ",", 
       RowBox[{"199", "\[Rule]", "32"}], ",", 
       RowBox[{"199", "\[Rule]", "32"}], ",", 
       RowBox[{"199", "\[Rule]", "368"}], ",", 
       RowBox[{"199", "\[Rule]", "368"}], ",", 
       RowBox[{"199", "\[Rule]", "200"}], ",", 
       RowBox[{"77", "\[Rule]", "246"}], ",", 
       RowBox[{"77", "\[Rule]", "190"}], ",", 
       RowBox[{"77", "\[Rule]", "78"}], ",", 
       RowBox[{"99", "\[Rule]", "268"}], ",", 
       RowBox[{"99", "\[Rule]", "212"}], ",", 
       RowBox[{"99", "\[Rule]", "100"}], ",", 
       RowBox[{"87", "\[Rule]", "256"}], ",", 
       RowBox[{"87", "\[Rule]", "200"}], ",", 
       RowBox[{"87", "\[Rule]", "88"}], ",", 
       RowBox[{"277", "\[Rule]", "166"}], ",", 
       RowBox[{"277", "\[Rule]", "166"}], ",", 
       RowBox[{"277", "\[Rule]", "502"}], ",", 
       RowBox[{"277", "\[Rule]", "502"}], ",", 
       RowBox[{"277", "\[Rule]", "110"}], ",", 
       RowBox[{"277", "\[Rule]", "446"}], ",", 
       RowBox[{"277", "\[Rule]", "278"}], ",", 
       RowBox[{"109", "\[Rule]", "278"}], ",", 
       RowBox[{"109", "\[Rule]", "222"}], ",", 
       RowBox[{"109", "\[Rule]", "110"}], ",", 
       RowBox[{"263", "\[Rule]", "152"}], ",", 
       RowBox[{"263", "\[Rule]", "152"}], ",", 
       RowBox[{"263", "\[Rule]", "488"}], ",", 
       RowBox[{"263", "\[Rule]", "488"}], ",", 
       RowBox[{"263", "\[Rule]", "96"}], ",", 
       RowBox[{"263", "\[Rule]", "432"}], ",", 
       RowBox[{"263", "\[Rule]", "264"}], ",", 
       RowBox[{"207", "\[Rule]", "96"}], ",", 
       RowBox[{"207", "\[Rule]", "432"}], ",", 
       RowBox[{"207", "\[Rule]", "40"}], ",", 
       RowBox[{"207", "\[Rule]", "40"}], ",", 
       RowBox[{"207", "\[Rule]", "376"}], ",", 
       RowBox[{"207", "\[Rule]", "376"}], ",", 
       RowBox[{"207", "\[Rule]", "208"}], ",", 
       RowBox[{"95", "\[Rule]", "264"}], ",", 
       RowBox[{"95", "\[Rule]", "208"}], ",", 
       RowBox[{"95", "\[Rule]", "96"}], ",", 
       RowBox[{"581", "\[Rule]", "470"}], ",", 
       RowBox[{"581", "\[Rule]", "470"}], ",", 
       RowBox[{"581", "\[Rule]", "806"}], ",", 
       RowBox[{"581", "\[Rule]", "806"}], ",", 
       RowBox[{"581", "\[Rule]", "414"}], ",", 
       RowBox[{"581", "\[Rule]", "414"}], ",", 
       RowBox[{"581", "\[Rule]", "750"}], ",", 
       RowBox[{"581", "\[Rule]", "750"}], ",", 
       RowBox[{"581", "\[Rule]", "582"}], ",", 
       RowBox[{"603", "\[Rule]", "492"}], ",", 
       RowBox[{"603", "\[Rule]", "492"}], ",", 
       RowBox[{"603", "\[Rule]", "828"}], ",", 
       RowBox[{"603", "\[Rule]", "828"}], ",", 
       RowBox[{"603", "\[Rule]", "436"}], ",", 
       RowBox[{"603", "\[Rule]", "436"}], ",", 
       RowBox[{"603", "\[Rule]", "772"}], ",", 
       RowBox[{"603", "\[Rule]", "772"}], ",", 
       RowBox[{"603", "\[Rule]", "604"}], ",", 
       RowBox[{"591", "\[Rule]", "480"}], ",", 
       RowBox[{"591", "\[Rule]", "480"}], ",", 
       RowBox[{"591", "\[Rule]", "816"}], ",", 
       RowBox[{"591", "\[Rule]", "816"}], ",", 
       RowBox[{"591", "\[Rule]", "424"}], ",", 
       RowBox[{"591", "\[Rule]", "424"}], ",", 
       RowBox[{"591", "\[Rule]", "760"}], ",", 
       RowBox[{"591", "\[Rule]", "760"}], ",", 
       RowBox[{"591", "\[Rule]", "592"}], ",", 
       RowBox[{"525", "\[Rule]", "414"}], ",", 
       RowBox[{"525", "\[Rule]", "414"}], ",", 
       RowBox[{"525", "\[Rule]", "750"}], ",", 
       RowBox[{"525", "\[Rule]", "750"}], ",", 
       RowBox[{"525", "\[Rule]", "358"}], ",", 
       RowBox[{"525", "\[Rule]", "694"}], ",", 
       RowBox[{"525", "\[Rule]", "526"}], ",", 
       RowBox[{"547", "\[Rule]", "436"}], ",", 
       RowBox[{"547", "\[Rule]", "436"}], ",", 
       RowBox[{"547", "\[Rule]", "772"}], ",", 
       RowBox[{"547", "\[Rule]", "772"}], ",", 
       RowBox[{"547", "\[Rule]", "380"}], ",", 
       RowBox[{"547", "\[Rule]", "716"}], ",", 
       RowBox[{"547", "\[Rule]", "548"}], ",", 
       RowBox[{"535", "\[Rule]", "424"}], ",", 
       RowBox[{"535", "\[Rule]", "424"}], ",", 
       RowBox[{"535", "\[Rule]", "760"}], ",", 
       RowBox[{"535", "\[Rule]", "760"}], ",", 
       RowBox[{"535", "\[Rule]", "368"}], ",", 
       RowBox[{"535", "\[Rule]", "704"}], ",", 
       RowBox[{"535", "\[Rule]", "536"}], ",", 
       RowBox[{"413", "\[Rule]", "246"}], ",", 
       RowBox[{"413", "\[Rule]", "582"}], ",", 
       RowBox[{"413", "\[Rule]", "582"}], ",", 
       RowBox[{"413", "\[Rule]", "190"}], ",", 
       RowBox[{"413", "\[Rule]", "526"}], ",", 
       RowBox[{"413", "\[Rule]", "526"}], ",", 
       RowBox[{"413", "\[Rule]", "414"}], ",", 
       RowBox[{"435", "\[Rule]", "268"}], ",", 
       RowBox[{"435", "\[Rule]", "604"}], ",", 
       RowBox[{"435", "\[Rule]", "604"}], ",", 
       RowBox[{"435", "\[Rule]", "212"}], ",", 
       RowBox[{"435", "\[Rule]", "548"}], ",", 
       RowBox[{"435", "\[Rule]", "548"}], ",", 
       RowBox[{"435", "\[Rule]", "436"}], ",", 
       RowBox[{"423", "\[Rule]", "256"}], ",", 
       RowBox[{"423", "\[Rule]", "592"}], ",", 
       RowBox[{"423", "\[Rule]", "592"}], ",", 
       RowBox[{"423", "\[Rule]", "200"}], ",", 
       RowBox[{"423", "\[Rule]", "536"}], ",", 
       RowBox[{"423", "\[Rule]", "536"}], ",", 
       RowBox[{"423", "\[Rule]", "424"}], ",", 
       RowBox[{"613", "\[Rule]", "502"}], ",", 
       RowBox[{"613", "\[Rule]", "502"}], ",", 
       RowBox[{"613", "\[Rule]", "838"}], ",", 
       RowBox[{"613", "\[Rule]", "838"}], ",", 
       RowBox[{"613", "\[Rule]", "446"}], ",", 
       RowBox[{"613", "\[Rule]", "446"}], ",", 
       RowBox[{"613", "\[Rule]", "782"}], ",", 
       RowBox[{"613", "\[Rule]", "782"}], ",", 
       RowBox[{"613", "\[Rule]", "614"}], ",", 
       RowBox[{"557", "\[Rule]", "446"}], ",", 
       RowBox[{"557", "\[Rule]", "446"}], ",", 
       RowBox[{"557", "\[Rule]", "782"}], ",", 
       RowBox[{"557", "\[Rule]", "782"}], ",", 
       RowBox[{"557", "\[Rule]", "390"}], ",", 
       RowBox[{"557", "\[Rule]", "726"}], ",", 
       RowBox[{"557", "\[Rule]", "558"}], ",", 
       RowBox[{"445", "\[Rule]", "278"}], ",", 
       RowBox[{"445", "\[Rule]", "614"}], ",", 
       RowBox[{"445", "\[Rule]", "614"}], ",", 
       RowBox[{"445", "\[Rule]", "222"}], ",", 
       RowBox[{"445", "\[Rule]", "558"}], ",", 
       RowBox[{"445", "\[Rule]", "558"}], ",", 
       RowBox[{"445", "\[Rule]", "446"}], ",", 
       RowBox[{"599", "\[Rule]", "488"}], ",", 
       RowBox[{"599", "\[Rule]", "488"}], ",", 
       RowBox[{"599", "\[Rule]", "824"}], ",", 
       RowBox[{"599", "\[Rule]", "824"}], ",", 
       RowBox[{"599", "\[Rule]", "432"}], ",", 
       RowBox[{"599", "\[Rule]", "432"}], ",", 
       RowBox[{"599", "\[Rule]", "768"}], ",", 
       RowBox[{"599", "\[Rule]", "768"}], ",", 
       RowBox[{"599", "\[Rule]", "600"}], ",", 
       RowBox[{"543", "\[Rule]", "432"}], ",", 
       RowBox[{"543", "\[Rule]", "432"}], ",", 
       RowBox[{"543", "\[Rule]", "768"}], ",", 
       RowBox[{"543", "\[Rule]", "768"}], ",", 
       RowBox[{"543", "\[Rule]", "376"}], ",", 
       RowBox[{"543", "\[Rule]", "712"}], ",", 
       RowBox[{"543", "\[Rule]", "544"}], ",", 
       RowBox[{"431", "\[Rule]", "264"}], ",", 
       RowBox[{"431", "\[Rule]", "600"}], ",", 
       RowBox[{"431", "\[Rule]", "600"}], ",", 
       RowBox[{"431", "\[Rule]", "208"}], ",", 
       RowBox[{"431", "\[Rule]", "544"}], ",", 
       RowBox[{"431", "\[Rule]", "544"}], ",", 
       RowBox[{"431", "\[Rule]", "432"}], ",", 
       RowBox[{"21", "\[Rule]", "190"}], ",", 
       RowBox[{"21", "\[Rule]", "190"}], ",", 
       RowBox[{"21", "\[Rule]", "22"}], ",", 
       RowBox[{"31", "\[Rule]", "200"}], ",", 
       RowBox[{"31", "\[Rule]", "200"}], ",", 
       RowBox[{"31", "\[Rule]", "32"}], ",", 
       RowBox[{"39", "\[Rule]", "208"}], ",", 
       RowBox[{"39", "\[Rule]", "208"}], ",", 
       RowBox[{"39", "\[Rule]", "40"}], ",", 
       RowBox[{"357", "\[Rule]", "190"}], ",", 
       RowBox[{"357", "\[Rule]", "190"}], ",", 
       RowBox[{"357", "\[Rule]", "526"}], ",", 
       RowBox[{"357", "\[Rule]", "358"}], ",", 
       RowBox[{"379", "\[Rule]", "212"}], ",", 
       RowBox[{"379", "\[Rule]", "212"}], ",", 
       RowBox[{"379", "\[Rule]", "548"}], ",", 
       RowBox[{"379", "\[Rule]", "380"}], ",", 
       RowBox[{"367", "\[Rule]", "200"}], ",", 
       RowBox[{"367", "\[Rule]", "200"}], ",", 
       RowBox[{"367", "\[Rule]", "536"}], ",", 
       RowBox[{"367", "\[Rule]", "368"}], ",", 
       RowBox[{"389", "\[Rule]", "222"}], ",", 
       RowBox[{"389", "\[Rule]", "222"}], ",", 
       RowBox[{"389", "\[Rule]", "558"}], ",", 
       RowBox[{"389", "\[Rule]", "390"}], ",", 
       RowBox[{"375", "\[Rule]", "208"}], ",", 
       RowBox[{"375", "\[Rule]", "208"}], ",", 
       RowBox[{"375", "\[Rule]", "544"}], ",", 
       RowBox[{"375", "\[Rule]", "376"}], ",", 
       RowBox[{"273", "\[Rule]", "162"}], ",", 
       RowBox[{"273", "\[Rule]", "162"}], ",", 
       RowBox[{"273", "\[Rule]", "498"}], ",", 
       RowBox[{"273", "\[Rule]", "498"}], ",", 
       RowBox[{"273", "\[Rule]", "106"}], ",", 
       RowBox[{"273", "\[Rule]", "442"}], ",", 
       RowBox[{"273", "\[Rule]", "274"}], ",", 
       RowBox[{"217", "\[Rule]", "106"}], ",", 
       RowBox[{"217", "\[Rule]", "442"}], ",", 
       RowBox[{"217", "\[Rule]", "50"}], ",", 
       RowBox[{"217", "\[Rule]", "50"}], ",", 
       RowBox[{"217", "\[Rule]", "386"}], ",", 
       RowBox[{"217", "\[Rule]", "386"}], ",", 
       RowBox[{"217", "\[Rule]", "218"}], ",", 
       RowBox[{"105", "\[Rule]", "274"}], ",", 
       RowBox[{"105", "\[Rule]", "218"}], ",", 
       RowBox[{"105", "\[Rule]", "106"}], ",", 
       RowBox[{"609", "\[Rule]", "498"}], ",", 
       RowBox[{"609", "\[Rule]", "498"}], ",", 
       RowBox[{"609", "\[Rule]", "834"}], ",", 
       RowBox[{"609", "\[Rule]", "834"}], ",", 
       RowBox[{"609", "\[Rule]", "442"}], ",", 
       RowBox[{"609", "\[Rule]", "442"}], ",", 
       RowBox[{"609", "\[Rule]", "778"}], ",", 
       RowBox[{"609", "\[Rule]", "778"}], ",", 
       RowBox[{"609", "\[Rule]", "610"}], ",", 
       RowBox[{"553", "\[Rule]", "442"}], ",", 
       RowBox[{"553", "\[Rule]", "442"}], ",", 
       RowBox[{"553", "\[Rule]", "778"}], ",", 
       RowBox[{"553", "\[Rule]", "778"}], ",", 
       RowBox[{"553", "\[Rule]", "386"}], ",", 
       RowBox[{"553", "\[Rule]", "722"}], ",", 
       RowBox[{"553", "\[Rule]", "554"}], ",", 
       RowBox[{"441", "\[Rule]", "274"}], ",", 
       RowBox[{"441", "\[Rule]", "610"}], ",", 
       RowBox[{"441", "\[Rule]", "610"}], ",", 
       RowBox[{"441", "\[Rule]", "218"}], ",", 
       RowBox[{"441", "\[Rule]", "554"}], ",", 
       RowBox[{"441", "\[Rule]", "554"}], ",", 
       RowBox[{"441", "\[Rule]", "442"}], ",", 
       RowBox[{"49", "\[Rule]", "218"}], ",", 
       RowBox[{"49", "\[Rule]", "218"}], ",", 
       RowBox[{"49", "\[Rule]", "50"}], ",", 
       RowBox[{"385", "\[Rule]", "218"}], ",", 
       RowBox[{"385", "\[Rule]", "218"}], ",", 
       RowBox[{"385", "\[Rule]", "554"}], ",", 
       RowBox[{"385", "\[Rule]", "386"}], ",", 
       RowBox[{"134", "\[Rule]", "123"}], ",", 
       RowBox[{"134", "\[Rule]", "145"}], ",", 
       RowBox[{"134", "\[Rule]", "131"}], ",", 
       RowBox[{"470", "\[Rule]", "459"}], ",", 
       RowBox[{"470", "\[Rule]", "481"}], ",", 
       RowBox[{"470", "\[Rule]", "467"}], ",", 
       RowBox[{"78", "\[Rule]", "67"}], ",", 
       RowBox[{"78", "\[Rule]", "89"}], ",", 
       RowBox[{"78", "\[Rule]", "75"}], ",", 
       RowBox[{"414", "\[Rule]", "403"}], ",", 
       RowBox[{"414", "\[Rule]", "425"}], ",", 
       RowBox[{"414", "\[Rule]", "411"}], ",", 
       RowBox[{"246", "\[Rule]", "235"}], ",", 
       RowBox[{"246", "\[Rule]", "257"}], ",", 
       RowBox[{"246", "\[Rule]", "243"}], ",", 
       RowBox[{"156", "\[Rule]", "145"}], ",", 
       RowBox[{"156", "\[Rule]", "167"}], ",", 
       RowBox[{"156", "\[Rule]", "153"}], ",", 
       RowBox[{"492", "\[Rule]", "481"}], ",", 
       RowBox[{"492", "\[Rule]", "503"}], ",", 
       RowBox[{"492", "\[Rule]", "489"}], ",", 
       RowBox[{"268", "\[Rule]", "257"}], ",", 
       RowBox[{"268", "\[Rule]", "279"}], ",", 
       RowBox[{"268", "\[Rule]", "265"}], ",", 
       RowBox[{"144", "\[Rule]", "131"}], ",", 
       RowBox[{"144", "\[Rule]", "153"}], ",", 
       RowBox[{"144", "\[Rule]", "145"}], ",", 
       RowBox[{"144", "\[Rule]", "141"}], ",", 
       RowBox[{"480", "\[Rule]", "467"}], ",", 
       RowBox[{"480", "\[Rule]", "489"}], ",", 
       RowBox[{"480", "\[Rule]", "481"}], ",", 
       RowBox[{"480", "\[Rule]", "477"}], ",", 
       RowBox[{"88", "\[Rule]", "75"}], ",", 
       RowBox[{"88", "\[Rule]", "97"}], ",", 
       RowBox[{"88", "\[Rule]", "89"}], ",", 
       RowBox[{"88", "\[Rule]", "85"}], ",", 
       RowBox[{"424", "\[Rule]", "411"}], ",", 
       RowBox[{"424", "\[Rule]", "433"}], ",", 
       RowBox[{"424", "\[Rule]", "425"}], ",", 
       RowBox[{"424", "\[Rule]", "421"}], ",", 
       RowBox[{"256", "\[Rule]", "243"}], ",", 
       RowBox[{"256", "\[Rule]", "265"}], ",", 
       RowBox[{"256", "\[Rule]", "257"}], ",", 
       RowBox[{"256", "\[Rule]", "253"}], ",", 
       RowBox[{"22", "\[Rule]", "11"}], ",", 
       RowBox[{"22", "\[Rule]", "33"}], ",", 
       RowBox[{"22", "\[Rule]", "19"}], ",", 
       RowBox[{"358", "\[Rule]", "347"}], ",", 
       RowBox[{"358", "\[Rule]", "369"}], ",", 
       RowBox[{"358", "\[Rule]", "355"}], ",", 
       RowBox[{"190", "\[Rule]", "179"}], ",", 
       RowBox[{"190", "\[Rule]", "201"}], ",", 
       RowBox[{"190", "\[Rule]", "187"}], ",", 
       RowBox[{"32", "\[Rule]", "19"}], ",", 
       RowBox[{"32", "\[Rule]", "41"}], ",", 
       RowBox[{"32", "\[Rule]", "33"}], ",", 
       RowBox[{"32", "\[Rule]", "29"}], ",", 
       RowBox[{"368", "\[Rule]", "355"}], ",", 
       RowBox[{"368", "\[Rule]", "377"}], ",", 
       RowBox[{"368", "\[Rule]", "369"}], ",", 
       RowBox[{"368", "\[Rule]", "365"}], ",", 
       RowBox[{"200", "\[Rule]", "187"}], ",", 
       RowBox[{"200", "\[Rule]", "209"}], ",", 
       RowBox[{"200", "\[Rule]", "201"}], ",", 
       RowBox[{"200", "\[Rule]", "197"}], ",", 
       RowBox[{"166", "\[Rule]", "153"}], ",", 
       RowBox[{"166", "\[Rule]", "167"}], ",", 
       RowBox[{"166", "\[Rule]", "163"}], ",", 
       RowBox[{"502", "\[Rule]", "489"}], ",", 
       RowBox[{"502", "\[Rule]", "503"}], ",", 
       RowBox[{"502", "\[Rule]", "499"}], ",", 
       RowBox[{"278", "\[Rule]", "265"}], ",", 
       RowBox[{"278", "\[Rule]", "279"}], ",", 
       RowBox[{"278", "\[Rule]", "275"}], ",", 
       RowBox[{"152", "\[Rule]", "141"}], ",", 
       RowBox[{"152", "\[Rule]", "163"}], ",", 
       RowBox[{"152", "\[Rule]", "153"}], ",", 
       RowBox[{"152", "\[Rule]", "149"}], ",", 
       RowBox[{"488", "\[Rule]", "477"}], ",", 
       RowBox[{"488", "\[Rule]", "499"}], ",", 
       RowBox[{"488", "\[Rule]", "489"}], ",", 
       RowBox[{"488", "\[Rule]", "485"}], ",", 
       RowBox[{"96", "\[Rule]", "85"}], ",", 
       RowBox[{"96", "\[Rule]", "107"}], ",", 
       RowBox[{"96", "\[Rule]", "97"}], ",", 
       RowBox[{"96", "\[Rule]", "93"}], ",", 
       RowBox[{"432", "\[Rule]", "421"}], ",", 
       RowBox[{"432", "\[Rule]", "443"}], ",", 
       RowBox[{"432", "\[Rule]", "433"}], ",", 
       RowBox[{"432", "\[Rule]", "429"}], ",", 
       RowBox[{"264", "\[Rule]", "253"}], ",", 
       RowBox[{"264", "\[Rule]", "275"}], ",", 
       RowBox[{"264", "\[Rule]", "265"}], ",", 
       RowBox[{"264", "\[Rule]", "261"}], ",", 
       RowBox[{"40", "\[Rule]", "29"}], ",", 
       RowBox[{"40", "\[Rule]", "51"}], ",", 
       RowBox[{"40", "\[Rule]", "41"}], ",", 
       RowBox[{"40", "\[Rule]", "37"}], ",", 
       RowBox[{"376", "\[Rule]", "365"}], ",", 
       RowBox[{"376", "\[Rule]", "387"}], ",", 
       RowBox[{"376", "\[Rule]", "377"}], ",", 
       RowBox[{"376", "\[Rule]", "373"}], ",", 
       RowBox[{"208", "\[Rule]", "197"}], ",", 
       RowBox[{"208", "\[Rule]", "219"}], ",", 
       RowBox[{"208", "\[Rule]", "209"}], ",", 
       RowBox[{"208", "\[Rule]", "205"}], ",", 
       RowBox[{"806", "\[Rule]", "795"}], ",", 
       RowBox[{"806", "\[Rule]", "817"}], ",", 
       RowBox[{"806", "\[Rule]", "803"}], ",", 
       RowBox[{"750", "\[Rule]", "739"}], ",", 
       RowBox[{"750", "\[Rule]", "761"}], ",", 
       RowBox[{"750", "\[Rule]", "747"}], ",", 
       RowBox[{"582", "\[Rule]", "571"}], ",", 
       RowBox[{"582", "\[Rule]", "593"}], ",", 
       RowBox[{"582", "\[Rule]", "579"}], ",", 
       RowBox[{"828", "\[Rule]", "817"}], ",", 
       RowBox[{"828", "\[Rule]", "839"}], ",", 
       RowBox[{"828", "\[Rule]", "825"}], ",", 
       RowBox[{"772", "\[Rule]", "761"}], ",", 
       RowBox[{"772", "\[Rule]", "783"}], ",", 
       RowBox[{"772", "\[Rule]", "769"}], ",", 
       RowBox[{"604", "\[Rule]", "593"}], ",", 
       RowBox[{"604", "\[Rule]", "615"}], ",", 
       RowBox[{"604", "\[Rule]", "601"}], ",", 
       RowBox[{"816", "\[Rule]", "803"}], ",", 
       RowBox[{"816", "\[Rule]", "825"}], ",", 
       RowBox[{"816", "\[Rule]", "817"}], ",", 
       RowBox[{"816", "\[Rule]", "813"}], ",", 
       RowBox[{"760", "\[Rule]", "747"}], ",", 
       RowBox[{"760", "\[Rule]", "769"}], ",", 
       RowBox[{"760", "\[Rule]", "761"}], ",", 
       RowBox[{"760", "\[Rule]", "757"}], ",", 
       RowBox[{"592", "\[Rule]", "579"}], ",", 
       RowBox[{"592", "\[Rule]", "601"}], ",", 
       RowBox[{"592", "\[Rule]", "593"}], ",", 
       RowBox[{"592", "\[Rule]", "589"}], ",", 
       RowBox[{"694", "\[Rule]", "683"}], ",", 
       RowBox[{"694", "\[Rule]", "705"}], ",", 
       RowBox[{"694", "\[Rule]", "691"}], ",", 
       RowBox[{"526", "\[Rule]", "515"}], ",", 
       RowBox[{"526", "\[Rule]", "537"}], ",", 
       RowBox[{"526", "\[Rule]", "523"}], ",", 
       RowBox[{"716", "\[Rule]", "705"}], ",", 
       RowBox[{"716", "\[Rule]", "727"}], ",", 
       RowBox[{"716", "\[Rule]", "713"}], ",", 
       RowBox[{"548", "\[Rule]", "537"}], ",", 
       RowBox[{"548", "\[Rule]", "559"}], ",", 
       RowBox[{"548", "\[Rule]", "545"}], ",", 
       RowBox[{"704", "\[Rule]", "691"}], ",", 
       RowBox[{"704", "\[Rule]", "713"}], ",", 
       RowBox[{"704", "\[Rule]", "705"}], ",", 
       RowBox[{"704", "\[Rule]", "701"}], ",", 
       RowBox[{"536", "\[Rule]", "523"}], ",", 
       RowBox[{"536", "\[Rule]", "545"}], ",", 
       RowBox[{"536", "\[Rule]", "537"}], ",", 
       RowBox[{"536", "\[Rule]", "533"}], ",", 
       RowBox[{"838", "\[Rule]", "825"}], ",", 
       RowBox[{"838", "\[Rule]", "839"}], ",", 
       RowBox[{"838", "\[Rule]", "835"}], ",", 
       RowBox[{"782", "\[Rule]", "769"}], ",", 
       RowBox[{"782", "\[Rule]", "783"}], ",", 
       RowBox[{"782", "\[Rule]", "779"}], ",", 
       RowBox[{"614", "\[Rule]", "601"}], ",", 
       RowBox[{"614", "\[Rule]", "615"}], ",", 
       RowBox[{"614", "\[Rule]", "611"}], ",", 
       RowBox[{"726", "\[Rule]", "713"}], ",", 
       RowBox[{"726", "\[Rule]", "727"}], ",", 
       RowBox[{"726", "\[Rule]", "723"}], ",", 
       RowBox[{"558", "\[Rule]", "545"}], ",", 
       RowBox[{"558", "\[Rule]", "559"}], ",", 
       RowBox[{"558", "\[Rule]", "555"}], ",", 
       RowBox[{"824", "\[Rule]", "813"}], ",", 
       RowBox[{"824", "\[Rule]", "835"}], ",", 
       RowBox[{"824", "\[Rule]", "825"}], ",", 
       RowBox[{"824", "\[Rule]", "821"}], ",", 
       RowBox[{"768", "\[Rule]", "757"}], ",", 
       RowBox[{"768", "\[Rule]", "779"}], ",", 
       RowBox[{"768", "\[Rule]", "769"}], ",", 
       RowBox[{"768", "\[Rule]", "765"}], ",", 
       RowBox[{"600", "\[Rule]", "589"}], ",", 
       RowBox[{"600", "\[Rule]", "611"}], ",", 
       RowBox[{"600", "\[Rule]", "601"}], ",", 
       RowBox[{"600", "\[Rule]", "597"}], ",", 
       RowBox[{"712", "\[Rule]", "701"}], ",", 
       RowBox[{"712", "\[Rule]", "723"}], ",", 
       RowBox[{"712", "\[Rule]", "713"}], ",", 
       RowBox[{"712", "\[Rule]", "709"}], ",", 
       RowBox[{"544", "\[Rule]", "533"}], ",", 
       RowBox[{"544", "\[Rule]", "555"}], ",", 
       RowBox[{"544", "\[Rule]", "545"}], ",", 
       RowBox[{"544", "\[Rule]", "541"}], ",", 
       RowBox[{"162", "\[Rule]", "149"}], ",", 
       RowBox[{"162", "\[Rule]", "163"}], ",", 
       RowBox[{"162", "\[Rule]", "159"}], ",", 
       RowBox[{"498", "\[Rule]", "485"}], ",", 
       RowBox[{"498", "\[Rule]", "499"}], ",", 
       RowBox[{"498", "\[Rule]", "495"}], ",", 
       RowBox[{"106", "\[Rule]", "93"}], ",", 
       RowBox[{"106", "\[Rule]", "107"}], ",", 
       RowBox[{"106", "\[Rule]", "103"}], ",", 
       RowBox[{"442", "\[Rule]", "429"}], ",", 
       RowBox[{"442", "\[Rule]", "443"}], ",", 
       RowBox[{"442", "\[Rule]", "439"}], ",", 
       RowBox[{"274", "\[Rule]", "261"}], ",", 
       RowBox[{"274", "\[Rule]", "275"}], ",", 
       RowBox[{"274", "\[Rule]", "271"}], ",", 
       RowBox[{"50", "\[Rule]", "37"}], ",", 
       RowBox[{"50", "\[Rule]", "51"}], ",", 
       RowBox[{"50", "\[Rule]", "47"}], ",", 
       RowBox[{"386", "\[Rule]", "373"}], ",", 
       RowBox[{"386", "\[Rule]", "387"}], ",", 
       RowBox[{"386", "\[Rule]", "383"}], ",", 
       RowBox[{"218", "\[Rule]", "205"}], ",", 
       RowBox[{"218", "\[Rule]", "219"}], ",", 
       RowBox[{"218", "\[Rule]", "215"}], ",", 
       RowBox[{"834", "\[Rule]", "821"}], ",", 
       RowBox[{"834", "\[Rule]", "835"}], ",", 
       RowBox[{"834", "\[Rule]", "831"}], ",", 
       RowBox[{"778", "\[Rule]", "765"}], ",", 
       RowBox[{"778", "\[Rule]", "779"}], ",", 
       RowBox[{"778", "\[Rule]", "775"}], ",", 
       RowBox[{"610", "\[Rule]", "597"}], ",", 
       RowBox[{"610", "\[Rule]", "611"}], ",", 
       RowBox[{"610", "\[Rule]", "607"}], ",", 
       RowBox[{"722", "\[Rule]", "709"}], ",", 
       RowBox[{"722", "\[Rule]", "723"}], ",", 
       RowBox[{"722", "\[Rule]", "719"}], ",", 
       RowBox[{"554", "\[Rule]", "541"}], ",", 
       RowBox[{"554", "\[Rule]", "555"}], ",", 
       RowBox[{"554", "\[Rule]", "551"}], ",", 
       RowBox[{"123", "\[Rule]", "292"}], ",", 
       RowBox[{"123", "\[Rule]", "236"}], ",", 
       RowBox[{"123", "\[Rule]", "236"}], ",", 
       RowBox[{"123", "\[Rule]", "124"}], ",", 
       RowBox[{"145", "\[Rule]", "314"}], ",", 
       RowBox[{"145", "\[Rule]", "314"}], ",", 
       RowBox[{"145", "\[Rule]", "258"}], ",", 
       RowBox[{"145", "\[Rule]", "258"}], ",", 
       RowBox[{"145", "\[Rule]", "146"}], ",", 
       RowBox[{"131", "\[Rule]", "300"}], ",", 
       RowBox[{"131", "\[Rule]", "244"}], ",", 
       RowBox[{"131", "\[Rule]", "132"}], ",", 
       RowBox[{"459", "\[Rule]", "292"}], ",", 
       RowBox[{"459", "\[Rule]", "292"}], ",", 
       RowBox[{"459", "\[Rule]", "628"}], ",", 
       RowBox[{"459", "\[Rule]", "628"}], ",", 
       RowBox[{"459", "\[Rule]", "236"}], ",", 
       RowBox[{"459", "\[Rule]", "236"}], ",", 
       RowBox[{"459", "\[Rule]", "572"}], ",", 
       RowBox[{"459", "\[Rule]", "572"}], ",", 
       RowBox[{"459", "\[Rule]", "460"}], ",", 
       RowBox[{"481", "\[Rule]", "314"}], ",", 
       RowBox[{"481", "\[Rule]", "650"}], ",", 
       RowBox[{"481", "\[Rule]", "258"}], ",", 
       RowBox[{"481", "\[Rule]", "258"}], ",", 
       RowBox[{"481", "\[Rule]", "594"}], ",", 
       RowBox[{"481", "\[Rule]", "594"}], ",", 
       RowBox[{"481", "\[Rule]", "482"}], ",", 
       RowBox[{"467", "\[Rule]", "300"}], ",", 
       RowBox[{"467", "\[Rule]", "636"}], ",", 
       RowBox[{"467", "\[Rule]", "636"}], ",", 
       RowBox[{"467", "\[Rule]", "244"}], ",", 
       RowBox[{"467", "\[Rule]", "580"}], ",", 
       RowBox[{"467", "\[Rule]", "580"}], ",", 
       RowBox[{"467", "\[Rule]", "468"}], ",", 
       RowBox[{"67", "\[Rule]", "236"}], ",", 
       RowBox[{"67", "\[Rule]", "180"}], ",", 
       RowBox[{"67", "\[Rule]", "68"}], ",", 
       RowBox[{"75", "\[Rule]", "244"}], ",", 
       RowBox[{"75", "\[Rule]", "188"}], ",", 
       RowBox[{"75", "\[Rule]", "76"}], ",", 
       RowBox[{"403", "\[Rule]", "236"}], ",", 
       RowBox[{"403", "\[Rule]", "572"}], ",", 
       RowBox[{"403", "\[Rule]", "572"}], ",", 
       RowBox[{"403", "\[Rule]", "180"}], ",", 
       RowBox[{"403", "\[Rule]", "516"}], ",", 
       RowBox[{"403", "\[Rule]", "516"}], ",", 
       RowBox[{"403", "\[Rule]", "404"}], ",", 
       RowBox[{"411", "\[Rule]", "244"}], ",", 
       RowBox[{"411", "\[Rule]", "580"}], ",", 
       RowBox[{"411", "\[Rule]", "580"}], ",", 
       RowBox[{"411", "\[Rule]", "188"}], ",", 
       RowBox[{"411", "\[Rule]", "524"}], ",", 
       RowBox[{"411", "\[Rule]", "524"}], ",", 
       RowBox[{"411", "\[Rule]", "412"}], ",", 
       RowBox[{"235", "\[Rule]", "124"}], ",", 
       RowBox[{"235", "\[Rule]", "124"}], ",", 
       RowBox[{"235", "\[Rule]", "460"}], ",", 
       RowBox[{"235", "\[Rule]", "460"}], ",", 
       RowBox[{"235", "\[Rule]", "68"}], ",", 
       RowBox[{"235", "\[Rule]", "404"}], ",", 
       RowBox[{"235", "\[Rule]", "236"}], ",", 
       RowBox[{"257", "\[Rule]", "146"}], ",", 
       RowBox[{"257", "\[Rule]", "146"}], ",", 
       RowBox[{"257", "\[Rule]", "482"}], ",", 
       RowBox[{"257", "\[Rule]", "482"}], ",", 
       RowBox[{"257", "\[Rule]", "90"}], ",", 
       RowBox[{"257", "\[Rule]", "426"}], ",", 
       RowBox[{"257", "\[Rule]", "258"}], ",", 
       RowBox[{"243", "\[Rule]", "132"}], ",", 
       RowBox[{"243", "\[Rule]", "468"}], ",", 
       RowBox[{"243", "\[Rule]", "76"}], ",", 
       RowBox[{"243", "\[Rule]", "412"}], ",", 
       RowBox[{"243", "\[Rule]", "244"}], ",", 
       RowBox[{"167", "\[Rule]", "336"}], ",", 
       RowBox[{"167", "\[Rule]", "336"}], ",", 
       RowBox[{"167", "\[Rule]", "280"}], ",", 
       RowBox[{"167", "\[Rule]", "280"}], ",", 
       RowBox[{"167", "\[Rule]", "168"}], ",", 
       RowBox[{"153", "\[Rule]", "322"}], ",", 
       RowBox[{"153", "\[Rule]", "322"}], ",", 
       RowBox[{"153", "\[Rule]", "266"}], ",", 
       RowBox[{"153", "\[Rule]", "266"}], ",", 
       RowBox[{"153", "\[Rule]", "154"}], ",", 
       RowBox[{"503", "\[Rule]", "336"}], ",", 
       RowBox[{"503", "\[Rule]", "336"}], ",", 
       RowBox[{"503", "\[Rule]", "672"}], ",", 
       RowBox[{"503", "\[Rule]", "672"}], ",", 
       RowBox[{"503", "\[Rule]", "280"}], ",", 
       RowBox[{"503", "\[Rule]", "280"}], ",", 
       RowBox[{"503", "\[Rule]", "616"}], ",", 
       RowBox[{"503", "\[Rule]", "616"}], ",", 
       RowBox[{"503", "\[Rule]", "504"}], ",", 
       RowBox[{"489", "\[Rule]", "322"}], ",", 
       RowBox[{"489", "\[Rule]", "322"}], ",", 
       RowBox[{"489", "\[Rule]", "658"}], ",", 
       RowBox[{"489", "\[Rule]", "266"}], ",", 
       RowBox[{"489", "\[Rule]", "266"}], ",", 
       RowBox[{"489", "\[Rule]", "602"}], ",", 
       RowBox[{"489", "\[Rule]", "490"}], ",", 
       RowBox[{"279", "\[Rule]", "168"}], ",", 
       RowBox[{"279", "\[Rule]", "168"}], ",", 
       RowBox[{"279", "\[Rule]", "504"}], ",", 
       RowBox[{"279", "\[Rule]", "504"}], ",", 
       RowBox[{"279", "\[Rule]", "112"}], ",", 
       RowBox[{"279", "\[Rule]", "448"}], ",", 
       RowBox[{"279", "\[Rule]", "280"}], ",", 
       RowBox[{"265", "\[Rule]", "154"}], ",", 
       RowBox[{"265", "\[Rule]", "154"}], ",", 
       RowBox[{"265", "\[Rule]", "490"}], ",", 
       RowBox[{"265", "\[Rule]", "490"}], ",", 
       RowBox[{"265", "\[Rule]", "98"}], ",", 
       RowBox[{"265", "\[Rule]", "434"}], ",", 
       RowBox[{"265", "\[Rule]", "266"}], ",", 
       RowBox[{"141", "\[Rule]", "310"}], ",", 
       RowBox[{"141", "\[Rule]", "310"}], ",", 
       RowBox[{"141", "\[Rule]", "254"}], ",", 
       RowBox[{"141", "\[Rule]", "254"}], ",", 
       RowBox[{"141", "\[Rule]", "142"}], ",", 
       RowBox[{"477", "\[Rule]", "310"}], ",", 
       RowBox[{"477", "\[Rule]", "310"}], ",", 
       RowBox[{"477", "\[Rule]", "646"}], ",", 
       RowBox[{"477", "\[Rule]", "646"}], ",", 
       RowBox[{"477", "\[Rule]", "254"}], ",", 
       RowBox[{"477", "\[Rule]", "590"}], ",", 
       RowBox[{"477", "\[Rule]", "478"}], ",", 
       RowBox[{"85", "\[Rule]", "254"}], ",", 
       RowBox[{"85", "\[Rule]", "198"}], ",", 
       RowBox[{"85", "\[Rule]", "86"}], ",", 
       RowBox[{"421", "\[Rule]", "590"}], ",", 
       RowBox[{"421", "\[Rule]", "198"}], ",", 
       RowBox[{"421", "\[Rule]", "534"}], ",", 
       RowBox[{"421", "\[Rule]", "534"}], ",", 
       RowBox[{"421", "\[Rule]", "422"}], ",", 
       RowBox[{"253", "\[Rule]", "142"}], ",", 
       RowBox[{"253", "\[Rule]", "142"}], ",", 
       RowBox[{"253", "\[Rule]", "478"}], ",", 
       RowBox[{"253", "\[Rule]", "86"}], ",", 
       RowBox[{"253", "\[Rule]", "254"}], ",", 
       RowBox[{"11", "\[Rule]", "180"}], ",", 
       RowBox[{"11", "\[Rule]", "180"}], ",", 
       RowBox[{"11", "\[Rule]", "12"}], ",", 
       RowBox[{"19", "\[Rule]", "188"}], ",", 
       RowBox[{"19", "\[Rule]", "188"}], ",", 
       RowBox[{"19", "\[Rule]", "20"}], ",", 
       RowBox[{"347", "\[Rule]", "180"}], ",", 
       RowBox[{"347", "\[Rule]", "180"}], ",", 
       RowBox[{"347", "\[Rule]", "516"}], ",", 
       RowBox[{"347", "\[Rule]", "348"}], ",", 
       RowBox[{"355", "\[Rule]", "188"}], ",", 
       RowBox[{"355", "\[Rule]", "188"}], ",", 
       RowBox[{"355", "\[Rule]", "524"}], ",", 
       RowBox[{"355", "\[Rule]", "356"}], ",", 
       RowBox[{"179", "\[Rule]", "68"}], ",", 
       RowBox[{"179", "\[Rule]", "404"}], ",", 
       RowBox[{"179", "\[Rule]", "12"}], ",", 
       RowBox[{"179", "\[Rule]", "12"}], ",", 
       RowBox[{"179", "\[Rule]", "348"}], ",", 
       RowBox[{"179", "\[Rule]", "348"}], ",", 
       RowBox[{"179", "\[Rule]", "180"}], ",", 
       RowBox[{"187", "\[Rule]", "76"}], ",", 
       RowBox[{"187", "\[Rule]", "412"}], ",", 
       RowBox[{"187", "\[Rule]", "20"}], ",", 
       RowBox[{"187", "\[Rule]", "20"}], ",", 
       RowBox[{"187", "\[Rule]", "356"}], ",", 
       RowBox[{"187", "\[Rule]", "356"}], ",", 
       RowBox[{"187", "\[Rule]", "188"}], ",", 
       RowBox[{"29", "\[Rule]", "198"}], ",", 
       RowBox[{"29", "\[Rule]", "198"}], ",", 
       RowBox[{"29", "\[Rule]", "30"}], ",", 
       RowBox[{"365", "\[Rule]", "198"}], ",", 
       RowBox[{"365", "\[Rule]", "198"}], ",", 
       RowBox[{"365", "\[Rule]", "534"}], ",", 
       RowBox[{"365", "\[Rule]", "366"}], ",", 
       RowBox[{"197", "\[Rule]", "86"}], ",", 
       RowBox[{"197", "\[Rule]", "422"}], ",", 
       RowBox[{"197", "\[Rule]", "30"}], ",", 
       RowBox[{"197", "\[Rule]", "30"}], ",", 
       RowBox[{"197", "\[Rule]", "366"}], ",", 
       RowBox[{"197", "\[Rule]", "366"}], ",", 
       RowBox[{"197", "\[Rule]", "198"}], ",", 
       RowBox[{"163", "\[Rule]", "332"}], ",", 
       RowBox[{"163", "\[Rule]", "332"}], ",", 
       RowBox[{"163", "\[Rule]", "276"}], ",", 
       RowBox[{"163", "\[Rule]", "276"}], ",", 
       RowBox[{"163", "\[Rule]", "164"}], ",", 
       RowBox[{"499", "\[Rule]", "332"}], ",", 
       RowBox[{"499", "\[Rule]", "332"}], ",", 
       RowBox[{"499", "\[Rule]", "668"}], ",", 
       RowBox[{"499", "\[Rule]", "668"}], ",", 
       RowBox[{"499", "\[Rule]", "276"}], ",", 
       RowBox[{"499", "\[Rule]", "276"}], ",", 
       RowBox[{"499", "\[Rule]", "612"}], ",", 
       RowBox[{"499", "\[Rule]", "612"}], ",", 
       RowBox[{"499", "\[Rule]", "500"}], ",", 
       RowBox[{"275", "\[Rule]", "164"}], ",", 
       RowBox[{"275", "\[Rule]", "164"}], ",", 
       RowBox[{"275", "\[Rule]", "500"}], ",", 
       RowBox[{"275", "\[Rule]", "500"}], ",", 
       RowBox[{"275", "\[Rule]", "108"}], ",", 
       RowBox[{"275", "\[Rule]", "444"}], ",", 
       RowBox[{"275", "\[Rule]", "276"}], ",", 
       RowBox[{"149", "\[Rule]", "318"}], ",", 
       RowBox[{"149", "\[Rule]", "318"}], ",", 
       RowBox[{"149", "\[Rule]", "262"}], ",", 
       RowBox[{"149", "\[Rule]", "262"}], ",", 
       RowBox[{"149", "\[Rule]", "150"}], ",", 
       RowBox[{"485", "\[Rule]", "318"}], ",", 
       RowBox[{"485", "\[Rule]", "318"}], ",", 
       RowBox[{"485", "\[Rule]", "654"}], ",", 
       RowBox[{"485", "\[Rule]", "654"}], ",", 
       RowBox[{"485", "\[Rule]", "262"}], ",", 
       RowBox[{"485", "\[Rule]", "262"}], ",", 
       RowBox[{"485", "\[Rule]", "598"}], ",", 
       RowBox[{"485", "\[Rule]", "598"}], ",", 
       RowBox[{"485", "\[Rule]", "486"}], ",", 
       RowBox[{"93", "\[Rule]", "262"}], ",", 
       RowBox[{"93", "\[Rule]", "206"}], ",", 
       RowBox[{"93", "\[Rule]", "94"}], ",", 
       RowBox[{"429", "\[Rule]", "262"}], ",", 
       RowBox[{"429", "\[Rule]", "598"}], ",", 
       RowBox[{"429", "\[Rule]", "206"}], ",", 
       RowBox[{"429", "\[Rule]", "542"}], ",", 
       RowBox[{"429", "\[Rule]", "430"}], ",", 
       RowBox[{"261", "\[Rule]", "150"}], ",", 
       RowBox[{"261", "\[Rule]", "150"}], ",", 
       RowBox[{"261", "\[Rule]", "486"}], ",", 
       RowBox[{"261", "\[Rule]", "486"}], ",", 
       RowBox[{"261", "\[Rule]", "94"}], ",", 
       RowBox[{"261", "\[Rule]", "430"}], ",", 
       RowBox[{"261", "\[Rule]", "262"}], ",", 
       RowBox[{"37", "\[Rule]", "206"}], ",", 
       RowBox[{"37", "\[Rule]", "206"}], ",", 
       RowBox[{"37", "\[Rule]", "38"}], ",", 
       RowBox[{"373", "\[Rule]", "206"}], ",", 
       RowBox[{"373", "\[Rule]", "206"}], ",", 
       RowBox[{"373", "\[Rule]", "542"}], ",", 
       RowBox[{"373", "\[Rule]", "374"}], ",", 
       RowBox[{"205", "\[Rule]", "94"}], ",", 
       RowBox[{"205", "\[Rule]", "430"}], ",", 
       RowBox[{"205", "\[Rule]", "38"}], ",", 
       RowBox[{"205", "\[Rule]", "38"}], ",", 
       RowBox[{"205", "\[Rule]", "374"}], ",", 
       RowBox[{"205", "\[Rule]", "374"}], ",", 
       RowBox[{"205", "\[Rule]", "206"}], ",", 
       RowBox[{"795", "\[Rule]", "628"}], ",", 
       RowBox[{"795", "\[Rule]", "628"}], ",", 
       RowBox[{"795", "\[Rule]", "572"}], ",", 
       RowBox[{"795", "\[Rule]", "572"}], ",", 
       RowBox[{"795", "\[Rule]", "796"}], ",", 
       RowBox[{"817", "\[Rule]", "650"}], ",", 
       RowBox[{"817", "\[Rule]", "650"}], ",", 
       RowBox[{"817", "\[Rule]", "594"}], ",", 
       RowBox[{"817", "\[Rule]", "594"}], ",", 
       RowBox[{"817", "\[Rule]", "818"}], ",", 
       RowBox[{"803", "\[Rule]", "636"}], ",", 
       RowBox[{"803", "\[Rule]", "636"}], ",", 
       RowBox[{"803", "\[Rule]", "580"}], ",", 
       RowBox[{"803", "\[Rule]", "580"}], ",", 
       RowBox[{"803", "\[Rule]", "804"}], ",", 
       RowBox[{"739", "\[Rule]", "572"}], ",", 
       RowBox[{"739", "\[Rule]", "572"}], ",", 
       RowBox[{"739", "\[Rule]", "516"}], ",", 
       RowBox[{"739", "\[Rule]", "516"}], ",", 
       RowBox[{"739", "\[Rule]", "740"}], ",", 
       RowBox[{"761", "\[Rule]", "594"}], ",", 
       RowBox[{"761", "\[Rule]", "594"}], ",", 
       RowBox[{"761", "\[Rule]", "538"}], ",", 
       RowBox[{"761", "\[Rule]", "538"}], ",", 
       RowBox[{"761", "\[Rule]", "762"}], ",", 
       RowBox[{"747", "\[Rule]", "580"}], ",", 
       RowBox[{"747", "\[Rule]", "580"}], ",", 
       RowBox[{"747", "\[Rule]", "524"}], ",", 
       RowBox[{"747", "\[Rule]", "524"}], ",", 
       RowBox[{"747", "\[Rule]", "748"}], ",", 
       RowBox[{"571", "\[Rule]", "460"}], ",", 
       RowBox[{"571", "\[Rule]", "460"}], ",", 
       RowBox[{"571", "\[Rule]", "796"}], ",", 
       RowBox[{"571", "\[Rule]", "796"}], ",", 
       RowBox[{"571", "\[Rule]", "404"}], ",", 
       RowBox[{"571", "\[Rule]", "404"}], ",", 
       RowBox[{"571", "\[Rule]", "740"}], ",", 
       RowBox[{"571", "\[Rule]", "740"}], ",", 
       RowBox[{"571", "\[Rule]", "572"}], ",", 
       RowBox[{"593", "\[Rule]", "482"}], ",", 
       RowBox[{"593", "\[Rule]", "482"}], ",", 
       RowBox[{"593", "\[Rule]", "818"}], ",", 
       RowBox[{"593", "\[Rule]", "818"}], ",", 
       RowBox[{"593", "\[Rule]", "426"}], ",", 
       RowBox[{"593", "\[Rule]", "426"}], ",", 
       RowBox[{"593", "\[Rule]", "762"}], ",", 
       RowBox[{"593", "\[Rule]", "762"}], ",", 
       RowBox[{"593", "\[Rule]", "594"}], ",", 
       RowBox[{"579", "\[Rule]", "468"}], ",", 
       RowBox[{"579", "\[Rule]", "468"}], ",", 
       RowBox[{"579", "\[Rule]", "804"}], ",", 
       RowBox[{"579", "\[Rule]", "804"}], ",", 
       RowBox[{"579", "\[Rule]", "412"}], ",", 
       RowBox[{"579", "\[Rule]", "412"}], ",", 
       RowBox[{"579", "\[Rule]", "748"}], ",", 
       RowBox[{"579", "\[Rule]", "748"}], ",", 
       RowBox[{"579", "\[Rule]", "580"}], ",", 
       RowBox[{"839", "\[Rule]", "672"}], ",", 
       RowBox[{"839", "\[Rule]", "616"}], ",", 
       RowBox[{"839", "\[Rule]", "616"}], ",", 
       RowBox[{"839", "\[Rule]", "840"}], ",", 
       RowBox[{"825", "\[Rule]", "658"}], ",", 
       RowBox[{"825", "\[Rule]", "602"}], ",", 
       RowBox[{"825", "\[Rule]", "826"}], ",", 
       RowBox[{"783", "\[Rule]", "616"}], ",", 
       RowBox[{"783", "\[Rule]", "616"}], ",", 
       RowBox[{"783", "\[Rule]", "560"}], ",", 
       RowBox[{"783", "\[Rule]", "560"}], ",", 
       RowBox[{"783", "\[Rule]", "784"}], ",", 
       RowBox[{"769", "\[Rule]", "602"}], ",", 
       RowBox[{"769", "\[Rule]", "602"}], ",", 
       RowBox[{"769", "\[Rule]", "546"}], ",", 
       RowBox[{"769", "\[Rule]", "546"}], ",", 
       RowBox[{"769", "\[Rule]", "770"}], ",", 
       RowBox[{"615", "\[Rule]", "504"}], ",", 
       RowBox[{"615", "\[Rule]", "504"}], ",", 
       RowBox[{"615", "\[Rule]", "840"}], ",", 
       RowBox[{"615", "\[Rule]", "840"}], ",", 
       RowBox[{"615", "\[Rule]", "448"}], ",", 
       RowBox[{"615", "\[Rule]", "448"}], ",", 
       RowBox[{"615", "\[Rule]", "784"}], ",", 
       RowBox[{"615", "\[Rule]", "784"}], ",", 
       RowBox[{"615", "\[Rule]", "616"}], ",", 
       RowBox[{"601", "\[Rule]", "490"}], ",", 
       RowBox[{"601", "\[Rule]", "826"}], ",", 
       RowBox[{"601", "\[Rule]", "434"}], ",", 
       RowBox[{"601", "\[Rule]", "434"}], ",", 
       RowBox[{"601", "\[Rule]", "770"}], ",", 
       RowBox[{"601", "\[Rule]", "770"}], ",", 
       RowBox[{"601", "\[Rule]", "602"}], ",", 
       RowBox[{"813", "\[Rule]", "646"}], ",", 
       RowBox[{"813", "\[Rule]", "646"}], ",", 
       RowBox[{"813", "\[Rule]", "590"}], ",", 
       RowBox[{"813", "\[Rule]", "590"}], ",", 
       RowBox[{"813", "\[Rule]", "814"}], ",", 
       RowBox[{"757", "\[Rule]", "590"}], ",", 
       RowBox[{"757", "\[Rule]", "590"}], ",", 
       RowBox[{"757", "\[Rule]", "534"}], ",", 
       RowBox[{"757", "\[Rule]", "534"}], ",", 
       RowBox[{"757", "\[Rule]", "758"}], ",", 
       RowBox[{"589", "\[Rule]", "478"}], ",", 
       RowBox[{"589", "\[Rule]", "814"}], ",", 
       RowBox[{"589", "\[Rule]", "814"}], ",", 
       RowBox[{"589", "\[Rule]", "422"}], ",", 
       RowBox[{"589", "\[Rule]", "758"}], ",", 
       RowBox[{"589", "\[Rule]", "758"}], ",", 
       RowBox[{"589", "\[Rule]", "590"}], ",", 
       RowBox[{"683", "\[Rule]", "516"}], ",", 
       RowBox[{"683", "\[Rule]", "684"}], ",", 
       RowBox[{"705", "\[Rule]", "538"}], ",", 
       RowBox[{"705", "\[Rule]", "706"}], ",", 
       RowBox[{"691", "\[Rule]", "524"}], ",", 
       RowBox[{"691", "\[Rule]", "692"}], ",", 
       RowBox[{"515", "\[Rule]", "404"}], ",", 
       RowBox[{"515", "\[Rule]", "404"}], ",", 
       RowBox[{"515", "\[Rule]", "740"}], ",", 
       RowBox[{"515", "\[Rule]", "740"}], ",", 
       RowBox[{"515", "\[Rule]", "348"}], ",", 
       RowBox[{"515", "\[Rule]", "684"}], ",", 
       RowBox[{"515", "\[Rule]", "516"}], ",", 
       RowBox[{"537", "\[Rule]", "426"}], ",", 
       RowBox[{"537", "\[Rule]", "426"}], ",", 
       RowBox[{"537", "\[Rule]", "762"}], ",", 
       RowBox[{"537", "\[Rule]", "762"}], ",", 
       RowBox[{"537", "\[Rule]", "370"}], ",", 
       RowBox[{"537", "\[Rule]", "706"}], ",", 
       RowBox[{"537", "\[Rule]", "538"}], ",", 
       RowBox[{"523", "\[Rule]", "412"}], ",", 
       RowBox[{"523", "\[Rule]", "412"}], ",", 
       RowBox[{"523", "\[Rule]", "748"}], ",", 
       RowBox[{"523", "\[Rule]", "748"}], ",", 
       RowBox[{"523", "\[Rule]", "356"}], ",", 
       RowBox[{"523", "\[Rule]", "692"}], ",", 
       RowBox[{"523", "\[Rule]", "524"}], ",", 
       RowBox[{"727", "\[Rule]", "560"}], ",", 
       RowBox[{"727", "\[Rule]", "728"}], ",", 
       RowBox[{"713", "\[Rule]", "546"}], ",", 
       RowBox[{"713", "\[Rule]", "714"}], ",", 
       RowBox[{"559", "\[Rule]", "448"}], ",", 
       RowBox[{"559", "\[Rule]", "448"}], ",", 
       RowBox[{"559", "\[Rule]", "784"}], ",", 
       RowBox[{"559", "\[Rule]", "784"}], ",", 
       RowBox[{"559", "\[Rule]", "392"}], ",", 
       RowBox[{"559", "\[Rule]", "728"}], ",", 
       RowBox[{"559", "\[Rule]", "560"}], ",", 
       RowBox[{"545", "\[Rule]", "434"}], ",", 
       RowBox[{"545", "\[Rule]", "434"}], ",", 
       RowBox[{"545", "\[Rule]", "770"}], ",", 
       RowBox[{"545", "\[Rule]", "770"}], ",", 
       RowBox[{"545", "\[Rule]", "378"}], ",", 
       RowBox[{"545", "\[Rule]", "714"}], ",", 
       RowBox[{"545", "\[Rule]", "546"}], ",", 
       RowBox[{"701", "\[Rule]", "534"}], ",", 
       RowBox[{"701", "\[Rule]", "702"}], ",", 
       RowBox[{"533", "\[Rule]", "422"}], ",", 
       RowBox[{"533", "\[Rule]", "422"}], ",", 
       RowBox[{"533", "\[Rule]", "758"}], ",", 
       RowBox[{"533", "\[Rule]", "758"}], ",", 
       RowBox[{"533", "\[Rule]", "366"}], ",", 
       RowBox[{"533", "\[Rule]", "702"}], ",", 
       RowBox[{"533", "\[Rule]", "534"}], ",", 
       RowBox[{"835", "\[Rule]", "668"}], ",", 
       RowBox[{"835", "\[Rule]", "668"}], ",", 
       RowBox[{"835", "\[Rule]", "612"}], ",", 
       RowBox[{"835", "\[Rule]", "836"}], ",", 
       RowBox[{"779", "\[Rule]", "612"}], ",", 
       RowBox[{"779", "\[Rule]", "556"}], ",", 
       RowBox[{"779", "\[Rule]", "556"}], ",", 
       RowBox[{"779", "\[Rule]", "780"}], ",", 
       RowBox[{"611", "\[Rule]", "500"}], ",", 
       RowBox[{"611", "\[Rule]", "500"}], ",", 
       RowBox[{"611", "\[Rule]", "836"}], ",", 
       RowBox[{"611", "\[Rule]", "444"}], ",", 
       RowBox[{"611", "\[Rule]", "444"}], ",", 
       RowBox[{"611", "\[Rule]", "780"}], ",", 
       RowBox[{"611", "\[Rule]", "612"}], ",", 
       RowBox[{"723", "\[Rule]", "556"}], ",", 
       RowBox[{"723", "\[Rule]", "724"}], ",", 
       RowBox[{"555", "\[Rule]", "444"}], ",", 
       RowBox[{"555", "\[Rule]", "444"}], ",", 
       RowBox[{"555", "\[Rule]", "780"}], ",", 
       RowBox[{"555", "\[Rule]", "780"}], ",", 
       RowBox[{"555", "\[Rule]", "388"}], ",", 
       RowBox[{"555", "\[Rule]", "724"}], ",", 
       RowBox[{"555", "\[Rule]", "556"}], ",", 
       RowBox[{"821", "\[Rule]", "654"}], ",", 
       RowBox[{"821", "\[Rule]", "654"}], ",", 
       RowBox[{"821", "\[Rule]", "598"}], ",", 
       RowBox[{"821", "\[Rule]", "598"}], ",", 
       RowBox[{"821", "\[Rule]", "822"}], ",", 
       RowBox[{"765", "\[Rule]", "598"}], ",", 
       RowBox[{"765", "\[Rule]", "542"}], ",", 
       RowBox[{"765", "\[Rule]", "766"}], ",", 
       RowBox[{"597", "\[Rule]", "486"}], ",", 
       RowBox[{"597", "\[Rule]", "486"}], ",", 
       RowBox[{"597", "\[Rule]", "822"}], ",", 
       RowBox[{"597", "\[Rule]", "822"}], ",", 
       RowBox[{"597", "\[Rule]", "430"}], ",", 
       RowBox[{"597", "\[Rule]", "766"}], ",", 
       RowBox[{"597", "\[Rule]", "598"}], ",", 
       RowBox[{"709", "\[Rule]", "542"}], ",", 
       RowBox[{"709", "\[Rule]", "710"}], ",", 
       RowBox[{"541", "\[Rule]", "430"}], ",", 
       RowBox[{"541", "\[Rule]", "766"}], ",", 
       RowBox[{"541", "\[Rule]", "374"}], ",", 
       RowBox[{"541", "\[Rule]", "710"}], ",", 
       RowBox[{"541", "\[Rule]", "542"}], ",", 
       RowBox[{"159", "\[Rule]", "328"}], ",", 
       RowBox[{"159", "\[Rule]", "328"}], ",", 
       RowBox[{"159", "\[Rule]", "272"}], ",", 
       RowBox[{"159", "\[Rule]", "272"}], ",", 
       RowBox[{"159", "\[Rule]", "160"}], ",", 
       RowBox[{"495", "\[Rule]", "328"}], ",", 
       RowBox[{"495", "\[Rule]", "328"}], ",", 
       RowBox[{"495", "\[Rule]", "664"}], ",", 
       RowBox[{"495", "\[Rule]", "664"}], ",", 
       RowBox[{"495", "\[Rule]", "272"}], ",", 
       RowBox[{"495", "\[Rule]", "272"}], ",", 
       RowBox[{"495", "\[Rule]", "608"}], ",", 
       RowBox[{"495", "\[Rule]", "608"}], ",", 
       RowBox[{"495", "\[Rule]", "496"}], ",", 
       RowBox[{"103", "\[Rule]", "272"}], ",", 
       RowBox[{"103", "\[Rule]", "216"}], ",", 
       RowBox[{"103", "\[Rule]", "104"}], ",", 
       RowBox[{"439", "\[Rule]", "272"}], ",", 
       RowBox[{"439", "\[Rule]", "608"}], ",", 
       RowBox[{"439", "\[Rule]", "608"}], ",", 
       RowBox[{"439", "\[Rule]", "216"}], ",", 
       RowBox[{"439", "\[Rule]", "552"}], ",", 
       RowBox[{"439", "\[Rule]", "552"}], ",", 
       RowBox[{"439", "\[Rule]", "440"}], ",", 
       RowBox[{"271", "\[Rule]", "160"}], ",", 
       RowBox[{"271", "\[Rule]", "160"}], ",", 
       RowBox[{"271", "\[Rule]", "496"}], ",", 
       RowBox[{"271", "\[Rule]", "496"}], ",", 
       RowBox[{"271", "\[Rule]", "104"}], ",", 
       RowBox[{"271", "\[Rule]", "440"}], ",", 
       RowBox[{"271", "\[Rule]", "272"}], ",", 
       RowBox[{"47", "\[Rule]", "216"}], ",", 
       RowBox[{"47", "\[Rule]", "216"}], ",", 
       RowBox[{"47", "\[Rule]", "48"}], ",", 
       RowBox[{"383", "\[Rule]", "216"}], ",", 
       RowBox[{"383", "\[Rule]", "216"}], ",", 
       RowBox[{"383", "\[Rule]", "552"}], ",", 
       RowBox[{"383", "\[Rule]", "384"}], ",", 
       RowBox[{"215", "\[Rule]", "104"}], ",", 
       RowBox[{"215", "\[Rule]", "440"}], ",", 
       RowBox[{"215", "\[Rule]", "48"}], ",", 
       RowBox[{"215", "\[Rule]", "48"}], ",", 
       RowBox[{"215", "\[Rule]", "384"}], ",", 
       RowBox[{"215", "\[Rule]", "384"}], ",", 
       RowBox[{"215", "\[Rule]", "216"}], ",", 
       RowBox[{"831", "\[Rule]", "664"}], ",", 
       RowBox[{"831", "\[Rule]", "664"}], ",", 
       RowBox[{"831", "\[Rule]", "608"}], ",", 
       RowBox[{"831", "\[Rule]", "608"}], ",", 
       RowBox[{"831", "\[Rule]", "832"}], ",", 
       RowBox[{"775", "\[Rule]", "608"}], ",", 
       RowBox[{"775", "\[Rule]", "608"}], ",", 
       RowBox[{"775", "\[Rule]", "552"}], ",", 
       RowBox[{"775", "\[Rule]", "776"}], ",", 
       RowBox[{"607", "\[Rule]", "496"}], ",", 
       RowBox[{"607", "\[Rule]", "496"}], ",", 
       RowBox[{"607", "\[Rule]", "832"}], ",", 
       RowBox[{"607", "\[Rule]", "832"}], ",", 
       RowBox[{"607", "\[Rule]", "440"}], ",", 
       RowBox[{"607", "\[Rule]", "440"}], ",", 
       RowBox[{"607", "\[Rule]", "776"}], ",", 
       RowBox[{"607", "\[Rule]", "776"}], ",", 
       RowBox[{"607", "\[Rule]", "608"}], ",", 
       RowBox[{"719", "\[Rule]", "720"}], ",", 
       RowBox[{"551", "\[Rule]", "440"}], ",", 
       RowBox[{"551", "\[Rule]", "440"}], ",", 
       RowBox[{"551", "\[Rule]", "776"}], ",", 
       RowBox[{"551", "\[Rule]", "384"}], ",", 
       RowBox[{"551", "\[Rule]", "552"}], ",", 
       RowBox[{"292", "\[Rule]", "301"}], ",", 
       RowBox[{"292", "\[Rule]", "289"}], ",", 
       RowBox[{"236", "\[Rule]", "245"}], ",", 
       RowBox[{"236", "\[Rule]", "233"}], ",", 
       RowBox[{"124", "\[Rule]", "133"}], ",", 
       RowBox[{"124", "\[Rule]", "121"}], ",", 
       RowBox[{"314", "\[Rule]", "301"}], ",", 
       RowBox[{"314", "\[Rule]", "323"}], ",", 
       RowBox[{"314", "\[Rule]", "311"}], ",", 
       RowBox[{"146", "\[Rule]", "133"}], ",", 
       RowBox[{"146", "\[Rule]", "155"}], ",", 
       RowBox[{"146", "\[Rule]", "143"}], ",", 
       RowBox[{"300", "\[Rule]", "289"}], ",", 
       RowBox[{"300", "\[Rule]", "311"}], ",", 
       RowBox[{"300", "\[Rule]", "301"}], ",", 
       RowBox[{"300", "\[Rule]", "297"}], ",", 
       RowBox[{"244", "\[Rule]", "233"}], ",", 
       RowBox[{"244", "\[Rule]", "255"}], ",", 
       RowBox[{"244", "\[Rule]", "245"}], ",", 
       RowBox[{"244", "\[Rule]", "241"}], ",", 
       RowBox[{"132", "\[Rule]", "121"}], ",", 
       RowBox[{"132", "\[Rule]", "143"}], ",", 
       RowBox[{"132", "\[Rule]", "133"}], ",", 
       RowBox[{"132", "\[Rule]", "129"}], ",", 
       RowBox[{"628", "\[Rule]", "637"}], ",", 
       RowBox[{"628", "\[Rule]", "625"}], ",", 
       RowBox[{"572", "\[Rule]", "581"}], ",", 
       RowBox[{"572", "\[Rule]", "569"}], ",", 
       RowBox[{"460", "\[Rule]", "469"}], ",", 
       RowBox[{"460", "\[Rule]", "457"}], ",", 
       RowBox[{"650", "\[Rule]", "637"}], ",", 
       RowBox[{"650", "\[Rule]", "659"}], ",", 
       RowBox[{"650", "\[Rule]", "647"}], ",", 
       RowBox[{"482", "\[Rule]", "469"}], ",", 
       RowBox[{"482", "\[Rule]", "491"}], ",", 
       RowBox[{"482", "\[Rule]", "479"}], ",", 
       RowBox[{"636", "\[Rule]", "625"}], ",", 
       RowBox[{"636", "\[Rule]", "647"}], ",", 
       RowBox[{"636", "\[Rule]", "637"}], ",", 
       RowBox[{"636", "\[Rule]", "633"}], ",", 
       RowBox[{"580", "\[Rule]", "569"}], ",", 
       RowBox[{"580", "\[Rule]", "591"}], ",", 
       RowBox[{"580", "\[Rule]", "581"}], ",", 
       RowBox[{"580", "\[Rule]", "577"}], ",", 
       RowBox[{"468", "\[Rule]", "457"}], ",", 
       RowBox[{"468", "\[Rule]", "479"}], ",", 
       RowBox[{"468", "\[Rule]", "469"}], ",", 
       RowBox[{"468", "\[Rule]", "465"}], ",", 
       RowBox[{"180", "\[Rule]", "189"}], ",", 
       RowBox[{"180", "\[Rule]", "177"}], ",", 
       RowBox[{"68", "\[Rule]", "77"}], ",", 
       RowBox[{"68", "\[Rule]", "65"}], ",", 
       RowBox[{"188", "\[Rule]", "177"}], ",", 
       RowBox[{"188", "\[Rule]", "199"}], ",", 
       RowBox[{"188", "\[Rule]", "189"}], ",", 
       RowBox[{"188", "\[Rule]", "185"}], ",", 
       RowBox[{"76", "\[Rule]", "65"}], ",", 
       RowBox[{"76", "\[Rule]", "87"}], ",", 
       RowBox[{"76", "\[Rule]", "77"}], ",", 
       RowBox[{"76", "\[Rule]", "73"}], ",", 
       RowBox[{"516", "\[Rule]", "525"}], ",", 
       RowBox[{"516", "\[Rule]", "513"}], ",", 
       RowBox[{"404", "\[Rule]", "413"}], ",", 
       RowBox[{"404", "\[Rule]", "401"}], ",", 
       RowBox[{"524", "\[Rule]", "513"}], ",", 
       RowBox[{"524", "\[Rule]", "535"}], ",", 
       RowBox[{"524", "\[Rule]", "525"}], ",", 
       RowBox[{"524", "\[Rule]", "521"}], ",", 
       RowBox[{"412", "\[Rule]", "401"}], ",", 
       RowBox[{"412", "\[Rule]", "423"}], ",", 
       RowBox[{"412", "\[Rule]", "413"}], ",", 
       RowBox[{"412", "\[Rule]", "409"}], ",", 
       RowBox[{"336", "\[Rule]", "323"}], ",", 
       RowBox[{"336", "\[Rule]", "333"}], ",", 
       RowBox[{"168", "\[Rule]", "155"}], ",", 
       RowBox[{"168", "\[Rule]", "165"}], ",", 
       RowBox[{"322", "\[Rule]", "311"}], ",", 
       RowBox[{"322", "\[Rule]", "333"}], ",", 
       RowBox[{"322", "\[Rule]", "323"}], ",", 
       RowBox[{"322", "\[Rule]", "319"}], ",", 
       RowBox[{"154", "\[Rule]", "143"}], ",", 
       RowBox[{"154", "\[Rule]", "165"}], ",", 
       RowBox[{"154", "\[Rule]", "155"}], ",", 
       RowBox[{"154", "\[Rule]", "151"}], ",", 
       RowBox[{"672", "\[Rule]", "659"}], ",", 
       RowBox[{"672", "\[Rule]", "669"}], ",", 
       RowBox[{"504", "\[Rule]", "491"}], ",", 
       RowBox[{"504", "\[Rule]", "501"}], ",", 
       RowBox[{"658", "\[Rule]", "647"}], ",", 
       RowBox[{"658", "\[Rule]", "669"}], ",", 
       RowBox[{"658", "\[Rule]", "659"}], ",", 
       RowBox[{"658", "\[Rule]", "655"}], ",", 
       RowBox[{"490", "\[Rule]", "479"}], ",", 
       RowBox[{"490", "\[Rule]", "501"}], ",", 
       RowBox[{"490", "\[Rule]", "491"}], ",", 
       RowBox[{"490", "\[Rule]", "487"}], ",", 
       RowBox[{"310", "\[Rule]", "297"}], ",", 
       RowBox[{"310", "\[Rule]", "319"}], ",", 
       RowBox[{"310", "\[Rule]", "311"}], ",", 
       RowBox[{"310", "\[Rule]", "307"}], ",", 
       RowBox[{"254", "\[Rule]", "241"}], ",", 
       RowBox[{"254", "\[Rule]", "263"}], ",", 
       RowBox[{"254", "\[Rule]", "255"}], ",", 
       RowBox[{"254", "\[Rule]", "251"}], ",", 
       RowBox[{"142", "\[Rule]", "129"}], ",", 
       RowBox[{"142", "\[Rule]", "151"}], ",", 
       RowBox[{"142", "\[Rule]", "143"}], ",", 
       RowBox[{"142", "\[Rule]", "139"}], ",", 
       RowBox[{"646", "\[Rule]", "633"}], ",", 
       RowBox[{"646", "\[Rule]", "655"}], ",", 
       RowBox[{"646", "\[Rule]", "647"}], ",", 
       RowBox[{"646", "\[Rule]", "643"}], ",", 
       RowBox[{"590", "\[Rule]", "577"}], ",", 
       RowBox[{"590", "\[Rule]", "599"}], ",", 
       RowBox[{"590", "\[Rule]", "591"}], ",", 
       RowBox[{"590", "\[Rule]", "587"}], ",", 
       RowBox[{"478", "\[Rule]", "465"}], ",", 
       RowBox[{"478", "\[Rule]", "487"}], ",", 
       RowBox[{"478", "\[Rule]", "479"}], ",", 
       RowBox[{"478", "\[Rule]", "475"}], ",", 
       RowBox[{"198", "\[Rule]", "185"}], ",", 
       RowBox[{"198", "\[Rule]", "207"}], ",", 
       RowBox[{"198", "\[Rule]", "199"}], ",", 
       RowBox[{"198", "\[Rule]", "195"}], ",", 
       RowBox[{"86", "\[Rule]", "73"}], ",", 
       RowBox[{"86", "\[Rule]", "95"}], ",", 
       RowBox[{"86", "\[Rule]", "87"}], ",", 
       RowBox[{"86", "\[Rule]", "83"}], ",", 
       RowBox[{"534", "\[Rule]", "521"}], ",", 
       RowBox[{"534", "\[Rule]", "543"}], ",", 
       RowBox[{"534", "\[Rule]", "535"}], ",", 
       RowBox[{"534", "\[Rule]", "531"}], ",", 
       RowBox[{"422", "\[Rule]", "409"}], ",", 
       RowBox[{"422", "\[Rule]", "431"}], ",", 
       RowBox[{"422", "\[Rule]", "423"}], ",", 
       RowBox[{"422", "\[Rule]", "419"}], ",", 
       RowBox[{"12", "\[Rule]", "21"}], ",", 
       RowBox[{"12", "\[Rule]", "9"}], ",", 
       RowBox[{"20", "\[Rule]", "9"}], ",", 
       RowBox[{"20", "\[Rule]", "31"}], ",", 
       RowBox[{"20", "\[Rule]", "21"}], ",", 
       RowBox[{"20", "\[Rule]", "17"}], ",", 
       RowBox[{"348", "\[Rule]", "357"}], ",", 
       RowBox[{"348", "\[Rule]", "345"}], ",", 
       RowBox[{"356", "\[Rule]", "345"}], ",", 
       RowBox[{"356", "\[Rule]", "367"}], ",", 
       RowBox[{"356", "\[Rule]", "357"}], ",", 
       RowBox[{"356", "\[Rule]", "353"}], ",", 
       RowBox[{"30", "\[Rule]", "17"}], ",", 
       RowBox[{"30", "\[Rule]", "39"}], ",", 
       RowBox[{"30", "\[Rule]", "31"}], ",", 
       RowBox[{"30", "\[Rule]", "27"}], ",", 
       RowBox[{"366", "\[Rule]", "353"}], ",", 
       RowBox[{"366", "\[Rule]", "375"}], ",", 
       RowBox[{"366", "\[Rule]", "367"}], ",", 
       RowBox[{"366", "\[Rule]", "363"}], ",", 
       RowBox[{"332", "\[Rule]", "319"}], ",", 
       RowBox[{"332", "\[Rule]", "333"}], ",", 
       RowBox[{"332", "\[Rule]", "329"}], ",", 
       RowBox[{"164", "\[Rule]", "151"}], ",", 
       RowBox[{"164", "\[Rule]", "165"}], ",", 
       RowBox[{"164", "\[Rule]", "161"}], ",", 
       RowBox[{"668", "\[Rule]", "655"}], ",", 
       RowBox[{"668", "\[Rule]", "669"}], ",", 
       RowBox[{"668", "\[Rule]", "665"}], ",", 
       RowBox[{"500", "\[Rule]", "487"}], ",", 
       RowBox[{"500", "\[Rule]", "501"}], ",", 
       RowBox[{"500", "\[Rule]", "497"}], ",", 
       RowBox[{"318", "\[Rule]", "307"}], ",", 
       RowBox[{"318", "\[Rule]", "329"}], ",", 
       RowBox[{"318", "\[Rule]", "319"}], ",", 
       RowBox[{"318", "\[Rule]", "315"}], ",", 
       RowBox[{"262", "\[Rule]", "251"}], ",", 
       RowBox[{"262", "\[Rule]", "273"}], ",", 
       RowBox[{"262", "\[Rule]", "263"}], ",", 
       RowBox[{"262", "\[Rule]", "259"}], ",", 
       RowBox[{"150", "\[Rule]", "139"}], ",", 
       RowBox[{"150", "\[Rule]", "161"}], ",", 
       RowBox[{"150", "\[Rule]", "151"}], ",", 
       RowBox[{"150", "\[Rule]", "147"}], ",", 
       RowBox[{"654", "\[Rule]", "643"}], ",", 
       RowBox[{"654", "\[Rule]", "665"}], ",", 
       RowBox[{"654", "\[Rule]", "655"}], ",", 
       RowBox[{"654", "\[Rule]", "651"}], ",", 
       RowBox[{"598", "\[Rule]", "587"}], ",", 
       RowBox[{"598", "\[Rule]", "609"}], ",", 
       RowBox[{"598", "\[Rule]", "599"}], ",", 
       RowBox[{"598", "\[Rule]", "595"}], ",", 
       RowBox[{"486", "\[Rule]", "475"}], ",", 
       RowBox[{"486", "\[Rule]", "497"}], ",", 
       RowBox[{"486", "\[Rule]", "487"}], ",", 
       RowBox[{"486", "\[Rule]", "483"}], ",", 
       RowBox[{"206", "\[Rule]", "195"}], ",", 
       RowBox[{"206", "\[Rule]", "217"}], ",", 
       RowBox[{"206", "\[Rule]", "207"}], ",", 
       RowBox[{"206", "\[Rule]", "203"}], ",", 
       RowBox[{"94", "\[Rule]", "83"}], ",", 
       RowBox[{"94", "\[Rule]", "105"}], ",", 
       RowBox[{"94", "\[Rule]", "95"}], ",", 
       RowBox[{"94", "\[Rule]", "91"}], ",", 
       RowBox[{"542", "\[Rule]", "531"}], ",", 
       RowBox[{"542", "\[Rule]", "553"}], ",", 
       RowBox[{"542", "\[Rule]", "543"}], ",", 
       RowBox[{"542", "\[Rule]", "539"}], ",", 
       RowBox[{"430", "\[Rule]", "419"}], ",", 
       RowBox[{"430", "\[Rule]", "441"}], ",", 
       RowBox[{"430", "\[Rule]", "431"}], ",", 
       RowBox[{"430", "\[Rule]", "427"}], ",", 
       RowBox[{"38", "\[Rule]", "27"}], ",", 
       RowBox[{"38", "\[Rule]", "49"}], ",", 
       RowBox[{"38", "\[Rule]", "39"}], ",", 
       RowBox[{"38", "\[Rule]", "35"}], ",", 
       RowBox[{"374", "\[Rule]", "363"}], ",", 
       RowBox[{"374", "\[Rule]", "385"}], ",", 
       RowBox[{"374", "\[Rule]", "375"}], ",", 
       RowBox[{"374", "\[Rule]", "371"}], ",", 
       RowBox[{"796", "\[Rule]", "805"}], ",", 
       RowBox[{"796", "\[Rule]", "793"}], ",", 
       RowBox[{"818", "\[Rule]", "805"}], ",", 
       RowBox[{"818", "\[Rule]", "827"}], ",", 
       RowBox[{"818", "\[Rule]", "815"}], ",", 
       RowBox[{"804", "\[Rule]", "793"}], ",", 
       RowBox[{"804", "\[Rule]", "815"}], ",", 
       RowBox[{"804", "\[Rule]", "805"}], ",", 
       RowBox[{"804", "\[Rule]", "801"}], ",", 
       RowBox[{"740", "\[Rule]", "749"}], ",", 
       RowBox[{"740", "\[Rule]", "737"}], ",", 
       RowBox[{"762", "\[Rule]", "749"}], ",", 
       RowBox[{"762", "\[Rule]", "771"}], ",", 
       RowBox[{"762", "\[Rule]", "759"}], ",", 
       RowBox[{"748", "\[Rule]", "737"}], ",", 
       RowBox[{"748", "\[Rule]", "759"}], ",", 
       RowBox[{"748", "\[Rule]", "749"}], ",", 
       RowBox[{"748", "\[Rule]", "745"}], ",", 
       RowBox[{"840", "\[Rule]", "827"}], ",", 
       RowBox[{"840", "\[Rule]", "837"}], ",", 
       RowBox[{"826", "\[Rule]", "815"}], ",", 
       RowBox[{"826", "\[Rule]", "837"}], ",", 
       RowBox[{"826", "\[Rule]", "827"}], ",", 
       RowBox[{"826", "\[Rule]", "823"}], ",", 
       RowBox[{"784", "\[Rule]", "771"}], ",", 
       RowBox[{"784", "\[Rule]", "781"}], ",", 
       RowBox[{"770", "\[Rule]", "759"}], ",", 
       RowBox[{"770", "\[Rule]", "781"}], ",", 
       RowBox[{"770", "\[Rule]", "771"}], ",", 
       RowBox[{"770", "\[Rule]", "767"}], ",", 
       RowBox[{"814", "\[Rule]", "801"}], ",", 
       RowBox[{"814", "\[Rule]", "823"}], ",", 
       RowBox[{"814", "\[Rule]", "815"}], ",", 
       RowBox[{"814", "\[Rule]", "811"}], ",", 
       RowBox[{"758", "\[Rule]", "745"}], ",", 
       RowBox[{"758", "\[Rule]", "767"}], ",", 
       RowBox[{"758", "\[Rule]", "759"}], ",", 
       RowBox[{"758", "\[Rule]", "755"}], ",", 
       RowBox[{"684", "\[Rule]", "693"}], ",", 
       RowBox[{"684", "\[Rule]", "681"}], ",", 
       RowBox[{"706", "\[Rule]", "693"}], ",", 
       RowBox[{"706", "\[Rule]", "715"}], ",", 
       RowBox[{"706", "\[Rule]", "703"}], ",", 
       RowBox[{"692", "\[Rule]", "681"}], ",", 
       RowBox[{"692", "\[Rule]", "703"}], ",", 
       RowBox[{"692", "\[Rule]", "693"}], ",", 
       RowBox[{"692", "\[Rule]", "689"}], ",", 
       RowBox[{"728", "\[Rule]", "715"}], ",", 
       RowBox[{"728", "\[Rule]", "725"}], ",", 
       RowBox[{"714", "\[Rule]", "703"}], ",", 
       RowBox[{"714", "\[Rule]", "725"}], ",", 
       RowBox[{"714", "\[Rule]", "715"}], ",", 
       RowBox[{"714", "\[Rule]", "711"}], ",", 
       RowBox[{"702", "\[Rule]", "689"}], ",", 
       RowBox[{"702", "\[Rule]", "711"}], ",", 
       RowBox[{"702", "\[Rule]", "703"}], ",", 
       RowBox[{"702", "\[Rule]", "699"}], ",", 
       RowBox[{"836", "\[Rule]", "823"}], ",", 
       RowBox[{"836", "\[Rule]", "837"}], ",", 
       RowBox[{"836", "\[Rule]", "833"}], ",", 
       RowBox[{"780", "\[Rule]", "767"}], ",", 
       RowBox[{"780", "\[Rule]", "781"}], ",", 
       RowBox[{"780", "\[Rule]", "777"}], ",", 
       RowBox[{"724", "\[Rule]", "711"}], ",", 
       RowBox[{"724", "\[Rule]", "725"}], ",", 
       RowBox[{"724", "\[Rule]", "721"}], ",", 
       RowBox[{"822", "\[Rule]", "811"}], ",", 
       RowBox[{"822", "\[Rule]", "833"}], ",", 
       RowBox[{"822", "\[Rule]", "823"}], ",", 
       RowBox[{"822", "\[Rule]", "819"}], ",", 
       RowBox[{"766", "\[Rule]", "755"}], ",", 
       RowBox[{"766", "\[Rule]", "777"}], ",", 
       RowBox[{"766", "\[Rule]", "767"}], ",", 
       RowBox[{"766", "\[Rule]", "763"}], ",", 
       RowBox[{"710", "\[Rule]", "699"}], ",", 
       RowBox[{"710", "\[Rule]", "721"}], ",", 
       RowBox[{"710", "\[Rule]", "711"}], ",", 
       RowBox[{"710", "\[Rule]", "707"}], ",", 
       RowBox[{"328", "\[Rule]", "315"}], ",", 
       RowBox[{"328", "\[Rule]", "329"}], ",", 
       RowBox[{"328", "\[Rule]", "325"}], ",", 
       RowBox[{"272", "\[Rule]", "259"}], ",", 
       RowBox[{"272", "\[Rule]", "273"}], ",", 
       RowBox[{"272", "\[Rule]", "269"}], ",", 
       RowBox[{"160", "\[Rule]", "147"}], ",", 
       RowBox[{"160", "\[Rule]", "161"}], ",", 
       RowBox[{"160", "\[Rule]", "157"}], ",", 
       RowBox[{"664", "\[Rule]", "651"}], ",", 
       RowBox[{"664", "\[Rule]", "665"}], ",", 
       RowBox[{"664", "\[Rule]", "661"}], ",", 
       RowBox[{"608", "\[Rule]", "595"}], ",", 
       RowBox[{"608", "\[Rule]", "609"}], ",", 
       RowBox[{"608", "\[Rule]", "605"}], ",", 
       RowBox[{"496", "\[Rule]", "483"}], ",", 
       RowBox[{"496", "\[Rule]", "497"}], ",", 
       RowBox[{"496", "\[Rule]", "493"}], ",", 
       RowBox[{"216", "\[Rule]", "203"}], ",", 
       RowBox[{"216", "\[Rule]", "217"}], ",", 
       RowBox[{"216", "\[Rule]", "213"}], ",", 
       RowBox[{"104", "\[Rule]", "91"}], ",", 
       RowBox[{"104", "\[Rule]", "105"}], ",", 
       RowBox[{"104", "\[Rule]", "101"}], ",", 
       RowBox[{"552", "\[Rule]", "539"}], ",", 
       RowBox[{"552", "\[Rule]", "553"}], ",", 
       RowBox[{"552", "\[Rule]", "549"}], ",", 
       RowBox[{"440", "\[Rule]", "427"}], ",", 
       RowBox[{"440", "\[Rule]", "441"}], ",", 
       RowBox[{"440", "\[Rule]", "437"}], ",", 
       RowBox[{"48", "\[Rule]", "35"}], ",", 
       RowBox[{"48", "\[Rule]", "49"}], ",", 
       RowBox[{"48", "\[Rule]", "45"}], ",", 
       RowBox[{"384", "\[Rule]", "371"}], ",", 
       RowBox[{"384", "\[Rule]", "385"}], ",", 
       RowBox[{"384", "\[Rule]", "381"}], ",", 
       RowBox[{"832", "\[Rule]", "819"}], ",", 
       RowBox[{"832", "\[Rule]", "833"}], ",", 
       RowBox[{"832", "\[Rule]", "829"}], ",", 
       RowBox[{"776", "\[Rule]", "763"}], ",", 
       RowBox[{"776", "\[Rule]", "777"}], ",", 
       RowBox[{"776", "\[Rule]", "773"}], ",", 
       RowBox[{"720", "\[Rule]", "707"}], ",", 
       RowBox[{"720", "\[Rule]", "721"}], ",", 
       RowBox[{"720", "\[Rule]", "717"}], ",", 
       RowBox[{"301", "\[Rule]", "134"}], ",", 
       RowBox[{"301", "\[Rule]", "134"}], ",", 
       RowBox[{"301", "\[Rule]", "470"}], ",", 
       RowBox[{"301", "\[Rule]", "470"}], ",", 
       RowBox[{"301", "\[Rule]", "302"}], ",", 
       RowBox[{"289", "\[Rule]", "122"}], ",", 
       RowBox[{"289", "\[Rule]", "122"}], ",", 
       RowBox[{"289", "\[Rule]", "458"}], ",", 
       RowBox[{"289", "\[Rule]", "458"}], ",", 
       RowBox[{"289", "\[Rule]", "290"}], ",", 
       RowBox[{"233", "\[Rule]", "122"}], ",", 
       RowBox[{"233", "\[Rule]", "122"}], ",", 
       RowBox[{"233", "\[Rule]", "458"}], ",", 
       RowBox[{"233", "\[Rule]", "458"}], ",", 
       RowBox[{"233", "\[Rule]", "66"}], ",", 
       RowBox[{"233", "\[Rule]", "402"}], ",", 
       RowBox[{"233", "\[Rule]", "234"}], ",", 
       RowBox[{"133", "\[Rule]", "302"}], ",", 
       RowBox[{"133", "\[Rule]", "302"}], ",", 
       RowBox[{"133", "\[Rule]", "246"}], ",", 
       RowBox[{"133", "\[Rule]", "246"}], ",", 
       RowBox[{"133", "\[Rule]", "134"}], ",", 
       RowBox[{"121", "\[Rule]", "290"}], ",", 
       RowBox[{"121", "\[Rule]", "290"}], ",", 
       RowBox[{"121", "\[Rule]", "234"}], ",", 
       RowBox[{"121", "\[Rule]", "234"}], ",", 
       RowBox[{"121", "\[Rule]", "122"}], ",", 
       RowBox[{"323", "\[Rule]", "156"}], ",", 
       RowBox[{"323", "\[Rule]", "156"}], ",", 
       RowBox[{"323", "\[Rule]", "492"}], ",", 
       RowBox[{"323", "\[Rule]", "492"}], ",", 
       RowBox[{"323", "\[Rule]", "324"}], ",", 
       RowBox[{"311", "\[Rule]", "144"}], ",", 
       RowBox[{"311", "\[Rule]", "144"}], ",", 
       RowBox[{"311", "\[Rule]", "480"}], ",", 
       RowBox[{"311", "\[Rule]", "480"}], ",", 
       RowBox[{"311", "\[Rule]", "312"}], ",", 
       RowBox[{"155", "\[Rule]", "324"}], ",", 
       RowBox[{"155", "\[Rule]", "324"}], ",", 
       RowBox[{"155", "\[Rule]", "268"}], ",", 
       RowBox[{"155", "\[Rule]", "268"}], ",", 
       RowBox[{"155", "\[Rule]", "156"}], ",", 
       RowBox[{"143", "\[Rule]", "312"}], ",", 
       RowBox[{"143", "\[Rule]", "312"}], ",", 
       RowBox[{"143", "\[Rule]", "256"}], ",", 
       RowBox[{"143", "\[Rule]", "256"}], ",", 
       RowBox[{"143", "\[Rule]", "144"}], ",", 
       RowBox[{"297", "\[Rule]", "130"}], ",", 
       RowBox[{"297", "\[Rule]", "130"}], ",", 
       RowBox[{"297", "\[Rule]", "466"}], ",", 
       RowBox[{"297", "\[Rule]", "466"}], ",", 
       RowBox[{"297", "\[Rule]", "298"}], ",", 
       RowBox[{"241", "\[Rule]", "130"}], ",", 
       RowBox[{"241", "\[Rule]", "130"}], ",", 
       RowBox[{"241", "\[Rule]", "466"}], ",", 
       RowBox[{"241", "\[Rule]", "466"}], ",", 
       RowBox[{"241", "\[Rule]", "74"}], ",", 
       RowBox[{"241", "\[Rule]", "410"}], ",", 
       RowBox[{"241", "\[Rule]", "242"}], ",", 
       RowBox[{"129", "\[Rule]", "298"}], ",", 
       RowBox[{"129", "\[Rule]", "298"}], ",", 
       RowBox[{"129", "\[Rule]", "242"}], ",", 
       RowBox[{"129", "\[Rule]", "242"}], ",", 
       RowBox[{"129", "\[Rule]", "130"}], ",", 
       RowBox[{"637", "\[Rule]", "470"}], ",", 
       RowBox[{"637", "\[Rule]", "470"}], ",", 
       RowBox[{"637", "\[Rule]", "806"}], ",", 
       RowBox[{"637", "\[Rule]", "806"}], ",", 
       RowBox[{"637", "\[Rule]", "638"}], ",", 
       RowBox[{"625", "\[Rule]", "458"}], ",", 
       RowBox[{"625", "\[Rule]", "458"}], ",", 
       RowBox[{"625", "\[Rule]", "794"}], ",", 
       RowBox[{"625", "\[Rule]", "794"}], ",", 
       RowBox[{"625", "\[Rule]", "626"}], ",", 
       RowBox[{"569", "\[Rule]", "458"}], ",", 
       RowBox[{"569", "\[Rule]", "458"}], ",", 
       RowBox[{"569", "\[Rule]", "794"}], ",", 
       RowBox[{"569", "\[Rule]", "794"}], ",", 
       RowBox[{"569", "\[Rule]", "402"}], ",", 
       RowBox[{"569", "\[Rule]", "402"}], ",", 
       RowBox[{"569", "\[Rule]", "738"}], ",", 
       RowBox[{"569", "\[Rule]", "738"}], ",", 
       RowBox[{"569", "\[Rule]", "570"}], ",", 
       RowBox[{"469", "\[Rule]", "302"}], ",", 
       RowBox[{"469", "\[Rule]", "302"}], ",", 
       RowBox[{"469", "\[Rule]", "638"}], ",", 
       RowBox[{"469", "\[Rule]", "638"}], ",", 
       RowBox[{"469", "\[Rule]", "246"}], ",", 
       RowBox[{"469", "\[Rule]", "246"}], ",", 
       RowBox[{"469", "\[Rule]", "582"}], ",", 
       RowBox[{"469", "\[Rule]", "582"}], ",", 
       RowBox[{"469", "\[Rule]", "470"}], ",", 
       RowBox[{"457", "\[Rule]", "290"}], ",", 
       RowBox[{"457", "\[Rule]", "290"}], ",", 
       RowBox[{"457", "\[Rule]", "626"}], ",", 
       RowBox[{"457", "\[Rule]", "626"}], ",", 
       RowBox[{"457", "\[Rule]", "234"}], ",", 
       RowBox[{"457", "\[Rule]", "234"}], ",", 
       RowBox[{"457", "\[Rule]", "570"}], ",", 
       RowBox[{"457", "\[Rule]", "570"}], ",", 
       RowBox[{"457", "\[Rule]", "458"}], ",", 
       RowBox[{"659", "\[Rule]", "492"}], ",", 
       RowBox[{"659", "\[Rule]", "492"}], ",", 
       RowBox[{"659", "\[Rule]", "828"}], ",", 
       RowBox[{"659", "\[Rule]", "828"}], ",", 
       RowBox[{"659", "\[Rule]", "660"}], ",", 
       RowBox[{"647", "\[Rule]", "480"}], ",", 
       RowBox[{"647", "\[Rule]", "480"}], ",", 
       RowBox[{"647", "\[Rule]", "816"}], ",", 
       RowBox[{"647", "\[Rule]", "816"}], ",", 
       RowBox[{"647", "\[Rule]", "648"}], ",", 
       RowBox[{"491", "\[Rule]", "324"}], ",", 
       RowBox[{"491", "\[Rule]", "324"}], ",", 
       RowBox[{"491", "\[Rule]", "660"}], ",", 
       RowBox[{"491", "\[Rule]", "660"}], ",", 
       RowBox[{"491", "\[Rule]", "268"}], ",", 
       RowBox[{"491", "\[Rule]", "268"}], ",", 
       RowBox[{"491", "\[Rule]", "604"}], ",", 
       RowBox[{"491", "\[Rule]", "604"}], ",", 
       RowBox[{"491", "\[Rule]", "492"}], ",", 
       RowBox[{"479", "\[Rule]", "312"}], ",", 
       RowBox[{"479", "\[Rule]", "312"}], ",", 
       RowBox[{"479", "\[Rule]", "648"}], ",", 
       RowBox[{"479", "\[Rule]", "648"}], ",", 
       RowBox[{"479", "\[Rule]", "256"}], ",", 
       RowBox[{"479", "\[Rule]", "256"}], ",", 
       RowBox[{"479", "\[Rule]", "592"}], ",", 
       RowBox[{"479", "\[Rule]", "592"}], ",", 
       RowBox[{"479", "\[Rule]", "480"}], ",", 
       RowBox[{"633", "\[Rule]", "466"}], ",", 
       RowBox[{"633", "\[Rule]", "466"}], ",", 
       RowBox[{"633", "\[Rule]", "802"}], ",", 
       RowBox[{"633", "\[Rule]", "802"}], ",", 
       RowBox[{"633", "\[Rule]", "634"}], ",", 
       RowBox[{"577", "\[Rule]", "466"}], ",", 
       RowBox[{"577", "\[Rule]", "466"}], ",", 
       RowBox[{"577", "\[Rule]", "802"}], ",", 
       RowBox[{"577", "\[Rule]", "802"}], ",", 
       RowBox[{"577", "\[Rule]", "410"}], ",", 
       RowBox[{"577", "\[Rule]", "410"}], ",", 
       RowBox[{"577", "\[Rule]", "746"}], ",", 
       RowBox[{"577", "\[Rule]", "746"}], ",", 
       RowBox[{"577", "\[Rule]", "578"}], ",", 
       RowBox[{"465", "\[Rule]", "298"}], ",", 
       RowBox[{"465", "\[Rule]", "298"}], ",", 
       RowBox[{"465", "\[Rule]", "634"}], ",", 
       RowBox[{"465", "\[Rule]", "634"}], ",", 
       RowBox[{"465", "\[Rule]", "242"}], ",", 
       RowBox[{"465", "\[Rule]", "242"}], ",", 
       RowBox[{"465", "\[Rule]", "578"}], ",", 
       RowBox[{"465", "\[Rule]", "578"}], ",", 
       RowBox[{"465", "\[Rule]", "466"}], ",", 
       RowBox[{"177", "\[Rule]", "66"}], ",", 
       RowBox[{"177", "\[Rule]", "402"}], ",", 
       RowBox[{"177", "\[Rule]", "10"}], ",", 
       RowBox[{"177", "\[Rule]", "10"}], ",", 
       RowBox[{"177", "\[Rule]", "346"}], ",", 
       RowBox[{"177", "\[Rule]", "346"}], ",", 
       RowBox[{"177", "\[Rule]", "178"}], ",", 
       RowBox[{"65", "\[Rule]", "234"}], ",", 
       RowBox[{"65", "\[Rule]", "178"}], ",", 
       RowBox[{"65", "\[Rule]", "66"}], ",", 
       RowBox[{"185", "\[Rule]", "74"}], ",", 
       RowBox[{"185", "\[Rule]", "410"}], ",", 
       RowBox[{"185", "\[Rule]", "18"}], ",", 
       RowBox[{"185", "\[Rule]", "18"}], ",", 
       RowBox[{"185", "\[Rule]", "354"}], ",", 
       RowBox[{"185", "\[Rule]", "354"}], ",", 
       RowBox[{"185", "\[Rule]", "186"}], ",", 
       RowBox[{"73", "\[Rule]", "242"}], ",", 
       RowBox[{"73", "\[Rule]", "186"}], ",", 
       RowBox[{"73", "\[Rule]", "74"}], ",", 
       RowBox[{"513", "\[Rule]", "402"}], ",", 
       RowBox[{"513", "\[Rule]", "402"}], ",", 
       RowBox[{"513", "\[Rule]", "738"}], ",", 
       RowBox[{"513", "\[Rule]", "738"}], ",", 
       RowBox[{"513", "\[Rule]", "346"}], ",", 
       RowBox[{"513", "\[Rule]", "682"}], ",", 
       RowBox[{"513", "\[Rule]", "514"}], ",", 
       RowBox[{"401", "\[Rule]", "234"}], ",", 
       RowBox[{"401", "\[Rule]", "570"}], ",", 
       RowBox[{"401", "\[Rule]", "570"}], ",", 
       RowBox[{"401", "\[Rule]", "178"}], ",", 
       RowBox[{"401", "\[Rule]", "514"}], ",", 
       RowBox[{"401", "\[Rule]", "514"}], ",", 
       RowBox[{"401", "\[Rule]", "402"}], ",", 
       RowBox[{"521", "\[Rule]", "410"}], ",", 
       RowBox[{"521", "\[Rule]", "410"}], ",", 
       RowBox[{"521", "\[Rule]", "746"}], ",", 
       RowBox[{"521", "\[Rule]", "746"}], ",", 
       RowBox[{"521", "\[Rule]", "354"}], ",", 
       RowBox[{"521", "\[Rule]", "690"}], ",", 
       RowBox[{"521", "\[Rule]", "522"}], ",", 
       RowBox[{"409", "\[Rule]", "242"}], ",", 
       RowBox[{"409", "\[Rule]", "578"}], ",", 
       RowBox[{"409", "\[Rule]", "578"}], ",", 
       RowBox[{"409", "\[Rule]", "186"}], ",", 
       RowBox[{"409", "\[Rule]", "522"}], ",", 
       RowBox[{"409", "\[Rule]", "522"}], ",", 
       RowBox[{"409", "\[Rule]", "410"}], ",", 
       RowBox[{"333", "\[Rule]", "166"}], ",", 
       RowBox[{"333", "\[Rule]", "166"}], ",", 
       RowBox[{"333", "\[Rule]", "502"}], ",", 
       RowBox[{"333", "\[Rule]", "502"}], ",", 
       RowBox[{"333", "\[Rule]", "334"}], ",", 
       RowBox[{"165", "\[Rule]", "334"}], ",", 
       RowBox[{"165", "\[Rule]", "334"}], ",", 
       RowBox[{"165", "\[Rule]", "278"}], ",", 
       RowBox[{"165", "\[Rule]", "278"}], ",", 
       RowBox[{"165", "\[Rule]", "166"}], ",", 
       RowBox[{"319", "\[Rule]", "152"}], ",", 
       RowBox[{"319", "\[Rule]", "152"}], ",", 
       RowBox[{"319", "\[Rule]", "488"}], ",", 
       RowBox[{"319", "\[Rule]", "488"}], ",", 
       RowBox[{"319", "\[Rule]", "320"}], ",", 
       RowBox[{"151", "\[Rule]", "320"}], ",", 
       RowBox[{"151", "\[Rule]", "320"}], ",", 
       RowBox[{"151", "\[Rule]", "264"}], ",", 
       RowBox[{"151", "\[Rule]", "264"}], ",", 
       RowBox[{"151", "\[Rule]", "152"}], ",", 
       RowBox[{"669", "\[Rule]", "502"}], ",", 
       RowBox[{"669", "\[Rule]", "502"}], ",", 
       RowBox[{"669", "\[Rule]", "838"}], ",", 
       RowBox[{"669", "\[Rule]", "838"}], ",", 
       RowBox[{"669", "\[Rule]", "670"}], ",", 
       RowBox[{"501", "\[Rule]", "334"}], ",", 
       RowBox[{"501", "\[Rule]", "334"}], ",", 
       RowBox[{"501", "\[Rule]", "670"}], ",", 
       RowBox[{"501", "\[Rule]", "670"}], ",", 
       RowBox[{"501", "\[Rule]", "278"}], ",", 
       RowBox[{"501", "\[Rule]", "278"}], ",", 
       RowBox[{"501", "\[Rule]", "614"}], ",", 
       RowBox[{"501", "\[Rule]", "614"}], ",", 
       RowBox[{"501", "\[Rule]", "502"}], ",", 
       RowBox[{"655", "\[Rule]", "488"}], ",", 
       RowBox[{"655", "\[Rule]", "488"}], ",", 
       RowBox[{"655", "\[Rule]", "824"}], ",", 
       RowBox[{"655", "\[Rule]", "824"}], ",", 
       RowBox[{"655", "\[Rule]", "656"}], ",", 
       RowBox[{"487", "\[Rule]", "320"}], ",", 
       RowBox[{"487", "\[Rule]", "320"}], ",", 
       RowBox[{"487", "\[Rule]", "656"}], ",", 
       RowBox[{"487", "\[Rule]", "656"}], ",", 
       RowBox[{"487", "\[Rule]", "264"}], ",", 
       RowBox[{"487", "\[Rule]", "264"}], ",", 
       RowBox[{"487", "\[Rule]", "600"}], ",", 
       RowBox[{"487", "\[Rule]", "600"}], ",", 
       RowBox[{"487", "\[Rule]", "488"}], ",", 
       RowBox[{"307", "\[Rule]", "140"}], ",", 
       RowBox[{"307", "\[Rule]", "140"}], ",", 
       RowBox[{"307", "\[Rule]", "476"}], ",", 
       RowBox[{"307", "\[Rule]", "476"}], ",", 
       RowBox[{"307", "\[Rule]", "308"}], ",", 
       RowBox[{"251", "\[Rule]", "140"}], ",", 
       RowBox[{"251", "\[Rule]", "140"}], ",", 
       RowBox[{"251", "\[Rule]", "476"}], ",", 
       RowBox[{"251", "\[Rule]", "476"}], ",", 
       RowBox[{"251", "\[Rule]", "84"}], ",", 
       RowBox[{"251", "\[Rule]", "420"}], ",", 
       RowBox[{"251", "\[Rule]", "252"}], ",", 
       RowBox[{"139", "\[Rule]", "308"}], ",", 
       RowBox[{"139", "\[Rule]", "308"}], ",", 
       RowBox[{"139", "\[Rule]", "252"}], ",", 
       RowBox[{"139", "\[Rule]", "252"}], ",", 
       RowBox[{"139", "\[Rule]", "140"}], ",", 
       RowBox[{"643", "\[Rule]", "476"}], ",", 
       RowBox[{"643", "\[Rule]", "476"}], ",", 
       RowBox[{"643", "\[Rule]", "812"}], ",", 
       RowBox[{"643", "\[Rule]", "812"}], ",", 
       RowBox[{"643", "\[Rule]", "644"}], ",", 
       RowBox[{"587", "\[Rule]", "476"}], ",", 
       RowBox[{"587", "\[Rule]", "476"}], ",", 
       RowBox[{"587", "\[Rule]", "812"}], ",", 
       RowBox[{"587", "\[Rule]", "812"}], ",", 
       RowBox[{"587", "\[Rule]", "420"}], ",", 
       RowBox[{"587", "\[Rule]", "420"}], ",", 
       RowBox[{"587", "\[Rule]", "756"}], ",", 
       RowBox[{"587", "\[Rule]", "756"}], ",", 
       RowBox[{"587", "\[Rule]", "588"}], ",", 
       RowBox[{"475", "\[Rule]", "308"}], ",", 
       RowBox[{"475", "\[Rule]", "308"}], ",", 
       RowBox[{"475", "\[Rule]", "644"}], ",", 
       RowBox[{"475", "\[Rule]", "644"}], ",", 
       RowBox[{"475", "\[Rule]", "252"}], ",", 
       RowBox[{"475", "\[Rule]", "252"}], ",", 
       RowBox[{"475", "\[Rule]", "588"}], ",", 
       RowBox[{"475", "\[Rule]", "588"}], ",", 
       RowBox[{"475", "\[Rule]", "476"}], ",", 
       RowBox[{"195", "\[Rule]", "84"}], ",", 
       RowBox[{"195", "\[Rule]", "420"}], ",", 
       RowBox[{"195", "\[Rule]", "28"}], ",", 
       RowBox[{"195", "\[Rule]", "28"}], ",", 
       RowBox[{"195", "\[Rule]", "364"}], ",", 
       RowBox[{"195", "\[Rule]", "364"}], ",", 
       RowBox[{"195", "\[Rule]", "196"}], ",", 
       RowBox[{"83", "\[Rule]", "252"}], ",", 
       RowBox[{"83", "\[Rule]", "196"}], ",", 
       RowBox[{"83", "\[Rule]", "84"}], ",", 
       RowBox[{"531", "\[Rule]", "420"}], ",", 
       RowBox[{"531", "\[Rule]", "420"}], ",", 
       RowBox[{"531", "\[Rule]", "756"}], ",", 
       RowBox[{"531", "\[Rule]", "756"}], ",", 
       RowBox[{"531", "\[Rule]", "364"}], ",", 
       RowBox[{"531", "\[Rule]", "700"}], ",", 
       RowBox[{"531", "\[Rule]", "532"}], ",", 
       RowBox[{"419", "\[Rule]", "252"}], ",", 
       RowBox[{"419", "\[Rule]", "588"}], ",", 
       RowBox[{"419", "\[Rule]", "588"}], ",", 
       RowBox[{"419", "\[Rule]", "196"}], ",", 
       RowBox[{"419", "\[Rule]", "532"}], ",", 
       RowBox[{"419", "\[Rule]", "532"}], ",", 
       RowBox[{"419", "\[Rule]", "420"}], ",", 
       RowBox[{"9", "\[Rule]", "178"}], ",", 
       RowBox[{"9", "\[Rule]", "178"}], ",", 
       RowBox[{"9", "\[Rule]", "10"}], ",", 
       RowBox[{"17", "\[Rule]", "186"}], ",", 
       RowBox[{"17", "\[Rule]", "186"}], ",", 
       RowBox[{"17", "\[Rule]", "18"}], ",", 
       RowBox[{"345", "\[Rule]", "178"}], ",", 
       RowBox[{"345", "\[Rule]", "178"}], ",", 
       RowBox[{"345", "\[Rule]", "514"}], ",", 
       RowBox[{"345", "\[Rule]", "346"}], ",", 
       RowBox[{"353", "\[Rule]", "186"}], ",", 
       RowBox[{"353", "\[Rule]", "186"}], ",", 
       RowBox[{"353", "\[Rule]", "522"}], ",", 
       RowBox[{"353", "\[Rule]", "354"}], ",", 
       RowBox[{"27", "\[Rule]", "196"}], ",", 
       RowBox[{"27", "\[Rule]", "196"}], ",", 
       RowBox[{"27", "\[Rule]", "28"}], ",", 
       RowBox[{"363", "\[Rule]", "196"}], ",", 
       RowBox[{"363", "\[Rule]", "196"}], ",", 
       RowBox[{"363", "\[Rule]", "532"}], ",", 
       RowBox[{"363", "\[Rule]", "364"}], ",", 
       RowBox[{"329", "\[Rule]", "162"}], ",", 
       RowBox[{"329", "\[Rule]", "162"}], ",", 
       RowBox[{"329", "\[Rule]", "498"}], ",", 
       RowBox[{"329", "\[Rule]", "498"}], ",", 
       RowBox[{"329", "\[Rule]", "330"}], ",", 
       RowBox[{"161", "\[Rule]", "330"}], ",", 
       RowBox[{"161", "\[Rule]", "330"}], ",", 
       RowBox[{"161", "\[Rule]", "274"}], ",", 
       RowBox[{"161", "\[Rule]", "274"}], ",", 
       RowBox[{"161", "\[Rule]", "162"}], ",", 
       RowBox[{"665", "\[Rule]", "498"}], ",", 
       RowBox[{"665", "\[Rule]", "498"}], ",", 
       RowBox[{"665", "\[Rule]", "834"}], ",", 
       RowBox[{"665", "\[Rule]", "834"}], ",", 
       RowBox[{"665", "\[Rule]", "666"}], ",", 
       RowBox[{"497", "\[Rule]", "330"}], ",", 
       RowBox[{"497", "\[Rule]", "330"}], ",", 
       RowBox[{"497", "\[Rule]", "666"}], ",", 
       RowBox[{"497", "\[Rule]", "666"}], ",", 
       RowBox[{"497", "\[Rule]", "274"}], ",", 
       RowBox[{"497", "\[Rule]", "274"}], ",", 
       RowBox[{"497", "\[Rule]", "610"}], ",", 
       RowBox[{"497", "\[Rule]", "610"}], ",", 
       RowBox[{"497", "\[Rule]", "498"}], ",", 
       RowBox[{"315", "\[Rule]", "148"}], ",", 
       RowBox[{"315", "\[Rule]", "148"}], ",", 
       RowBox[{"315", "\[Rule]", "484"}], ",", 
       RowBox[{"315", "\[Rule]", "484"}], ",", 
       RowBox[{"315", "\[Rule]", "316"}], ",", 
       RowBox[{"259", "\[Rule]", "148"}], ",", 
       RowBox[{"259", "\[Rule]", "148"}], ",", 
       RowBox[{"259", "\[Rule]", "484"}], ",", 
       RowBox[{"259", "\[Rule]", "484"}], ",", 
       RowBox[{"259", "\[Rule]", "92"}], ",", 
       RowBox[{"259", "\[Rule]", "428"}], ",", 
       RowBox[{"259", "\[Rule]", "260"}], ",", 
       RowBox[{"147", "\[Rule]", "316"}], ",", 
       RowBox[{"147", "\[Rule]", "316"}], ",", 
       RowBox[{"147", "\[Rule]", "260"}], ",", 
       RowBox[{"147", "\[Rule]", "260"}], ",", 
       RowBox[{"147", "\[Rule]", "148"}], ",", 
       RowBox[{"651", "\[Rule]", "484"}], ",", 
       RowBox[{"651", "\[Rule]", "484"}], ",", 
       RowBox[{"651", "\[Rule]", "820"}], ",", 
       RowBox[{"651", "\[Rule]", "820"}], ",", 
       RowBox[{"651", "\[Rule]", "652"}], ",", 
       RowBox[{"595", "\[Rule]", "484"}], ",", 
       RowBox[{"595", "\[Rule]", "484"}], ",", 
       RowBox[{"595", "\[Rule]", "820"}], ",", 
       RowBox[{"595", "\[Rule]", "820"}], ",", 
       RowBox[{"595", "\[Rule]", "428"}], ",", 
       RowBox[{"595", "\[Rule]", "428"}], ",", 
       RowBox[{"595", "\[Rule]", "764"}], ",", 
       RowBox[{"595", "\[Rule]", "764"}], ",", 
       RowBox[{"595", "\[Rule]", "596"}], ",", 
       RowBox[{"483", "\[Rule]", "316"}], ",", 
       RowBox[{"483", "\[Rule]", "316"}], ",", 
       RowBox[{"483", "\[Rule]", "652"}], ",", 
       RowBox[{"483", "\[Rule]", "652"}], ",", 
       RowBox[{"483", "\[Rule]", "260"}], ",", 
       RowBox[{"483", "\[Rule]", "260"}], ",", 
       RowBox[{"483", "\[Rule]", "596"}], ",", 
       RowBox[{"483", "\[Rule]", "596"}], ",", 
       RowBox[{"483", "\[Rule]", "484"}], ",", 
       RowBox[{"203", "\[Rule]", "92"}], ",", 
       RowBox[{"203", "\[Rule]", "428"}], ",", 
       RowBox[{"203", "\[Rule]", "36"}], ",", 
       RowBox[{"203", "\[Rule]", "36"}], ",", 
       RowBox[{"203", "\[Rule]", "372"}], ",", 
       RowBox[{"203", "\[Rule]", "372"}], ",", 
       RowBox[{"203", "\[Rule]", "204"}], ",", 
       RowBox[{"91", "\[Rule]", "260"}], ",", 
       RowBox[{"91", "\[Rule]", "204"}], ",", 
       RowBox[{"91", "\[Rule]", "92"}], ",", 
       RowBox[{"539", "\[Rule]", "428"}], ",", 
       RowBox[{"539", "\[Rule]", "428"}], ",", 
       RowBox[{"539", "\[Rule]", "764"}], ",", 
       RowBox[{"539", "\[Rule]", "764"}], ",", 
       RowBox[{"539", "\[Rule]", "372"}], ",", 
       RowBox[{"539", "\[Rule]", "708"}], ",", 
       RowBox[{"539", "\[Rule]", "540"}], ",", 
       RowBox[{"427", "\[Rule]", "260"}], ",", 
       RowBox[{"427", "\[Rule]", "596"}], ",", 
       RowBox[{"427", "\[Rule]", "596"}], ",", 
       RowBox[{"427", "\[Rule]", "204"}], ",", 
       RowBox[{"427", "\[Rule]", "540"}], ",", 
       RowBox[{"427", "\[Rule]", "540"}], ",", 
       RowBox[{"427", "\[Rule]", "428"}], ",", 
       RowBox[{"35", "\[Rule]", "204"}], ",", 
       RowBox[{"35", "\[Rule]", "204"}], ",", 
       RowBox[{"35", "\[Rule]", "36"}], ",", 
       RowBox[{"371", "\[Rule]", "204"}], ",", 
       RowBox[{"371", "\[Rule]", "204"}], ",", 
       RowBox[{"371", "\[Rule]", "540"}], ",", 
       RowBox[{"371", "\[Rule]", "372"}], ",", 
       RowBox[{"805", "\[Rule]", "638"}], ",", 
       RowBox[{"805", "\[Rule]", "638"}], ",", 
       RowBox[{"805", "\[Rule]", "582"}], ",", 
       RowBox[{"805", "\[Rule]", "582"}], ",", 
       RowBox[{"805", "\[Rule]", "806"}], ",", 
       RowBox[{"793", "\[Rule]", "626"}], ",", 
       RowBox[{"793", "\[Rule]", "626"}], ",", 
       RowBox[{"793", "\[Rule]", "570"}], ",", 
       RowBox[{"793", "\[Rule]", "570"}], ",", 
       RowBox[{"793", "\[Rule]", "794"}], ",", 
       RowBox[{"827", "\[Rule]", "660"}], ",", 
       RowBox[{"827", "\[Rule]", "660"}], ",", 
       RowBox[{"827", "\[Rule]", "604"}], ",", 
       RowBox[{"827", "\[Rule]", "604"}], ",", 
       RowBox[{"827", "\[Rule]", "828"}], ",", 
       RowBox[{"815", "\[Rule]", "648"}], ",", 
       RowBox[{"815", "\[Rule]", "648"}], ",", 
       RowBox[{"815", "\[Rule]", "592"}], ",", 
       RowBox[{"815", "\[Rule]", "592"}], ",", 
       RowBox[{"815", "\[Rule]", "816"}], ",", 
       RowBox[{"801", "\[Rule]", "634"}], ",", 
       RowBox[{"801", "\[Rule]", "634"}], ",", 
       RowBox[{"801", "\[Rule]", "578"}], ",", 
       RowBox[{"801", "\[Rule]", "578"}], ",", 
       RowBox[{"801", "\[Rule]", "802"}], ",", 
       RowBox[{"749", "\[Rule]", "582"}], ",", 
       RowBox[{"749", "\[Rule]", "582"}], ",", 
       RowBox[{"749", "\[Rule]", "526"}], ",", 
       RowBox[{"749", "\[Rule]", "526"}], ",", 
       RowBox[{"749", "\[Rule]", "750"}], ",", 
       RowBox[{"737", "\[Rule]", "570"}], ",", 
       RowBox[{"737", "\[Rule]", "570"}], ",", 
       RowBox[{"737", "\[Rule]", "514"}], ",", 
       RowBox[{"737", "\[Rule]", "514"}], ",", 
       RowBox[{"737", "\[Rule]", "738"}], ",", 
       RowBox[{"771", "\[Rule]", "604"}], ",", 
       RowBox[{"771", "\[Rule]", "604"}], ",", 
       RowBox[{"771", "\[Rule]", "548"}], ",", 
       RowBox[{"771", "\[Rule]", "548"}], ",", 
       RowBox[{"771", "\[Rule]", "772"}], ",", 
       RowBox[{"759", "\[Rule]", "592"}], ",", 
       RowBox[{"759", "\[Rule]", "592"}], ",", 
       RowBox[{"759", "\[Rule]", "536"}], ",", 
       RowBox[{"759", "\[Rule]", "536"}], ",", 
       RowBox[{"759", "\[Rule]", "760"}], ",", 
       RowBox[{"745", "\[Rule]", "578"}], ",", 
       RowBox[{"745", "\[Rule]", "578"}], ",", 
       RowBox[{"745", "\[Rule]", "522"}], ",", 
       RowBox[{"745", "\[Rule]", "522"}], ",", 
       RowBox[{"745", "\[Rule]", "746"}], ",", 
       RowBox[{"837", "\[Rule]", "670"}], ",", 
       RowBox[{"837", "\[Rule]", "670"}], ",", 
       RowBox[{"837", "\[Rule]", "614"}], ",", 
       RowBox[{"837", "\[Rule]", "614"}], ",", 
       RowBox[{"837", "\[Rule]", "838"}], ",", 
       RowBox[{"823", "\[Rule]", "656"}], ",", 
       RowBox[{"823", "\[Rule]", "656"}], ",", 
       RowBox[{"823", "\[Rule]", "600"}], ",", 
       RowBox[{"823", "\[Rule]", "600"}], ",", 
       RowBox[{"823", "\[Rule]", "824"}], ",", 
       RowBox[{"781", "\[Rule]", "614"}], ",", 
       RowBox[{"781", "\[Rule]", "614"}], ",", 
       RowBox[{"781", "\[Rule]", "558"}], ",", 
       RowBox[{"781", "\[Rule]", "558"}], ",", 
       RowBox[{"781", "\[Rule]", "782"}], ",", 
       RowBox[{"767", "\[Rule]", "600"}], ",", 
       RowBox[{"767", "\[Rule]", "600"}], ",", 
       RowBox[{"767", "\[Rule]", "544"}], ",", 
       RowBox[{"767", "\[Rule]", "544"}], ",", 
       RowBox[{"767", "\[Rule]", "768"}], ",", 
       RowBox[{"811", "\[Rule]", "644"}], ",", 
       RowBox[{"811", "\[Rule]", "644"}], ",", 
       RowBox[{"811", "\[Rule]", "588"}], ",", 
       RowBox[{"811", "\[Rule]", "588"}], ",", 
       RowBox[{"811", "\[Rule]", "812"}], ",", 
       RowBox[{"755", "\[Rule]", "588"}], ",", 
       RowBox[{"755", "\[Rule]", "588"}], ",", 
       RowBox[{"755", "\[Rule]", "532"}], ",", 
       RowBox[{"755", "\[Rule]", "532"}], ",", 
       RowBox[{"755", "\[Rule]", "756"}], ",", 
       RowBox[{"693", "\[Rule]", "526"}], ",", 
       RowBox[{"693", "\[Rule]", "694"}], ",", 
       RowBox[{"681", "\[Rule]", "514"}], ",", 
       RowBox[{"681", "\[Rule]", "682"}], ",", 
       RowBox[{"715", "\[Rule]", "548"}], ",", 
       RowBox[{"715", "\[Rule]", "716"}], ",", 
       RowBox[{"703", "\[Rule]", "536"}], ",", 
       RowBox[{"703", "\[Rule]", "704"}], ",", 
       RowBox[{"689", "\[Rule]", "522"}], ",", 
       RowBox[{"689", "\[Rule]", "690"}], ",", 
       RowBox[{"725", "\[Rule]", "558"}], ",", 
       RowBox[{"725", "\[Rule]", "726"}], ",", 
       RowBox[{"711", "\[Rule]", "544"}], ",", 
       RowBox[{"711", "\[Rule]", "712"}], ",", 
       RowBox[{"699", "\[Rule]", "532"}], ",", 
       RowBox[{"699", "\[Rule]", "700"}], ",", 
       RowBox[{"833", "\[Rule]", "666"}], ",", 
       RowBox[{"833", "\[Rule]", "666"}], ",", 
       RowBox[{"833", "\[Rule]", "610"}], ",", 
       RowBox[{"833", "\[Rule]", "610"}], ",", 
       RowBox[{"833", "\[Rule]", "834"}], ",", 
       RowBox[{"777", "\[Rule]", "610"}], ",", 
       RowBox[{"777", "\[Rule]", "610"}], ",", 
       RowBox[{"777", "\[Rule]", "554"}], ",", 
       RowBox[{"777", "\[Rule]", "554"}], ",", 
       RowBox[{"777", "\[Rule]", "778"}], ",", 
       RowBox[{"721", "\[Rule]", "554"}], ",", 
       RowBox[{"721", "\[Rule]", "722"}], ",", 
       RowBox[{"819", "\[Rule]", "652"}], ",", 
       RowBox[{"819", "\[Rule]", "652"}], ",", 
       RowBox[{"819", "\[Rule]", "596"}], ",", 
       RowBox[{"819", "\[Rule]", "596"}], ",", 
       RowBox[{"819", "\[Rule]", "820"}], ",", 
       RowBox[{"763", "\[Rule]", "596"}], ",", 
       RowBox[{"763", "\[Rule]", "596"}], ",", 
       RowBox[{"763", "\[Rule]", "540"}], ",", 
       RowBox[{"763", "\[Rule]", "540"}], ",", 
       RowBox[{"763", "\[Rule]", "764"}], ",", 
       RowBox[{"707", "\[Rule]", "540"}], ",", 
       RowBox[{"707", "\[Rule]", "708"}], ",", 
       RowBox[{"325", "\[Rule]", "158"}], ",", 
       RowBox[{"325", "\[Rule]", "158"}], ",", 
       RowBox[{"325", "\[Rule]", "494"}], ",", 
       RowBox[{"325", "\[Rule]", "494"}], ",", 
       RowBox[{"325", "\[Rule]", "326"}], ",", 
       RowBox[{"269", "\[Rule]", "158"}], ",", 
       RowBox[{"269", "\[Rule]", "158"}], ",", 
       RowBox[{"269", "\[Rule]", "494"}], ",", 
       RowBox[{"269", "\[Rule]", "494"}], ",", 
       RowBox[{"269", "\[Rule]", "102"}], ",", 
       RowBox[{"269", "\[Rule]", "438"}], ",", 
       RowBox[{"269", "\[Rule]", "270"}], ",", 
       RowBox[{"157", "\[Rule]", "326"}], ",", 
       RowBox[{"157", "\[Rule]", "326"}], ",", 
       RowBox[{"157", "\[Rule]", "270"}], ",", 
       RowBox[{"157", "\[Rule]", "270"}], ",", 
       RowBox[{"157", "\[Rule]", "158"}], ",", 
       RowBox[{"661", "\[Rule]", "494"}], ",", 
       RowBox[{"661", "\[Rule]", "494"}], ",", 
       RowBox[{"661", "\[Rule]", "830"}], ",", 
       RowBox[{"661", "\[Rule]", "830"}], ",", 
       RowBox[{"661", "\[Rule]", "662"}], ",", 
       RowBox[{"605", "\[Rule]", "494"}], ",", 
       RowBox[{"605", "\[Rule]", "494"}], ",", 
       RowBox[{"605", "\[Rule]", "830"}], ",", 
       RowBox[{"605", "\[Rule]", "830"}], ",", 
       RowBox[{"605", "\[Rule]", "438"}], ",", 
       RowBox[{"605", "\[Rule]", "438"}], ",", 
       RowBox[{"605", "\[Rule]", "774"}], ",", 
       RowBox[{"605", "\[Rule]", "774"}], ",", 
       RowBox[{"605", "\[Rule]", "606"}], ",", 
       RowBox[{"493", "\[Rule]", "326"}], ",", 
       RowBox[{"493", "\[Rule]", "326"}], ",", 
       RowBox[{"493", "\[Rule]", "662"}], ",", 
       RowBox[{"493", "\[Rule]", "662"}], ",", 
       RowBox[{"493", "\[Rule]", "270"}], ",", 
       RowBox[{"493", "\[Rule]", "270"}], ",", 
       RowBox[{"493", "\[Rule]", "606"}], ",", 
       RowBox[{"493", "\[Rule]", "606"}], ",", 
       RowBox[{"493", "\[Rule]", "494"}], ",", 
       RowBox[{"213", "\[Rule]", "102"}], ",", 
       RowBox[{"213", "\[Rule]", "438"}], ",", 
       RowBox[{"213", "\[Rule]", "46"}], ",", 
       RowBox[{"213", "\[Rule]", "46"}], ",", 
       RowBox[{"213", "\[Rule]", "382"}], ",", 
       RowBox[{"213", "\[Rule]", "382"}], ",", 
       RowBox[{"213", "\[Rule]", "214"}], ",", 
       RowBox[{"101", "\[Rule]", "270"}], ",", 
       RowBox[{"101", "\[Rule]", "214"}], ",", 
       RowBox[{"101", "\[Rule]", "102"}], ",", 
       RowBox[{"549", "\[Rule]", "438"}], ",", 
       RowBox[{"549", "\[Rule]", "438"}], ",", 
       RowBox[{"549", "\[Rule]", "774"}], ",", 
       RowBox[{"549", "\[Rule]", "774"}], ",", 
       RowBox[{"549", "\[Rule]", "382"}], ",", 
       RowBox[{"549", "\[Rule]", "718"}], ",", 
       RowBox[{"549", "\[Rule]", "550"}], ",", 
       RowBox[{"437", "\[Rule]", "270"}], ",", 
       RowBox[{"437", "\[Rule]", "606"}], ",", 
       RowBox[{"437", "\[Rule]", "606"}], ",", 
       RowBox[{"437", "\[Rule]", "214"}], ",", 
       RowBox[{"437", "\[Rule]", "550"}], ",", 
       RowBox[{"437", "\[Rule]", "550"}], ",", 
       RowBox[{"437", "\[Rule]", "438"}], ",", 
       RowBox[{"45", "\[Rule]", "214"}], ",", 
       RowBox[{"45", "\[Rule]", "214"}], ",", 
       RowBox[{"45", "\[Rule]", "46"}], ",", 
       RowBox[{"381", "\[Rule]", "214"}], ",", 
       RowBox[{"381", "\[Rule]", "214"}], ",", 
       RowBox[{"381", "\[Rule]", "550"}], ",", 
       RowBox[{"381", "\[Rule]", "382"}], ",", 
       RowBox[{"829", "\[Rule]", "662"}], ",", 
       RowBox[{"829", "\[Rule]", "662"}], ",", 
       RowBox[{"829", "\[Rule]", "606"}], ",", 
       RowBox[{"829", "\[Rule]", "606"}], ",", 
       RowBox[{"829", "\[Rule]", "830"}], ",", 
       RowBox[{"773", "\[Rule]", "606"}], ",", 
       RowBox[{"773", "\[Rule]", "606"}], ",", 
       RowBox[{"773", "\[Rule]", "550"}], ",", 
       RowBox[{"773", "\[Rule]", "550"}], ",", 
       RowBox[{"773", "\[Rule]", "774"}], ",", 
       RowBox[{"717", "\[Rule]", "550"}], ",", 
       RowBox[{"717", "\[Rule]", "718"}], ",", 
       RowBox[{"302", "\[Rule]", "291"}], ",", 
       RowBox[{"302", "\[Rule]", "313"}], ",", 
       RowBox[{"302", "\[Rule]", "299"}], ",", 
       RowBox[{"122", "\[Rule]", "131"}], ",", 
       RowBox[{"122", "\[Rule]", "123"}], ",", 
       RowBox[{"122", "\[Rule]", "119"}], ",", 
       RowBox[{"458", "\[Rule]", "467"}], ",", 
       RowBox[{"458", "\[Rule]", "459"}], ",", 
       RowBox[{"458", "\[Rule]", "455"}], ",", 
       RowBox[{"290", "\[Rule]", "299"}], ",", 
       RowBox[{"290", "\[Rule]", "291"}], ",", 
       RowBox[{"290", "\[Rule]", "287"}], ",", 
       RowBox[{"66", "\[Rule]", "75"}], ",", 
       RowBox[{"66", "\[Rule]", "67"}], ",", 
       RowBox[{"66", "\[Rule]", "63"}], ",", 
       RowBox[{"402", "\[Rule]", "411"}], ",", 
       RowBox[{"402", "\[Rule]", "403"}], ",", 
       RowBox[{"402", "\[Rule]", "399"}], ",", 
       RowBox[{"234", "\[Rule]", "243"}], ",", 
       RowBox[{"234", "\[Rule]", "235"}], ",", 
       RowBox[{"234", "\[Rule]", "231"}], ",", 
       RowBox[{"324", "\[Rule]", "313"}], ",", 
       RowBox[{"324", "\[Rule]", "335"}], ",", 
       RowBox[{"324", "\[Rule]", "321"}], ",", 
       RowBox[{"312", "\[Rule]", "299"}], ",", 
       RowBox[{"312", "\[Rule]", "321"}], ",", 
       RowBox[{"312", "\[Rule]", "313"}], ",", 
       RowBox[{"312", "\[Rule]", "309"}], ",", 
       RowBox[{"130", "\[Rule]", "119"}], ",", 
       RowBox[{"130", "\[Rule]", "141"}], ",", 
       RowBox[{"130", "\[Rule]", "131"}], ",", 
       RowBox[{"466", "\[Rule]", "455"}], ",", 
       RowBox[{"466", "\[Rule]", "477"}], ",", 
       RowBox[{"466", "\[Rule]", "467"}], ",", 
       RowBox[{"298", "\[Rule]", "287"}], ",", 
       RowBox[{"298", "\[Rule]", "309"}], ",", 
       RowBox[{"298", "\[Rule]", "299"}], ",", 
       RowBox[{"74", "\[Rule]", "63"}], ",", 
       RowBox[{"74", "\[Rule]", "85"}], ",", 
       RowBox[{"74", "\[Rule]", "75"}], ",", 
       RowBox[{"410", "\[Rule]", "399"}], ",", 
       RowBox[{"410", "\[Rule]", "421"}], ",", 
       RowBox[{"410", "\[Rule]", "411"}], ",", 
       RowBox[{"242", "\[Rule]", "231"}], ",", 
       RowBox[{"242", "\[Rule]", "253"}], ",", 
       RowBox[{"242", "\[Rule]", "243"}], ",", 
       RowBox[{"638", "\[Rule]", "627"}], ",", 
       RowBox[{"638", "\[Rule]", "649"}], ",", 
       RowBox[{"638", "\[Rule]", "635"}], ",", 
       RowBox[{"794", "\[Rule]", "803"}], ",", 
       RowBox[{"794", "\[Rule]", "795"}], ",", 
       RowBox[{"794", "\[Rule]", "791"}], ",", 
       RowBox[{"626", "\[Rule]", "635"}], ",", 
       RowBox[{"626", "\[Rule]", "627"}], ",", 
       RowBox[{"626", "\[Rule]", "623"}], ",", 
       RowBox[{"738", "\[Rule]", "747"}], ",", 
       RowBox[{"738", "\[Rule]", "739"}], ",", 
       RowBox[{"738", "\[Rule]", "735"}], ",", 
       RowBox[{"570", "\[Rule]", "579"}], ",", 
       RowBox[{"570", "\[Rule]", "571"}], ",", 
       RowBox[{"570", "\[Rule]", "567"}], ",", 
       RowBox[{"660", "\[Rule]", "649"}], ",", 
       RowBox[{"660", "\[Rule]", "671"}], ",", 
       RowBox[{"660", "\[Rule]", "657"}], ",", 
       RowBox[{"648", "\[Rule]", "635"}], ",", 
       RowBox[{"648", "\[Rule]", "657"}], ",", 
       RowBox[{"648", "\[Rule]", "649"}], ",", 
       RowBox[{"648", "\[Rule]", "645"}], ",", 
       RowBox[{"802", "\[Rule]", "791"}], ",", 
       RowBox[{"802", "\[Rule]", "813"}], ",", 
       RowBox[{"802", "\[Rule]", "803"}], ",", 
       RowBox[{"634", "\[Rule]", "623"}], ",", 
       RowBox[{"634", "\[Rule]", "645"}], ",", 
       RowBox[{"634", "\[Rule]", "635"}], ",", 
       RowBox[{"746", "\[Rule]", "735"}], ",", 
       RowBox[{"746", "\[Rule]", "757"}], ",", 
       RowBox[{"746", "\[Rule]", "747"}], ",", 
       RowBox[{"578", "\[Rule]", "567"}], ",", 
       RowBox[{"578", "\[Rule]", "589"}], ",", 
       RowBox[{"578", "\[Rule]", "579"}], ",", 
       RowBox[{"10", "\[Rule]", "19"}], ",", 
       RowBox[{"10", "\[Rule]", "11"}], ",", 
       RowBox[{"10", "\[Rule]", "7"}], ",", 
       RowBox[{"346", "\[Rule]", "355"}], ",", 
       RowBox[{"346", "\[Rule]", "347"}], ",", 
       RowBox[{"346", "\[Rule]", "343"}], ",", 
       RowBox[{"178", "\[Rule]", "187"}], ",", 
       RowBox[{"178", "\[Rule]", "179"}], ",", 
       RowBox[{"178", "\[Rule]", "175"}], ",", 
       RowBox[{"18", "\[Rule]", "7"}], ",", 
       RowBox[{"18", "\[Rule]", "29"}], ",", 
       RowBox[{"18", "\[Rule]", "19"}], ",", 
       RowBox[{"354", "\[Rule]", "343"}], ",", 
       RowBox[{"354", "\[Rule]", "365"}], ",", 
       RowBox[{"354", "\[Rule]", "355"}], ",", 
       RowBox[{"186", "\[Rule]", "175"}], ",", 
       RowBox[{"186", "\[Rule]", "197"}], ",", 
       RowBox[{"186", "\[Rule]", "187"}], ",", 
       RowBox[{"682", "\[Rule]", "691"}], ",", 
       RowBox[{"682", "\[Rule]", "683"}], ",", 
       RowBox[{"682", "\[Rule]", "679"}], ",", 
       RowBox[{"514", "\[Rule]", "523"}], ",", 
       RowBox[{"514", "\[Rule]", "515"}], ",", 
       RowBox[{"514", "\[Rule]", "511"}], ",", 
       RowBox[{"690", "\[Rule]", "679"}], ",", 
       RowBox[{"690", "\[Rule]", "701"}], ",", 
       RowBox[{"690", "\[Rule]", "691"}], ",", 
       RowBox[{"522", "\[Rule]", "511"}], ",", 
       RowBox[{"522", "\[Rule]", "533"}], ",", 
       RowBox[{"522", "\[Rule]", "523"}], ",", 
       RowBox[{"334", "\[Rule]", "321"}], ",", 
       RowBox[{"334", "\[Rule]", "335"}], ",", 
       RowBox[{"334", "\[Rule]", "331"}], ",", 
       RowBox[{"320", "\[Rule]", "309"}], ",", 
       RowBox[{"320", "\[Rule]", "331"}], ",", 
       RowBox[{"320", "\[Rule]", "321"}], ",", 
       RowBox[{"320", "\[Rule]", "317"}], ",", 
       RowBox[{"670", "\[Rule]", "657"}], ",", 
       RowBox[{"670", "\[Rule]", "671"}], ",", 
       RowBox[{"670", "\[Rule]", "667"}], ",", 
       RowBox[{"656", "\[Rule]", "645"}], ",", 
       RowBox[{"656", "\[Rule]", "667"}], ",", 
       RowBox[{"656", "\[Rule]", "657"}], ",", 
       RowBox[{"656", "\[Rule]", "653"}], ",", 
       RowBox[{"140", "\[Rule]", "149"}], ",", 
       RowBox[{"140", "\[Rule]", "141"}], ",", 
       RowBox[{"140", "\[Rule]", "137"}], ",", 
       RowBox[{"476", "\[Rule]", "485"}], ",", 
       RowBox[{"476", "\[Rule]", "477"}], ",", 
       RowBox[{"476", "\[Rule]", "473"}], ",", 
       RowBox[{"308", "\[Rule]", "317"}], ",", 
       RowBox[{"308", "\[Rule]", "309"}], ",", 
       RowBox[{"308", "\[Rule]", "305"}], ",", 
       RowBox[{"84", "\[Rule]", "93"}], ",", 
       RowBox[{"84", "\[Rule]", "85"}], ",", 
       RowBox[{"84", "\[Rule]", "81"}], ",", 
       RowBox[{"420", "\[Rule]", "429"}], ",", 
       RowBox[{"420", "\[Rule]", "421"}], ",", 
       RowBox[{"420", "\[Rule]", "417"}], ",", 
       RowBox[{"252", "\[Rule]", "261"}], ",", 
       RowBox[{"252", "\[Rule]", "253"}], ",", 
       RowBox[{"252", "\[Rule]", "249"}], ",", 
       RowBox[{"812", "\[Rule]", "821"}], ",", 
       RowBox[{"812", "\[Rule]", "813"}], ",", 
       RowBox[{"812", "\[Rule]", "809"}], ",", 
       RowBox[{"644", "\[Rule]", "653"}], ",", 
       RowBox[{"644", "\[Rule]", "645"}], ",", 
       RowBox[{"644", "\[Rule]", "641"}], ",", 
       RowBox[{"756", "\[Rule]", "765"}], ",", 
       RowBox[{"756", "\[Rule]", "757"}], ",", 
       RowBox[{"756", "\[Rule]", "753"}], ",", 
       RowBox[{"588", "\[Rule]", "597"}], ",", 
       RowBox[{"588", "\[Rule]", "589"}], ",", 
       RowBox[{"588", "\[Rule]", "585"}], ",", 
       RowBox[{"28", "\[Rule]", "37"}], ",", 
       RowBox[{"28", "\[Rule]", "29"}], ",", 
       RowBox[{"28", "\[Rule]", "25"}], ",", 
       RowBox[{"364", "\[Rule]", "373"}], ",", 
       RowBox[{"364", "\[Rule]", "365"}], ",", 
       RowBox[{"364", "\[Rule]", "361"}], ",", 
       RowBox[{"196", "\[Rule]", "205"}], ",", 
       RowBox[{"196", "\[Rule]", "197"}], ",", 
       RowBox[{"196", "\[Rule]", "193"}], ",", 
       RowBox[{"700", "\[Rule]", "709"}], ",", 
       RowBox[{"700", "\[Rule]", "701"}], ",", 
       RowBox[{"700", "\[Rule]", "697"}], ",", 
       RowBox[{"532", "\[Rule]", "541"}], ",", 
       RowBox[{"532", "\[Rule]", "533"}], ",", 
       RowBox[{"532", "\[Rule]", "529"}], ",", 
       RowBox[{"330", "\[Rule]", "317"}], ",", 
       RowBox[{"330", "\[Rule]", "331"}], ",", 
       RowBox[{"330", "\[Rule]", "327"}], ",", 
       RowBox[{"666", "\[Rule]", "653"}], ",", 
       RowBox[{"666", "\[Rule]", "667"}], ",", 
       RowBox[{"666", "\[Rule]", "663"}], ",", 
       RowBox[{"148", "\[Rule]", "137"}], ",", 
       RowBox[{"148", "\[Rule]", "159"}], ",", 
       RowBox[{"148", "\[Rule]", "149"}], ",", 
       RowBox[{"484", "\[Rule]", "473"}], ",", 
       RowBox[{"484", "\[Rule]", "495"}], ",", 
       RowBox[{"484", "\[Rule]", "485"}], ",", 
       RowBox[{"316", "\[Rule]", "305"}], ",", 
       RowBox[{"316", "\[Rule]", "327"}], ",", 
       RowBox[{"316", "\[Rule]", "317"}], ",", 
       RowBox[{"92", "\[Rule]", "81"}], ",", 
       RowBox[{"92", "\[Rule]", "103"}], ",", 
       RowBox[{"92", "\[Rule]", "93"}], ",", 
       RowBox[{"428", "\[Rule]", "417"}], ",", 
       RowBox[{"428", "\[Rule]", "439"}], ",", 
       RowBox[{"428", "\[Rule]", "429"}], ",", 
       RowBox[{"260", "\[Rule]", "249"}], ",", 
       RowBox[{"260", "\[Rule]", "271"}], ",", 
       RowBox[{"260", "\[Rule]", "261"}], ",", 
       RowBox[{"820", "\[Rule]", "809"}], ",", 
       RowBox[{"820", "\[Rule]", "831"}], ",", 
       RowBox[{"820", "\[Rule]", "821"}], ",", 
       RowBox[{"652", "\[Rule]", "641"}], ",", 
       RowBox[{"652", "\[Rule]", "663"}], ",", 
       RowBox[{"652", "\[Rule]", "653"}], ",", 
       RowBox[{"764", "\[Rule]", "753"}], ",", 
       RowBox[{"764", "\[Rule]", "775"}], ",", 
       RowBox[{"764", "\[Rule]", "765"}], ",", 
       RowBox[{"596", "\[Rule]", "585"}], ",", 
       RowBox[{"596", "\[Rule]", "607"}], ",", 
       RowBox[{"596", "\[Rule]", "597"}], ",", 
       RowBox[{"36", "\[Rule]", "25"}], ",", 
       RowBox[{"36", "\[Rule]", "47"}], ",", 
       RowBox[{"36", "\[Rule]", "37"}], ",", 
       RowBox[{"372", "\[Rule]", "361"}], ",", 
       RowBox[{"372", "\[Rule]", "383"}], ",", 
       RowBox[{"372", "\[Rule]", "373"}], ",", 
       RowBox[{"204", "\[Rule]", "193"}], ",", 
       RowBox[{"204", "\[Rule]", "215"}], ",", 
       RowBox[{"204", "\[Rule]", "205"}], ",", 
       RowBox[{"708", "\[Rule]", "697"}], ",", 
       RowBox[{"708", "\[Rule]", "719"}], ",", 
       RowBox[{"708", "\[Rule]", "709"}], ",", 
       RowBox[{"540", "\[Rule]", "529"}], ",", 
       RowBox[{"540", "\[Rule]", "551"}], ",", 
       RowBox[{"540", "\[Rule]", "541"}], ",", 
       RowBox[{"158", "\[Rule]", "159"}], ",", 
       RowBox[{"494", "\[Rule]", "495"}], ",", 
       RowBox[{"326", "\[Rule]", "327"}], ",", 
       RowBox[{"102", "\[Rule]", "103"}], ",", 
       RowBox[{"438", "\[Rule]", "439"}], ",", 
       RowBox[{"270", "\[Rule]", "271"}], ",", 
       RowBox[{"830", "\[Rule]", "831"}], ",", 
       RowBox[{"662", "\[Rule]", "663"}], ",", 
       RowBox[{"774", "\[Rule]", "775"}], ",", 
       RowBox[{"606", "\[Rule]", "607"}], ",", 
       RowBox[{"46", "\[Rule]", "47"}], ",", 
       RowBox[{"382", "\[Rule]", "383"}], ",", 
       RowBox[{"214", "\[Rule]", "215"}], ",", 
       RowBox[{"718", "\[Rule]", "719"}], ",", 
       RowBox[{"550", "\[Rule]", "551"}], ",", 
       RowBox[{"291", "\[Rule]", "124"}], ",", 
       RowBox[{"291", "\[Rule]", "460"}], ",", 
       RowBox[{"291", "\[Rule]", "460"}], ",", 
       RowBox[{"291", "\[Rule]", "292"}], ",", 
       RowBox[{"313", "\[Rule]", "146"}], ",", 
       RowBox[{"313", "\[Rule]", "146"}], ",", 
       RowBox[{"313", "\[Rule]", "482"}], ",", 
       RowBox[{"313", "\[Rule]", "314"}], ",", 
       RowBox[{"299", "\[Rule]", "132"}], ",", 
       RowBox[{"299", "\[Rule]", "468"}], ",", 
       RowBox[{"299", "\[Rule]", "300"}], ",", 
       RowBox[{"119", "\[Rule]", "288"}], ",", 
       RowBox[{"119", "\[Rule]", "288"}], ",", 
       RowBox[{"119", "\[Rule]", "232"}], ",", 
       RowBox[{"119", "\[Rule]", "120"}], ",", 
       RowBox[{"455", "\[Rule]", "288"}], ",", 
       RowBox[{"455", "\[Rule]", "288"}], ",", 
       RowBox[{"455", "\[Rule]", "624"}], ",", 
       RowBox[{"455", "\[Rule]", "624"}], ",", 
       RowBox[{"455", "\[Rule]", "232"}], ",", 
       RowBox[{"455", "\[Rule]", "232"}], ",", 
       RowBox[{"455", "\[Rule]", "568"}], ",", 
       RowBox[{"455", "\[Rule]", "568"}], ",", 
       RowBox[{"455", "\[Rule]", "456"}], ",", 
       RowBox[{"287", "\[Rule]", "120"}], ",", 
       RowBox[{"287", "\[Rule]", "120"}], ",", 
       RowBox[{"287", "\[Rule]", "456"}], ",", 
       RowBox[{"287", "\[Rule]", "456"}], ",", 
       RowBox[{"287", "\[Rule]", "288"}], ",", 
       RowBox[{"63", "\[Rule]", "176"}], ",", 
       RowBox[{"63", "\[Rule]", "64"}], ",", 
       RowBox[{"399", "\[Rule]", "232"}], ",", 
       RowBox[{"399", "\[Rule]", "568"}], ",", 
       RowBox[{"399", "\[Rule]", "568"}], ",", 
       RowBox[{"399", "\[Rule]", "176"}], ",", 
       RowBox[{"399", "\[Rule]", "512"}], ",", 
       RowBox[{"399", "\[Rule]", "512"}], ",", 
       RowBox[{"399", "\[Rule]", "400"}], ",", 
       RowBox[{"231", "\[Rule]", "120"}], ",", 
       RowBox[{"231", "\[Rule]", "456"}], ",", 
       RowBox[{"231", "\[Rule]", "456"}], ",", 
       RowBox[{"231", "\[Rule]", "400"}], ",", 
       RowBox[{"231", "\[Rule]", "232"}], ",", 
       RowBox[{"335", "\[Rule]", "168"}], ",", 
       RowBox[{"335", "\[Rule]", "168"}], ",", 
       RowBox[{"335", "\[Rule]", "504"}], ",", 
       RowBox[{"335", "\[Rule]", "504"}], ",", 
       RowBox[{"335", "\[Rule]", "336"}], ",", 
       RowBox[{"321", "\[Rule]", "154"}], ",", 
       RowBox[{"321", "\[Rule]", "154"}], ",", 
       RowBox[{"321", "\[Rule]", "490"}], ",", 
       RowBox[{"321", "\[Rule]", "490"}], ",", 
       RowBox[{"321", "\[Rule]", "322"}], ",", 
       RowBox[{"309", "\[Rule]", "142"}], ",", 
       RowBox[{"309", "\[Rule]", "142"}], ",", 
       RowBox[{"309", "\[Rule]", "478"}], ",", 
       RowBox[{"309", "\[Rule]", "478"}], ",", 
       RowBox[{"309", "\[Rule]", "310"}], ",", 
       RowBox[{"627", "\[Rule]", "460"}], ",", 
       RowBox[{"627", "\[Rule]", "460"}], ",", 
       RowBox[{"627", "\[Rule]", "796"}], ",", 
       RowBox[{"627", "\[Rule]", "796"}], ",", 
       RowBox[{"627", "\[Rule]", "628"}], ",", 
       RowBox[{"649", "\[Rule]", "482"}], ",", 
       RowBox[{"649", "\[Rule]", "818"}], ",", 
       RowBox[{"649", "\[Rule]", "818"}], ",", 
       RowBox[{"649", "\[Rule]", "650"}], ",", 
       RowBox[{"635", "\[Rule]", "468"}], ",", 
       RowBox[{"635", "\[Rule]", "468"}], ",", 
       RowBox[{"635", "\[Rule]", "804"}], ",", 
       RowBox[{"635", "\[Rule]", "804"}], ",", 
       RowBox[{"635", "\[Rule]", "636"}], ",", 
       RowBox[{"791", "\[Rule]", "624"}], ",", 
       RowBox[{"791", "\[Rule]", "624"}], ",", 
       RowBox[{"791", "\[Rule]", "568"}], ",", 
       RowBox[{"791", "\[Rule]", "568"}], ",", 
       RowBox[{"791", "\[Rule]", "792"}], ",", 
       RowBox[{"623", "\[Rule]", "456"}], ",", 
       RowBox[{"623", "\[Rule]", "456"}], ",", 
       RowBox[{"623", "\[Rule]", "792"}], ",", 
       RowBox[{"623", "\[Rule]", "792"}], ",", 
       RowBox[{"623", "\[Rule]", "624"}], ",", 
       RowBox[{"735", "\[Rule]", "568"}], ",", 
       RowBox[{"735", "\[Rule]", "568"}], ",", 
       RowBox[{"735", "\[Rule]", "512"}], ",", 
       RowBox[{"735", "\[Rule]", "512"}], ",", 
       RowBox[{"735", "\[Rule]", "736"}], ",", 
       RowBox[{"567", "\[Rule]", "456"}], ",", 
       RowBox[{"567", "\[Rule]", "456"}], ",", 
       RowBox[{"567", "\[Rule]", "792"}], ",", 
       RowBox[{"567", "\[Rule]", "792"}], ",", 
       RowBox[{"567", "\[Rule]", "400"}], ",", 
       RowBox[{"567", "\[Rule]", "400"}], ",", 
       RowBox[{"567", "\[Rule]", "736"}], ",", 
       RowBox[{"567", "\[Rule]", "736"}], ",", 
       RowBox[{"567", "\[Rule]", "568"}], ",", 
       RowBox[{"671", "\[Rule]", "504"}], ",", 
       RowBox[{"671", "\[Rule]", "504"}], ",", 
       RowBox[{"671", "\[Rule]", "840"}], ",", 
       RowBox[{"671", "\[Rule]", "672"}], ",", 
       RowBox[{"657", "\[Rule]", "490"}], ",", 
       RowBox[{"657", "\[Rule]", "826"}], ",", 
       RowBox[{"657", "\[Rule]", "658"}], ",", 
       RowBox[{"645", "\[Rule]", "478"}], ",", 
       RowBox[{"645", "\[Rule]", "478"}], ",", 
       RowBox[{"645", "\[Rule]", "814"}], ",", 
       RowBox[{"645", "\[Rule]", "814"}], ",", 
       RowBox[{"645", "\[Rule]", "646"}], ",", 
       RowBox[{"7", "\[Rule]", "176"}], ",", 
       RowBox[{"7", "\[Rule]", "176"}], ",", 
       RowBox[{"7", "\[Rule]", "8"}], ",", 
       RowBox[{"343", "\[Rule]", "176"}], ",", 
       RowBox[{"343", "\[Rule]", "176"}], ",", 
       RowBox[{"343", "\[Rule]", "512"}], ",", 
       RowBox[{"343", "\[Rule]", "344"}], ",", 
       RowBox[{"175", "\[Rule]", "64"}], ",", 
       RowBox[{"175", "\[Rule]", "400"}], ",", 
       RowBox[{"175", "\[Rule]", "8"}], ",", 
       RowBox[{"175", "\[Rule]", "8"}], ",", 
       RowBox[{"175", "\[Rule]", "344"}], ",", 
       RowBox[{"175", "\[Rule]", "344"}], ",", 
       RowBox[{"175", "\[Rule]", "176"}], ",", 
       RowBox[{"679", "\[Rule]", "512"}], ",", 
       RowBox[{"679", "\[Rule]", "680"}], ",", 
       RowBox[{"511", "\[Rule]", "400"}], ",", 
       RowBox[{"511", "\[Rule]", "400"}], ",", 
       RowBox[{"511", "\[Rule]", "736"}], ",", 
       RowBox[{"511", "\[Rule]", "736"}], ",", 
       RowBox[{"511", "\[Rule]", "344"}], ",", 
       RowBox[{"511", "\[Rule]", "680"}], ",", 
       RowBox[{"511", "\[Rule]", "512"}], ",", 
       RowBox[{"331", "\[Rule]", "164"}], ",", 
       RowBox[{"331", "\[Rule]", "164"}], ",", 
       RowBox[{"331", "\[Rule]", "500"}], ",", 
       RowBox[{"331", "\[Rule]", "500"}], ",", 
       RowBox[{"331", "\[Rule]", "332"}], ",", 
       RowBox[{"317", "\[Rule]", "150"}], ",", 
       RowBox[{"317", "\[Rule]", "150"}], ",", 
       RowBox[{"317", "\[Rule]", "486"}], ",", 
       RowBox[{"317", "\[Rule]", "486"}], ",", 
       RowBox[{"317", "\[Rule]", "318"}], ",", 
       RowBox[{"667", "\[Rule]", "500"}], ",", 
       RowBox[{"667", "\[Rule]", "500"}], ",", 
       RowBox[{"667", "\[Rule]", "836"}], ",", 
       RowBox[{"667", "\[Rule]", "836"}], ",", 
       RowBox[{"667", "\[Rule]", "668"}], ",", 
       RowBox[{"653", "\[Rule]", "486"}], ",", 
       RowBox[{"653", "\[Rule]", "486"}], ",", 
       RowBox[{"653", "\[Rule]", "822"}], ",", 
       RowBox[{"653", "\[Rule]", "822"}], ",", 
       RowBox[{"653", "\[Rule]", "654"}], ",", 
       RowBox[{"137", "\[Rule]", "306"}], ",", 
       RowBox[{"137", "\[Rule]", "306"}], ",", 
       RowBox[{"137", "\[Rule]", "250"}], ",", 
       RowBox[{"137", "\[Rule]", "250"}], ",", 
       RowBox[{"137", "\[Rule]", "138"}], ",", 
       RowBox[{"473", "\[Rule]", "306"}], ",", 
       RowBox[{"473", "\[Rule]", "306"}], ",", 
       RowBox[{"473", "\[Rule]", "642"}], ",", 
       RowBox[{"473", "\[Rule]", "642"}], ",", 
       RowBox[{"473", "\[Rule]", "250"}], ",", 
       RowBox[{"473", "\[Rule]", "250"}], ",", 
       RowBox[{"473", "\[Rule]", "586"}], ",", 
       RowBox[{"473", "\[Rule]", "586"}], ",", 
       RowBox[{"473", "\[Rule]", "474"}], ",", 
       RowBox[{"305", "\[Rule]", "138"}], ",", 
       RowBox[{"305", "\[Rule]", "138"}], ",", 
       RowBox[{"305", "\[Rule]", "474"}], ",", 
       RowBox[{"305", "\[Rule]", "474"}], ",", 
       RowBox[{"305", "\[Rule]", "306"}], ",", 
       RowBox[{"81", "\[Rule]", "250"}], ",", 
       RowBox[{"81", "\[Rule]", "194"}], ",", 
       RowBox[{"81", "\[Rule]", "82"}], ",", 
       RowBox[{"417", "\[Rule]", "250"}], ",", 
       RowBox[{"417", "\[Rule]", "586"}], ",", 
       RowBox[{"417", "\[Rule]", "586"}], ",", 
       RowBox[{"417", "\[Rule]", "530"}], ",", 
       RowBox[{"417", "\[Rule]", "418"}], ",", 
       RowBox[{"249", "\[Rule]", "138"}], ",", 
       RowBox[{"249", "\[Rule]", "138"}], ",", 
       RowBox[{"249", "\[Rule]", "474"}], ",", 
       RowBox[{"249", "\[Rule]", "474"}], ",", 
       RowBox[{"249", "\[Rule]", "82"}], ",", 
       RowBox[{"249", "\[Rule]", "418"}], ",", 
       RowBox[{"249", "\[Rule]", "250"}], ",", 
       RowBox[{"809", "\[Rule]", "642"}], ",", 
       RowBox[{"809", "\[Rule]", "642"}], ",", 
       RowBox[{"809", "\[Rule]", "586"}], ",", 
       RowBox[{"809", "\[Rule]", "586"}], ",", 
       RowBox[{"809", "\[Rule]", "810"}], ",", 
       RowBox[{"641", "\[Rule]", "474"}], ",", 
       RowBox[{"641", "\[Rule]", "474"}], ",", 
       RowBox[{"641", "\[Rule]", "810"}], ",", 
       RowBox[{"641", "\[Rule]", "810"}], ",", 
       RowBox[{"641", "\[Rule]", "642"}], ",", 
       RowBox[{"753", "\[Rule]", "586"}], ",", 
       RowBox[{"753", "\[Rule]", "586"}], ",", 
       RowBox[{"753", "\[Rule]", "530"}], ",", 
       RowBox[{"753", "\[Rule]", "530"}], ",", 
       RowBox[{"753", "\[Rule]", "754"}], ",", 
       RowBox[{"585", "\[Rule]", "474"}], ",", 
       RowBox[{"585", "\[Rule]", "474"}], ",", 
       RowBox[{"585", "\[Rule]", "810"}], ",", 
       RowBox[{"585", "\[Rule]", "810"}], ",", 
       RowBox[{"585", "\[Rule]", "418"}], ",", 
       RowBox[{"585", "\[Rule]", "418"}], ",", 
       RowBox[{"585", "\[Rule]", "754"}], ",", 
       RowBox[{"585", "\[Rule]", "754"}], ",", 
       RowBox[{"585", "\[Rule]", "586"}], ",", 
       RowBox[{"25", "\[Rule]", "194"}], ",", 
       RowBox[{"25", "\[Rule]", "194"}], ",", 
       RowBox[{"25", "\[Rule]", "26"}], ",", 
       RowBox[{"361", "\[Rule]", "194"}], ",", 
       RowBox[{"361", "\[Rule]", "362"}], ",", 
       RowBox[{"193", "\[Rule]", "82"}], ",", 
       RowBox[{"193", "\[Rule]", "26"}], ",", 
       RowBox[{"193", "\[Rule]", "26"}], ",", 
       RowBox[{"193", "\[Rule]", "362"}], ",", 
       RowBox[{"193", "\[Rule]", "194"}], ",", 
       RowBox[{"697", "\[Rule]", "530"}], ",", 
       RowBox[{"697", "\[Rule]", "698"}], ",", 
       RowBox[{"529", "\[Rule]", "418"}], ",", 
       RowBox[{"529", "\[Rule]", "754"}], ",", 
       RowBox[{"529", "\[Rule]", "754"}], ",", 
       RowBox[{"529", "\[Rule]", "698"}], ",", 
       RowBox[{"529", "\[Rule]", "530"}], ",", 
       RowBox[{"327", "\[Rule]", "160"}], ",", 
       RowBox[{"327", "\[Rule]", "160"}], ",", 
       RowBox[{"327", "\[Rule]", "496"}], ",", 
       RowBox[{"327", "\[Rule]", "496"}], ",", 
       RowBox[{"327", "\[Rule]", "328"}], ",", 
       RowBox[{"663", "\[Rule]", "496"}], ",", 
       RowBox[{"663", "\[Rule]", "496"}], ",", 
       RowBox[{"663", "\[Rule]", "832"}], ",", 
       RowBox[{"663", "\[Rule]", "832"}], ",", 
       RowBox[{"663", "\[Rule]", "664"}], ",", 
       RowBox[{"288", "\[Rule]", "297"}], ",", 
       RowBox[{"288", "\[Rule]", "289"}], ",", 
       RowBox[{"288", "\[Rule]", "285"}], ",", 
       RowBox[{"232", "\[Rule]", "241"}], ",", 
       RowBox[{"232", "\[Rule]", "233"}], ",", 
       RowBox[{"232", "\[Rule]", "229"}], ",", 
       RowBox[{"120", "\[Rule]", "129"}], ",", 
       RowBox[{"120", "\[Rule]", "121"}], ",", 
       RowBox[{"120", "\[Rule]", "117"}], ",", 
       RowBox[{"624", "\[Rule]", "633"}], ",", 
       RowBox[{"624", "\[Rule]", "625"}], ",", 
       RowBox[{"624", "\[Rule]", "621"}], ",", 
       RowBox[{"568", "\[Rule]", "577"}], ",", 
       RowBox[{"568", "\[Rule]", "569"}], ",", 
       RowBox[{"568", "\[Rule]", "565"}], ",", 
       RowBox[{"456", "\[Rule]", "465"}], ",", 
       RowBox[{"456", "\[Rule]", "457"}], ",", 
       RowBox[{"456", "\[Rule]", "453"}], ",", 
       RowBox[{"176", "\[Rule]", "185"}], ",", 
       RowBox[{"176", "\[Rule]", "177"}], ",", 
       RowBox[{"176", "\[Rule]", "173"}], ",", 
       RowBox[{"64", "\[Rule]", "73"}], ",", 
       RowBox[{"64", "\[Rule]", "65"}], ",", 
       RowBox[{"64", "\[Rule]", "61"}], ",", 
       RowBox[{"512", "\[Rule]", "521"}], ",", 
       RowBox[{"512", "\[Rule]", "513"}], ",", 
       RowBox[{"512", "\[Rule]", "509"}], ",", 
       RowBox[{"400", "\[Rule]", "409"}], ",", 
       RowBox[{"400", "\[Rule]", "401"}], ",", 
       RowBox[{"400", "\[Rule]", "397"}], ",", 
       RowBox[{"792", "\[Rule]", "801"}], ",", 
       RowBox[{"792", "\[Rule]", "793"}], ",", 
       RowBox[{"792", "\[Rule]", "789"}], ",", 
       RowBox[{"736", "\[Rule]", "745"}], ",", 
       RowBox[{"736", "\[Rule]", "737"}], ",", 
       RowBox[{"736", "\[Rule]", "733"}], ",", 
       RowBox[{"8", "\[Rule]", "17"}], ",", 
       RowBox[{"8", "\[Rule]", "9"}], ",", 
       RowBox[{"8", "\[Rule]", "5"}], ",", 
       RowBox[{"344", "\[Rule]", "353"}], ",", 
       RowBox[{"344", "\[Rule]", "345"}], ",", 
       RowBox[{"344", "\[Rule]", "341"}], ",", 
       RowBox[{"680", "\[Rule]", "689"}], ",", 
       RowBox[{"680", "\[Rule]", "681"}], ",", 
       RowBox[{"680", "\[Rule]", "677"}], ",", 
       RowBox[{"306", "\[Rule]", "295"}], ",", 
       RowBox[{"306", "\[Rule]", "315"}], ",", 
       RowBox[{"306", "\[Rule]", "307"}], ",", 
       RowBox[{"306", "\[Rule]", "303"}], ",", 
       RowBox[{"250", "\[Rule]", "239"}], ",", 
       RowBox[{"250", "\[Rule]", "259"}], ",", 
       RowBox[{"250", "\[Rule]", "251"}], ",", 
       RowBox[{"250", "\[Rule]", "247"}], ",", 
       RowBox[{"138", "\[Rule]", "127"}], ",", 
       RowBox[{"138", "\[Rule]", "147"}], ",", 
       RowBox[{"138", "\[Rule]", "139"}], ",", 
       RowBox[{"138", "\[Rule]", "135"}], ",", 
       RowBox[{"642", "\[Rule]", "631"}], ",", 
       RowBox[{"642", "\[Rule]", "651"}], ",", 
       RowBox[{"642", "\[Rule]", "643"}], ",", 
       RowBox[{"642", "\[Rule]", "639"}], ",", 
       RowBox[{"586", "\[Rule]", "575"}], ",", 
       RowBox[{"586", "\[Rule]", "595"}], ",", 
       RowBox[{"586", "\[Rule]", "587"}], ",", 
       RowBox[{"586", "\[Rule]", "583"}], ",", 
       RowBox[{"474", "\[Rule]", "463"}], ",", 
       RowBox[{"474", "\[Rule]", "483"}], ",", 
       RowBox[{"474", "\[Rule]", "475"}], ",", 
       RowBox[{"474", "\[Rule]", "471"}], ",", 
       RowBox[{"194", "\[Rule]", "183"}], ",", 
       RowBox[{"194", "\[Rule]", "203"}], ",", 
       RowBox[{"194", "\[Rule]", "195"}], ",", 
       RowBox[{"194", "\[Rule]", "191"}], ",", 
       RowBox[{"82", "\[Rule]", "71"}], ",", 
       RowBox[{"82", "\[Rule]", "91"}], ",", 
       RowBox[{"82", "\[Rule]", "83"}], ",", 
       RowBox[{"82", "\[Rule]", "79"}], ",", 
       RowBox[{"530", "\[Rule]", "519"}], ",", 
       RowBox[{"530", "\[Rule]", "539"}], ",", 
       RowBox[{"530", "\[Rule]", "531"}], ",", 
       RowBox[{"530", "\[Rule]", "527"}], ",", 
       RowBox[{"418", "\[Rule]", "407"}], ",", 
       RowBox[{"418", "\[Rule]", "427"}], ",", 
       RowBox[{"418", "\[Rule]", "419"}], ",", 
       RowBox[{"418", "\[Rule]", "415"}], ",", 
       RowBox[{"810", "\[Rule]", "799"}], ",", 
       RowBox[{"810", "\[Rule]", "819"}], ",", 
       RowBox[{"810", "\[Rule]", "811"}], ",", 
       RowBox[{"810", "\[Rule]", "807"}], ",", 
       RowBox[{"754", "\[Rule]", "743"}], ",", 
       RowBox[{"754", "\[Rule]", "763"}], ",", 
       RowBox[{"754", "\[Rule]", "755"}], ",", 
       RowBox[{"754", "\[Rule]", "751"}], ",", 
       RowBox[{"26", "\[Rule]", "15"}], ",", 
       RowBox[{"26", "\[Rule]", "35"}], ",", 
       RowBox[{"26", "\[Rule]", "27"}], ",", 
       RowBox[{"26", "\[Rule]", "23"}], ",", 
       RowBox[{"362", "\[Rule]", "351"}], ",", 
       RowBox[{"362", "\[Rule]", "371"}], ",", 
       RowBox[{"362", "\[Rule]", "363"}], ",", 
       RowBox[{"362", "\[Rule]", "359"}], ",", 
       RowBox[{"698", "\[Rule]", "687"}], ",", 
       RowBox[{"698", "\[Rule]", "707"}], ",", 
       RowBox[{"698", "\[Rule]", "699"}], ",", 
       RowBox[{"698", "\[Rule]", "695"}], ",", 
       RowBox[{"285", "\[Rule]", "118"}], ",", 
       RowBox[{"285", "\[Rule]", "118"}], ",", 
       RowBox[{"285", "\[Rule]", "454"}], ",", 
       RowBox[{"285", "\[Rule]", "454"}], ",", 
       RowBox[{"285", "\[Rule]", "286"}], ",", 
       RowBox[{"229", "\[Rule]", "118"}], ",", 
       RowBox[{"229", "\[Rule]", "118"}], ",", 
       RowBox[{"229", "\[Rule]", "454"}], ",", 
       RowBox[{"229", "\[Rule]", "454"}], ",", 
       RowBox[{"229", "\[Rule]", "62"}], ",", 
       RowBox[{"229", "\[Rule]", "398"}], ",", 
       RowBox[{"229", "\[Rule]", "230"}], ",", 
       RowBox[{"117", "\[Rule]", "286"}], ",", 
       RowBox[{"117", "\[Rule]", "286"}], ",", 
       RowBox[{"117", "\[Rule]", "230"}], ",", 
       RowBox[{"117", "\[Rule]", "230"}], ",", 
       RowBox[{"117", "\[Rule]", "118"}], ",", 
       RowBox[{"621", "\[Rule]", "454"}], ",", 
       RowBox[{"621", "\[Rule]", "454"}], ",", 
       RowBox[{"621", "\[Rule]", "790"}], ",", 
       RowBox[{"621", "\[Rule]", "790"}], ",", 
       RowBox[{"621", "\[Rule]", "622"}], ",", 
       RowBox[{"565", "\[Rule]", "454"}], ",", 
       RowBox[{"565", "\[Rule]", "454"}], ",", 
       RowBox[{"565", "\[Rule]", "790"}], ",", 
       RowBox[{"565", "\[Rule]", "790"}], ",", 
       RowBox[{"565", "\[Rule]", "398"}], ",", 
       RowBox[{"565", "\[Rule]", "398"}], ",", 
       RowBox[{"565", "\[Rule]", "734"}], ",", 
       RowBox[{"565", "\[Rule]", "734"}], ",", 
       RowBox[{"565", "\[Rule]", "566"}], ",", 
       RowBox[{"453", "\[Rule]", "286"}], ",", 
       RowBox[{"453", "\[Rule]", "286"}], ",", 
       RowBox[{"453", "\[Rule]", "622"}], ",", 
       RowBox[{"453", "\[Rule]", "622"}], ",", 
       RowBox[{"453", "\[Rule]", "230"}], ",", 
       RowBox[{"453", "\[Rule]", "230"}], ",", 
       RowBox[{"453", "\[Rule]", "566"}], ",", 
       RowBox[{"453", "\[Rule]", "566"}], ",", 
       RowBox[{"453", "\[Rule]", "454"}], ",", 
       RowBox[{"173", "\[Rule]", "62"}], ",", 
       RowBox[{"173", "\[Rule]", "398"}], ",", 
       RowBox[{"173", "\[Rule]", "6"}], ",", 
       RowBox[{"173", "\[Rule]", "6"}], ",", 
       RowBox[{"173", "\[Rule]", "342"}], ",", 
       RowBox[{"173", "\[Rule]", "342"}], ",", 
       RowBox[{"173", "\[Rule]", "174"}], ",", 
       RowBox[{"61", "\[Rule]", "230"}], ",", 
       RowBox[{"61", "\[Rule]", "174"}], ",", 
       RowBox[{"61", "\[Rule]", "62"}], ",", 
       RowBox[{"509", "\[Rule]", "398"}], ",", 
       RowBox[{"509", "\[Rule]", "398"}], ",", 
       RowBox[{"509", "\[Rule]", "734"}], ",", 
       RowBox[{"509", "\[Rule]", "734"}], ",", 
       RowBox[{"509", "\[Rule]", "342"}], ",", 
       RowBox[{"509", "\[Rule]", "678"}], ",", 
       RowBox[{"509", "\[Rule]", "510"}], ",", 
       RowBox[{"397", "\[Rule]", "230"}], ",", 
       RowBox[{"397", "\[Rule]", "566"}], ",", 
       RowBox[{"397", "\[Rule]", "566"}], ",", 
       RowBox[{"397", "\[Rule]", "174"}], ",", 
       RowBox[{"397", "\[Rule]", "510"}], ",", 
       RowBox[{"397", "\[Rule]", "510"}], ",", 
       RowBox[{"397", "\[Rule]", "398"}], ",", 
       RowBox[{"789", "\[Rule]", "622"}], ",", 
       RowBox[{"789", "\[Rule]", "622"}], ",", 
       RowBox[{"789", "\[Rule]", "566"}], ",", 
       RowBox[{"789", "\[Rule]", "566"}], ",", 
       RowBox[{"789", "\[Rule]", "790"}], ",", 
       RowBox[{"733", "\[Rule]", "566"}], ",", 
       RowBox[{"733", "\[Rule]", "566"}], ",", 
       RowBox[{"733", "\[Rule]", "510"}], ",", 
       RowBox[{"733", "\[Rule]", "510"}], ",", 
       RowBox[{"733", "\[Rule]", "734"}], ",", 
       RowBox[{"5", "\[Rule]", "174"}], ",", 
       RowBox[{"5", "\[Rule]", "174"}], ",", 
       RowBox[{"5", "\[Rule]", "6"}], ",", 
       RowBox[{"341", "\[Rule]", "174"}], ",", 
       RowBox[{"341", "\[Rule]", "174"}], ",", 
       RowBox[{"341", "\[Rule]", "510"}], ",", 
       RowBox[{"341", "\[Rule]", "342"}], ",", 
       RowBox[{"677", "\[Rule]", "510"}], ",", 
       RowBox[{"677", "\[Rule]", "678"}], ",", 
       RowBox[{"295", "\[Rule]", "128"}], ",", 
       RowBox[{"295", "\[Rule]", "128"}], ",", 
       RowBox[{"295", "\[Rule]", "464"}], ",", 
       RowBox[{"295", "\[Rule]", "464"}], ",", 
       RowBox[{"295", "\[Rule]", "296"}], ",", 
       RowBox[{"303", "\[Rule]", "136"}], ",", 
       RowBox[{"303", "\[Rule]", "136"}], ",", 
       RowBox[{"303", "\[Rule]", "472"}], ",", 
       RowBox[{"303", "\[Rule]", "472"}], ",", 
       RowBox[{"303", "\[Rule]", "304"}], ",", 
       RowBox[{"239", "\[Rule]", "128"}], ",", 
       RowBox[{"239", "\[Rule]", "128"}], ",", 
       RowBox[{"239", "\[Rule]", "464"}], ",", 
       RowBox[{"239", "\[Rule]", "464"}], ",", 
       RowBox[{"239", "\[Rule]", "72"}], ",", 
       RowBox[{"239", "\[Rule]", "408"}], ",", 
       RowBox[{"239", "\[Rule]", "240"}], ",", 
       RowBox[{"247", "\[Rule]", "136"}], ",", 
       RowBox[{"247", "\[Rule]", "136"}], ",", 
       RowBox[{"247", "\[Rule]", "472"}], ",", 
       RowBox[{"247", "\[Rule]", "472"}], ",", 
       RowBox[{"247", "\[Rule]", "80"}], ",", 
       RowBox[{"247", "\[Rule]", "416"}], ",", 
       RowBox[{"247", "\[Rule]", "248"}], ",", 
       RowBox[{"127", "\[Rule]", "296"}], ",", 
       RowBox[{"127", "\[Rule]", "296"}], ",", 
       RowBox[{"127", "\[Rule]", "240"}], ",", 
       RowBox[{"127", "\[Rule]", "240"}], ",", 
       RowBox[{"127", "\[Rule]", "128"}], ",", 
       RowBox[{"135", "\[Rule]", "304"}], ",", 
       RowBox[{"135", "\[Rule]", "304"}], ",", 
       RowBox[{"135", "\[Rule]", "248"}], ",", 
       RowBox[{"135", "\[Rule]", "248"}], ",", 
       RowBox[{"135", "\[Rule]", "136"}], ",", 
       RowBox[{"631", "\[Rule]", "464"}], ",", 
       RowBox[{"631", "\[Rule]", "464"}], ",", 
       RowBox[{"631", "\[Rule]", "800"}], ",", 
       RowBox[{"631", "\[Rule]", "800"}], ",", 
       RowBox[{"631", "\[Rule]", "632"}], ",", 
       RowBox[{"639", "\[Rule]", "472"}], ",", 
       RowBox[{"639", "\[Rule]", "472"}], ",", 
       RowBox[{"639", "\[Rule]", "808"}], ",", 
       RowBox[{"639", "\[Rule]", "808"}], ",", 
       RowBox[{"639", "\[Rule]", "640"}], ",", 
       RowBox[{"575", "\[Rule]", "464"}], ",", 
       RowBox[{"575", "\[Rule]", "464"}], ",", 
       RowBox[{"575", "\[Rule]", "800"}], ",", 
       RowBox[{"575", "\[Rule]", "800"}], ",", 
       RowBox[{"575", "\[Rule]", "408"}], ",", 
       RowBox[{"575", "\[Rule]", "408"}], ",", 
       RowBox[{"575", "\[Rule]", "744"}], ",", 
       RowBox[{"575", "\[Rule]", "744"}], ",", 
       RowBox[{"575", "\[Rule]", "576"}], ",", 
       RowBox[{"583", "\[Rule]", "472"}], ",", 
       RowBox[{"583", "\[Rule]", "472"}], ",", 
       RowBox[{"583", "\[Rule]", "808"}], ",", 
       RowBox[{"583", "\[Rule]", "808"}], ",", 
       RowBox[{"583", "\[Rule]", "416"}], ",", 
       RowBox[{"583", "\[Rule]", "416"}], ",", 
       RowBox[{"583", "\[Rule]", "752"}], ",", 
       RowBox[{"583", "\[Rule]", "752"}], ",", 
       RowBox[{"583", "\[Rule]", "584"}], ",", 
       RowBox[{"463", "\[Rule]", "296"}], ",", 
       RowBox[{"463", "\[Rule]", "296"}], ",", 
       RowBox[{"463", "\[Rule]", "632"}], ",", 
       RowBox[{"463", "\[Rule]", "632"}], ",", 
       RowBox[{"463", "\[Rule]", "240"}], ",", 
       RowBox[{"463", "\[Rule]", "240"}], ",", 
       RowBox[{"463", "\[Rule]", "576"}], ",", 
       RowBox[{"463", "\[Rule]", "576"}], ",", 
       RowBox[{"463", "\[Rule]", "464"}], ",", 
       RowBox[{"471", "\[Rule]", "304"}], ",", 
       RowBox[{"471", "\[Rule]", "304"}], ",", 
       RowBox[{"471", "\[Rule]", "640"}], ",", 
       RowBox[{"471", "\[Rule]", "640"}], ",", 
       RowBox[{"471", "\[Rule]", "248"}], ",", 
       RowBox[{"471", "\[Rule]", "248"}], ",", 
       RowBox[{"471", "\[Rule]", "584"}], ",", 
       RowBox[{"471", "\[Rule]", "584"}], ",", 
       RowBox[{"471", "\[Rule]", "472"}], ",", 
       RowBox[{"183", "\[Rule]", "72"}], ",", 
       RowBox[{"183", "\[Rule]", "408"}], ",", 
       RowBox[{"183", "\[Rule]", "16"}], ",", 
       RowBox[{"183", "\[Rule]", "16"}], ",", 
       RowBox[{"183", "\[Rule]", "352"}], ",", 
       RowBox[{"183", "\[Rule]", "352"}], ",", 
       RowBox[{"183", "\[Rule]", "184"}], ",", 
       RowBox[{"191", "\[Rule]", "80"}], ",", 
       RowBox[{"191", "\[Rule]", "416"}], ",", 
       RowBox[{"191", "\[Rule]", "24"}], ",", 
       RowBox[{"191", "\[Rule]", "24"}], ",", 
       RowBox[{"191", "\[Rule]", "360"}], ",", 
       RowBox[{"191", "\[Rule]", "360"}], ",", 
       RowBox[{"191", "\[Rule]", "192"}], ",", 
       RowBox[{"71", "\[Rule]", "240"}], ",", 
       RowBox[{"71", "\[Rule]", "184"}], ",", 
       RowBox[{"71", "\[Rule]", "72"}], ",", 
       RowBox[{"79", "\[Rule]", "248"}], ",", 
       RowBox[{"79", "\[Rule]", "192"}], ",", 
       RowBox[{"79", "\[Rule]", "80"}], ",", 
       RowBox[{"519", "\[Rule]", "408"}], ",", 
       RowBox[{"519", "\[Rule]", "408"}], ",", 
       RowBox[{"519", "\[Rule]", "744"}], ",", 
       RowBox[{"519", "\[Rule]", "744"}], ",", 
       RowBox[{"519", "\[Rule]", "352"}], ",", 
       RowBox[{"519", "\[Rule]", "688"}], ",", 
       RowBox[{"519", "\[Rule]", "520"}], ",", 
       RowBox[{"527", "\[Rule]", "416"}], ",", 
       RowBox[{"527", "\[Rule]", "416"}], ",", 
       RowBox[{"527", "\[Rule]", "752"}], ",", 
       RowBox[{"527", "\[Rule]", "752"}], ",", 
       RowBox[{"527", "\[Rule]", "360"}], ",", 
       RowBox[{"527", "\[Rule]", "696"}], ",", 
       RowBox[{"527", "\[Rule]", "528"}], ",", 
       RowBox[{"407", "\[Rule]", "240"}], ",", 
       RowBox[{"407", "\[Rule]", "576"}], ",", 
       RowBox[{"407", "\[Rule]", "576"}], ",", 
       RowBox[{"407", "\[Rule]", "184"}], ",", 
       RowBox[{"407", "\[Rule]", "520"}], ",", 
       RowBox[{"407", "\[Rule]", "520"}], ",", 
       RowBox[{"407", "\[Rule]", "408"}], ",", 
       RowBox[{"415", "\[Rule]", "248"}], ",", 
       RowBox[{"415", "\[Rule]", "584"}], ",", 
       RowBox[{"415", "\[Rule]", "584"}], ",", 
       RowBox[{"415", "\[Rule]", "192"}], ",", 
       RowBox[{"415", "\[Rule]", "528"}], ",", 
       RowBox[{"415", "\[Rule]", "528"}], ",", 
       RowBox[{"415", "\[Rule]", "416"}], ",", 
       RowBox[{"799", "\[Rule]", "632"}], ",", 
       RowBox[{"799", "\[Rule]", "632"}], ",", 
       RowBox[{"799", "\[Rule]", "576"}], ",", 
       RowBox[{"799", "\[Rule]", "576"}], ",", 
       RowBox[{"799", "\[Rule]", "800"}], ",", 
       RowBox[{"807", "\[Rule]", "640"}], ",", 
       RowBox[{"807", "\[Rule]", "640"}], ",", 
       RowBox[{"807", "\[Rule]", "584"}], ",", 
       RowBox[{"807", "\[Rule]", "584"}], ",", 
       RowBox[{"807", "\[Rule]", "808"}], ",", 
       RowBox[{"743", "\[Rule]", "576"}], ",", 
       RowBox[{"743", "\[Rule]", "576"}], ",", 
       RowBox[{"743", "\[Rule]", "520"}], ",", 
       RowBox[{"743", "\[Rule]", "520"}], ",", 
       RowBox[{"743", "\[Rule]", "744"}], ",", 
       RowBox[{"751", "\[Rule]", "584"}], ",", 
       RowBox[{"751", "\[Rule]", "584"}], ",", 
       RowBox[{"751", "\[Rule]", "528"}], ",", 
       RowBox[{"751", "\[Rule]", "528"}], ",", 
       RowBox[{"751", "\[Rule]", "752"}], ",", 
       RowBox[{"15", "\[Rule]", "184"}], ",", 
       RowBox[{"15", "\[Rule]", "184"}], ",", 
       RowBox[{"15", "\[Rule]", "16"}], ",", 
       RowBox[{"23", "\[Rule]", "192"}], ",", 
       RowBox[{"23", "\[Rule]", "192"}], ",", 
       RowBox[{"23", "\[Rule]", "24"}], ",", 
       RowBox[{"351", "\[Rule]", "184"}], ",", 
       RowBox[{"351", "\[Rule]", "184"}], ",", 
       RowBox[{"351", "\[Rule]", "520"}], ",", 
       RowBox[{"351", "\[Rule]", "352"}], ",", 
       RowBox[{"359", "\[Rule]", "192"}], ",", 
       RowBox[{"359", "\[Rule]", "192"}], ",", 
       RowBox[{"359", "\[Rule]", "528"}], ",", 
       RowBox[{"359", "\[Rule]", "360"}], ",", 
       RowBox[{"687", "\[Rule]", "520"}], ",", 
       RowBox[{"687", "\[Rule]", "688"}], ",", 
       RowBox[{"695", "\[Rule]", "528"}], ",", 
       RowBox[{"695", "\[Rule]", "696"}], ",", 
       RowBox[{"118", "\[Rule]", "119"}], ",", 
       RowBox[{"118", "\[Rule]", "115"}], ",", 
       RowBox[{"454", "\[Rule]", "455"}], ",", 
       RowBox[{"454", "\[Rule]", "451"}], ",", 
       RowBox[{"286", "\[Rule]", "287"}], ",", 
       RowBox[{"286", "\[Rule]", "283"}], ",", 
       RowBox[{"62", "\[Rule]", "63"}], ",", 
       RowBox[{"62", "\[Rule]", "59"}], ",", 
       RowBox[{"398", "\[Rule]", "399"}], ",", 
       RowBox[{"398", "\[Rule]", "395"}], ",", 
       RowBox[{"230", "\[Rule]", "231"}], ",", 
       RowBox[{"230", "\[Rule]", "227"}], ",", 
       RowBox[{"790", "\[Rule]", "791"}], ",", 
       RowBox[{"790", "\[Rule]", "787"}], ",", 
       RowBox[{"622", "\[Rule]", "623"}], ",", 
       RowBox[{"622", "\[Rule]", "619"}], ",", 
       RowBox[{"734", "\[Rule]", "735"}], ",", 
       RowBox[{"734", "\[Rule]", "731"}], ",", 
       RowBox[{"566", "\[Rule]", "567"}], ",", 
       RowBox[{"566", "\[Rule]", "563"}], ",", 
       RowBox[{"6", "\[Rule]", "7"}], ",", 
       RowBox[{"6", "\[Rule]", "3"}], ",", 
       RowBox[{"342", "\[Rule]", "343"}], ",", 
       RowBox[{"342", "\[Rule]", "339"}], ",", 
       RowBox[{"174", "\[Rule]", "175"}], ",", 
       RowBox[{"174", "\[Rule]", "171"}], ",", 
       RowBox[{"678", "\[Rule]", "679"}], ",", 
       RowBox[{"678", "\[Rule]", "675"}], ",", 
       RowBox[{"510", "\[Rule]", "511"}], ",", 
       RowBox[{"510", "\[Rule]", "507"}], ",", 
       RowBox[{"128", "\[Rule]", "115"}], ",", 
       RowBox[{"128", "\[Rule]", "137"}], ",", 
       RowBox[{"128", "\[Rule]", "125"}], ",", 
       RowBox[{"464", "\[Rule]", "451"}], ",", 
       RowBox[{"464", "\[Rule]", "473"}], ",", 
       RowBox[{"464", "\[Rule]", "461"}], ",", 
       RowBox[{"296", "\[Rule]", "283"}], ",", 
       RowBox[{"296", "\[Rule]", "305"}], ",", 
       RowBox[{"296", "\[Rule]", "293"}], ",", 
       RowBox[{"136", "\[Rule]", "125"}], ",", 
       RowBox[{"136", "\[Rule]", "137"}], ",", 
       RowBox[{"472", "\[Rule]", "461"}], ",", 
       RowBox[{"472", "\[Rule]", "473"}], ",", 
       RowBox[{"304", "\[Rule]", "293"}], ",", 
       RowBox[{"304", "\[Rule]", "305"}], ",", 
       RowBox[{"72", "\[Rule]", "59"}], ",", 
       RowBox[{"72", "\[Rule]", "81"}], ",", 
       RowBox[{"72", "\[Rule]", "69"}], ",", 
       RowBox[{"408", "\[Rule]", "395"}], ",", 
       RowBox[{"408", "\[Rule]", "417"}], ",", 
       RowBox[{"408", "\[Rule]", "405"}], ",", 
       RowBox[{"240", "\[Rule]", "227"}], ",", 
       RowBox[{"240", "\[Rule]", "249"}], ",", 
       RowBox[{"240", "\[Rule]", "237"}], ",", 
       RowBox[{"80", "\[Rule]", "69"}], ",", 
       RowBox[{"80", "\[Rule]", "81"}], ",", 
       RowBox[{"416", "\[Rule]", "405"}], ",", 
       RowBox[{"416", "\[Rule]", "417"}], ",", 
       RowBox[{"248", "\[Rule]", "237"}], ",", 
       RowBox[{"248", "\[Rule]", "249"}], ",", 
       RowBox[{"800", "\[Rule]", "787"}], ",", 
       RowBox[{"800", "\[Rule]", "809"}], ",", 
       RowBox[{"800", "\[Rule]", "797"}], ",", 
       RowBox[{"632", "\[Rule]", "619"}], ",", 
       RowBox[{"632", "\[Rule]", "641"}], ",", 
       RowBox[{"632", "\[Rule]", "629"}], ",", 
       RowBox[{"808", "\[Rule]", "797"}], ",", 
       RowBox[{"808", "\[Rule]", "809"}], ",", 
       RowBox[{"640", "\[Rule]", "629"}], ",", 
       RowBox[{"640", "\[Rule]", "641"}], ",", 
       RowBox[{"744", "\[Rule]", "731"}], ",", 
       RowBox[{"744", "\[Rule]", "753"}], ",", 
       RowBox[{"744", "\[Rule]", "741"}], ",", 
       RowBox[{"576", "\[Rule]", "563"}], ",", 
       RowBox[{"576", "\[Rule]", "585"}], ",", 
       RowBox[{"576", "\[Rule]", "573"}], ",", 
       RowBox[{"752", "\[Rule]", "741"}], ",", 
       RowBox[{"752", "\[Rule]", "753"}], ",", 
       RowBox[{"584", "\[Rule]", "573"}], ",", 
       RowBox[{"584", "\[Rule]", "585"}], ",", 
       RowBox[{"16", "\[Rule]", "3"}], ",", 
       RowBox[{"16", "\[Rule]", "25"}], ",", 
       RowBox[{"16", "\[Rule]", "13"}], ",", 
       RowBox[{"352", "\[Rule]", "339"}], ",", 
       RowBox[{"352", "\[Rule]", "361"}], ",", 
       RowBox[{"352", "\[Rule]", "349"}], ",", 
       RowBox[{"184", "\[Rule]", "171"}], ",", 
       RowBox[{"184", "\[Rule]", "193"}], ",", 
       RowBox[{"184", "\[Rule]", "181"}], ",", 
       RowBox[{"24", "\[Rule]", "13"}], ",", 
       RowBox[{"24", "\[Rule]", "25"}], ",", 
       RowBox[{"360", "\[Rule]", "349"}], ",", 
       RowBox[{"360", "\[Rule]", "361"}], ",", 
       RowBox[{"192", "\[Rule]", "181"}], ",", 
       RowBox[{"192", "\[Rule]", "193"}], ",", 
       RowBox[{"688", "\[Rule]", "675"}], ",", 
       RowBox[{"688", "\[Rule]", "697"}], ",", 
       RowBox[{"688", "\[Rule]", "685"}], ",", 
       RowBox[{"520", "\[Rule]", "507"}], ",", 
       RowBox[{"520", "\[Rule]", "529"}], ",", 
       RowBox[{"520", "\[Rule]", "517"}], ",", 
       RowBox[{"696", "\[Rule]", "685"}], ",", 
       RowBox[{"696", "\[Rule]", "697"}], ",", 
       RowBox[{"528", "\[Rule]", "517"}], ",", 
       RowBox[{"528", "\[Rule]", "529"}], ",", 
       RowBox[{"115", "\[Rule]", "284"}], ",", 
       RowBox[{"115", "\[Rule]", "284"}], ",", 
       RowBox[{"115", "\[Rule]", "228"}], ",", 
       RowBox[{"115", "\[Rule]", "228"}], ",", 
       RowBox[{"115", "\[Rule]", "116"}], ",", 
       RowBox[{"451", "\[Rule]", "284"}], ",", 
       RowBox[{"451", "\[Rule]", "284"}], ",", 
       RowBox[{"451", "\[Rule]", "620"}], ",", 
       RowBox[{"451", "\[Rule]", "620"}], ",", 
       RowBox[{"451", "\[Rule]", "228"}], ",", 
       RowBox[{"451", "\[Rule]", "228"}], ",", 
       RowBox[{"451", "\[Rule]", "564"}], ",", 
       RowBox[{"451", "\[Rule]", "564"}], ",", 
       RowBox[{"451", "\[Rule]", "452"}], ",", 
       RowBox[{"283", "\[Rule]", "116"}], ",", 
       RowBox[{"283", "\[Rule]", "116"}], ",", 
       RowBox[{"283", "\[Rule]", "452"}], ",", 
       RowBox[{"283", "\[Rule]", "452"}], ",", 
       RowBox[{"283", "\[Rule]", "284"}], ",", 
       RowBox[{"59", "\[Rule]", "228"}], ",", 
       RowBox[{"59", "\[Rule]", "60"}], ",", 
       RowBox[{"395", "\[Rule]", "228"}], ",", 
       RowBox[{"395", "\[Rule]", "564"}], ",", 
       RowBox[{"395", "\[Rule]", "564"}], ",", 
       RowBox[{"395", "\[Rule]", "172"}], ",", 
       RowBox[{"395", "\[Rule]", "508"}], ",", 
       RowBox[{"395", "\[Rule]", "508"}], ",", 
       RowBox[{"395", "\[Rule]", "396"}], ",", 
       RowBox[{"227", "\[Rule]", "116"}], ",", 
       RowBox[{"227", "\[Rule]", "116"}], ",", 
       RowBox[{"227", "\[Rule]", "452"}], ",", 
       RowBox[{"227", "\[Rule]", "452"}], ",", 
       RowBox[{"227", "\[Rule]", "60"}], ",", 
       RowBox[{"227", "\[Rule]", "396"}], ",", 
       RowBox[{"227", "\[Rule]", "228"}], ",", 
       RowBox[{"787", "\[Rule]", "620"}], ",", 
       RowBox[{"787", "\[Rule]", "620"}], ",", 
       RowBox[{"787", "\[Rule]", "564"}], ",", 
       RowBox[{"787", "\[Rule]", "564"}], ",", 
       RowBox[{"787", "\[Rule]", "788"}], ",", 
       RowBox[{"619", "\[Rule]", "452"}], ",", 
       RowBox[{"619", "\[Rule]", "452"}], ",", 
       RowBox[{"619", "\[Rule]", "788"}], ",", 
       RowBox[{"619", "\[Rule]", "788"}], ",", 
       RowBox[{"619", "\[Rule]", "620"}], ",", 
       RowBox[{"731", "\[Rule]", "564"}], ",", 
       RowBox[{"731", "\[Rule]", "564"}], ",", 
       RowBox[{"731", "\[Rule]", "508"}], ",", 
       RowBox[{"731", "\[Rule]", "508"}], ",", 
       RowBox[{"731", "\[Rule]", "732"}], ",", 
       RowBox[{"563", "\[Rule]", "452"}], ",", 
       RowBox[{"563", "\[Rule]", "452"}], ",", 
       RowBox[{"563", "\[Rule]", "788"}], ",", 
       RowBox[{"563", "\[Rule]", "788"}], ",", 
       RowBox[{"563", "\[Rule]", "396"}], ",", 
       RowBox[{"563", "\[Rule]", "396"}], ",", 
       RowBox[{"563", "\[Rule]", "732"}], ",", 
       RowBox[{"563", "\[Rule]", "732"}], ",", 
       RowBox[{"563", "\[Rule]", "564"}], ",", 
       RowBox[{"3", "\[Rule]", "172"}], ",", 
       RowBox[{"3", "\[Rule]", "4"}], ",", 
       RowBox[{"339", "\[Rule]", "172"}], ",", 
       RowBox[{"339", "\[Rule]", "172"}], ",", 
       RowBox[{"339", "\[Rule]", "508"}], ",", 
       RowBox[{"339", "\[Rule]", "340"}], ",", 
       RowBox[{"171", "\[Rule]", "396"}], ",", 
       RowBox[{"171", "\[Rule]", "4"}], ",", 
       RowBox[{"171", "\[Rule]", "340"}], ",", 
       RowBox[{"171", "\[Rule]", "340"}], ",", 
       RowBox[{"171", "\[Rule]", "172"}], ",", 
       RowBox[{"675", "\[Rule]", "508"}], ",", 
       RowBox[{"675", "\[Rule]", "676"}], ",", 
       RowBox[{"507", "\[Rule]", "396"}], ",", 
       RowBox[{"507", "\[Rule]", "396"}], ",", 
       RowBox[{"507", "\[Rule]", "732"}], ",", 
       RowBox[{"507", "\[Rule]", "732"}], ",", 
       RowBox[{"507", "\[Rule]", "340"}], ",", 
       RowBox[{"507", "\[Rule]", "676"}], ",", 
       RowBox[{"507", "\[Rule]", "508"}], ",", 
       RowBox[{"125", "\[Rule]", "294"}], ",", 
       RowBox[{"125", "\[Rule]", "294"}], ",", 
       RowBox[{"125", "\[Rule]", "238"}], ",", 
       RowBox[{"125", "\[Rule]", "238"}], ",", 
       RowBox[{"125", "\[Rule]", "126"}], ",", 
       RowBox[{"461", "\[Rule]", "294"}], ",", 
       RowBox[{"461", "\[Rule]", "294"}], ",", 
       RowBox[{"461", "\[Rule]", "630"}], ",", 
       RowBox[{"461", "\[Rule]", "630"}], ",", 
       RowBox[{"461", "\[Rule]", "238"}], ",", 
       RowBox[{"461", "\[Rule]", "238"}], ",", 
       RowBox[{"461", "\[Rule]", "574"}], ",", 
       RowBox[{"461", "\[Rule]", "574"}], ",", 
       RowBox[{"461", "\[Rule]", "462"}], ",", 
       RowBox[{"293", "\[Rule]", "126"}], ",", 
       RowBox[{"293", "\[Rule]", "126"}], ",", 
       RowBox[{"293", "\[Rule]", "462"}], ",", 
       RowBox[{"293", "\[Rule]", "462"}], ",", 
       RowBox[{"293", "\[Rule]", "294"}], ",", 
       RowBox[{"69", "\[Rule]", "238"}], ",", 
       RowBox[{"69", "\[Rule]", "182"}], ",", 
       RowBox[{"69", "\[Rule]", "70"}], ",", 
       RowBox[{"405", "\[Rule]", "238"}], ",", 
       RowBox[{"405", "\[Rule]", "574"}], ",", 
       RowBox[{"405", "\[Rule]", "574"}], ",", 
       RowBox[{"405", "\[Rule]", "182"}], ",", 
       RowBox[{"405", "\[Rule]", "518"}], ",", 
       RowBox[{"405", "\[Rule]", "518"}], ",", 
       RowBox[{"405", "\[Rule]", "406"}], ",", 
       RowBox[{"237", "\[Rule]", "126"}], ",", 
       RowBox[{"237", "\[Rule]", "126"}], ",", 
       RowBox[{"237", "\[Rule]", "462"}], ",", 
       RowBox[{"237", "\[Rule]", "462"}], ",", 
       RowBox[{"237", "\[Rule]", "70"}], ",", 
       RowBox[{"237", "\[Rule]", "406"}], ",", 
       RowBox[{"237", "\[Rule]", "238"}], ",", 
       RowBox[{"797", "\[Rule]", "630"}], ",", 
       RowBox[{"797", "\[Rule]", "630"}], ",", 
       RowBox[{"797", "\[Rule]", "574"}], ",", 
       RowBox[{"797", "\[Rule]", "574"}], ",", 
       RowBox[{"797", "\[Rule]", "798"}], ",", 
       RowBox[{"629", "\[Rule]", "462"}], ",", 
       RowBox[{"629", "\[Rule]", "462"}], ",", 
       RowBox[{"629", "\[Rule]", "798"}], ",", 
       RowBox[{"629", "\[Rule]", "798"}], ",", 
       RowBox[{"629", "\[Rule]", "630"}], ",", 
       RowBox[{"741", "\[Rule]", "574"}], ",", 
       RowBox[{"741", "\[Rule]", "574"}], ",", 
       RowBox[{"741", "\[Rule]", "518"}], ",", 
       RowBox[{"741", "\[Rule]", "518"}], ",", 
       RowBox[{"741", "\[Rule]", "742"}], ",", 
       RowBox[{"573", "\[Rule]", "462"}], ",", 
       RowBox[{"573", "\[Rule]", "462"}], ",", 
       RowBox[{"573", "\[Rule]", "798"}], ",", 
       RowBox[{"573", "\[Rule]", "798"}], ",", 
       RowBox[{"573", "\[Rule]", "406"}], ",", 
       RowBox[{"573", "\[Rule]", "406"}], ",", 
       RowBox[{"573", "\[Rule]", "742"}], ",", 
       RowBox[{"573", "\[Rule]", "742"}], ",", 
       RowBox[{"573", "\[Rule]", "574"}], ",", 
       RowBox[{"13", "\[Rule]", "182"}], ",", 
       RowBox[{"13", "\[Rule]", "14"}], ",", 
       RowBox[{"349", "\[Rule]", "182"}], ",", 
       RowBox[{"349", "\[Rule]", "518"}], ",", 
       RowBox[{"349", "\[Rule]", "350"}], ",", 
       RowBox[{"181", "\[Rule]", "70"}], ",", 
       RowBox[{"181", "\[Rule]", "406"}], ",", 
       RowBox[{"181", "\[Rule]", "14"}], ",", 
       RowBox[{"181", "\[Rule]", "350"}], ",", 
       RowBox[{"181", "\[Rule]", "182"}], ",", 
       RowBox[{"685", "\[Rule]", "518"}], ",", 
       RowBox[{"685", "\[Rule]", "686"}], ",", 
       RowBox[{"517", "\[Rule]", "406"}], ",", 
       RowBox[{"517", "\[Rule]", "406"}], ",", 
       RowBox[{"517", "\[Rule]", "742"}], ",", 
       RowBox[{"517", "\[Rule]", "742"}], ",", 
       RowBox[{"517", "\[Rule]", "350"}], ",", 
       RowBox[{"517", "\[Rule]", "686"}], ",", 
       RowBox[{"517", "\[Rule]", "518"}], ",", 
       RowBox[{"284", "\[Rule]", "295"}], ",", 
       RowBox[{"284", "\[Rule]", "285"}], ",", 
       RowBox[{"284", "\[Rule]", "281"}], ",", 
       RowBox[{"228", "\[Rule]", "239"}], ",", 
       RowBox[{"228", "\[Rule]", "229"}], ",", 
       RowBox[{"228", "\[Rule]", "225"}], ",", 
       RowBox[{"116", "\[Rule]", "127"}], ",", 
       RowBox[{"116", "\[Rule]", "117"}], ",", 
       RowBox[{"116", "\[Rule]", "113"}], ",", 
       RowBox[{"620", "\[Rule]", "631"}], ",", 
       RowBox[{"620", "\[Rule]", "621"}], ",", 
       RowBox[{"620", "\[Rule]", "617"}], ",", 
       RowBox[{"564", "\[Rule]", "575"}], ",", 
       RowBox[{"564", "\[Rule]", "565"}], ",", 
       RowBox[{"564", "\[Rule]", "561"}], ",", 
       RowBox[{"452", "\[Rule]", "463"}], ",", 
       RowBox[{"452", "\[Rule]", "453"}], ",", 
       RowBox[{"452", "\[Rule]", "449"}], ",", 
       RowBox[{"60", "\[Rule]", "71"}], ",", 
       RowBox[{"60", "\[Rule]", "61"}], ",", 
       RowBox[{"60", "\[Rule]", "57"}], ",", 
       RowBox[{"172", "\[Rule]", "183"}], ",", 
       RowBox[{"172", "\[Rule]", "173"}], ",", 
       RowBox[{"172", "\[Rule]", "169"}], ",", 
       RowBox[{"508", "\[Rule]", "519"}], ",", 
       RowBox[{"508", "\[Rule]", "509"}], ",", 
       RowBox[{"508", "\[Rule]", "505"}], ",", 
       RowBox[{"396", "\[Rule]", "407"}], ",", 
       RowBox[{"396", "\[Rule]", "397"}], ",", 
       RowBox[{"396", "\[Rule]", "393"}], ",", 
       RowBox[{"788", "\[Rule]", "799"}], ",", 
       RowBox[{"788", "\[Rule]", "789"}], ",", 
       RowBox[{"788", "\[Rule]", "785"}], ",", 
       RowBox[{"732", "\[Rule]", "743"}], ",", 
       RowBox[{"732", "\[Rule]", "733"}], ",", 
       RowBox[{"732", "\[Rule]", "729"}], ",", 
       RowBox[{"4", "\[Rule]", "15"}], ",", 
       RowBox[{"4", "\[Rule]", "5"}], ",", 
       RowBox[{"4", "\[Rule]", "1"}], ",", 
       RowBox[{"340", "\[Rule]", "351"}], ",", 
       RowBox[{"340", "\[Rule]", "341"}], ",", 
       RowBox[{"340", "\[Rule]", "337"}], ",", 
       RowBox[{"676", "\[Rule]", "687"}], ",", 
       RowBox[{"676", "\[Rule]", "677"}], ",", 
       RowBox[{"676", "\[Rule]", "673"}], ",", 
       RowBox[{"294", "\[Rule]", "281"}], ",", 
       RowBox[{"294", "\[Rule]", "303"}], ",", 
       RowBox[{"294", "\[Rule]", "295"}], ",", 
       RowBox[{"238", "\[Rule]", "225"}], ",", 
       RowBox[{"238", "\[Rule]", "247"}], ",", 
       RowBox[{"238", "\[Rule]", "239"}], ",", 
       RowBox[{"126", "\[Rule]", "113"}], ",", 
       RowBox[{"126", "\[Rule]", "135"}], ",", 
       RowBox[{"126", "\[Rule]", "127"}], ",", 
       RowBox[{"630", "\[Rule]", "617"}], ",", 
       RowBox[{"630", "\[Rule]", "639"}], ",", 
       RowBox[{"630", "\[Rule]", "631"}], ",", 
       RowBox[{"574", "\[Rule]", "561"}], ",", 
       RowBox[{"574", "\[Rule]", "583"}], ",", 
       RowBox[{"574", "\[Rule]", "575"}], ",", 
       RowBox[{"462", "\[Rule]", "449"}], ",", 
       RowBox[{"462", "\[Rule]", "471"}], ",", 
       RowBox[{"462", "\[Rule]", "463"}], ",", 
       RowBox[{"182", "\[Rule]", "169"}], ",", 
       RowBox[{"182", "\[Rule]", "191"}], ",", 
       RowBox[{"182", "\[Rule]", "183"}], ",", 
       RowBox[{"70", "\[Rule]", "57"}], ",", 
       RowBox[{"70", "\[Rule]", "79"}], ",", 
       RowBox[{"70", "\[Rule]", "71"}], ",", 
       RowBox[{"518", "\[Rule]", "505"}], ",", 
       RowBox[{"518", "\[Rule]", "527"}], ",", 
       RowBox[{"518", "\[Rule]", "519"}], ",", 
       RowBox[{"406", "\[Rule]", "393"}], ",", 
       RowBox[{"406", "\[Rule]", "415"}], ",", 
       RowBox[{"406", "\[Rule]", "407"}], ",", 
       RowBox[{"798", "\[Rule]", "785"}], ",", 
       RowBox[{"798", "\[Rule]", "807"}], ",", 
       RowBox[{"798", "\[Rule]", "799"}], ",", 
       RowBox[{"742", "\[Rule]", "729"}], ",", 
       RowBox[{"742", "\[Rule]", "751"}], ",", 
       RowBox[{"742", "\[Rule]", "743"}], ",", 
       RowBox[{"14", "\[Rule]", "1"}], ",", 
       RowBox[{"14", "\[Rule]", "23"}], ",", 
       RowBox[{"14", "\[Rule]", "15"}], ",", 
       RowBox[{"350", "\[Rule]", "337"}], ",", 
       RowBox[{"350", "\[Rule]", "359"}], ",", 
       RowBox[{"350", "\[Rule]", "351"}], ",", 
       RowBox[{"686", "\[Rule]", "673"}], ",", 
       RowBox[{"686", "\[Rule]", "695"}], ",", 
       RowBox[{"686", "\[Rule]", "687"}], ",", 
       RowBox[{"281", "\[Rule]", "114"}], ",", 
       RowBox[{"281", "\[Rule]", "114"}], ",", 
       RowBox[{"281", "\[Rule]", "450"}], ",", 
       RowBox[{"281", "\[Rule]", "450"}], ",", 
       RowBox[{"281", "\[Rule]", "282"}], ",", 
       RowBox[{"225", "\[Rule]", "114"}], ",", 
       RowBox[{"225", "\[Rule]", "114"}], ",", 
       RowBox[{"225", "\[Rule]", "450"}], ",", 
       RowBox[{"225", "\[Rule]", "450"}], ",", 
       RowBox[{"225", "\[Rule]", "58"}], ",", 
       RowBox[{"225", "\[Rule]", "394"}], ",", 
       RowBox[{"225", "\[Rule]", "226"}], ",", 
       RowBox[{"113", "\[Rule]", "282"}], ",", 
       RowBox[{"113", "\[Rule]", "282"}], ",", 
       RowBox[{"113", "\[Rule]", "226"}], ",", 
       RowBox[{"113", "\[Rule]", "226"}], ",", 
       RowBox[{"113", "\[Rule]", "114"}], ",", 
       RowBox[{"617", "\[Rule]", "450"}], ",", 
       RowBox[{"617", "\[Rule]", "450"}], ",", 
       RowBox[{"617", "\[Rule]", "786"}], ",", 
       RowBox[{"617", "\[Rule]", "786"}], ",", 
       RowBox[{"617", "\[Rule]", "618"}], ",", 
       RowBox[{"561", "\[Rule]", "450"}], ",", 
       RowBox[{"561", "\[Rule]", "450"}], ",", 
       RowBox[{"561", "\[Rule]", "786"}], ",", 
       RowBox[{"561", "\[Rule]", "786"}], ",", 
       RowBox[{"561", "\[Rule]", "394"}], ",", 
       RowBox[{"561", "\[Rule]", "394"}], ",", 
       RowBox[{"561", "\[Rule]", "730"}], ",", 
       RowBox[{"561", "\[Rule]", "730"}], ",", 
       RowBox[{"561", "\[Rule]", "562"}], ",", 
       RowBox[{"449", "\[Rule]", "282"}], ",", 
       RowBox[{"449", "\[Rule]", "282"}], ",", 
       RowBox[{"449", "\[Rule]", "618"}], ",", 
       RowBox[{"449", "\[Rule]", "618"}], ",", 
       RowBox[{"449", "\[Rule]", "226"}], ",", 
       RowBox[{"449", "\[Rule]", "226"}], ",", 
       RowBox[{"449", "\[Rule]", "562"}], ",", 
       RowBox[{"449", "\[Rule]", "562"}], ",", 
       RowBox[{"449", "\[Rule]", "450"}], ",", 
       RowBox[{"57", "\[Rule]", "226"}], ",", 
       RowBox[{"57", "\[Rule]", "170"}], ",", 
       RowBox[{"57", "\[Rule]", "58"}], ",", 
       RowBox[{"169", "\[Rule]", "58"}], ",", 
       RowBox[{"169", "\[Rule]", "394"}], ",", 
       RowBox[{"169", "\[Rule]", "2"}], ",", 
       RowBox[{"169", "\[Rule]", "2"}], ",", 
       RowBox[{"169", "\[Rule]", "338"}], ",", 
       RowBox[{"169", "\[Rule]", "338"}], ",", 
       RowBox[{"169", "\[Rule]", "170"}], ",", 
       RowBox[{"505", "\[Rule]", "394"}], ",", 
       RowBox[{"505", "\[Rule]", "394"}], ",", 
       RowBox[{"505", "\[Rule]", "730"}], ",", 
       RowBox[{"505", "\[Rule]", "730"}], ",", 
       RowBox[{"505", "\[Rule]", "338"}], ",", 
       RowBox[{"505", "\[Rule]", "674"}], ",", 
       RowBox[{"505", "\[Rule]", "506"}], ",", 
       RowBox[{"393", "\[Rule]", "226"}], ",", 
       RowBox[{"393", "\[Rule]", "562"}], ",", 
       RowBox[{"393", "\[Rule]", "562"}], ",", 
       RowBox[{"393", "\[Rule]", "170"}], ",", 
       RowBox[{"393", "\[Rule]", "506"}], ",", 
       RowBox[{"393", "\[Rule]", "506"}], ",", 
       RowBox[{"393", "\[Rule]", "394"}], ",", 
       RowBox[{"785", "\[Rule]", "618"}], ",", 
       RowBox[{"785", "\[Rule]", "618"}], ",", 
       RowBox[{"785", "\[Rule]", "562"}], ",", 
       RowBox[{"785", "\[Rule]", "562"}], ",", 
       RowBox[{"785", "\[Rule]", "786"}], ",", 
       RowBox[{"729", "\[Rule]", "562"}], ",", 
       RowBox[{"729", "\[Rule]", "562"}], ",", 
       RowBox[{"729", "\[Rule]", "506"}], ",", 
       RowBox[{"729", "\[Rule]", "506"}], ",", 
       RowBox[{"729", "\[Rule]", "730"}], ",", 
       RowBox[{"1", "\[Rule]", "170"}], ",", 
       RowBox[{"1", "\[Rule]", "170"}], ",", 
       RowBox[{"1", "\[Rule]", "2"}], ",", 
       RowBox[{"337", "\[Rule]", "170"}], ",", 
       RowBox[{"337", "\[Rule]", "170"}], ",", 
       RowBox[{"337", "\[Rule]", "506"}], ",", 
       RowBox[{"337", "\[Rule]", "338"}], ",", 
       RowBox[{"673", "\[Rule]", "506"}], ",", 
       RowBox[{"673", "\[Rule]", "674"}], ",", 
       RowBox[{"114", "\[Rule]", "125"}], ",", 
       RowBox[{"114", "\[Rule]", "115"}], ",", 
       RowBox[{"450", "\[Rule]", "461"}], ",", 
       RowBox[{"450", "\[Rule]", "451"}], ",", 
       RowBox[{"282", "\[Rule]", "293"}], ",", 
       RowBox[{"282", "\[Rule]", "283"}], ",", 
       RowBox[{"58", "\[Rule]", "69"}], ",", 
       RowBox[{"58", "\[Rule]", "59"}], ",", 
       RowBox[{"394", "\[Rule]", "405"}], ",", 
       RowBox[{"394", "\[Rule]", "395"}], ",", 
       RowBox[{"226", "\[Rule]", "237"}], ",", 
       RowBox[{"226", "\[Rule]", "227"}], ",", 
       RowBox[{"786", "\[Rule]", "797"}], ",", 
       RowBox[{"786", "\[Rule]", "787"}], ",", 
       RowBox[{"618", "\[Rule]", "629"}], ",", 
       RowBox[{"618", "\[Rule]", "619"}], ",", 
       RowBox[{"730", "\[Rule]", "741"}], ",", 
       RowBox[{"730", "\[Rule]", "731"}], ",", 
       RowBox[{"562", "\[Rule]", "573"}], ",", 
       RowBox[{"562", "\[Rule]", "563"}], ",", 
       RowBox[{"170", "\[Rule]", "181"}], ",", 
       RowBox[{"170", "\[Rule]", "171"}], ",", 
       RowBox[{"2", "\[Rule]", "13"}], ",", 
       RowBox[{"2", "\[Rule]", "3"}], ",", 
       RowBox[{"338", "\[Rule]", "349"}], ",", 
       RowBox[{"338", "\[Rule]", "339"}], ",", 
       RowBox[{"674", "\[Rule]", "685"}], ",", 
       RowBox[{"674", "\[Rule]", "675"}], ",", 
       RowBox[{"506", "\[Rule]", "517"}], ",", 
       RowBox[{"506", "\[Rule]", "507"}]}], "}"}], ",", 
     RowBox[{"EdgeWeight", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "c", ",", "d", ",", "i", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "i", ",", "c", ",", "d", ",", "i", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "c", ",", "g", ",", "i", ",", "c", ",", "g", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", 
        "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "i", ",", "c", ",", "d", ",", "i", ",", 
        "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "d", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "g", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "b", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "e", ",", "f", ",", "g", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", 
        "g", ",", "i", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "f", ",", "i", ",", "c", ",", "d", ",", 
        "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "b", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "b", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", 
        "i", ",", "a", ",", "c", ",", "e", ",", "g", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "b", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "e", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "i", ",", "a", ",", "i", ",", "a", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "a", ",", "i", ",", "a", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "f", ",", "i", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "e", ",", "f", ",", "g", ",", "i", ",", 
        "a", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "e", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "a", ",", "i", ",", "b", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "b", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "f", ",", "i", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "b", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "i", ",", "a", ",", "i", ",", "a", ",", 
        "i", ",", "a", ",", "i", ",", "a", ",", "i", ",", "a", ",", "i", ",", 
        "a", ",", "i", ",", "a", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "i", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "e", ",", "g", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "i", ",", "f", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "g", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "g", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "i", ",", "f", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "b", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "b", ",", "i", ",", 
        "b", ",", "e", ",", "f", ",", "g", ",", "i", ",", "a", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "c", ",", 
        "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "c", ",", "d", ",", "i", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "i", ",", "a", ",", "i", ",", "a", ",", "i", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "c", ",", "d", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", 
        "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "i", ",", "a", ",", 
        "c", ",", "i", ",", "b", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "a", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "g", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", "i", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"init6", "=", 
   RowBox[{"{", "55", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bad6", "=", 
   RowBox[{"{", 
    RowBox[{
    "2", ",", "62", ",", "122", ",", "184", ",", "242", ",", "302", ",", 
     "360", ",", "420", ",", "480", ",", "540", ",", "600", ",", "660", ",", 
     "718", ",", "778", ",", "838", ",", "1", ",", "61", ",", "121", ",", 
     "183", ",", "241", ",", "301", ",", "359", ",", "419", ",", "479", ",", 
     "539", ",", "599", ",", "659", ",", "717", ",", "777", ",", "837"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lag6", "=", "13"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"graphical6", "=", "0"}], ";"}]}], "Input",
 CellChangeTimes->{{3.686025994957309*^9, 3.686026099831461*^9}, {
   3.6860261438122177`*^9, 3.686026176931148*^9}, 3.686026214223475*^9, {
   3.6860262647459717`*^9, 3.686026264982861*^9}, {3.686034622552107*^9, 
   3.686034628125643*^9}, {3.686046104270862*^9, 3.686046104850851*^9}, {
   3.686046154719606*^9, 3.686046158030952*^9}, 3.686047550621757*^9, {
   3.6930373931279917`*^9, 3.693037399556898*^9}, 3.693037472771635*^9, {
   3.693038158973789*^9, 3.6930381650361757`*^9}, {3.6930428123397503`*^9, 
   3.6930428231360483`*^9}, {3.693042919219357*^9, 3.6930429194085093`*^9}, {
   3.6930429516798887`*^9, 3.693042982121161*^9}, {3.693043077791449*^9, 
   3.69304309606213*^9}, 3.693043291196598*^9, 3.693043620502562*^9, {
   3.693044334417268*^9, 3.693044334984551*^9}, 3.693090945355526*^9, {
   3.69309202141042*^9, 3.6930920401067057`*^9}, {3.693093467244327*^9, 
   3.693093488693907*^9}, {3.6930969242492123`*^9, 3.693096982719348*^9}, {
   3.6930971376719913`*^9, 3.69309719866507*^9}, {3.6933835181102943`*^9, 
   3.69338351834798*^9}, 3.693388371642913*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"main", "[", 
  RowBox[{"g6", ",", "init6", ",", "bad6", ",", "lag6", ",", "graphical6"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6930430476106987`*^9, 3.693043058627466*^9}, {
  3.6930920447959757`*^9, 3.693092052345579*^9}, {3.6930935011457863`*^9, 
  3.6930935089531193`*^9}, {3.69309693897694*^9, 3.693096946943969*^9}}],

Cell[CellGroupData[{

Cell[BoxData["\<\"Under delay = 0 :\"\>"], "Print",
 CellChangeTimes->{3.694003307043482*^9, 3.694056011474036*^9, 
  3.6941478746297207`*^9, 3.714821095341061*^9}],

Cell[BoxData["\<\"(*hidden for the sake of space*)\"\>"], "Print",
 CellChangeTimes->{3.694003307043482*^9, 3.694056011474036*^9, 
  3.6941478746297207`*^9, 3.714821095341992*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Under delay = \"\>", "\[InvisibleSpace]", "1", 
   "\[InvisibleSpace]", "\<\" :\"\>"}],
  SequenceForm["Under delay = ", 1, " :"],
  Editable->False]], "Print",
 CellChangeTimes->{3.694003307043482*^9, 3.694056011474036*^9, 
  3.6941478746297207`*^9, 3.714821095342782*^9}],

Cell[BoxData["\<\"(*hidden for the sake of space*)\"\>"], "Print",
 CellChangeTimes->{3.694003307043482*^9, 3.694056011474036*^9, 
  3.6941478746297207`*^9, 3.714821095760487*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Under delay = \"\>", "\[InvisibleSpace]", "2", 
   "\[InvisibleSpace]", "\<\" :\"\>"}],
  SequenceForm["Under delay = ", 2, " :"],
  Editable->False]], "Print",
 CellChangeTimes->{3.694003307043482*^9, 3.694056011474036*^9, 
  3.6941478746297207`*^9, 3.714821095761585*^9}],

Cell[BoxData["\<\"(*hidden for the sake of space*)\"\>"], "Print",
 CellChangeTimes->{3.694003307043482*^9, 3.694056011474036*^9, 
  3.6941478746297207`*^9, 3.7148210967418127`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Under delay = \"\>", "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\" :\"\>"}],
  SequenceForm["Under delay = ", 3, " :"],
  Editable->False]], "Print",
 CellChangeTimes->{3.694003307043482*^9, 3.694056011474036*^9, 
  3.6941478746297207`*^9, 3.7148210967864857`*^9}],

Cell[BoxData["\<\"(*hidden for the sake of space*)\"\>"], "Print",
 CellChangeTimes->{3.694003307043482*^9, 3.694056011474036*^9, 
  3.6941478746297207`*^9, 3.714821098642022*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Not possible for sure-winning anymore under delay=\"\>", 
   "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\" with uncontrollable states \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "602", ",", "612", ",", "134", ",", "144", ",", "152", ",", "488", ",", 
     "828", ",", "816", ",", "824", ",", "768", ",", "712", ",", "834", ",", 
     "722", ",", "292", ",", "124", ",", "314", ",", "300", ",", "244", ",", 
     "132", ",", "650", ",", "482", ",", "636", ",", "468", ",", "322", ",", 
     "672", ",", "658", ",", "490", ",", "310", ",", "254", ",", "142", ",", 
     "646", ",", "590", ",", "478", ",", "422", ",", "332", ",", "668", ",", 
     "318", ",", "654", ",", "598", ",", "542", ",", "430", ",", "840", ",", 
     "826", ",", "814", ",", "836", ",", "780", ",", "822", ",", "766", ",", 
     "710", ",", "552", ",", "776", ",", "720", ",", "290", ",", "312", ",", 
     "130", ",", "466", ",", "298", ",", "648", ",", "802", ",", "634", ",", 
     "320", ",", "670", ",", "656", ",", "140", ",", "476", ",", "308", ",", 
     "812", ",", "644", ",", "756", ",", "588", ",", "28", ",", "364", ",", 
     "700", ",", "532", ",", "820", ",", "764", ",", "36", ",", "372", ",", 
     "708", ",", "288", ",", "232", ",", "120", ",", "624", ",", "64", ",", 
     "306", ",", "642", ",", "194", ",", "530", ",", "418", ",", "26", ",", 
     "362", ",", "698", ",", "118", ",", "6", ",", "16", ",", "352", ",", 
     "24", ",", "688", ",", "696", ",", "60", ",", "172", ",", "4", ",", 
     "182", ",", "14", ",", "350", ",", "88", ",", "96", ",", "424", ",", 
     "266", ",", "210", ",", "546", ",", "434", ",", "432", ",", "276", ",", 
     "220", ",", "556", ",", "444", ",", "32", ",", "40", ",", "368", ",", 
     "376", ",", "200", ",", "208", ",", "198", ",", "258", ",", "202", ",", 
     "90", ",", "98", ",", "108", ",", "256", ",", "100", ",", "436", ",", 
     "110", ",", "446", ",", "426", ",", "264", ",", "86", ",", "594", ",", 
     "538", ",", "760", ",", "704", ",", "536", ",", "534", ",", "34", ",", 
     "42", ",", "52", ",", "30", ",", "378", ",", "388", ",", "44", ",", "54",
      ",", "380", ",", "390", ",", "212", ",", "222", ",", "224", ",", "56", 
     ",", "544", ",", "370", ",", "366", ",", "55"}], "}"}], 
   "\[InvisibleSpace]", "\<\".\\n\"\>"}],
  SequenceForm[
  "Not possible for sure-winning anymore under delay=", 3, 
   " with uncontrollable states ", CompressedData["
1:eJwV0U8o5GEYB/DXnyRJkjZJGnKQtG3bNKZJkhwc5OAgOUhy2mS3TZKcNE2S
JCcHbctBkiRJ0iRJkpOmOU7SnuTs4LDJ5z18+n6f531nfn6jbfrn6FxZCGGX
ifIQZsjpm2zz4rC3IoRvpAncuzMgC7LD+bJ1RnbzpmdZc/YvnsmiHOCvvsWr
nuLDvQ1ydiM82e0zzI65T27IMVo5Ng95boavDFJLig/nd3RSbX6U7e6nWfGM
guxiNe6dL8l+8x+5ybo7JXMyvofzrN0bw7Q4m7XP640knf+P724/b3+rJ+SL
eZFf8bvl9/hs/UZvkHvmZv2HvDQv6FXUM2XXJE/sL+jVj6jknDom3RmPdznQ
ayjo7e6f6ic0UrLrtsvrCb0z/k36Ivf6I3eUmx/i/53p+I4EuxlxJufklTyk
mjHzqO9t5p1rmvgSf1NnXSRpZcn9bPwt9RTLeo6i/sQzaRI++zs+ix7zJ02t
SQY=
   "], ".\n"],
  Editable->False]], "Print",
 CellChangeTimes->{3.694003307043482*^9, 3.694056011474036*^9, 
  3.6941478746297207`*^9, 3.7148210987061663`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Computation time under increasing delays : \\n\"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "1.`", ",", "1.4200000000000017`", ",", "2.4039999999999964`", ",", 
     "4.303999999999988`"}], "}"}]}],
  SequenceForm[
  "Computation time under increasing delays : \n", {1., 1.4200000000000017`, 
   2.4039999999999964`, 4.303999999999988}],
  Editable->False]], "Print",
 CellChangeTimes->{3.694003307043482*^9, 3.694056011474036*^9, 
  3.6941478746297207`*^9, 3.714821098707329*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Escp. 6 x 6", "Subsection",
 CellChangeTimes->{{3.725591965751573*^9, 3.7255919705511703`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"g7", "=", 
   RowBox[{"Graph", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"67", "\[Rule]", "272"}], ",", 
       RowBox[{"67", "\[Rule]", "272"}], ",", 
       RowBox[{"67", "\[Rule]", "68"}], ",", 
       RowBox[{"272", "\[Rule]", "259"}], ",", 
       RowBox[{"272", "\[Rule]", "269"}], ",", 
       RowBox[{"68", "\[Rule]", "55"}], ",", 
       RowBox[{"68", "\[Rule]", "65"}], ",", 
       RowBox[{"259", "\[Rule]", "124"}], ",", 
       RowBox[{"259", "\[Rule]", "532"}], ",", 
       RowBox[{"259", "\[Rule]", "56"}], ",", 
       RowBox[{"259", "\[Rule]", "56"}], ",", 
       RowBox[{"259", "\[Rule]", "464"}], ",", 
       RowBox[{"259", "\[Rule]", "464"}], ",", 
       RowBox[{"259", "\[Rule]", "260"}], ",", 
       RowBox[{"269", "\[Rule]", "134"}], ",", 
       RowBox[{"269", "\[Rule]", "542"}], ",", 
       RowBox[{"269", "\[Rule]", "66"}], ",", 
       RowBox[{"269", "\[Rule]", "66"}], ",", 
       RowBox[{"269", "\[Rule]", "474"}], ",", 
       RowBox[{"269", "\[Rule]", "474"}], ",", 
       RowBox[{"269", "\[Rule]", "270"}], ",", 
       RowBox[{"55", "\[Rule]", "260"}], ",", 
       RowBox[{"55", "\[Rule]", "260"}], ",", 
       RowBox[{"55", "\[Rule]", "56"}], ",", 
       RowBox[{"65", "\[Rule]", "270"}], ",", 
       RowBox[{"65", "\[Rule]", "270"}], ",", 
       RowBox[{"65", "\[Rule]", "66"}], ",", 
       RowBox[{"124", "\[Rule]", "111"}], ",", 
       RowBox[{"124", "\[Rule]", "135"}], ",", 
       RowBox[{"124", "\[Rule]", "121"}], ",", 
       RowBox[{"532", "\[Rule]", "519"}], ",", 
       RowBox[{"532", "\[Rule]", "543"}], ",", 
       RowBox[{"532", "\[Rule]", "529"}], ",", 
       RowBox[{"56", "\[Rule]", "43"}], ",", 
       RowBox[{"56", "\[Rule]", "67"}], ",", 
       RowBox[{"56", "\[Rule]", "53"}], ",", 
       RowBox[{"464", "\[Rule]", "451"}], ",", 
       RowBox[{"464", "\[Rule]", "475"}], ",", 
       RowBox[{"464", "\[Rule]", "461"}], ",", 
       RowBox[{"260", "\[Rule]", "247"}], ",", 
       RowBox[{"260", "\[Rule]", "271"}], ",", 
       RowBox[{"260", "\[Rule]", "257"}], ",", 
       RowBox[{"134", "\[Rule]", "121"}], ",", 
       RowBox[{"134", "\[Rule]", "135"}], ",", 
       RowBox[{"134", "\[Rule]", "131"}], ",", 
       RowBox[{"542", "\[Rule]", "529"}], ",", 
       RowBox[{"542", "\[Rule]", "543"}], ",", 
       RowBox[{"542", "\[Rule]", "539"}], ",", 
       RowBox[{"66", "\[Rule]", "53"}], ",", 
       RowBox[{"66", "\[Rule]", "67"}], ",", 
       RowBox[{"66", "\[Rule]", "63"}], ",", 
       RowBox[{"474", "\[Rule]", "461"}], ",", 
       RowBox[{"474", "\[Rule]", "475"}], ",", 
       RowBox[{"474", "\[Rule]", "471"}], ",", 
       RowBox[{"270", "\[Rule]", "257"}], ",", 
       RowBox[{"270", "\[Rule]", "271"}], ",", 
       RowBox[{"270", "\[Rule]", "267"}], ",", 
       RowBox[{"111", "\[Rule]", "316"}], ",", 
       RowBox[{"111", "\[Rule]", "248"}], ",", 
       RowBox[{"111", "\[Rule]", "112"}], ",", 
       RowBox[{"135", "\[Rule]", "340"}], ",", 
       RowBox[{"135", "\[Rule]", "272"}], ",", 
       RowBox[{"135", "\[Rule]", "136"}], ",", 
       RowBox[{"121", "\[Rule]", "326"}], ",", 
       RowBox[{"121", "\[Rule]", "258"}], ",", 
       RowBox[{"121", "\[Rule]", "122"}], ",", 
       RowBox[{"519", "\[Rule]", "316"}], ",", 
       RowBox[{"519", "\[Rule]", "724"}], ",", 
       RowBox[{"519", "\[Rule]", "724"}], ",", 
       RowBox[{"519", "\[Rule]", "248"}], ",", 
       RowBox[{"519", "\[Rule]", "656"}], ",", 
       RowBox[{"519", "\[Rule]", "656"}], ",", 
       RowBox[{"519", "\[Rule]", "520"}], ",", 
       RowBox[{"543", "\[Rule]", "340"}], ",", 
       RowBox[{"543", "\[Rule]", "748"}], ",", 
       RowBox[{"543", "\[Rule]", "748"}], ",", 
       RowBox[{"543", "\[Rule]", "272"}], ",", 
       RowBox[{"543", "\[Rule]", "680"}], ",", 
       RowBox[{"543", "\[Rule]", "680"}], ",", 
       RowBox[{"543", "\[Rule]", "544"}], ",", 
       RowBox[{"529", "\[Rule]", "326"}], ",", 
       RowBox[{"529", "\[Rule]", "734"}], ",", 
       RowBox[{"529", "\[Rule]", "734"}], ",", 
       RowBox[{"529", "\[Rule]", "258"}], ",", 
       RowBox[{"529", "\[Rule]", "666"}], ",", 
       RowBox[{"529", "\[Rule]", "666"}], ",", 
       RowBox[{"529", "\[Rule]", "530"}], ",", 
       RowBox[{"43", "\[Rule]", "248"}], ",", 
       RowBox[{"43", "\[Rule]", "248"}], ",", 
       RowBox[{"43", "\[Rule]", "44"}], ",", 
       RowBox[{"53", "\[Rule]", "258"}], ",", 
       RowBox[{"53", "\[Rule]", "258"}], ",", 
       RowBox[{"53", "\[Rule]", "54"}], ",", 
       RowBox[{"451", "\[Rule]", "248"}], ",", 
       RowBox[{"451", "\[Rule]", "248"}], ",", 
       RowBox[{"451", "\[Rule]", "656"}], ",", 
       RowBox[{"451", "\[Rule]", "452"}], ",", 
       RowBox[{"475", "\[Rule]", "272"}], ",", 
       RowBox[{"475", "\[Rule]", "272"}], ",", 
       RowBox[{"475", "\[Rule]", "680"}], ",", 
       RowBox[{"475", "\[Rule]", "476"}], ",", 
       RowBox[{"461", "\[Rule]", "258"}], ",", 
       RowBox[{"461", "\[Rule]", "258"}], ",", 
       RowBox[{"461", "\[Rule]", "666"}], ",", 
       RowBox[{"461", "\[Rule]", "462"}], ",", 
       RowBox[{"247", "\[Rule]", "112"}], ",", 
       RowBox[{"247", "\[Rule]", "520"}], ",", 
       RowBox[{"247", "\[Rule]", "44"}], ",", 
       RowBox[{"247", "\[Rule]", "44"}], ",", 
       RowBox[{"247", "\[Rule]", "452"}], ",", 
       RowBox[{"247", "\[Rule]", "452"}], ",", 
       RowBox[{"247", "\[Rule]", "248"}], ",", 
       RowBox[{"271", "\[Rule]", "136"}], ",", 
       RowBox[{"271", "\[Rule]", "544"}], ",", 
       RowBox[{"271", "\[Rule]", "68"}], ",", 
       RowBox[{"271", "\[Rule]", "68"}], ",", 
       RowBox[{"271", "\[Rule]", "476"}], ",", 
       RowBox[{"271", "\[Rule]", "476"}], ",", 
       RowBox[{"271", "\[Rule]", "272"}], ",", 
       RowBox[{"257", "\[Rule]", "122"}], ",", 
       RowBox[{"257", "\[Rule]", "530"}], ",", 
       RowBox[{"257", "\[Rule]", "54"}], ",", 
       RowBox[{"257", "\[Rule]", "54"}], ",", 
       RowBox[{"257", "\[Rule]", "462"}], ",", 
       RowBox[{"257", "\[Rule]", "462"}], ",", 
       RowBox[{"257", "\[Rule]", "258"}], ",", 
       RowBox[{"131", "\[Rule]", "336"}], ",", 
       RowBox[{"131", "\[Rule]", "268"}], ",", 
       RowBox[{"131", "\[Rule]", "132"}], ",", 
       RowBox[{"539", "\[Rule]", "336"}], ",", 
       RowBox[{"539", "\[Rule]", "744"}], ",", 
       RowBox[{"539", "\[Rule]", "744"}], ",", 
       RowBox[{"539", "\[Rule]", "268"}], ",", 
       RowBox[{"539", "\[Rule]", "676"}], ",", 
       RowBox[{"539", "\[Rule]", "676"}], ",", 
       RowBox[{"539", "\[Rule]", "540"}], ",", 
       RowBox[{"63", "\[Rule]", "268"}], ",", 
       RowBox[{"63", "\[Rule]", "268"}], ",", 
       RowBox[{"63", "\[Rule]", "64"}], ",", 
       RowBox[{"471", "\[Rule]", "268"}], ",", 
       RowBox[{"471", "\[Rule]", "268"}], ",", 
       RowBox[{"471", "\[Rule]", "676"}], ",", 
       RowBox[{"471", "\[Rule]", "472"}], ",", 
       RowBox[{"267", "\[Rule]", "132"}], ",", 
       RowBox[{"267", "\[Rule]", "540"}], ",", 
       RowBox[{"267", "\[Rule]", "64"}], ",", 
       RowBox[{"267", "\[Rule]", "64"}], ",", 
       RowBox[{"267", "\[Rule]", "472"}], ",", 
       RowBox[{"267", "\[Rule]", "472"}], ",", 
       RowBox[{"267", "\[Rule]", "268"}], ",", 
       RowBox[{"316", "\[Rule]", "305"}], ",", 
       RowBox[{"316", "\[Rule]", "327"}], ",", 
       RowBox[{"316", "\[Rule]", "313"}], ",", 
       RowBox[{"248", "\[Rule]", "237"}], ",", 
       RowBox[{"248", "\[Rule]", "259"}], ",", 
       RowBox[{"248", "\[Rule]", "245"}], ",", 
       RowBox[{"112", "\[Rule]", "101"}], ",", 
       RowBox[{"112", "\[Rule]", "123"}], ",", 
       RowBox[{"112", "\[Rule]", "109"}], ",", 
       RowBox[{"340", "\[Rule]", "327"}], ",", 
       RowBox[{"340", "\[Rule]", "337"}], ",", 
       RowBox[{"136", "\[Rule]", "123"}], ",", 
       RowBox[{"136", "\[Rule]", "133"}], ",", 
       RowBox[{"326", "\[Rule]", "313"}], ",", 
       RowBox[{"326", "\[Rule]", "337"}], ",", 
       RowBox[{"326", "\[Rule]", "327"}], ",", 
       RowBox[{"326", "\[Rule]", "323"}], ",", 
       RowBox[{"258", "\[Rule]", "245"}], ",", 
       RowBox[{"258", "\[Rule]", "269"}], ",", 
       RowBox[{"258", "\[Rule]", "259"}], ",", 
       RowBox[{"258", "\[Rule]", "255"}], ",", 
       RowBox[{"122", "\[Rule]", "109"}], ",", 
       RowBox[{"122", "\[Rule]", "133"}], ",", 
       RowBox[{"122", "\[Rule]", "123"}], ",", 
       RowBox[{"122", "\[Rule]", "119"}], ",", 
       RowBox[{"724", "\[Rule]", "713"}], ",", 
       RowBox[{"724", "\[Rule]", "735"}], ",", 
       RowBox[{"724", "\[Rule]", "721"}], ",", 
       RowBox[{"656", "\[Rule]", "645"}], ",", 
       RowBox[{"656", "\[Rule]", "667"}], ",", 
       RowBox[{"656", "\[Rule]", "653"}], ",", 
       RowBox[{"520", "\[Rule]", "509"}], ",", 
       RowBox[{"520", "\[Rule]", "531"}], ",", 
       RowBox[{"520", "\[Rule]", "517"}], ",", 
       RowBox[{"748", "\[Rule]", "735"}], ",", 
       RowBox[{"748", "\[Rule]", "745"}], ",", 
       RowBox[{"680", "\[Rule]", "667"}], ",", 
       RowBox[{"680", "\[Rule]", "677"}], ",", 
       RowBox[{"544", "\[Rule]", "531"}], ",", 
       RowBox[{"544", "\[Rule]", "541"}], ",", 
       RowBox[{"734", "\[Rule]", "721"}], ",", 
       RowBox[{"734", "\[Rule]", "745"}], ",", 
       RowBox[{"734", "\[Rule]", "735"}], ",", 
       RowBox[{"734", "\[Rule]", "731"}], ",", 
       RowBox[{"666", "\[Rule]", "653"}], ",", 
       RowBox[{"666", "\[Rule]", "677"}], ",", 
       RowBox[{"666", "\[Rule]", "667"}], ",", 
       RowBox[{"666", "\[Rule]", "663"}], ",", 
       RowBox[{"530", "\[Rule]", "517"}], ",", 
       RowBox[{"530", "\[Rule]", "541"}], ",", 
       RowBox[{"530", "\[Rule]", "531"}], ",", 
       RowBox[{"530", "\[Rule]", "527"}], ",", 
       RowBox[{"44", "\[Rule]", "33"}], ",", 
       RowBox[{"44", "\[Rule]", "55"}], ",", 
       RowBox[{"44", "\[Rule]", "41"}], ",", 
       RowBox[{"54", "\[Rule]", "41"}], ",", 
       RowBox[{"54", "\[Rule]", "65"}], ",", 
       RowBox[{"54", "\[Rule]", "55"}], ",", 
       RowBox[{"54", "\[Rule]", "51"}], ",", 
       RowBox[{"452", "\[Rule]", "441"}], ",", 
       RowBox[{"452", "\[Rule]", "463"}], ",", 
       RowBox[{"452", "\[Rule]", "449"}], ",", 
       RowBox[{"476", "\[Rule]", "463"}], ",", 
       RowBox[{"476", "\[Rule]", "473"}], ",", 
       RowBox[{"462", "\[Rule]", "449"}], ",", 
       RowBox[{"462", "\[Rule]", "473"}], ",", 
       RowBox[{"462", "\[Rule]", "463"}], ",", 
       RowBox[{"462", "\[Rule]", "459"}], ",", 
       RowBox[{"336", "\[Rule]", "323"}], ",", 
       RowBox[{"336", "\[Rule]", "337"}], ",", 
       RowBox[{"336", "\[Rule]", "333"}], ",", 
       RowBox[{"268", "\[Rule]", "255"}], ",", 
       RowBox[{"268", "\[Rule]", "269"}], ",", 
       RowBox[{"268", "\[Rule]", "265"}], ",", 
       RowBox[{"132", "\[Rule]", "119"}], ",", 
       RowBox[{"132", "\[Rule]", "133"}], ",", 
       RowBox[{"132", "\[Rule]", "129"}], ",", 
       RowBox[{"744", "\[Rule]", "731"}], ",", 
       RowBox[{"744", "\[Rule]", "745"}], ",", 
       RowBox[{"744", "\[Rule]", "741"}], ",", 
       RowBox[{"676", "\[Rule]", "663"}], ",", 
       RowBox[{"676", "\[Rule]", "677"}], ",", 
       RowBox[{"676", "\[Rule]", "673"}], ",", 
       RowBox[{"540", "\[Rule]", "527"}], ",", 
       RowBox[{"540", "\[Rule]", "541"}], ",", 
       RowBox[{"540", "\[Rule]", "537"}], ",", 
       RowBox[{"64", "\[Rule]", "51"}], ",", 
       RowBox[{"64", "\[Rule]", "65"}], ",", 
       RowBox[{"64", "\[Rule]", "61"}], ",", 
       RowBox[{"472", "\[Rule]", "459"}], ",", 
       RowBox[{"472", "\[Rule]", "473"}], ",", 
       RowBox[{"472", "\[Rule]", "469"}], ",", 
       RowBox[{"305", "\[Rule]", "170"}], ",", 
       RowBox[{"305", "\[Rule]", "170"}], ",", 
       RowBox[{"305", "\[Rule]", "578"}], ",", 
       RowBox[{"305", "\[Rule]", "578"}], ",", 
       RowBox[{"305", "\[Rule]", "102"}], ",", 
       RowBox[{"305", "\[Rule]", "510"}], ",", 
       RowBox[{"305", "\[Rule]", "306"}], ",", 
       RowBox[{"327", "\[Rule]", "192"}], ",", 
       RowBox[{"327", "\[Rule]", "192"}], ",", 
       RowBox[{"327", "\[Rule]", "600"}], ",", 
       RowBox[{"327", "\[Rule]", "600"}], ",", 
       RowBox[{"327", "\[Rule]", "124"}], ",", 
       RowBox[{"327", "\[Rule]", "532"}], ",", 
       RowBox[{"327", "\[Rule]", "328"}], ",", 
       RowBox[{"313", "\[Rule]", "178"}], ",", 
       RowBox[{"313", "\[Rule]", "178"}], ",", 
       RowBox[{"313", "\[Rule]", "586"}], ",", 
       RowBox[{"313", "\[Rule]", "586"}], ",", 
       RowBox[{"313", "\[Rule]", "110"}], ",", 
       RowBox[{"313", "\[Rule]", "518"}], ",", 
       RowBox[{"313", "\[Rule]", "314"}], ",", 
       RowBox[{"237", "\[Rule]", "102"}], ",", 
       RowBox[{"237", "\[Rule]", "510"}], ",", 
       RowBox[{"237", "\[Rule]", "34"}], ",", 
       RowBox[{"237", "\[Rule]", "34"}], ",", 
       RowBox[{"237", "\[Rule]", "442"}], ",", 
       RowBox[{"237", "\[Rule]", "442"}], ",", 
       RowBox[{"237", "\[Rule]", "238"}], ",", 
       RowBox[{"245", "\[Rule]", "110"}], ",", 
       RowBox[{"245", "\[Rule]", "518"}], ",", 
       RowBox[{"245", "\[Rule]", "42"}], ",", 
       RowBox[{"245", "\[Rule]", "42"}], ",", 
       RowBox[{"245", "\[Rule]", "450"}], ",", 
       RowBox[{"245", "\[Rule]", "450"}], ",", 
       RowBox[{"245", "\[Rule]", "246"}], ",", 
       RowBox[{"101", "\[Rule]", "306"}], ",", 
       RowBox[{"101", "\[Rule]", "238"}], ",", 
       RowBox[{"101", "\[Rule]", "102"}], ",", 
       RowBox[{"123", "\[Rule]", "328"}], ",", 
       RowBox[{"123", "\[Rule]", "260"}], ",", 
       RowBox[{"123", "\[Rule]", "124"}], ",", 
       RowBox[{"109", "\[Rule]", "314"}], ",", 
       RowBox[{"109", "\[Rule]", "246"}], ",", 
       RowBox[{"109", "\[Rule]", "110"}], ",", 
       RowBox[{"337", "\[Rule]", "202"}], ",", 
       RowBox[{"337", "\[Rule]", "202"}], ",", 
       RowBox[{"337", "\[Rule]", "610"}], ",", 
       RowBox[{"337", "\[Rule]", "610"}], ",", 
       RowBox[{"337", "\[Rule]", "134"}], ",", 
       RowBox[{"337", "\[Rule]", "542"}], ",", 
       RowBox[{"337", "\[Rule]", "338"}], ",", 
       RowBox[{"133", "\[Rule]", "338"}], ",", 
       RowBox[{"133", "\[Rule]", "270"}], ",", 
       RowBox[{"133", "\[Rule]", "134"}], ",", 
       RowBox[{"323", "\[Rule]", "188"}], ",", 
       RowBox[{"323", "\[Rule]", "188"}], ",", 
       RowBox[{"323", "\[Rule]", "596"}], ",", 
       RowBox[{"323", "\[Rule]", "596"}], ",", 
       RowBox[{"323", "\[Rule]", "120"}], ",", 
       RowBox[{"323", "\[Rule]", "528"}], ",", 
       RowBox[{"323", "\[Rule]", "324"}], ",", 
       RowBox[{"255", "\[Rule]", "120"}], ",", 
       RowBox[{"255", "\[Rule]", "528"}], ",", 
       RowBox[{"255", "\[Rule]", "52"}], ",", 
       RowBox[{"255", "\[Rule]", "52"}], ",", 
       RowBox[{"255", "\[Rule]", "460"}], ",", 
       RowBox[{"255", "\[Rule]", "460"}], ",", 
       RowBox[{"255", "\[Rule]", "256"}], ",", 
       RowBox[{"119", "\[Rule]", "324"}], ",", 
       RowBox[{"119", "\[Rule]", "256"}], ",", 
       RowBox[{"119", "\[Rule]", "120"}], ",", 
       RowBox[{"713", "\[Rule]", "578"}], ",", 
       RowBox[{"713", "\[Rule]", "578"}], ",", 
       RowBox[{"713", "\[Rule]", "986"}], ",", 
       RowBox[{"713", "\[Rule]", "986"}], ",", 
       RowBox[{"713", "\[Rule]", "510"}], ",", 
       RowBox[{"713", "\[Rule]", "510"}], ",", 
       RowBox[{"713", "\[Rule]", "918"}], ",", 
       RowBox[{"713", "\[Rule]", "918"}], ",", 
       RowBox[{"713", "\[Rule]", "714"}], ",", 
       RowBox[{"735", "\[Rule]", "600"}], ",", 
       RowBox[{"735", "\[Rule]", "600"}], ",", 
       RowBox[{"735", "\[Rule]", "1008"}], ",", 
       RowBox[{"735", "\[Rule]", "1008"}], ",", 
       RowBox[{"735", "\[Rule]", "532"}], ",", 
       RowBox[{"735", "\[Rule]", "532"}], ",", 
       RowBox[{"735", "\[Rule]", "940"}], ",", 
       RowBox[{"735", "\[Rule]", "940"}], ",", 
       RowBox[{"735", "\[Rule]", "736"}], ",", 
       RowBox[{"721", "\[Rule]", "586"}], ",", 
       RowBox[{"721", "\[Rule]", "994"}], ",", 
       RowBox[{"721", "\[Rule]", "518"}], ",", 
       RowBox[{"721", "\[Rule]", "518"}], ",", 
       RowBox[{"721", "\[Rule]", "926"}], ",", 
       RowBox[{"721", "\[Rule]", "926"}], ",", 
       RowBox[{"721", "\[Rule]", "722"}], ",", 
       RowBox[{"645", "\[Rule]", "510"}], ",", 
       RowBox[{"645", "\[Rule]", "510"}], ",", 
       RowBox[{"645", "\[Rule]", "918"}], ",", 
       RowBox[{"645", "\[Rule]", "918"}], ",", 
       RowBox[{"645", "\[Rule]", "442"}], ",", 
       RowBox[{"645", "\[Rule]", "850"}], ",", 
       RowBox[{"645", "\[Rule]", "646"}], ",", 
       RowBox[{"667", "\[Rule]", "532"}], ",", 
       RowBox[{"667", "\[Rule]", "532"}], ",", 
       RowBox[{"667", "\[Rule]", "940"}], ",", 
       RowBox[{"667", "\[Rule]", "940"}], ",", 
       RowBox[{"667", "\[Rule]", "464"}], ",", 
       RowBox[{"667", "\[Rule]", "872"}], ",", 
       RowBox[{"667", "\[Rule]", "668"}], ",", 
       RowBox[{"653", "\[Rule]", "518"}], ",", 
       RowBox[{"653", "\[Rule]", "518"}], ",", 
       RowBox[{"653", "\[Rule]", "926"}], ",", 
       RowBox[{"653", "\[Rule]", "926"}], ",", 
       RowBox[{"653", "\[Rule]", "450"}], ",", 
       RowBox[{"653", "\[Rule]", "858"}], ",", 
       RowBox[{"653", "\[Rule]", "654"}], ",", 
       RowBox[{"509", "\[Rule]", "306"}], ",", 
       RowBox[{"509", "\[Rule]", "714"}], ",", 
       RowBox[{"509", "\[Rule]", "714"}], ",", 
       RowBox[{"509", "\[Rule]", "238"}], ",", 
       RowBox[{"509", "\[Rule]", "646"}], ",", 
       RowBox[{"509", "\[Rule]", "646"}], ",", 
       RowBox[{"509", "\[Rule]", "510"}], ",", 
       RowBox[{"531", "\[Rule]", "328"}], ",", 
       RowBox[{"531", "\[Rule]", "736"}], ",", 
       RowBox[{"531", "\[Rule]", "736"}], ",", 
       RowBox[{"531", "\[Rule]", "260"}], ",", 
       RowBox[{"531", "\[Rule]", "668"}], ",", 
       RowBox[{"531", "\[Rule]", "668"}], ",", 
       RowBox[{"531", "\[Rule]", "532"}], ",", 
       RowBox[{"517", "\[Rule]", "314"}], ",", 
       RowBox[{"517", "\[Rule]", "722"}], ",", 
       RowBox[{"517", "\[Rule]", "722"}], ",", 
       RowBox[{"517", "\[Rule]", "246"}], ",", 
       RowBox[{"517", "\[Rule]", "654"}], ",", 
       RowBox[{"517", "\[Rule]", "654"}], ",", 
       RowBox[{"517", "\[Rule]", "518"}], ",", 
       RowBox[{"745", "\[Rule]", "610"}], ",", 
       RowBox[{"745", "\[Rule]", "610"}], ",", 
       RowBox[{"745", "\[Rule]", "1018"}], ",", 
       RowBox[{"745", "\[Rule]", "1018"}], ",", 
       RowBox[{"745", "\[Rule]", "542"}], ",", 
       RowBox[{"745", "\[Rule]", "542"}], ",", 
       RowBox[{"745", "\[Rule]", "950"}], ",", 
       RowBox[{"745", "\[Rule]", "950"}], ",", 
       RowBox[{"745", "\[Rule]", "746"}], ",", 
       RowBox[{"677", "\[Rule]", "542"}], ",", 
       RowBox[{"677", "\[Rule]", "542"}], ",", 
       RowBox[{"677", "\[Rule]", "950"}], ",", 
       RowBox[{"677", "\[Rule]", "950"}], ",", 
       RowBox[{"677", "\[Rule]", "474"}], ",", 
       RowBox[{"677", "\[Rule]", "882"}], ",", 
       RowBox[{"677", "\[Rule]", "678"}], ",", 
       RowBox[{"541", "\[Rule]", "338"}], ",", 
       RowBox[{"541", "\[Rule]", "746"}], ",", 
       RowBox[{"541", "\[Rule]", "746"}], ",", 
       RowBox[{"541", "\[Rule]", "270"}], ",", 
       RowBox[{"541", "\[Rule]", "678"}], ",", 
       RowBox[{"541", "\[Rule]", "678"}], ",", 
       RowBox[{"541", "\[Rule]", "542"}], ",", 
       RowBox[{"731", "\[Rule]", "596"}], ",", 
       RowBox[{"731", "\[Rule]", "596"}], ",", 
       RowBox[{"731", "\[Rule]", "1004"}], ",", 
       RowBox[{"731", "\[Rule]", "528"}], ",", 
       RowBox[{"731", "\[Rule]", "528"}], ",", 
       RowBox[{"731", "\[Rule]", "936"}], ",", 
       RowBox[{"731", "\[Rule]", "732"}], ",", 
       RowBox[{"663", "\[Rule]", "528"}], ",", 
       RowBox[{"663", "\[Rule]", "528"}], ",", 
       RowBox[{"663", "\[Rule]", "936"}], ",", 
       RowBox[{"663", "\[Rule]", "936"}], ",", 
       RowBox[{"663", "\[Rule]", "460"}], ",", 
       RowBox[{"663", "\[Rule]", "868"}], ",", 
       RowBox[{"663", "\[Rule]", "664"}], ",", 
       RowBox[{"527", "\[Rule]", "324"}], ",", 
       RowBox[{"527", "\[Rule]", "732"}], ",", 
       RowBox[{"527", "\[Rule]", "732"}], ",", 
       RowBox[{"527", "\[Rule]", "256"}], ",", 
       RowBox[{"527", "\[Rule]", "664"}], ",", 
       RowBox[{"527", "\[Rule]", "664"}], ",", 
       RowBox[{"527", "\[Rule]", "528"}], ",", 
       RowBox[{"33", "\[Rule]", "238"}], ",", 
       RowBox[{"33", "\[Rule]", "238"}], ",", 
       RowBox[{"33", "\[Rule]", "34"}], ",", 
       RowBox[{"41", "\[Rule]", "246"}], ",", 
       RowBox[{"41", "\[Rule]", "246"}], ",", 
       RowBox[{"41", "\[Rule]", "42"}], ",", 
       RowBox[{"51", "\[Rule]", "256"}], ",", 
       RowBox[{"51", "\[Rule]", "256"}], ",", 
       RowBox[{"51", "\[Rule]", "52"}], ",", 
       RowBox[{"441", "\[Rule]", "238"}], ",", 
       RowBox[{"441", "\[Rule]", "238"}], ",", 
       RowBox[{"441", "\[Rule]", "646"}], ",", 
       RowBox[{"441", "\[Rule]", "442"}], ",", 
       RowBox[{"463", "\[Rule]", "260"}], ",", 
       RowBox[{"463", "\[Rule]", "260"}], ",", 
       RowBox[{"463", "\[Rule]", "668"}], ",", 
       RowBox[{"463", "\[Rule]", "464"}], ",", 
       RowBox[{"449", "\[Rule]", "246"}], ",", 
       RowBox[{"449", "\[Rule]", "246"}], ",", 
       RowBox[{"449", "\[Rule]", "654"}], ",", 
       RowBox[{"449", "\[Rule]", "450"}], ",", 
       RowBox[{"473", "\[Rule]", "270"}], ",", 
       RowBox[{"473", "\[Rule]", "270"}], ",", 
       RowBox[{"473", "\[Rule]", "678"}], ",", 
       RowBox[{"473", "\[Rule]", "474"}], ",", 
       RowBox[{"459", "\[Rule]", "256"}], ",", 
       RowBox[{"459", "\[Rule]", "256"}], ",", 
       RowBox[{"459", "\[Rule]", "664"}], ",", 
       RowBox[{"459", "\[Rule]", "460"}], ",", 
       RowBox[{"333", "\[Rule]", "198"}], ",", 
       RowBox[{"333", "\[Rule]", "198"}], ",", 
       RowBox[{"333", "\[Rule]", "606"}], ",", 
       RowBox[{"333", "\[Rule]", "606"}], ",", 
       RowBox[{"333", "\[Rule]", "130"}], ",", 
       RowBox[{"333", "\[Rule]", "538"}], ",", 
       RowBox[{"333", "\[Rule]", "334"}], ",", 
       RowBox[{"265", "\[Rule]", "130"}], ",", 
       RowBox[{"265", "\[Rule]", "538"}], ",", 
       RowBox[{"265", "\[Rule]", "62"}], ",", 
       RowBox[{"265", "\[Rule]", "62"}], ",", 
       RowBox[{"265", "\[Rule]", "470"}], ",", 
       RowBox[{"265", "\[Rule]", "470"}], ",", 
       RowBox[{"265", "\[Rule]", "266"}], ",", 
       RowBox[{"129", "\[Rule]", "334"}], ",", 
       RowBox[{"129", "\[Rule]", "266"}], ",", 
       RowBox[{"129", "\[Rule]", "130"}], ",", 
       RowBox[{"741", "\[Rule]", "606"}], ",", 
       RowBox[{"741", "\[Rule]", "606"}], ",", 
       RowBox[{"741", "\[Rule]", "1014"}], ",", 
       RowBox[{"741", "\[Rule]", "1014"}], ",", 
       RowBox[{"741", "\[Rule]", "538"}], ",", 
       RowBox[{"741", "\[Rule]", "538"}], ",", 
       RowBox[{"741", "\[Rule]", "946"}], ",", 
       RowBox[{"741", "\[Rule]", "946"}], ",", 
       RowBox[{"741", "\[Rule]", "742"}], ",", 
       RowBox[{"673", "\[Rule]", "538"}], ",", 
       RowBox[{"673", "\[Rule]", "538"}], ",", 
       RowBox[{"673", "\[Rule]", "946"}], ",", 
       RowBox[{"673", "\[Rule]", "946"}], ",", 
       RowBox[{"673", "\[Rule]", "470"}], ",", 
       RowBox[{"673", "\[Rule]", "878"}], ",", 
       RowBox[{"673", "\[Rule]", "674"}], ",", 
       RowBox[{"537", "\[Rule]", "334"}], ",", 
       RowBox[{"537", "\[Rule]", "742"}], ",", 
       RowBox[{"537", "\[Rule]", "742"}], ",", 
       RowBox[{"537", "\[Rule]", "266"}], ",", 
       RowBox[{"537", "\[Rule]", "674"}], ",", 
       RowBox[{"537", "\[Rule]", "674"}], ",", 
       RowBox[{"537", "\[Rule]", "538"}], ",", 
       RowBox[{"61", "\[Rule]", "266"}], ",", 
       RowBox[{"61", "\[Rule]", "266"}], ",", 
       RowBox[{"61", "\[Rule]", "62"}], ",", 
       RowBox[{"469", "\[Rule]", "266"}], ",", 
       RowBox[{"469", "\[Rule]", "266"}], ",", 
       RowBox[{"469", "\[Rule]", "674"}], ",", 
       RowBox[{"469", "\[Rule]", "470"}], ",", 
       RowBox[{"170", "\[Rule]", "157"}], ",", 
       RowBox[{"170", "\[Rule]", "179"}], ",", 
       RowBox[{"170", "\[Rule]", "167"}], ",", 
       RowBox[{"578", "\[Rule]", "565"}], ",", 
       RowBox[{"578", "\[Rule]", "587"}], ",", 
       RowBox[{"578", "\[Rule]", "575"}], ",", 
       RowBox[{"102", "\[Rule]", "89"}], ",", 
       RowBox[{"102", "\[Rule]", "111"}], ",", 
       RowBox[{"102", "\[Rule]", "99"}], ",", 
       RowBox[{"510", "\[Rule]", "497"}], ",", 
       RowBox[{"510", "\[Rule]", "519"}], ",", 
       RowBox[{"510", "\[Rule]", "507"}], ",", 
       RowBox[{"306", "\[Rule]", "293"}], ",", 
       RowBox[{"306", "\[Rule]", "315"}], ",", 
       RowBox[{"306", "\[Rule]", "303"}], ",", 
       RowBox[{"192", "\[Rule]", "179"}], ",", 
       RowBox[{"192", "\[Rule]", "203"}], ",", 
       RowBox[{"192", "\[Rule]", "189"}], ",", 
       RowBox[{"600", "\[Rule]", "587"}], ",", 
       RowBox[{"600", "\[Rule]", "611"}], ",", 
       RowBox[{"600", "\[Rule]", "597"}], ",", 
       RowBox[{"328", "\[Rule]", "315"}], ",", 
       RowBox[{"328", "\[Rule]", "339"}], ",", 
       RowBox[{"328", "\[Rule]", "325"}], ",", 
       RowBox[{"178", "\[Rule]", "167"}], ",", 
       RowBox[{"178", "\[Rule]", "189"}], ",", 
       RowBox[{"178", "\[Rule]", "179"}], ",", 
       RowBox[{"178", "\[Rule]", "175"}], ",", 
       RowBox[{"586", "\[Rule]", "575"}], ",", 
       RowBox[{"586", "\[Rule]", "597"}], ",", 
       RowBox[{"586", "\[Rule]", "587"}], ",", 
       RowBox[{"586", "\[Rule]", "583"}], ",", 
       RowBox[{"110", "\[Rule]", "99"}], ",", 
       RowBox[{"110", "\[Rule]", "121"}], ",", 
       RowBox[{"110", "\[Rule]", "111"}], ",", 
       RowBox[{"110", "\[Rule]", "107"}], ",", 
       RowBox[{"518", "\[Rule]", "507"}], ",", 
       RowBox[{"518", "\[Rule]", "529"}], ",", 
       RowBox[{"518", "\[Rule]", "519"}], ",", 
       RowBox[{"518", "\[Rule]", "515"}], ",", 
       RowBox[{"314", "\[Rule]", "303"}], ",", 
       RowBox[{"314", "\[Rule]", "325"}], ",", 
       RowBox[{"314", "\[Rule]", "315"}], ",", 
       RowBox[{"314", "\[Rule]", "311"}], ",", 
       RowBox[{"34", "\[Rule]", "21"}], ",", 
       RowBox[{"34", "\[Rule]", "43"}], ",", 
       RowBox[{"34", "\[Rule]", "31"}], ",", 
       RowBox[{"442", "\[Rule]", "429"}], ",", 
       RowBox[{"442", "\[Rule]", "451"}], ",", 
       RowBox[{"442", "\[Rule]", "439"}], ",", 
       RowBox[{"238", "\[Rule]", "225"}], ",", 
       RowBox[{"238", "\[Rule]", "247"}], ",", 
       RowBox[{"238", "\[Rule]", "235"}], ",", 
       RowBox[{"42", "\[Rule]", "31"}], ",", 
       RowBox[{"42", "\[Rule]", "53"}], ",", 
       RowBox[{"42", "\[Rule]", "43"}], ",", 
       RowBox[{"42", "\[Rule]", "39"}], ",", 
       RowBox[{"450", "\[Rule]", "439"}], ",", 
       RowBox[{"450", "\[Rule]", "461"}], ",", 
       RowBox[{"450", "\[Rule]", "451"}], ",", 
       RowBox[{"450", "\[Rule]", "447"}], ",", 
       RowBox[{"246", "\[Rule]", "235"}], ",", 
       RowBox[{"246", "\[Rule]", "257"}], ",", 
       RowBox[{"246", "\[Rule]", "247"}], ",", 
       RowBox[{"246", "\[Rule]", "243"}], ",", 
       RowBox[{"202", "\[Rule]", "189"}], ",", 
       RowBox[{"202", "\[Rule]", "203"}], ",", 
       RowBox[{"202", "\[Rule]", "199"}], ",", 
       RowBox[{"610", "\[Rule]", "597"}], ",", 
       RowBox[{"610", "\[Rule]", "611"}], ",", 
       RowBox[{"610", "\[Rule]", "607"}], ",", 
       RowBox[{"338", "\[Rule]", "325"}], ",", 
       RowBox[{"338", "\[Rule]", "339"}], ",", 
       RowBox[{"338", "\[Rule]", "335"}], ",", 
       RowBox[{"188", "\[Rule]", "175"}], ",", 
       RowBox[{"188", "\[Rule]", "199"}], ",", 
       RowBox[{"188", "\[Rule]", "189"}], ",", 
       RowBox[{"188", "\[Rule]", "185"}], ",", 
       RowBox[{"596", "\[Rule]", "583"}], ",", 
       RowBox[{"596", "\[Rule]", "607"}], ",", 
       RowBox[{"596", "\[Rule]", "597"}], ",", 
       RowBox[{"596", "\[Rule]", "593"}], ",", 
       RowBox[{"120", "\[Rule]", "107"}], ",", 
       RowBox[{"120", "\[Rule]", "131"}], ",", 
       RowBox[{"120", "\[Rule]", "121"}], ",", 
       RowBox[{"120", "\[Rule]", "117"}], ",", 
       RowBox[{"528", "\[Rule]", "515"}], ",", 
       RowBox[{"528", "\[Rule]", "539"}], ",", 
       RowBox[{"528", "\[Rule]", "529"}], ",", 
       RowBox[{"528", "\[Rule]", "525"}], ",", 
       RowBox[{"324", "\[Rule]", "311"}], ",", 
       RowBox[{"324", "\[Rule]", "335"}], ",", 
       RowBox[{"324", "\[Rule]", "325"}], ",", 
       RowBox[{"324", "\[Rule]", "321"}], ",", 
       RowBox[{"52", "\[Rule]", "39"}], ",", 
       RowBox[{"52", "\[Rule]", "63"}], ",", 
       RowBox[{"52", "\[Rule]", "53"}], ",", 
       RowBox[{"52", "\[Rule]", "49"}], ",", 
       RowBox[{"460", "\[Rule]", "447"}], ",", 
       RowBox[{"460", "\[Rule]", "471"}], ",", 
       RowBox[{"460", "\[Rule]", "461"}], ",", 
       RowBox[{"460", "\[Rule]", "457"}], ",", 
       RowBox[{"256", "\[Rule]", "243"}], ",", 
       RowBox[{"256", "\[Rule]", "267"}], ",", 
       RowBox[{"256", "\[Rule]", "257"}], ",", 
       RowBox[{"256", "\[Rule]", "253"}], ",", 
       RowBox[{"986", "\[Rule]", "973"}], ",", 
       RowBox[{"986", "\[Rule]", "995"}], ",", 
       RowBox[{"986", "\[Rule]", "983"}], ",", 
       RowBox[{"918", "\[Rule]", "905"}], ",", 
       RowBox[{"918", "\[Rule]", "927"}], ",", 
       RowBox[{"918", "\[Rule]", "915"}], ",", 
       RowBox[{"714", "\[Rule]", "701"}], ",", 
       RowBox[{"714", "\[Rule]", "723"}], ",", 
       RowBox[{"714", "\[Rule]", "711"}], ",", 
       RowBox[{"1008", "\[Rule]", "995"}], ",", 
       RowBox[{"1008", "\[Rule]", "1019"}], ",", 
       RowBox[{"1008", "\[Rule]", "1005"}], ",", 
       RowBox[{"940", "\[Rule]", "927"}], ",", 
       RowBox[{"940", "\[Rule]", "951"}], ",", 
       RowBox[{"940", "\[Rule]", "937"}], ",", 
       RowBox[{"736", "\[Rule]", "723"}], ",", 
       RowBox[{"736", "\[Rule]", "747"}], ",", 
       RowBox[{"736", "\[Rule]", "733"}], ",", 
       RowBox[{"994", "\[Rule]", "983"}], ",", 
       RowBox[{"994", "\[Rule]", "1005"}], ",", 
       RowBox[{"994", "\[Rule]", "995"}], ",", 
       RowBox[{"994", "\[Rule]", "991"}], ",", 
       RowBox[{"926", "\[Rule]", "915"}], ",", 
       RowBox[{"926", "\[Rule]", "937"}], ",", 
       RowBox[{"926", "\[Rule]", "927"}], ",", 
       RowBox[{"926", "\[Rule]", "923"}], ",", 
       RowBox[{"722", "\[Rule]", "711"}], ",", 
       RowBox[{"722", "\[Rule]", "733"}], ",", 
       RowBox[{"722", "\[Rule]", "723"}], ",", 
       RowBox[{"722", "\[Rule]", "719"}], ",", 
       RowBox[{"850", "\[Rule]", "837"}], ",", 
       RowBox[{"850", "\[Rule]", "859"}], ",", 
       RowBox[{"850", "\[Rule]", "847"}], ",", 
       RowBox[{"646", "\[Rule]", "633"}], ",", 
       RowBox[{"646", "\[Rule]", "655"}], ",", 
       RowBox[{"646", "\[Rule]", "643"}], ",", 
       RowBox[{"872", "\[Rule]", "859"}], ",", 
       RowBox[{"872", "\[Rule]", "883"}], ",", 
       RowBox[{"872", "\[Rule]", "869"}], ",", 
       RowBox[{"668", "\[Rule]", "655"}], ",", 
       RowBox[{"668", "\[Rule]", "679"}], ",", 
       RowBox[{"668", "\[Rule]", "665"}], ",", 
       RowBox[{"858", "\[Rule]", "847"}], ",", 
       RowBox[{"858", "\[Rule]", "869"}], ",", 
       RowBox[{"858", "\[Rule]", "859"}], ",", 
       RowBox[{"858", "\[Rule]", "855"}], ",", 
       RowBox[{"654", "\[Rule]", "643"}], ",", 
       RowBox[{"654", "\[Rule]", "665"}], ",", 
       RowBox[{"654", "\[Rule]", "655"}], ",", 
       RowBox[{"654", "\[Rule]", "651"}], ",", 
       RowBox[{"1018", "\[Rule]", "1005"}], ",", 
       RowBox[{"1018", "\[Rule]", "1019"}], ",", 
       RowBox[{"1018", "\[Rule]", "1015"}], ",", 
       RowBox[{"950", "\[Rule]", "937"}], ",", 
       RowBox[{"950", "\[Rule]", "951"}], ",", 
       RowBox[{"950", "\[Rule]", "947"}], ",", 
       RowBox[{"746", "\[Rule]", "733"}], ",", 
       RowBox[{"746", "\[Rule]", "747"}], ",", 
       RowBox[{"746", "\[Rule]", "743"}], ",", 
       RowBox[{"882", "\[Rule]", "869"}], ",", 
       RowBox[{"882", "\[Rule]", "883"}], ",", 
       RowBox[{"882", "\[Rule]", "879"}], ",", 
       RowBox[{"678", "\[Rule]", "665"}], ",", 
       RowBox[{"678", "\[Rule]", "679"}], ",", 
       RowBox[{"678", "\[Rule]", "675"}], ",", 
       RowBox[{"1004", "\[Rule]", "991"}], ",", 
       RowBox[{"1004", "\[Rule]", "1015"}], ",", 
       RowBox[{"1004", "\[Rule]", "1005"}], ",", 
       RowBox[{"1004", "\[Rule]", "1001"}], ",", 
       RowBox[{"936", "\[Rule]", "923"}], ",", 
       RowBox[{"936", "\[Rule]", "947"}], ",", 
       RowBox[{"936", "\[Rule]", "937"}], ",", 
       RowBox[{"936", "\[Rule]", "933"}], ",", 
       RowBox[{"732", "\[Rule]", "719"}], ",", 
       RowBox[{"732", "\[Rule]", "743"}], ",", 
       RowBox[{"732", "\[Rule]", "733"}], ",", 
       RowBox[{"732", "\[Rule]", "729"}], ",", 
       RowBox[{"868", "\[Rule]", "855"}], ",", 
       RowBox[{"868", "\[Rule]", "879"}], ",", 
       RowBox[{"868", "\[Rule]", "869"}], ",", 
       RowBox[{"868", "\[Rule]", "865"}], ",", 
       RowBox[{"664", "\[Rule]", "651"}], ",", 
       RowBox[{"664", "\[Rule]", "675"}], ",", 
       RowBox[{"664", "\[Rule]", "665"}], ",", 
       RowBox[{"664", "\[Rule]", "661"}], ",", 
       RowBox[{"198", "\[Rule]", "185"}], ",", 
       RowBox[{"198", "\[Rule]", "199"}], ",", 
       RowBox[{"198", "\[Rule]", "195"}], ",", 
       RowBox[{"606", "\[Rule]", "593"}], ",", 
       RowBox[{"606", "\[Rule]", "607"}], ",", 
       RowBox[{"606", "\[Rule]", "603"}], ",", 
       RowBox[{"130", "\[Rule]", "117"}], ",", 
       RowBox[{"130", "\[Rule]", "131"}], ",", 
       RowBox[{"130", "\[Rule]", "127"}], ",", 
       RowBox[{"538", "\[Rule]", "525"}], ",", 
       RowBox[{"538", "\[Rule]", "539"}], ",", 
       RowBox[{"538", "\[Rule]", "535"}], ",", 
       RowBox[{"334", "\[Rule]", "321"}], ",", 
       RowBox[{"334", "\[Rule]", "335"}], ",", 
       RowBox[{"334", "\[Rule]", "331"}], ",", 
       RowBox[{"62", "\[Rule]", "49"}], ",", 
       RowBox[{"62", "\[Rule]", "63"}], ",", 
       RowBox[{"62", "\[Rule]", "59"}], ",", 
       RowBox[{"470", "\[Rule]", "457"}], ",", 
       RowBox[{"470", "\[Rule]", "471"}], ",", 
       RowBox[{"470", "\[Rule]", "467"}], ",", 
       RowBox[{"266", "\[Rule]", "253"}], ",", 
       RowBox[{"266", "\[Rule]", "267"}], ",", 
       RowBox[{"266", "\[Rule]", "263"}], ",", 
       RowBox[{"1014", "\[Rule]", "1001"}], ",", 
       RowBox[{"1014", "\[Rule]", "1015"}], ",", 
       RowBox[{"1014", "\[Rule]", "1011"}], ",", 
       RowBox[{"946", "\[Rule]", "933"}], ",", 
       RowBox[{"946", "\[Rule]", "947"}], ",", 
       RowBox[{"946", "\[Rule]", "943"}], ",", 
       RowBox[{"742", "\[Rule]", "729"}], ",", 
       RowBox[{"742", "\[Rule]", "743"}], ",", 
       RowBox[{"742", "\[Rule]", "739"}], ",", 
       RowBox[{"878", "\[Rule]", "865"}], ",", 
       RowBox[{"878", "\[Rule]", "879"}], ",", 
       RowBox[{"878", "\[Rule]", "875"}], ",", 
       RowBox[{"674", "\[Rule]", "661"}], ",", 
       RowBox[{"674", "\[Rule]", "675"}], ",", 
       RowBox[{"674", "\[Rule]", "671"}], ",", 
       RowBox[{"157", "\[Rule]", "362"}], ",", 
       RowBox[{"157", "\[Rule]", "362"}], ",", 
       RowBox[{"157", "\[Rule]", "294"}], ",", 
       RowBox[{"157", "\[Rule]", "294"}], ",", 
       RowBox[{"157", "\[Rule]", "158"}], ",", 
       RowBox[{"179", "\[Rule]", "384"}], ",", 
       RowBox[{"179", "\[Rule]", "384"}], ",", 
       RowBox[{"179", "\[Rule]", "316"}], ",", 
       RowBox[{"179", "\[Rule]", "316"}], ",", 
       RowBox[{"179", "\[Rule]", "180"}], ",", 
       RowBox[{"167", "\[Rule]", "372"}], ",", 
       RowBox[{"167", "\[Rule]", "372"}], ",", 
       RowBox[{"167", "\[Rule]", "304"}], ",", 
       RowBox[{"167", "\[Rule]", "304"}], ",", 
       RowBox[{"167", "\[Rule]", "168"}], ",", 
       RowBox[{"565", "\[Rule]", "362"}], ",", 
       RowBox[{"565", "\[Rule]", "362"}], ",", 
       RowBox[{"565", "\[Rule]", "770"}], ",", 
       RowBox[{"565", "\[Rule]", "770"}], ",", 
       RowBox[{"565", "\[Rule]", "294"}], ",", 
       RowBox[{"565", "\[Rule]", "294"}], ",", 
       RowBox[{"565", "\[Rule]", "702"}], ",", 
       RowBox[{"565", "\[Rule]", "702"}], ",", 
       RowBox[{"565", "\[Rule]", "566"}], ",", 
       RowBox[{"587", "\[Rule]", "384"}], ",", 
       RowBox[{"587", "\[Rule]", "384"}], ",", 
       RowBox[{"587", "\[Rule]", "792"}], ",", 
       RowBox[{"587", "\[Rule]", "792"}], ",", 
       RowBox[{"587", "\[Rule]", "316"}], ",", 
       RowBox[{"587", "\[Rule]", "316"}], ",", 
       RowBox[{"587", "\[Rule]", "724"}], ",", 
       RowBox[{"587", "\[Rule]", "724"}], ",", 
       RowBox[{"587", "\[Rule]", "588"}], ",", 
       RowBox[{"575", "\[Rule]", "372"}], ",", 
       RowBox[{"575", "\[Rule]", "372"}], ",", 
       RowBox[{"575", "\[Rule]", "780"}], ",", 
       RowBox[{"575", "\[Rule]", "780"}], ",", 
       RowBox[{"575", "\[Rule]", "304"}], ",", 
       RowBox[{"575", "\[Rule]", "304"}], ",", 
       RowBox[{"575", "\[Rule]", "712"}], ",", 
       RowBox[{"575", "\[Rule]", "712"}], ",", 
       RowBox[{"575", "\[Rule]", "576"}], ",", 
       RowBox[{"89", "\[Rule]", "294"}], ",", 
       RowBox[{"89", "\[Rule]", "226"}], ",", 
       RowBox[{"89", "\[Rule]", "90"}], ",", 
       RowBox[{"99", "\[Rule]", "304"}], ",", 
       RowBox[{"99", "\[Rule]", "236"}], ",", 
       RowBox[{"99", "\[Rule]", "100"}], ",", 
       RowBox[{"497", "\[Rule]", "294"}], ",", 
       RowBox[{"497", "\[Rule]", "702"}], ",", 
       RowBox[{"497", "\[Rule]", "702"}], ",", 
       RowBox[{"497", "\[Rule]", "226"}], ",", 
       RowBox[{"497", "\[Rule]", "634"}], ",", 
       RowBox[{"497", "\[Rule]", "634"}], ",", 
       RowBox[{"497", "\[Rule]", "498"}], ",", 
       RowBox[{"507", "\[Rule]", "304"}], ",", 
       RowBox[{"507", "\[Rule]", "712"}], ",", 
       RowBox[{"507", "\[Rule]", "712"}], ",", 
       RowBox[{"507", "\[Rule]", "236"}], ",", 
       RowBox[{"507", "\[Rule]", "644"}], ",", 
       RowBox[{"507", "\[Rule]", "644"}], ",", 
       RowBox[{"507", "\[Rule]", "508"}], ",", 
       RowBox[{"293", "\[Rule]", "158"}], ",", 
       RowBox[{"293", "\[Rule]", "158"}], ",", 
       RowBox[{"293", "\[Rule]", "566"}], ",", 
       RowBox[{"293", "\[Rule]", "566"}], ",", 
       RowBox[{"293", "\[Rule]", "90"}], ",", 
       RowBox[{"293", "\[Rule]", "498"}], ",", 
       RowBox[{"293", "\[Rule]", "294"}], ",", 
       RowBox[{"315", "\[Rule]", "180"}], ",", 
       RowBox[{"315", "\[Rule]", "180"}], ",", 
       RowBox[{"315", "\[Rule]", "588"}], ",", 
       RowBox[{"315", "\[Rule]", "588"}], ",", 
       RowBox[{"315", "\[Rule]", "112"}], ",", 
       RowBox[{"315", "\[Rule]", "520"}], ",", 
       RowBox[{"315", "\[Rule]", "316"}], ",", 
       RowBox[{"303", "\[Rule]", "168"}], ",", 
       RowBox[{"303", "\[Rule]", "168"}], ",", 
       RowBox[{"303", "\[Rule]", "576"}], ",", 
       RowBox[{"303", "\[Rule]", "576"}], ",", 
       RowBox[{"303", "\[Rule]", "100"}], ",", 
       RowBox[{"303", "\[Rule]", "508"}], ",", 
       RowBox[{"303", "\[Rule]", "304"}], ",", 
       RowBox[{"203", "\[Rule]", "408"}], ",", 
       RowBox[{"203", "\[Rule]", "408"}], ",", 
       RowBox[{"203", "\[Rule]", "340"}], ",", 
       RowBox[{"203", "\[Rule]", "340"}], ",", 
       RowBox[{"203", "\[Rule]", "204"}], ",", 
       RowBox[{"189", "\[Rule]", "394"}], ",", 
       RowBox[{"189", "\[Rule]", "394"}], ",", 
       RowBox[{"189", "\[Rule]", "326"}], ",", 
       RowBox[{"189", "\[Rule]", "326"}], ",", 
       RowBox[{"189", "\[Rule]", "190"}], ",", 
       RowBox[{"611", "\[Rule]", "408"}], ",", 
       RowBox[{"611", "\[Rule]", "408"}], ",", 
       RowBox[{"611", "\[Rule]", "816"}], ",", 
       RowBox[{"611", "\[Rule]", "816"}], ",", 
       RowBox[{"611", "\[Rule]", "340"}], ",", 
       RowBox[{"611", "\[Rule]", "340"}], ",", 
       RowBox[{"611", "\[Rule]", "748"}], ",", 
       RowBox[{"611", "\[Rule]", "748"}], ",", 
       RowBox[{"611", "\[Rule]", "612"}], ",", 
       RowBox[{"597", "\[Rule]", "394"}], ",", 
       RowBox[{"597", "\[Rule]", "394"}], ",", 
       RowBox[{"597", "\[Rule]", "802"}], ",", 
       RowBox[{"597", "\[Rule]", "802"}], ",", 
       RowBox[{"597", "\[Rule]", "326"}], ",", 
       RowBox[{"597", "\[Rule]", "326"}], ",", 
       RowBox[{"597", "\[Rule]", "734"}], ",", 
       RowBox[{"597", "\[Rule]", "734"}], ",", 
       RowBox[{"597", "\[Rule]", "598"}], ",", 
       RowBox[{"339", "\[Rule]", "204"}], ",", 
       RowBox[{"339", "\[Rule]", "204"}], ",", 
       RowBox[{"339", "\[Rule]", "612"}], ",", 
       RowBox[{"339", "\[Rule]", "612"}], ",", 
       RowBox[{"339", "\[Rule]", "136"}], ",", 
       RowBox[{"339", "\[Rule]", "544"}], ",", 
       RowBox[{"339", "\[Rule]", "340"}], ",", 
       RowBox[{"325", "\[Rule]", "190"}], ",", 
       RowBox[{"325", "\[Rule]", "190"}], ",", 
       RowBox[{"325", "\[Rule]", "598"}], ",", 
       RowBox[{"325", "\[Rule]", "598"}], ",", 
       RowBox[{"325", "\[Rule]", "122"}], ",", 
       RowBox[{"325", "\[Rule]", "530"}], ",", 
       RowBox[{"325", "\[Rule]", "326"}], ",", 
       RowBox[{"175", "\[Rule]", "380"}], ",", 
       RowBox[{"175", "\[Rule]", "380"}], ",", 
       RowBox[{"175", "\[Rule]", "312"}], ",", 
       RowBox[{"175", "\[Rule]", "312"}], ",", 
       RowBox[{"175", "\[Rule]", "176"}], ",", 
       RowBox[{"583", "\[Rule]", "380"}], ",", 
       RowBox[{"583", "\[Rule]", "380"}], ",", 
       RowBox[{"583", "\[Rule]", "788"}], ",", 
       RowBox[{"583", "\[Rule]", "788"}], ",", 
       RowBox[{"583", "\[Rule]", "312"}], ",", 
       RowBox[{"583", "\[Rule]", "312"}], ",", 
       RowBox[{"583", "\[Rule]", "720"}], ",", 
       RowBox[{"583", "\[Rule]", "720"}], ",", 
       RowBox[{"583", "\[Rule]", "584"}], ",", 
       RowBox[{"107", "\[Rule]", "312"}], ",", 
       RowBox[{"107", "\[Rule]", "244"}], ",", 
       RowBox[{"107", "\[Rule]", "108"}], ",", 
       RowBox[{"515", "\[Rule]", "312"}], ",", 
       RowBox[{"515", "\[Rule]", "720"}], ",", 
       RowBox[{"515", "\[Rule]", "720"}], ",", 
       RowBox[{"515", "\[Rule]", "244"}], ",", 
       RowBox[{"515", "\[Rule]", "652"}], ",", 
       RowBox[{"515", "\[Rule]", "652"}], ",", 
       RowBox[{"515", "\[Rule]", "516"}], ",", 
       RowBox[{"311", "\[Rule]", "176"}], ",", 
       RowBox[{"311", "\[Rule]", "176"}], ",", 
       RowBox[{"311", "\[Rule]", "584"}], ",", 
       RowBox[{"311", "\[Rule]", "584"}], ",", 
       RowBox[{"311", "\[Rule]", "108"}], ",", 
       RowBox[{"311", "\[Rule]", "516"}], ",", 
       RowBox[{"311", "\[Rule]", "312"}], ",", 
       RowBox[{"21", "\[Rule]", "226"}], ",", 
       RowBox[{"21", "\[Rule]", "226"}], ",", 
       RowBox[{"21", "\[Rule]", "22"}], ",", 
       RowBox[{"31", "\[Rule]", "236"}], ",", 
       RowBox[{"31", "\[Rule]", "236"}], ",", 
       RowBox[{"31", "\[Rule]", "32"}], ",", 
       RowBox[{"429", "\[Rule]", "226"}], ",", 
       RowBox[{"429", "\[Rule]", "226"}], ",", 
       RowBox[{"429", "\[Rule]", "634"}], ",", 
       RowBox[{"429", "\[Rule]", "430"}], ",", 
       RowBox[{"439", "\[Rule]", "236"}], ",", 
       RowBox[{"439", "\[Rule]", "236"}], ",", 
       RowBox[{"439", "\[Rule]", "644"}], ",", 
       RowBox[{"439", "\[Rule]", "440"}], ",", 
       RowBox[{"225", "\[Rule]", "90"}], ",", 
       RowBox[{"225", "\[Rule]", "498"}], ",", 
       RowBox[{"225", "\[Rule]", "22"}], ",", 
       RowBox[{"225", "\[Rule]", "22"}], ",", 
       RowBox[{"225", "\[Rule]", "430"}], ",", 
       RowBox[{"225", "\[Rule]", "430"}], ",", 
       RowBox[{"225", "\[Rule]", "226"}], ",", 
       RowBox[{"235", "\[Rule]", "100"}], ",", 
       RowBox[{"235", "\[Rule]", "508"}], ",", 
       RowBox[{"235", "\[Rule]", "32"}], ",", 
       RowBox[{"235", "\[Rule]", "32"}], ",", 
       RowBox[{"235", "\[Rule]", "440"}], ",", 
       RowBox[{"235", "\[Rule]", "440"}], ",", 
       RowBox[{"235", "\[Rule]", "236"}], ",", 
       RowBox[{"39", "\[Rule]", "244"}], ",", 
       RowBox[{"39", "\[Rule]", "244"}], ",", 
       RowBox[{"39", "\[Rule]", "40"}], ",", 
       RowBox[{"447", "\[Rule]", "244"}], ",", 
       RowBox[{"447", "\[Rule]", "244"}], ",", 
       RowBox[{"447", "\[Rule]", "652"}], ",", 
       RowBox[{"447", "\[Rule]", "448"}], ",", 
       RowBox[{"243", "\[Rule]", "108"}], ",", 
       RowBox[{"243", "\[Rule]", "516"}], ",", 
       RowBox[{"243", "\[Rule]", "40"}], ",", 
       RowBox[{"243", "\[Rule]", "40"}], ",", 
       RowBox[{"243", "\[Rule]", "448"}], ",", 
       RowBox[{"243", "\[Rule]", "448"}], ",", 
       RowBox[{"243", "\[Rule]", "244"}], ",", 
       RowBox[{"199", "\[Rule]", "404"}], ",", 
       RowBox[{"199", "\[Rule]", "404"}], ",", 
       RowBox[{"199", "\[Rule]", "336"}], ",", 
       RowBox[{"199", "\[Rule]", "336"}], ",", 
       RowBox[{"199", "\[Rule]", "200"}], ",", 
       RowBox[{"607", "\[Rule]", "404"}], ",", 
       RowBox[{"607", "\[Rule]", "404"}], ",", 
       RowBox[{"607", "\[Rule]", "812"}], ",", 
       RowBox[{"607", "\[Rule]", "812"}], ",", 
       RowBox[{"607", "\[Rule]", "336"}], ",", 
       RowBox[{"607", "\[Rule]", "336"}], ",", 
       RowBox[{"607", "\[Rule]", "744"}], ",", 
       RowBox[{"607", "\[Rule]", "744"}], ",", 
       RowBox[{"607", "\[Rule]", "608"}], ",", 
       RowBox[{"335", "\[Rule]", "200"}], ",", 
       RowBox[{"335", "\[Rule]", "200"}], ",", 
       RowBox[{"335", "\[Rule]", "608"}], ",", 
       RowBox[{"335", "\[Rule]", "608"}], ",", 
       RowBox[{"335", "\[Rule]", "132"}], ",", 
       RowBox[{"335", "\[Rule]", "540"}], ",", 
       RowBox[{"335", "\[Rule]", "336"}], ",", 
       RowBox[{"185", "\[Rule]", "390"}], ",", 
       RowBox[{"185", "\[Rule]", "390"}], ",", 
       RowBox[{"185", "\[Rule]", "322"}], ",", 
       RowBox[{"185", "\[Rule]", "322"}], ",", 
       RowBox[{"185", "\[Rule]", "186"}], ",", 
       RowBox[{"593", "\[Rule]", "390"}], ",", 
       RowBox[{"593", "\[Rule]", "390"}], ",", 
       RowBox[{"593", "\[Rule]", "798"}], ",", 
       RowBox[{"593", "\[Rule]", "798"}], ",", 
       RowBox[{"593", "\[Rule]", "322"}], ",", 
       RowBox[{"593", "\[Rule]", "322"}], ",", 
       RowBox[{"593", "\[Rule]", "730"}], ",", 
       RowBox[{"593", "\[Rule]", "730"}], ",", 
       RowBox[{"593", "\[Rule]", "594"}], ",", 
       RowBox[{"117", "\[Rule]", "322"}], ",", 
       RowBox[{"117", "\[Rule]", "254"}], ",", 
       RowBox[{"117", "\[Rule]", "118"}], ",", 
       RowBox[{"525", "\[Rule]", "322"}], ",", 
       RowBox[{"525", "\[Rule]", "730"}], ",", 
       RowBox[{"525", "\[Rule]", "730"}], ",", 
       RowBox[{"525", "\[Rule]", "254"}], ",", 
       RowBox[{"525", "\[Rule]", "662"}], ",", 
       RowBox[{"525", "\[Rule]", "662"}], ",", 
       RowBox[{"525", "\[Rule]", "526"}], ",", 
       RowBox[{"321", "\[Rule]", "186"}], ",", 
       RowBox[{"321", "\[Rule]", "186"}], ",", 
       RowBox[{"321", "\[Rule]", "594"}], ",", 
       RowBox[{"321", "\[Rule]", "594"}], ",", 
       RowBox[{"321", "\[Rule]", "118"}], ",", 
       RowBox[{"321", "\[Rule]", "526"}], ",", 
       RowBox[{"321", "\[Rule]", "322"}], ",", 
       RowBox[{"49", "\[Rule]", "254"}], ",", 
       RowBox[{"49", "\[Rule]", "254"}], ",", 
       RowBox[{"49", "\[Rule]", "50"}], ",", 
       RowBox[{"457", "\[Rule]", "254"}], ",", 
       RowBox[{"457", "\[Rule]", "254"}], ",", 
       RowBox[{"457", "\[Rule]", "662"}], ",", 
       RowBox[{"457", "\[Rule]", "458"}], ",", 
       RowBox[{"253", "\[Rule]", "118"}], ",", 
       RowBox[{"253", "\[Rule]", "526"}], ",", 
       RowBox[{"253", "\[Rule]", "50"}], ",", 
       RowBox[{"253", "\[Rule]", "50"}], ",", 
       RowBox[{"253", "\[Rule]", "458"}], ",", 
       RowBox[{"253", "\[Rule]", "458"}], ",", 
       RowBox[{"253", "\[Rule]", "254"}], ",", 
       RowBox[{"973", "\[Rule]", "770"}], ",", 
       RowBox[{"973", "\[Rule]", "770"}], ",", 
       RowBox[{"973", "\[Rule]", "1178"}], ",", 
       RowBox[{"973", "\[Rule]", "1178"}], ",", 
       RowBox[{"973", "\[Rule]", "702"}], ",", 
       RowBox[{"973", "\[Rule]", "702"}], ",", 
       RowBox[{"973", "\[Rule]", "1110"}], ",", 
       RowBox[{"973", "\[Rule]", "1110"}], ",", 
       RowBox[{"973", "\[Rule]", "974"}], ",", 
       RowBox[{"995", "\[Rule]", "792"}], ",", 
       RowBox[{"995", "\[Rule]", "792"}], ",", 
       RowBox[{"995", "\[Rule]", "1200"}], ",", 
       RowBox[{"995", "\[Rule]", "1200"}], ",", 
       RowBox[{"995", "\[Rule]", "724"}], ",", 
       RowBox[{"995", "\[Rule]", "724"}], ",", 
       RowBox[{"995", "\[Rule]", "1132"}], ",", 
       RowBox[{"995", "\[Rule]", "1132"}], ",", 
       RowBox[{"995", "\[Rule]", "996"}], ",", 
       RowBox[{"983", "\[Rule]", "780"}], ",", 
       RowBox[{"983", "\[Rule]", "780"}], ",", 
       RowBox[{"983", "\[Rule]", "1188"}], ",", 
       RowBox[{"983", "\[Rule]", "1188"}], ",", 
       RowBox[{"983", "\[Rule]", "712"}], ",", 
       RowBox[{"983", "\[Rule]", "712"}], ",", 
       RowBox[{"983", "\[Rule]", "1120"}], ",", 
       RowBox[{"983", "\[Rule]", "1120"}], ",", 
       RowBox[{"983", "\[Rule]", "984"}], ",", 
       RowBox[{"905", "\[Rule]", "702"}], ",", 
       RowBox[{"905", "\[Rule]", "702"}], ",", 
       RowBox[{"905", "\[Rule]", "1110"}], ",", 
       RowBox[{"905", "\[Rule]", "1110"}], ",", 
       RowBox[{"905", "\[Rule]", "634"}], ",", 
       RowBox[{"905", "\[Rule]", "634"}], ",", 
       RowBox[{"905", "\[Rule]", "1042"}], ",", 
       RowBox[{"905", "\[Rule]", "1042"}], ",", 
       RowBox[{"905", "\[Rule]", "906"}], ",", 
       RowBox[{"927", "\[Rule]", "724"}], ",", 
       RowBox[{"927", "\[Rule]", "724"}], ",", 
       RowBox[{"927", "\[Rule]", "1132"}], ",", 
       RowBox[{"927", "\[Rule]", "1132"}], ",", 
       RowBox[{"927", "\[Rule]", "656"}], ",", 
       RowBox[{"927", "\[Rule]", "656"}], ",", 
       RowBox[{"927", "\[Rule]", "1064"}], ",", 
       RowBox[{"927", "\[Rule]", "1064"}], ",", 
       RowBox[{"927", "\[Rule]", "928"}], ",", 
       RowBox[{"915", "\[Rule]", "712"}], ",", 
       RowBox[{"915", "\[Rule]", "712"}], ",", 
       RowBox[{"915", "\[Rule]", "1120"}], ",", 
       RowBox[{"915", "\[Rule]", "1120"}], ",", 
       RowBox[{"915", "\[Rule]", "644"}], ",", 
       RowBox[{"915", "\[Rule]", "644"}], ",", 
       RowBox[{"915", "\[Rule]", "1052"}], ",", 
       RowBox[{"915", "\[Rule]", "1052"}], ",", 
       RowBox[{"915", "\[Rule]", "916"}], ",", 
       RowBox[{"701", "\[Rule]", "566"}], ",", 
       RowBox[{"701", "\[Rule]", "566"}], ",", 
       RowBox[{"701", "\[Rule]", "974"}], ",", 
       RowBox[{"701", "\[Rule]", "974"}], ",", 
       RowBox[{"701", "\[Rule]", "498"}], ",", 
       RowBox[{"701", "\[Rule]", "498"}], ",", 
       RowBox[{"701", "\[Rule]", "906"}], ",", 
       RowBox[{"701", "\[Rule]", "906"}], ",", 
       RowBox[{"701", "\[Rule]", "702"}], ",", 
       RowBox[{"723", "\[Rule]", "588"}], ",", 
       RowBox[{"723", "\[Rule]", "588"}], ",", 
       RowBox[{"723", "\[Rule]", "996"}], ",", 
       RowBox[{"723", "\[Rule]", "996"}], ",", 
       RowBox[{"723", "\[Rule]", "520"}], ",", 
       RowBox[{"723", "\[Rule]", "520"}], ",", 
       RowBox[{"723", "\[Rule]", "928"}], ",", 
       RowBox[{"723", "\[Rule]", "928"}], ",", 
       RowBox[{"723", "\[Rule]", "724"}], ",", 
       RowBox[{"711", "\[Rule]", "576"}], ",", 
       RowBox[{"711", "\[Rule]", "576"}], ",", 
       RowBox[{"711", "\[Rule]", "984"}], ",", 
       RowBox[{"711", "\[Rule]", "984"}], ",", 
       RowBox[{"711", "\[Rule]", "508"}], ",", 
       RowBox[{"711", "\[Rule]", "508"}], ",", 
       RowBox[{"711", "\[Rule]", "916"}], ",", 
       RowBox[{"711", "\[Rule]", "916"}], ",", 
       RowBox[{"711", "\[Rule]", "712"}], ",", 
       RowBox[{"1019", "\[Rule]", "816"}], ",", 
       RowBox[{"1019", "\[Rule]", "816"}], ",", 
       RowBox[{"1019", "\[Rule]", "1224"}], ",", 
       RowBox[{"1019", "\[Rule]", "1224"}], ",", 
       RowBox[{"1019", "\[Rule]", "748"}], ",", 
       RowBox[{"1019", "\[Rule]", "748"}], ",", 
       RowBox[{"1019", "\[Rule]", "1156"}], ",", 
       RowBox[{"1019", "\[Rule]", "1156"}], ",", 
       RowBox[{"1019", "\[Rule]", "1020"}], ",", 
       RowBox[{"1005", "\[Rule]", "802"}], ",", 
       RowBox[{"1005", "\[Rule]", "802"}], ",", 
       RowBox[{"1005", "\[Rule]", "1210"}], ",", 
       RowBox[{"1005", "\[Rule]", "1210"}], ",", 
       RowBox[{"1005", "\[Rule]", "734"}], ",", 
       RowBox[{"1005", "\[Rule]", "734"}], ",", 
       RowBox[{"1005", "\[Rule]", "1142"}], ",", 
       RowBox[{"1005", "\[Rule]", "1142"}], ",", 
       RowBox[{"1005", "\[Rule]", "1006"}], ",", 
       RowBox[{"951", "\[Rule]", "748"}], ",", 
       RowBox[{"951", "\[Rule]", "748"}], ",", 
       RowBox[{"951", "\[Rule]", "1156"}], ",", 
       RowBox[{"951", "\[Rule]", "1156"}], ",", 
       RowBox[{"951", "\[Rule]", "680"}], ",", 
       RowBox[{"951", "\[Rule]", "680"}], ",", 
       RowBox[{"951", "\[Rule]", "1088"}], ",", 
       RowBox[{"951", "\[Rule]", "1088"}], ",", 
       RowBox[{"951", "\[Rule]", "952"}], ",", 
       RowBox[{"937", "\[Rule]", "734"}], ",", 
       RowBox[{"937", "\[Rule]", "734"}], ",", 
       RowBox[{"937", "\[Rule]", "1142"}], ",", 
       RowBox[{"937", "\[Rule]", "1142"}], ",", 
       RowBox[{"937", "\[Rule]", "666"}], ",", 
       RowBox[{"937", "\[Rule]", "666"}], ",", 
       RowBox[{"937", "\[Rule]", "1074"}], ",", 
       RowBox[{"937", "\[Rule]", "1074"}], ",", 
       RowBox[{"937", "\[Rule]", "938"}], ",", 
       RowBox[{"747", "\[Rule]", "612"}], ",", 
       RowBox[{"747", "\[Rule]", "612"}], ",", 
       RowBox[{"747", "\[Rule]", "1020"}], ",", 
       RowBox[{"747", "\[Rule]", "1020"}], ",", 
       RowBox[{"747", "\[Rule]", "544"}], ",", 
       RowBox[{"747", "\[Rule]", "544"}], ",", 
       RowBox[{"747", "\[Rule]", "952"}], ",", 
       RowBox[{"747", "\[Rule]", "952"}], ",", 
       RowBox[{"747", "\[Rule]", "748"}], ",", 
       RowBox[{"733", "\[Rule]", "598"}], ",", 
       RowBox[{"733", "\[Rule]", "598"}], ",", 
       RowBox[{"733", "\[Rule]", "1006"}], ",", 
       RowBox[{"733", "\[Rule]", "1006"}], ",", 
       RowBox[{"733", "\[Rule]", "530"}], ",", 
       RowBox[{"733", "\[Rule]", "530"}], ",", 
       RowBox[{"733", "\[Rule]", "938"}], ",", 
       RowBox[{"733", "\[Rule]", "938"}], ",", 
       RowBox[{"733", "\[Rule]", "734"}], ",", 
       RowBox[{"991", "\[Rule]", "788"}], ",", 
       RowBox[{"991", "\[Rule]", "788"}], ",", 
       RowBox[{"991", "\[Rule]", "1196"}], ",", 
       RowBox[{"991", "\[Rule]", "1196"}], ",", 
       RowBox[{"991", "\[Rule]", "720"}], ",", 
       RowBox[{"991", "\[Rule]", "720"}], ",", 
       RowBox[{"991", "\[Rule]", "1128"}], ",", 
       RowBox[{"991", "\[Rule]", "1128"}], ",", 
       RowBox[{"991", "\[Rule]", "992"}], ",", 
       RowBox[{"923", "\[Rule]", "720"}], ",", 
       RowBox[{"923", "\[Rule]", "720"}], ",", 
       RowBox[{"923", "\[Rule]", "1128"}], ",", 
       RowBox[{"923", "\[Rule]", "1128"}], ",", 
       RowBox[{"923", "\[Rule]", "652"}], ",", 
       RowBox[{"923", "\[Rule]", "652"}], ",", 
       RowBox[{"923", "\[Rule]", "1060"}], ",", 
       RowBox[{"923", "\[Rule]", "1060"}], ",", 
       RowBox[{"923", "\[Rule]", "924"}], ",", 
       RowBox[{"719", "\[Rule]", "584"}], ",", 
       RowBox[{"719", "\[Rule]", "584"}], ",", 
       RowBox[{"719", "\[Rule]", "992"}], ",", 
       RowBox[{"719", "\[Rule]", "992"}], ",", 
       RowBox[{"719", "\[Rule]", "516"}], ",", 
       RowBox[{"719", "\[Rule]", "516"}], ",", 
       RowBox[{"719", "\[Rule]", "924"}], ",", 
       RowBox[{"719", "\[Rule]", "924"}], ",", 
       RowBox[{"719", "\[Rule]", "720"}], ",", 
       RowBox[{"837", "\[Rule]", "634"}], ",", 
       RowBox[{"837", "\[Rule]", "1042"}], ",", 
       RowBox[{"837", "\[Rule]", "1042"}], ",", 
       RowBox[{"837", "\[Rule]", "838"}], ",", 
       RowBox[{"859", "\[Rule]", "656"}], ",", 
       RowBox[{"859", "\[Rule]", "1064"}], ",", 
       RowBox[{"859", "\[Rule]", "1064"}], ",", 
       RowBox[{"859", "\[Rule]", "860"}], ",", 
       RowBox[{"847", "\[Rule]", "644"}], ",", 
       RowBox[{"847", "\[Rule]", "1052"}], ",", 
       RowBox[{"847", "\[Rule]", "1052"}], ",", 
       RowBox[{"847", "\[Rule]", "848"}], ",", 
       RowBox[{"633", "\[Rule]", "498"}], ",", 
       RowBox[{"633", "\[Rule]", "498"}], ",", 
       RowBox[{"633", "\[Rule]", "906"}], ",", 
       RowBox[{"633", "\[Rule]", "906"}], ",", 
       RowBox[{"633", "\[Rule]", "430"}], ",", 
       RowBox[{"633", "\[Rule]", "838"}], ",", 
       RowBox[{"633", "\[Rule]", "634"}], ",", 
       RowBox[{"655", "\[Rule]", "520"}], ",", 
       RowBox[{"655", "\[Rule]", "520"}], ",", 
       RowBox[{"655", "\[Rule]", "928"}], ",", 
       RowBox[{"655", "\[Rule]", "928"}], ",", 
       RowBox[{"655", "\[Rule]", "452"}], ",", 
       RowBox[{"655", "\[Rule]", "860"}], ",", 
       RowBox[{"655", "\[Rule]", "656"}], ",", 
       RowBox[{"643", "\[Rule]", "508"}], ",", 
       RowBox[{"643", "\[Rule]", "508"}], ",", 
       RowBox[{"643", "\[Rule]", "916"}], ",", 
       RowBox[{"643", "\[Rule]", "916"}], ",", 
       RowBox[{"643", "\[Rule]", "440"}], ",", 
       RowBox[{"643", "\[Rule]", "848"}], ",", 
       RowBox[{"643", "\[Rule]", "644"}], ",", 
       RowBox[{"883", "\[Rule]", "680"}], ",", 
       RowBox[{"883", "\[Rule]", "1088"}], ",", 
       RowBox[{"883", "\[Rule]", "1088"}], ",", 
       RowBox[{"883", "\[Rule]", "884"}], ",", 
       RowBox[{"869", "\[Rule]", "666"}], ",", 
       RowBox[{"869", "\[Rule]", "1074"}], ",", 
       RowBox[{"869", "\[Rule]", "1074"}], ",", 
       RowBox[{"869", "\[Rule]", "870"}], ",", 
       RowBox[{"679", "\[Rule]", "544"}], ",", 
       RowBox[{"679", "\[Rule]", "544"}], ",", 
       RowBox[{"679", "\[Rule]", "952"}], ",", 
       RowBox[{"679", "\[Rule]", "952"}], ",", 
       RowBox[{"679", "\[Rule]", "476"}], ",", 
       RowBox[{"679", "\[Rule]", "884"}], ",", 
       RowBox[{"679", "\[Rule]", "680"}], ",", 
       RowBox[{"665", "\[Rule]", "530"}], ",", 
       RowBox[{"665", "\[Rule]", "530"}], ",", 
       RowBox[{"665", "\[Rule]", "938"}], ",", 
       RowBox[{"665", "\[Rule]", "938"}], ",", 
       RowBox[{"665", "\[Rule]", "462"}], ",", 
       RowBox[{"665", "\[Rule]", "870"}], ",", 
       RowBox[{"665", "\[Rule]", "666"}], ",", 
       RowBox[{"855", "\[Rule]", "652"}], ",", 
       RowBox[{"855", "\[Rule]", "1060"}], ",", 
       RowBox[{"855", "\[Rule]", "1060"}], ",", 
       RowBox[{"855", "\[Rule]", "856"}], ",", 
       RowBox[{"651", "\[Rule]", "516"}], ",", 
       RowBox[{"651", "\[Rule]", "516"}], ",", 
       RowBox[{"651", "\[Rule]", "924"}], ",", 
       RowBox[{"651", "\[Rule]", "924"}], ",", 
       RowBox[{"651", "\[Rule]", "448"}], ",", 
       RowBox[{"651", "\[Rule]", "856"}], ",", 
       RowBox[{"651", "\[Rule]", "652"}], ",", 
       RowBox[{"1015", "\[Rule]", "812"}], ",", 
       RowBox[{"1015", "\[Rule]", "812"}], ",", 
       RowBox[{"1015", "\[Rule]", "1220"}], ",", 
       RowBox[{"1015", "\[Rule]", "1220"}], ",", 
       RowBox[{"1015", "\[Rule]", "744"}], ",", 
       RowBox[{"1015", "\[Rule]", "744"}], ",", 
       RowBox[{"1015", "\[Rule]", "1152"}], ",", 
       RowBox[{"1015", "\[Rule]", "1152"}], ",", 
       RowBox[{"1015", "\[Rule]", "1016"}], ",", 
       RowBox[{"947", "\[Rule]", "744"}], ",", 
       RowBox[{"947", "\[Rule]", "744"}], ",", 
       RowBox[{"947", "\[Rule]", "1152"}], ",", 
       RowBox[{"947", "\[Rule]", "1152"}], ",", 
       RowBox[{"947", "\[Rule]", "676"}], ",", 
       RowBox[{"947", "\[Rule]", "676"}], ",", 
       RowBox[{"947", "\[Rule]", "1084"}], ",", 
       RowBox[{"947", "\[Rule]", "1084"}], ",", 
       RowBox[{"947", "\[Rule]", "948"}], ",", 
       RowBox[{"743", "\[Rule]", "608"}], ",", 
       RowBox[{"743", "\[Rule]", "608"}], ",", 
       RowBox[{"743", "\[Rule]", "1016"}], ",", 
       RowBox[{"743", "\[Rule]", "1016"}], ",", 
       RowBox[{"743", "\[Rule]", "540"}], ",", 
       RowBox[{"743", "\[Rule]", "540"}], ",", 
       RowBox[{"743", "\[Rule]", "948"}], ",", 
       RowBox[{"743", "\[Rule]", "948"}], ",", 
       RowBox[{"743", "\[Rule]", "744"}], ",", 
       RowBox[{"879", "\[Rule]", "676"}], ",", 
       RowBox[{"879", "\[Rule]", "1084"}], ",", 
       RowBox[{"879", "\[Rule]", "1084"}], ",", 
       RowBox[{"879", "\[Rule]", "880"}], ",", 
       RowBox[{"675", "\[Rule]", "540"}], ",", 
       RowBox[{"675", "\[Rule]", "540"}], ",", 
       RowBox[{"675", "\[Rule]", "948"}], ",", 
       RowBox[{"675", "\[Rule]", "948"}], ",", 
       RowBox[{"675", "\[Rule]", "472"}], ",", 
       RowBox[{"675", "\[Rule]", "880"}], ",", 
       RowBox[{"675", "\[Rule]", "676"}], ",", 
       RowBox[{"1001", "\[Rule]", "798"}], ",", 
       RowBox[{"1001", "\[Rule]", "798"}], ",", 
       RowBox[{"1001", "\[Rule]", "1206"}], ",", 
       RowBox[{"1001", "\[Rule]", "1206"}], ",", 
       RowBox[{"1001", "\[Rule]", "730"}], ",", 
       RowBox[{"1001", "\[Rule]", "730"}], ",", 
       RowBox[{"1001", "\[Rule]", "1138"}], ",", 
       RowBox[{"1001", "\[Rule]", "1138"}], ",", 
       RowBox[{"1001", "\[Rule]", "1002"}], ",", 
       RowBox[{"933", "\[Rule]", "730"}], ",", 
       RowBox[{"933", "\[Rule]", "730"}], ",", 
       RowBox[{"933", "\[Rule]", "1138"}], ",", 
       RowBox[{"933", "\[Rule]", "1138"}], ",", 
       RowBox[{"933", "\[Rule]", "662"}], ",", 
       RowBox[{"933", "\[Rule]", "662"}], ",", 
       RowBox[{"933", "\[Rule]", "1070"}], ",", 
       RowBox[{"933", "\[Rule]", "1070"}], ",", 
       RowBox[{"933", "\[Rule]", "934"}], ",", 
       RowBox[{"729", "\[Rule]", "594"}], ",", 
       RowBox[{"729", "\[Rule]", "594"}], ",", 
       RowBox[{"729", "\[Rule]", "1002"}], ",", 
       RowBox[{"729", "\[Rule]", "1002"}], ",", 
       RowBox[{"729", "\[Rule]", "526"}], ",", 
       RowBox[{"729", "\[Rule]", "526"}], ",", 
       RowBox[{"729", "\[Rule]", "934"}], ",", 
       RowBox[{"729", "\[Rule]", "934"}], ",", 
       RowBox[{"729", "\[Rule]", "730"}], ",", 
       RowBox[{"865", "\[Rule]", "662"}], ",", 
       RowBox[{"865", "\[Rule]", "1070"}], ",", 
       RowBox[{"865", "\[Rule]", "1070"}], ",", 
       RowBox[{"865", "\[Rule]", "866"}], ",", 
       RowBox[{"661", "\[Rule]", "526"}], ",", 
       RowBox[{"661", "\[Rule]", "526"}], ",", 
       RowBox[{"661", "\[Rule]", "934"}], ",", 
       RowBox[{"661", "\[Rule]", "934"}], ",", 
       RowBox[{"661", "\[Rule]", "458"}], ",", 
       RowBox[{"661", "\[Rule]", "866"}], ",", 
       RowBox[{"661", "\[Rule]", "662"}], ",", 
       RowBox[{"195", "\[Rule]", "400"}], ",", 
       RowBox[{"195", "\[Rule]", "400"}], ",", 
       RowBox[{"195", "\[Rule]", "332"}], ",", 
       RowBox[{"195", "\[Rule]", "332"}], ",", 
       RowBox[{"195", "\[Rule]", "196"}], ",", 
       RowBox[{"603", "\[Rule]", "400"}], ",", 
       RowBox[{"603", "\[Rule]", "400"}], ",", 
       RowBox[{"603", "\[Rule]", "808"}], ",", 
       RowBox[{"603", "\[Rule]", "808"}], ",", 
       RowBox[{"603", "\[Rule]", "332"}], ",", 
       RowBox[{"603", "\[Rule]", "332"}], ",", 
       RowBox[{"603", "\[Rule]", "740"}], ",", 
       RowBox[{"603", "\[Rule]", "740"}], ",", 
       RowBox[{"603", "\[Rule]", "604"}], ",", 
       RowBox[{"127", "\[Rule]", "332"}], ",", 
       RowBox[{"127", "\[Rule]", "264"}], ",", 
       RowBox[{"127", "\[Rule]", "128"}], ",", 
       RowBox[{"535", "\[Rule]", "332"}], ",", 
       RowBox[{"535", "\[Rule]", "740"}], ",", 
       RowBox[{"535", "\[Rule]", "740"}], ",", 
       RowBox[{"535", "\[Rule]", "264"}], ",", 
       RowBox[{"535", "\[Rule]", "672"}], ",", 
       RowBox[{"535", "\[Rule]", "672"}], ",", 
       RowBox[{"535", "\[Rule]", "536"}], ",", 
       RowBox[{"331", "\[Rule]", "196"}], ",", 
       RowBox[{"331", "\[Rule]", "196"}], ",", 
       RowBox[{"331", "\[Rule]", "604"}], ",", 
       RowBox[{"331", "\[Rule]", "604"}], ",", 
       RowBox[{"331", "\[Rule]", "128"}], ",", 
       RowBox[{"331", "\[Rule]", "536"}], ",", 
       RowBox[{"331", "\[Rule]", "332"}], ",", 
       RowBox[{"59", "\[Rule]", "264"}], ",", 
       RowBox[{"59", "\[Rule]", "264"}], ",", 
       RowBox[{"59", "\[Rule]", "60"}], ",", 
       RowBox[{"467", "\[Rule]", "264"}], ",", 
       RowBox[{"467", "\[Rule]", "264"}], ",", 
       RowBox[{"467", "\[Rule]", "672"}], ",", 
       RowBox[{"467", "\[Rule]", "468"}], ",", 
       RowBox[{"263", "\[Rule]", "128"}], ",", 
       RowBox[{"263", "\[Rule]", "536"}], ",", 
       RowBox[{"263", "\[Rule]", "60"}], ",", 
       RowBox[{"263", "\[Rule]", "60"}], ",", 
       RowBox[{"263", "\[Rule]", "468"}], ",", 
       RowBox[{"263", "\[Rule]", "468"}], ",", 
       RowBox[{"263", "\[Rule]", "264"}], ",", 
       RowBox[{"1011", "\[Rule]", "808"}], ",", 
       RowBox[{"1011", "\[Rule]", "808"}], ",", 
       RowBox[{"1011", "\[Rule]", "1216"}], ",", 
       RowBox[{"1011", "\[Rule]", "1216"}], ",", 
       RowBox[{"1011", "\[Rule]", "740"}], ",", 
       RowBox[{"1011", "\[Rule]", "740"}], ",", 
       RowBox[{"1011", "\[Rule]", "1148"}], ",", 
       RowBox[{"1011", "\[Rule]", "1148"}], ",", 
       RowBox[{"1011", "\[Rule]", "1012"}], ",", 
       RowBox[{"943", "\[Rule]", "740"}], ",", 
       RowBox[{"943", "\[Rule]", "740"}], ",", 
       RowBox[{"943", "\[Rule]", "1148"}], ",", 
       RowBox[{"943", "\[Rule]", "1148"}], ",", 
       RowBox[{"943", "\[Rule]", "672"}], ",", 
       RowBox[{"943", "\[Rule]", "672"}], ",", 
       RowBox[{"943", "\[Rule]", "1080"}], ",", 
       RowBox[{"943", "\[Rule]", "1080"}], ",", 
       RowBox[{"943", "\[Rule]", "944"}], ",", 
       RowBox[{"739", "\[Rule]", "604"}], ",", 
       RowBox[{"739", "\[Rule]", "604"}], ",", 
       RowBox[{"739", "\[Rule]", "1012"}], ",", 
       RowBox[{"739", "\[Rule]", "1012"}], ",", 
       RowBox[{"739", "\[Rule]", "536"}], ",", 
       RowBox[{"739", "\[Rule]", "536"}], ",", 
       RowBox[{"739", "\[Rule]", "944"}], ",", 
       RowBox[{"739", "\[Rule]", "944"}], ",", 
       RowBox[{"739", "\[Rule]", "740"}], ",", 
       RowBox[{"875", "\[Rule]", "672"}], ",", 
       RowBox[{"875", "\[Rule]", "1080"}], ",", 
       RowBox[{"875", "\[Rule]", "1080"}], ",", 
       RowBox[{"875", "\[Rule]", "876"}], ",", 
       RowBox[{"671", "\[Rule]", "536"}], ",", 
       RowBox[{"671", "\[Rule]", "536"}], ",", 
       RowBox[{"671", "\[Rule]", "944"}], ",", 
       RowBox[{"671", "\[Rule]", "944"}], ",", 
       RowBox[{"671", "\[Rule]", "468"}], ",", 
       RowBox[{"671", "\[Rule]", "876"}], ",", 
       RowBox[{"671", "\[Rule]", "672"}], ",", 
       RowBox[{"362", "\[Rule]", "351"}], ",", 
       RowBox[{"362", "\[Rule]", "373"}], ",", 
       RowBox[{"362", "\[Rule]", "359"}], ",", 
       RowBox[{"294", "\[Rule]", "283"}], ",", 
       RowBox[{"294", "\[Rule]", "305"}], ",", 
       RowBox[{"294", "\[Rule]", "291"}], ",", 
       RowBox[{"158", "\[Rule]", "147"}], ",", 
       RowBox[{"158", "\[Rule]", "169"}], ",", 
       RowBox[{"158", "\[Rule]", "155"}], ",", 
       RowBox[{"384", "\[Rule]", "373"}], ",", 
       RowBox[{"384", "\[Rule]", "395"}], ",", 
       RowBox[{"384", "\[Rule]", "381"}], ",", 
       RowBox[{"180", "\[Rule]", "169"}], ",", 
       RowBox[{"180", "\[Rule]", "191"}], ",", 
       RowBox[{"180", "\[Rule]", "177"}], ",", 
       RowBox[{"372", "\[Rule]", "359"}], ",", 
       RowBox[{"372", "\[Rule]", "381"}], ",", 
       RowBox[{"372", "\[Rule]", "373"}], ",", 
       RowBox[{"372", "\[Rule]", "369"}], ",", 
       RowBox[{"304", "\[Rule]", "291"}], ",", 
       RowBox[{"304", "\[Rule]", "313"}], ",", 
       RowBox[{"304", "\[Rule]", "305"}], ",", 
       RowBox[{"304", "\[Rule]", "301"}], ",", 
       RowBox[{"168", "\[Rule]", "155"}], ",", 
       RowBox[{"168", "\[Rule]", "177"}], ",", 
       RowBox[{"168", "\[Rule]", "169"}], ",", 
       RowBox[{"168", "\[Rule]", "165"}], ",", 
       RowBox[{"770", "\[Rule]", "759"}], ",", 
       RowBox[{"770", "\[Rule]", "781"}], ",", 
       RowBox[{"770", "\[Rule]", "767"}], ",", 
       RowBox[{"702", "\[Rule]", "691"}], ",", 
       RowBox[{"702", "\[Rule]", "713"}], ",", 
       RowBox[{"702", "\[Rule]", "699"}], ",", 
       RowBox[{"566", "\[Rule]", "555"}], ",", 
       RowBox[{"566", "\[Rule]", "577"}], ",", 
       RowBox[{"566", "\[Rule]", "563"}], ",", 
       RowBox[{"792", "\[Rule]", "781"}], ",", 
       RowBox[{"792", "\[Rule]", "803"}], ",", 
       RowBox[{"792", "\[Rule]", "789"}], ",", 
       RowBox[{"588", "\[Rule]", "577"}], ",", 
       RowBox[{"588", "\[Rule]", "599"}], ",", 
       RowBox[{"588", "\[Rule]", "585"}], ",", 
       RowBox[{"780", "\[Rule]", "767"}], ",", 
       RowBox[{"780", "\[Rule]", "789"}], ",", 
       RowBox[{"780", "\[Rule]", "781"}], ",", 
       RowBox[{"780", "\[Rule]", "777"}], ",", 
       RowBox[{"712", "\[Rule]", "699"}], ",", 
       RowBox[{"712", "\[Rule]", "721"}], ",", 
       RowBox[{"712", "\[Rule]", "713"}], ",", 
       RowBox[{"712", "\[Rule]", "709"}], ",", 
       RowBox[{"576", "\[Rule]", "563"}], ",", 
       RowBox[{"576", "\[Rule]", "585"}], ",", 
       RowBox[{"576", "\[Rule]", "577"}], ",", 
       RowBox[{"576", "\[Rule]", "573"}], ",", 
       RowBox[{"226", "\[Rule]", "215"}], ",", 
       RowBox[{"226", "\[Rule]", "237"}], ",", 
       RowBox[{"226", "\[Rule]", "223"}], ",", 
       RowBox[{"90", "\[Rule]", "79"}], ",", 
       RowBox[{"90", "\[Rule]", "101"}], ",", 
       RowBox[{"90", "\[Rule]", "87"}], ",", 
       RowBox[{"236", "\[Rule]", "223"}], ",", 
       RowBox[{"236", "\[Rule]", "245"}], ",", 
       RowBox[{"236", "\[Rule]", "237"}], ",", 
       RowBox[{"236", "\[Rule]", "233"}], ",", 
       RowBox[{"100", "\[Rule]", "87"}], ",", 
       RowBox[{"100", "\[Rule]", "109"}], ",", 
       RowBox[{"100", "\[Rule]", "101"}], ",", 
       RowBox[{"100", "\[Rule]", "97"}], ",", 
       RowBox[{"634", "\[Rule]", "623"}], ",", 
       RowBox[{"634", "\[Rule]", "645"}], ",", 
       RowBox[{"634", "\[Rule]", "631"}], ",", 
       RowBox[{"498", "\[Rule]", "487"}], ",", 
       RowBox[{"498", "\[Rule]", "509"}], ",", 
       RowBox[{"498", "\[Rule]", "495"}], ",", 
       RowBox[{"644", "\[Rule]", "631"}], ",", 
       RowBox[{"644", "\[Rule]", "653"}], ",", 
       RowBox[{"644", "\[Rule]", "645"}], ",", 
       RowBox[{"644", "\[Rule]", "641"}], ",", 
       RowBox[{"508", "\[Rule]", "495"}], ",", 
       RowBox[{"508", "\[Rule]", "517"}], ",", 
       RowBox[{"508", "\[Rule]", "509"}], ",", 
       RowBox[{"508", "\[Rule]", "505"}], ",", 
       RowBox[{"408", "\[Rule]", "395"}], ",", 
       RowBox[{"408", "\[Rule]", "405"}], ",", 
       RowBox[{"204", "\[Rule]", "191"}], ",", 
       RowBox[{"204", "\[Rule]", "201"}], ",", 
       RowBox[{"394", "\[Rule]", "381"}], ",", 
       RowBox[{"394", "\[Rule]", "405"}], ",", 
       RowBox[{"394", "\[Rule]", "395"}], ",", 
       RowBox[{"394", "\[Rule]", "391"}], ",", 
       RowBox[{"190", "\[Rule]", "177"}], ",", 
       RowBox[{"190", "\[Rule]", "201"}], ",", 
       RowBox[{"190", "\[Rule]", "191"}], ",", 
       RowBox[{"190", "\[Rule]", "187"}], ",", 
       RowBox[{"816", "\[Rule]", "803"}], ",", 
       RowBox[{"816", "\[Rule]", "813"}], ",", 
       RowBox[{"612", "\[Rule]", "599"}], ",", 
       RowBox[{"612", "\[Rule]", "609"}], ",", 
       RowBox[{"802", "\[Rule]", "789"}], ",", 
       RowBox[{"802", "\[Rule]", "813"}], ",", 
       RowBox[{"802", "\[Rule]", "803"}], ",", 
       RowBox[{"802", "\[Rule]", "799"}], ",", 
       RowBox[{"598", "\[Rule]", "585"}], ",", 
       RowBox[{"598", "\[Rule]", "609"}], ",", 
       RowBox[{"598", "\[Rule]", "599"}], ",", 
       RowBox[{"598", "\[Rule]", "595"}], ",", 
       RowBox[{"380", "\[Rule]", "369"}], ",", 
       RowBox[{"380", "\[Rule]", "391"}], ",", 
       RowBox[{"380", "\[Rule]", "381"}], ",", 
       RowBox[{"380", "\[Rule]", "377"}], ",", 
       RowBox[{"312", "\[Rule]", "301"}], ",", 
       RowBox[{"312", "\[Rule]", "323"}], ",", 
       RowBox[{"312", "\[Rule]", "313"}], ",", 
       RowBox[{"312", "\[Rule]", "309"}], ",", 
       RowBox[{"176", "\[Rule]", "165"}], ",", 
       RowBox[{"176", "\[Rule]", "187"}], ",", 
       RowBox[{"176", "\[Rule]", "177"}], ",", 
       RowBox[{"176", "\[Rule]", "173"}], ",", 
       RowBox[{"788", "\[Rule]", "777"}], ",", 
       RowBox[{"788", "\[Rule]", "799"}], ",", 
       RowBox[{"788", "\[Rule]", "789"}], ",", 
       RowBox[{"788", "\[Rule]", "785"}], ",", 
       RowBox[{"720", "\[Rule]", "709"}], ",", 
       RowBox[{"720", "\[Rule]", "731"}], ",", 
       RowBox[{"720", "\[Rule]", "721"}], ",", 
       RowBox[{"720", "\[Rule]", "717"}], ",", 
       RowBox[{"584", "\[Rule]", "573"}], ",", 
       RowBox[{"584", "\[Rule]", "595"}], ",", 
       RowBox[{"584", "\[Rule]", "585"}], ",", 
       RowBox[{"584", "\[Rule]", "581"}], ",", 
       RowBox[{"244", "\[Rule]", "233"}], ",", 
       RowBox[{"244", "\[Rule]", "255"}], ",", 
       RowBox[{"244", "\[Rule]", "245"}], ",", 
       RowBox[{"244", "\[Rule]", "241"}], ",", 
       RowBox[{"108", "\[Rule]", "97"}], ",", 
       RowBox[{"108", "\[Rule]", "119"}], ",", 
       RowBox[{"108", "\[Rule]", "109"}], ",", 
       RowBox[{"108", "\[Rule]", "105"}], ",", 
       RowBox[{"652", "\[Rule]", "641"}], ",", 
       RowBox[{"652", "\[Rule]", "663"}], ",", 
       RowBox[{"652", "\[Rule]", "653"}], ",", 
       RowBox[{"652", "\[Rule]", "649"}], ",", 
       RowBox[{"516", "\[Rule]", "505"}], ",", 
       RowBox[{"516", "\[Rule]", "527"}], ",", 
       RowBox[{"516", "\[Rule]", "517"}], ",", 
       RowBox[{"516", "\[Rule]", "513"}], ",", 
       RowBox[{"22", "\[Rule]", "11"}], ",", 
       RowBox[{"22", "\[Rule]", "33"}], ",", 
       RowBox[{"22", "\[Rule]", "19"}], ",", 
       RowBox[{"32", "\[Rule]", "19"}], ",", 
       RowBox[{"32", "\[Rule]", "41"}], ",", 
       RowBox[{"32", "\[Rule]", "33"}], ",", 
       RowBox[{"32", "\[Rule]", "29"}], ",", 
       RowBox[{"430", "\[Rule]", "419"}], ",", 
       RowBox[{"430", "\[Rule]", "441"}], ",", 
       RowBox[{"430", "\[Rule]", "427"}], ",", 
       RowBox[{"440", "\[Rule]", "427"}], ",", 
       RowBox[{"440", "\[Rule]", "449"}], ",", 
       RowBox[{"440", "\[Rule]", "441"}], ",", 
       RowBox[{"440", "\[Rule]", "437"}], ",", 
       RowBox[{"40", "\[Rule]", "29"}], ",", 
       RowBox[{"40", "\[Rule]", "51"}], ",", 
       RowBox[{"40", "\[Rule]", "41"}], ",", 
       RowBox[{"40", "\[Rule]", "37"}], ",", 
       RowBox[{"448", "\[Rule]", "437"}], ",", 
       RowBox[{"448", "\[Rule]", "459"}], ",", 
       RowBox[{"448", "\[Rule]", "449"}], ",", 
       RowBox[{"448", "\[Rule]", "445"}], ",", 
       RowBox[{"404", "\[Rule]", "391"}], ",", 
       RowBox[{"404", "\[Rule]", "405"}], ",", 
       RowBox[{"404", "\[Rule]", "401"}], ",", 
       RowBox[{"200", "\[Rule]", "187"}], ",", 
       RowBox[{"200", "\[Rule]", "201"}], ",", 
       RowBox[{"200", "\[Rule]", "197"}], ",", 
       RowBox[{"812", "\[Rule]", "799"}], ",", 
       RowBox[{"812", "\[Rule]", "813"}], ",", 
       RowBox[{"812", "\[Rule]", "809"}], ",", 
       RowBox[{"608", "\[Rule]", "595"}], ",", 
       RowBox[{"608", "\[Rule]", "609"}], ",", 
       RowBox[{"608", "\[Rule]", "605"}], ",", 
       RowBox[{"390", "\[Rule]", "377"}], ",", 
       RowBox[{"390", "\[Rule]", "401"}], ",", 
       RowBox[{"390", "\[Rule]", "391"}], ",", 
       RowBox[{"390", "\[Rule]", "387"}], ",", 
       RowBox[{"322", "\[Rule]", "309"}], ",", 
       RowBox[{"322", "\[Rule]", "333"}], ",", 
       RowBox[{"322", "\[Rule]", "323"}], ",", 
       RowBox[{"322", "\[Rule]", "319"}], ",", 
       RowBox[{"186", "\[Rule]", "173"}], ",", 
       RowBox[{"186", "\[Rule]", "197"}], ",", 
       RowBox[{"186", "\[Rule]", "187"}], ",", 
       RowBox[{"186", "\[Rule]", "183"}], ",", 
       RowBox[{"798", "\[Rule]", "785"}], ",", 
       RowBox[{"798", "\[Rule]", "809"}], ",", 
       RowBox[{"798", "\[Rule]", "799"}], ",", 
       RowBox[{"798", "\[Rule]", "795"}], ",", 
       RowBox[{"730", "\[Rule]", "717"}], ",", 
       RowBox[{"730", "\[Rule]", "741"}], ",", 
       RowBox[{"730", "\[Rule]", "731"}], ",", 
       RowBox[{"730", "\[Rule]", "727"}], ",", 
       RowBox[{"594", "\[Rule]", "581"}], ",", 
       RowBox[{"594", "\[Rule]", "605"}], ",", 
       RowBox[{"594", "\[Rule]", "595"}], ",", 
       RowBox[{"594", "\[Rule]", "591"}], ",", 
       RowBox[{"254", "\[Rule]", "241"}], ",", 
       RowBox[{"254", "\[Rule]", "265"}], ",", 
       RowBox[{"254", "\[Rule]", "255"}], ",", 
       RowBox[{"254", "\[Rule]", "251"}], ",", 
       RowBox[{"118", "\[Rule]", "105"}], ",", 
       RowBox[{"118", "\[Rule]", "129"}], ",", 
       RowBox[{"118", "\[Rule]", "119"}], ",", 
       RowBox[{"118", "\[Rule]", "115"}], ",", 
       RowBox[{"662", "\[Rule]", "649"}], ",", 
       RowBox[{"662", "\[Rule]", "673"}], ",", 
       RowBox[{"662", "\[Rule]", "663"}], ",", 
       RowBox[{"662", "\[Rule]", "659"}], ",", 
       RowBox[{"526", "\[Rule]", "513"}], ",", 
       RowBox[{"526", "\[Rule]", "537"}], ",", 
       RowBox[{"526", "\[Rule]", "527"}], ",", 
       RowBox[{"526", "\[Rule]", "523"}], ",", 
       RowBox[{"50", "\[Rule]", "37"}], ",", 
       RowBox[{"50", "\[Rule]", "61"}], ",", 
       RowBox[{"50", "\[Rule]", "51"}], ",", 
       RowBox[{"50", "\[Rule]", "47"}], ",", 
       RowBox[{"458", "\[Rule]", "445"}], ",", 
       RowBox[{"458", "\[Rule]", "469"}], ",", 
       RowBox[{"458", "\[Rule]", "459"}], ",", 
       RowBox[{"458", "\[Rule]", "455"}], ",", 
       RowBox[{"1178", "\[Rule]", "1167"}], ",", 
       RowBox[{"1178", "\[Rule]", "1189"}], ",", 
       RowBox[{"1178", "\[Rule]", "1175"}], ",", 
       RowBox[{"1110", "\[Rule]", "1099"}], ",", 
       RowBox[{"1110", "\[Rule]", "1121"}], ",", 
       RowBox[{"1110", "\[Rule]", "1107"}], ",", 
       RowBox[{"974", "\[Rule]", "963"}], ",", 
       RowBox[{"974", "\[Rule]", "985"}], ",", 
       RowBox[{"974", "\[Rule]", "971"}], ",", 
       RowBox[{"1200", "\[Rule]", "1189"}], ",", 
       RowBox[{"1200", "\[Rule]", "1211"}], ",", 
       RowBox[{"1200", "\[Rule]", "1197"}], ",", 
       RowBox[{"1132", "\[Rule]", "1121"}], ",", 
       RowBox[{"1132", "\[Rule]", "1143"}], ",", 
       RowBox[{"1132", "\[Rule]", "1129"}], ",", 
       RowBox[{"996", "\[Rule]", "985"}], ",", 
       RowBox[{"996", "\[Rule]", "1007"}], ",", 
       RowBox[{"996", "\[Rule]", "993"}], ",", 
       RowBox[{"1188", "\[Rule]", "1175"}], ",", 
       RowBox[{"1188", "\[Rule]", "1197"}], ",", 
       RowBox[{"1188", "\[Rule]", "1189"}], ",", 
       RowBox[{"1188", "\[Rule]", "1185"}], ",", 
       RowBox[{"1120", "\[Rule]", "1107"}], ",", 
       RowBox[{"1120", "\[Rule]", "1129"}], ",", 
       RowBox[{"1120", "\[Rule]", "1121"}], ",", 
       RowBox[{"1120", "\[Rule]", "1117"}], ",", 
       RowBox[{"984", "\[Rule]", "971"}], ",", 
       RowBox[{"984", "\[Rule]", "993"}], ",", 
       RowBox[{"984", "\[Rule]", "985"}], ",", 
       RowBox[{"984", "\[Rule]", "981"}], ",", 
       RowBox[{"1042", "\[Rule]", "1031"}], ",", 
       RowBox[{"1042", "\[Rule]", "1053"}], ",", 
       RowBox[{"1042", "\[Rule]", "1039"}], ",", 
       RowBox[{"906", "\[Rule]", "895"}], ",", 
       RowBox[{"906", "\[Rule]", "917"}], ",", 
       RowBox[{"906", "\[Rule]", "903"}], ",", 
       RowBox[{"1064", "\[Rule]", "1053"}], ",", 
       RowBox[{"1064", "\[Rule]", "1075"}], ",", 
       RowBox[{"1064", "\[Rule]", "1061"}], ",", 
       RowBox[{"928", "\[Rule]", "917"}], ",", 
       RowBox[{"928", "\[Rule]", "939"}], ",", 
       RowBox[{"928", "\[Rule]", "925"}], ",", 
       RowBox[{"1052", "\[Rule]", "1039"}], ",", 
       RowBox[{"1052", "\[Rule]", "1061"}], ",", 
       RowBox[{"1052", "\[Rule]", "1053"}], ",", 
       RowBox[{"1052", "\[Rule]", "1049"}], ",", 
       RowBox[{"916", "\[Rule]", "903"}], ",", 
       RowBox[{"916", "\[Rule]", "925"}], ",", 
       RowBox[{"916", "\[Rule]", "917"}], ",", 
       RowBox[{"916", "\[Rule]", "913"}], ",", 
       RowBox[{"1224", "\[Rule]", "1211"}], ",", 
       RowBox[{"1224", "\[Rule]", "1221"}], ",", 
       RowBox[{"1156", "\[Rule]", "1143"}], ",", 
       RowBox[{"1156", "\[Rule]", "1153"}], ",", 
       RowBox[{"1020", "\[Rule]", "1007"}], ",", 
       RowBox[{"1020", "\[Rule]", "1017"}], ",", 
       RowBox[{"1210", "\[Rule]", "1197"}], ",", 
       RowBox[{"1210", "\[Rule]", "1221"}], ",", 
       RowBox[{"1210", "\[Rule]", "1211"}], ",", 
       RowBox[{"1210", "\[Rule]", "1207"}], ",", 
       RowBox[{"1142", "\[Rule]", "1129"}], ",", 
       RowBox[{"1142", "\[Rule]", "1153"}], ",", 
       RowBox[{"1142", "\[Rule]", "1143"}], ",", 
       RowBox[{"1142", "\[Rule]", "1139"}], ",", 
       RowBox[{"1006", "\[Rule]", "993"}], ",", 
       RowBox[{"1006", "\[Rule]", "1017"}], ",", 
       RowBox[{"1006", "\[Rule]", "1007"}], ",", 
       RowBox[{"1006", "\[Rule]", "1003"}], ",", 
       RowBox[{"1088", "\[Rule]", "1075"}], ",", 
       RowBox[{"1088", "\[Rule]", "1085"}], ",", 
       RowBox[{"952", "\[Rule]", "939"}], ",", 
       RowBox[{"952", "\[Rule]", "949"}], ",", 
       RowBox[{"1074", "\[Rule]", "1061"}], ",", 
       RowBox[{"1074", "\[Rule]", "1085"}], ",", 
       RowBox[{"1074", "\[Rule]", "1075"}], ",", 
       RowBox[{"1074", "\[Rule]", "1071"}], ",", 
       RowBox[{"938", "\[Rule]", "925"}], ",", 
       RowBox[{"938", "\[Rule]", "949"}], ",", 
       RowBox[{"938", "\[Rule]", "939"}], ",", 
       RowBox[{"938", "\[Rule]", "935"}], ",", 
       RowBox[{"1196", "\[Rule]", "1185"}], ",", 
       RowBox[{"1196", "\[Rule]", "1207"}], ",", 
       RowBox[{"1196", "\[Rule]", "1197"}], ",", 
       RowBox[{"1196", "\[Rule]", "1193"}], ",", 
       RowBox[{"1128", "\[Rule]", "1117"}], ",", 
       RowBox[{"1128", "\[Rule]", "1139"}], ",", 
       RowBox[{"1128", "\[Rule]", "1129"}], ",", 
       RowBox[{"1128", "\[Rule]", "1125"}], ",", 
       RowBox[{"992", "\[Rule]", "981"}], ",", 
       RowBox[{"992", "\[Rule]", "1003"}], ",", 
       RowBox[{"992", "\[Rule]", "993"}], ",", 
       RowBox[{"992", "\[Rule]", "989"}], ",", 
       RowBox[{"1060", "\[Rule]", "1049"}], ",", 
       RowBox[{"1060", "\[Rule]", "1071"}], ",", 
       RowBox[{"1060", "\[Rule]", "1061"}], ",", 
       RowBox[{"1060", "\[Rule]", "1057"}], ",", 
       RowBox[{"924", "\[Rule]", "913"}], ",", 
       RowBox[{"924", "\[Rule]", "935"}], ",", 
       RowBox[{"924", "\[Rule]", "925"}], ",", 
       RowBox[{"924", "\[Rule]", "921"}], ",", 
       RowBox[{"838", "\[Rule]", "827"}], ",", 
       RowBox[{"838", "\[Rule]", "849"}], ",", 
       RowBox[{"838", "\[Rule]", "835"}], ",", 
       RowBox[{"860", "\[Rule]", "849"}], ",", 
       RowBox[{"860", "\[Rule]", "871"}], ",", 
       RowBox[{"860", "\[Rule]", "857"}], ",", 
       RowBox[{"848", "\[Rule]", "835"}], ",", 
       RowBox[{"848", "\[Rule]", "857"}], ",", 
       RowBox[{"848", "\[Rule]", "849"}], ",", 
       RowBox[{"848", "\[Rule]", "845"}], ",", 
       RowBox[{"884", "\[Rule]", "871"}], ",", 
       RowBox[{"884", "\[Rule]", "881"}], ",", 
       RowBox[{"870", "\[Rule]", "857"}], ",", 
       RowBox[{"870", "\[Rule]", "881"}], ",", 
       RowBox[{"870", "\[Rule]", "871"}], ",", 
       RowBox[{"870", "\[Rule]", "867"}], ",", 
       RowBox[{"856", "\[Rule]", "845"}], ",", 
       RowBox[{"856", "\[Rule]", "867"}], ",", 
       RowBox[{"856", "\[Rule]", "857"}], ",", 
       RowBox[{"856", "\[Rule]", "853"}], ",", 
       RowBox[{"1220", "\[Rule]", "1207"}], ",", 
       RowBox[{"1220", "\[Rule]", "1221"}], ",", 
       RowBox[{"1220", "\[Rule]", "1217"}], ",", 
       RowBox[{"1152", "\[Rule]", "1139"}], ",", 
       RowBox[{"1152", "\[Rule]", "1153"}], ",", 
       RowBox[{"1152", "\[Rule]", "1149"}], ",", 
       RowBox[{"1016", "\[Rule]", "1003"}], ",", 
       RowBox[{"1016", "\[Rule]", "1017"}], ",", 
       RowBox[{"1016", "\[Rule]", "1013"}], ",", 
       RowBox[{"1084", "\[Rule]", "1071"}], ",", 
       RowBox[{"1084", "\[Rule]", "1085"}], ",", 
       RowBox[{"1084", "\[Rule]", "1081"}], ",", 
       RowBox[{"948", "\[Rule]", "935"}], ",", 
       RowBox[{"948", "\[Rule]", "949"}], ",", 
       RowBox[{"948", "\[Rule]", "945"}], ",", 
       RowBox[{"880", "\[Rule]", "867"}], ",", 
       RowBox[{"880", "\[Rule]", "881"}], ",", 
       RowBox[{"880", "\[Rule]", "877"}], ",", 
       RowBox[{"1206", "\[Rule]", "1193"}], ",", 
       RowBox[{"1206", "\[Rule]", "1217"}], ",", 
       RowBox[{"1206", "\[Rule]", "1207"}], ",", 
       RowBox[{"1206", "\[Rule]", "1203"}], ",", 
       RowBox[{"1138", "\[Rule]", "1125"}], ",", 
       RowBox[{"1138", "\[Rule]", "1149"}], ",", 
       RowBox[{"1138", "\[Rule]", "1139"}], ",", 
       RowBox[{"1138", "\[Rule]", "1135"}], ",", 
       RowBox[{"1002", "\[Rule]", "989"}], ",", 
       RowBox[{"1002", "\[Rule]", "1013"}], ",", 
       RowBox[{"1002", "\[Rule]", "1003"}], ",", 
       RowBox[{"1002", "\[Rule]", "999"}], ",", 
       RowBox[{"1070", "\[Rule]", "1057"}], ",", 
       RowBox[{"1070", "\[Rule]", "1081"}], ",", 
       RowBox[{"1070", "\[Rule]", "1071"}], ",", 
       RowBox[{"1070", "\[Rule]", "1067"}], ",", 
       RowBox[{"934", "\[Rule]", "921"}], ",", 
       RowBox[{"934", "\[Rule]", "945"}], ",", 
       RowBox[{"934", "\[Rule]", "935"}], ",", 
       RowBox[{"934", "\[Rule]", "931"}], ",", 
       RowBox[{"866", "\[Rule]", "853"}], ",", 
       RowBox[{"866", "\[Rule]", "877"}], ",", 
       RowBox[{"866", "\[Rule]", "867"}], ",", 
       RowBox[{"866", "\[Rule]", "863"}], ",", 
       RowBox[{"400", "\[Rule]", "387"}], ",", 
       RowBox[{"400", "\[Rule]", "401"}], ",", 
       RowBox[{"400", "\[Rule]", "397"}], ",", 
       RowBox[{"332", "\[Rule]", "319"}], ",", 
       RowBox[{"332", "\[Rule]", "333"}], ",", 
       RowBox[{"332", "\[Rule]", "329"}], ",", 
       RowBox[{"196", "\[Rule]", "183"}], ",", 
       RowBox[{"196", "\[Rule]", "197"}], ",", 
       RowBox[{"196", "\[Rule]", "193"}], ",", 
       RowBox[{"808", "\[Rule]", "795"}], ",", 
       RowBox[{"808", "\[Rule]", "809"}], ",", 
       RowBox[{"808", "\[Rule]", "805"}], ",", 
       RowBox[{"740", "\[Rule]", "727"}], ",", 
       RowBox[{"740", "\[Rule]", "741"}], ",", 
       RowBox[{"740", "\[Rule]", "737"}], ",", 
       RowBox[{"604", "\[Rule]", "591"}], ",", 
       RowBox[{"604", "\[Rule]", "605"}], ",", 
       RowBox[{"604", "\[Rule]", "601"}], ",", 
       RowBox[{"264", "\[Rule]", "251"}], ",", 
       RowBox[{"264", "\[Rule]", "265"}], ",", 
       RowBox[{"264", "\[Rule]", "261"}], ",", 
       RowBox[{"128", "\[Rule]", "115"}], ",", 
       RowBox[{"128", "\[Rule]", "129"}], ",", 
       RowBox[{"128", "\[Rule]", "125"}], ",", 
       RowBox[{"672", "\[Rule]", "659"}], ",", 
       RowBox[{"672", "\[Rule]", "673"}], ",", 
       RowBox[{"672", "\[Rule]", "669"}], ",", 
       RowBox[{"536", "\[Rule]", "523"}], ",", 
       RowBox[{"536", "\[Rule]", "537"}], ",", 
       RowBox[{"536", "\[Rule]", "533"}], ",", 
       RowBox[{"60", "\[Rule]", "47"}], ",", 
       RowBox[{"60", "\[Rule]", "61"}], ",", 
       RowBox[{"60", "\[Rule]", "57"}], ",", 
       RowBox[{"468", "\[Rule]", "455"}], ",", 
       RowBox[{"468", "\[Rule]", "469"}], ",", 
       RowBox[{"468", "\[Rule]", "465"}], ",", 
       RowBox[{"1216", "\[Rule]", "1203"}], ",", 
       RowBox[{"1216", "\[Rule]", "1217"}], ",", 
       RowBox[{"1216", "\[Rule]", "1213"}], ",", 
       RowBox[{"1148", "\[Rule]", "1135"}], ",", 
       RowBox[{"1148", "\[Rule]", "1149"}], ",", 
       RowBox[{"1148", "\[Rule]", "1145"}], ",", 
       RowBox[{"1012", "\[Rule]", "999"}], ",", 
       RowBox[{"1012", "\[Rule]", "1013"}], ",", 
       RowBox[{"1012", "\[Rule]", "1009"}], ",", 
       RowBox[{"1080", "\[Rule]", "1067"}], ",", 
       RowBox[{"1080", "\[Rule]", "1081"}], ",", 
       RowBox[{"1080", "\[Rule]", "1077"}], ",", 
       RowBox[{"944", "\[Rule]", "931"}], ",", 
       RowBox[{"944", "\[Rule]", "945"}], ",", 
       RowBox[{"944", "\[Rule]", "941"}], ",", 
       RowBox[{"876", "\[Rule]", "863"}], ",", 
       RowBox[{"876", "\[Rule]", "877"}], ",", 
       RowBox[{"876", "\[Rule]", "873"}], ",", 
       RowBox[{"351", "\[Rule]", "148"}], ",", 
       RowBox[{"351", "\[Rule]", "556"}], ",", 
       RowBox[{"351", "\[Rule]", "556"}], ",", 
       RowBox[{"351", "\[Rule]", "352"}], ",", 
       RowBox[{"373", "\[Rule]", "170"}], ",", 
       RowBox[{"373", "\[Rule]", "170"}], ",", 
       RowBox[{"373", "\[Rule]", "578"}], ",", 
       RowBox[{"373", "\[Rule]", "374"}], ",", 
       RowBox[{"359", "\[Rule]", "156"}], ",", 
       RowBox[{"359", "\[Rule]", "564"}], ",", 
       RowBox[{"359", "\[Rule]", "360"}], ",", 
       RowBox[{"283", "\[Rule]", "148"}], ",", 
       RowBox[{"283", "\[Rule]", "148"}], ",", 
       RowBox[{"283", "\[Rule]", "556"}], ",", 
       RowBox[{"283", "\[Rule]", "556"}], ",", 
       RowBox[{"283", "\[Rule]", "80"}], ",", 
       RowBox[{"283", "\[Rule]", "488"}], ",", 
       RowBox[{"283", "\[Rule]", "284"}], ",", 
       RowBox[{"291", "\[Rule]", "156"}], ",", 
       RowBox[{"291", "\[Rule]", "564"}], ",", 
       RowBox[{"291", "\[Rule]", "88"}], ",", 
       RowBox[{"291", "\[Rule]", "496"}], ",", 
       RowBox[{"291", "\[Rule]", "292"}], ",", 
       RowBox[{"147", "\[Rule]", "352"}], ",", 
       RowBox[{"147", "\[Rule]", "284"}], ",", 
       RowBox[{"147", "\[Rule]", "284"}], ",", 
       RowBox[{"147", "\[Rule]", "148"}], ",", 
       RowBox[{"169", "\[Rule]", "374"}], ",", 
       RowBox[{"169", "\[Rule]", "374"}], ",", 
       RowBox[{"169", "\[Rule]", "306"}], ",", 
       RowBox[{"169", "\[Rule]", "306"}], ",", 
       RowBox[{"169", "\[Rule]", "170"}], ",", 
       RowBox[{"155", "\[Rule]", "360"}], ",", 
       RowBox[{"155", "\[Rule]", "292"}], ",", 
       RowBox[{"155", "\[Rule]", "156"}], ",", 
       RowBox[{"395", "\[Rule]", "192"}], ",", 
       RowBox[{"395", "\[Rule]", "192"}], ",", 
       RowBox[{"395", "\[Rule]", "600"}], ",", 
       RowBox[{"395", "\[Rule]", "600"}], ",", 
       RowBox[{"395", "\[Rule]", "396"}], ",", 
       RowBox[{"381", "\[Rule]", "178"}], ",", 
       RowBox[{"381", "\[Rule]", "178"}], ",", 
       RowBox[{"381", "\[Rule]", "586"}], ",", 
       RowBox[{"381", "\[Rule]", "586"}], ",", 
       RowBox[{"381", "\[Rule]", "382"}], ",", 
       RowBox[{"191", "\[Rule]", "396"}], ",", 
       RowBox[{"191", "\[Rule]", "396"}], ",", 
       RowBox[{"191", "\[Rule]", "328"}], ",", 
       RowBox[{"191", "\[Rule]", "328"}], ",", 
       RowBox[{"191", "\[Rule]", "192"}], ",", 
       RowBox[{"177", "\[Rule]", "382"}], ",", 
       RowBox[{"177", "\[Rule]", "382"}], ",", 
       RowBox[{"177", "\[Rule]", "314"}], ",", 
       RowBox[{"177", "\[Rule]", "314"}], ",", 
       RowBox[{"177", "\[Rule]", "178"}], ",", 
       RowBox[{"369", "\[Rule]", "166"}], ",", 
       RowBox[{"369", "\[Rule]", "166"}], ",", 
       RowBox[{"369", "\[Rule]", "574"}], ",", 
       RowBox[{"369", "\[Rule]", "574"}], ",", 
       RowBox[{"369", "\[Rule]", "370"}], ",", 
       RowBox[{"301", "\[Rule]", "166"}], ",", 
       RowBox[{"301", "\[Rule]", "166"}], ",", 
       RowBox[{"301", "\[Rule]", "574"}], ",", 
       RowBox[{"301", "\[Rule]", "98"}], ",", 
       RowBox[{"301", "\[Rule]", "302"}], ",", 
       RowBox[{"165", "\[Rule]", "370"}], ",", 
       RowBox[{"165", "\[Rule]", "370"}], ",", 
       RowBox[{"165", "\[Rule]", "302"}], ",", 
       RowBox[{"165", "\[Rule]", "302"}], ",", 
       RowBox[{"165", "\[Rule]", "166"}], ",", 
       RowBox[{"759", "\[Rule]", "556"}], ",", 
       RowBox[{"759", "\[Rule]", "556"}], ",", 
       RowBox[{"759", "\[Rule]", "964"}], ",", 
       RowBox[{"759", "\[Rule]", "964"}], ",", 
       RowBox[{"759", "\[Rule]", "760"}], ",", 
       RowBox[{"781", "\[Rule]", "578"}], ",", 
       RowBox[{"781", "\[Rule]", "986"}], ",", 
       RowBox[{"781", "\[Rule]", "986"}], ",", 
       RowBox[{"781", "\[Rule]", "782"}], ",", 
       RowBox[{"767", "\[Rule]", "564"}], ",", 
       RowBox[{"767", "\[Rule]", "564"}], ",", 
       RowBox[{"767", "\[Rule]", "972"}], ",", 
       RowBox[{"767", "\[Rule]", "972"}], ",", 
       RowBox[{"767", "\[Rule]", "768"}], ",", 
       RowBox[{"691", "\[Rule]", "556"}], ",", 
       RowBox[{"691", "\[Rule]", "556"}], ",", 
       RowBox[{"691", "\[Rule]", "964"}], ",", 
       RowBox[{"691", "\[Rule]", "964"}], ",", 
       RowBox[{"691", "\[Rule]", "488"}], ",", 
       RowBox[{"691", "\[Rule]", "488"}], ",", 
       RowBox[{"691", "\[Rule]", "896"}], ",", 
       RowBox[{"691", "\[Rule]", "896"}], ",", 
       RowBox[{"691", "\[Rule]", "692"}], ",", 
       RowBox[{"699", "\[Rule]", "564"}], ",", 
       RowBox[{"699", "\[Rule]", "564"}], ",", 
       RowBox[{"699", "\[Rule]", "972"}], ",", 
       RowBox[{"699", "\[Rule]", "972"}], ",", 
       RowBox[{"699", "\[Rule]", "496"}], ",", 
       RowBox[{"699", "\[Rule]", "496"}], ",", 
       RowBox[{"699", "\[Rule]", "904"}], ",", 
       RowBox[{"699", "\[Rule]", "904"}], ",", 
       RowBox[{"699", "\[Rule]", "700"}], ",", 
       RowBox[{"555", "\[Rule]", "352"}], ",", 
       RowBox[{"555", "\[Rule]", "352"}], ",", 
       RowBox[{"555", "\[Rule]", "760"}], ",", 
       RowBox[{"555", "\[Rule]", "760"}], ",", 
       RowBox[{"555", "\[Rule]", "284"}], ",", 
       RowBox[{"555", "\[Rule]", "284"}], ",", 
       RowBox[{"555", "\[Rule]", "692"}], ",", 
       RowBox[{"555", "\[Rule]", "692"}], ",", 
       RowBox[{"555", "\[Rule]", "556"}], ",", 
       RowBox[{"577", "\[Rule]", "374"}], ",", 
       RowBox[{"577", "\[Rule]", "782"}], ",", 
       RowBox[{"577", "\[Rule]", "306"}], ",", 
       RowBox[{"577", "\[Rule]", "306"}], ",", 
       RowBox[{"577", "\[Rule]", "714"}], ",", 
       RowBox[{"577", "\[Rule]", "714"}], ",", 
       RowBox[{"577", "\[Rule]", "578"}], ",", 
       RowBox[{"563", "\[Rule]", "360"}], ",", 
       RowBox[{"563", "\[Rule]", "768"}], ",", 
       RowBox[{"563", "\[Rule]", "768"}], ",", 
       RowBox[{"563", "\[Rule]", "292"}], ",", 
       RowBox[{"563", "\[Rule]", "700"}], ",", 
       RowBox[{"563", "\[Rule]", "700"}], ",", 
       RowBox[{"563", "\[Rule]", "564"}], ",", 
       RowBox[{"803", "\[Rule]", "600"}], ",", 
       RowBox[{"803", "\[Rule]", "600"}], ",", 
       RowBox[{"803", "\[Rule]", "1008"}], ",", 
       RowBox[{"803", "\[Rule]", "804"}], ",", 
       RowBox[{"789", "\[Rule]", "586"}], ",", 
       RowBox[{"789", "\[Rule]", "994"}], ",", 
       RowBox[{"789", "\[Rule]", "790"}], ",", 
       RowBox[{"599", "\[Rule]", "396"}], ",", 
       RowBox[{"599", "\[Rule]", "396"}], ",", 
       RowBox[{"599", "\[Rule]", "804"}], ",", 
       RowBox[{"599", "\[Rule]", "804"}], ",", 
       RowBox[{"599", "\[Rule]", "328"}], ",", 
       RowBox[{"599", "\[Rule]", "328"}], ",", 
       RowBox[{"599", "\[Rule]", "736"}], ",", 
       RowBox[{"599", "\[Rule]", "736"}], ",", 
       RowBox[{"599", "\[Rule]", "600"}], ",", 
       RowBox[{"585", "\[Rule]", "382"}], ",", 
       RowBox[{"585", "\[Rule]", "382"}], ",", 
       RowBox[{"585", "\[Rule]", "790"}], ",", 
       RowBox[{"585", "\[Rule]", "314"}], ",", 
       RowBox[{"585", "\[Rule]", "314"}], ",", 
       RowBox[{"585", "\[Rule]", "722"}], ",", 
       RowBox[{"585", "\[Rule]", "586"}], ",", 
       RowBox[{"777", "\[Rule]", "574"}], ",", 
       RowBox[{"777", "\[Rule]", "574"}], ",", 
       RowBox[{"777", "\[Rule]", "982"}], ",", 
       RowBox[{"777", "\[Rule]", "982"}], ",", 
       RowBox[{"777", "\[Rule]", "778"}], ",", 
       RowBox[{"709", "\[Rule]", "574"}], ",", 
       RowBox[{"709", "\[Rule]", "982"}], ",", 
       RowBox[{"709", "\[Rule]", "982"}], ",", 
       RowBox[{"709", "\[Rule]", "506"}], ",", 
       RowBox[{"709", "\[Rule]", "914"}], ",", 
       RowBox[{"709", "\[Rule]", "914"}], ",", 
       RowBox[{"709", "\[Rule]", "710"}], ",", 
       RowBox[{"573", "\[Rule]", "370"}], ",", 
       RowBox[{"573", "\[Rule]", "370"}], ",", 
       RowBox[{"573", "\[Rule]", "778"}], ",", 
       RowBox[{"573", "\[Rule]", "778"}], ",", 
       RowBox[{"573", "\[Rule]", "302"}], ",", 
       RowBox[{"573", "\[Rule]", "710"}], ",", 
       RowBox[{"573", "\[Rule]", "574"}], ",", 
       RowBox[{"215", "\[Rule]", "80"}], ",", 
       RowBox[{"215", "\[Rule]", "488"}], ",", 
       RowBox[{"215", "\[Rule]", "12"}], ",", 
       RowBox[{"215", "\[Rule]", "12"}], ",", 
       RowBox[{"215", "\[Rule]", "420"}], ",", 
       RowBox[{"215", "\[Rule]", "420"}], ",", 
       RowBox[{"215", "\[Rule]", "216"}], ",", 
       RowBox[{"223", "\[Rule]", "88"}], ",", 
       RowBox[{"223", "\[Rule]", "496"}], ",", 
       RowBox[{"223", "\[Rule]", "20"}], ",", 
       RowBox[{"223", "\[Rule]", "20"}], ",", 
       RowBox[{"223", "\[Rule]", "428"}], ",", 
       RowBox[{"223", "\[Rule]", "428"}], ",", 
       RowBox[{"223", "\[Rule]", "224"}], ",", 
       RowBox[{"79", "\[Rule]", "284"}], ",", 
       RowBox[{"79", "\[Rule]", "216"}], ",", 
       RowBox[{"79", "\[Rule]", "80"}], ",", 
       RowBox[{"87", "\[Rule]", "292"}], ",", 
       RowBox[{"87", "\[Rule]", "224"}], ",", 
       RowBox[{"87", "\[Rule]", "88"}], ",", 
       RowBox[{"233", "\[Rule]", "98"}], ",", 
       RowBox[{"233", "\[Rule]", "506"}], ",", 
       RowBox[{"233", "\[Rule]", "30"}], ",", 
       RowBox[{"233", "\[Rule]", "30"}], ",", 
       RowBox[{"233", "\[Rule]", "438"}], ",", 
       RowBox[{"233", "\[Rule]", "438"}], ",", 
       RowBox[{"233", "\[Rule]", "234"}], ",", 
       RowBox[{"97", "\[Rule]", "302"}], ",", 
       RowBox[{"97", "\[Rule]", "234"}], ",", 
       RowBox[{"97", "\[Rule]", "98"}], ",", 
       RowBox[{"623", "\[Rule]", "488"}], ",", 
       RowBox[{"623", "\[Rule]", "488"}], ",", 
       RowBox[{"623", "\[Rule]", "896"}], ",", 
       RowBox[{"623", "\[Rule]", "896"}], ",", 
       RowBox[{"623", "\[Rule]", "420"}], ",", 
       RowBox[{"623", "\[Rule]", "828"}], ",", 
       RowBox[{"623", "\[Rule]", "624"}], ",", 
       RowBox[{"631", "\[Rule]", "496"}], ",", 
       RowBox[{"631", "\[Rule]", "496"}], ",", 
       RowBox[{"631", "\[Rule]", "904"}], ",", 
       RowBox[{"631", "\[Rule]", "904"}], ",", 
       RowBox[{"631", "\[Rule]", "428"}], ",", 
       RowBox[{"631", "\[Rule]", "836"}], ",", 
       RowBox[{"631", "\[Rule]", "632"}], ",", 
       RowBox[{"487", "\[Rule]", "284"}], ",", 
       RowBox[{"487", "\[Rule]", "692"}], ",", 
       RowBox[{"487", "\[Rule]", "692"}], ",", 
       RowBox[{"487", "\[Rule]", "216"}], ",", 
       RowBox[{"487", "\[Rule]", "624"}], ",", 
       RowBox[{"487", "\[Rule]", "624"}], ",", 
       RowBox[{"487", "\[Rule]", "488"}], ",", 
       RowBox[{"495", "\[Rule]", "292"}], ",", 
       RowBox[{"495", "\[Rule]", "700"}], ",", 
       RowBox[{"495", "\[Rule]", "700"}], ",", 
       RowBox[{"495", "\[Rule]", "224"}], ",", 
       RowBox[{"495", "\[Rule]", "632"}], ",", 
       RowBox[{"495", "\[Rule]", "632"}], ",", 
       RowBox[{"495", "\[Rule]", "496"}], ",", 
       RowBox[{"641", "\[Rule]", "506"}], ",", 
       RowBox[{"641", "\[Rule]", "506"}], ",", 
       RowBox[{"641", "\[Rule]", "914"}], ",", 
       RowBox[{"641", "\[Rule]", "914"}], ",", 
       RowBox[{"641", "\[Rule]", "438"}], ",", 
       RowBox[{"641", "\[Rule]", "846"}], ",", 
       RowBox[{"641", "\[Rule]", "642"}], ",", 
       RowBox[{"505", "\[Rule]", "710"}], ",", 
       RowBox[{"505", "\[Rule]", "234"}], ",", 
       RowBox[{"505", "\[Rule]", "642"}], ",", 
       RowBox[{"505", "\[Rule]", "642"}], ",", 
       RowBox[{"505", "\[Rule]", "506"}], ",", 
       RowBox[{"405", "\[Rule]", "202"}], ",", 
       RowBox[{"405", "\[Rule]", "202"}], ",", 
       RowBox[{"405", "\[Rule]", "610"}], ",", 
       RowBox[{"405", "\[Rule]", "610"}], ",", 
       RowBox[{"405", "\[Rule]", "406"}], ",", 
       RowBox[{"201", "\[Rule]", "406"}], ",", 
       RowBox[{"201", "\[Rule]", "406"}], ",", 
       RowBox[{"201", "\[Rule]", "338"}], ",", 
       RowBox[{"201", "\[Rule]", "338"}], ",", 
       RowBox[{"201", "\[Rule]", "202"}], ",", 
       RowBox[{"391", "\[Rule]", "188"}], ",", 
       RowBox[{"391", "\[Rule]", "188"}], ",", 
       RowBox[{"391", "\[Rule]", "596"}], ",", 
       RowBox[{"391", "\[Rule]", "596"}], ",", 
       RowBox[{"391", "\[Rule]", "392"}], ",", 
       RowBox[{"187", "\[Rule]", "392"}], ",", 
       RowBox[{"187", "\[Rule]", "392"}], ",", 
       RowBox[{"187", "\[Rule]", "324"}], ",", 
       RowBox[{"187", "\[Rule]", "324"}], ",", 
       RowBox[{"187", "\[Rule]", "188"}], ",", 
       RowBox[{"813", "\[Rule]", "610"}], ",", 
       RowBox[{"813", "\[Rule]", "610"}], ",", 
       RowBox[{"813", "\[Rule]", "1018"}], ",", 
       RowBox[{"813", "\[Rule]", "1018"}], ",", 
       RowBox[{"813", "\[Rule]", "814"}], ",", 
       RowBox[{"609", "\[Rule]", "406"}], ",", 
       RowBox[{"609", "\[Rule]", "406"}], ",", 
       RowBox[{"609", "\[Rule]", "814"}], ",", 
       RowBox[{"609", "\[Rule]", "814"}], ",", 
       RowBox[{"609", "\[Rule]", "338"}], ",", 
       RowBox[{"609", "\[Rule]", "338"}], ",", 
       RowBox[{"609", "\[Rule]", "746"}], ",", 
       RowBox[{"609", "\[Rule]", "746"}], ",", 
       RowBox[{"609", "\[Rule]", "610"}], ",", 
       RowBox[{"799", "\[Rule]", "596"}], ",", 
       RowBox[{"799", "\[Rule]", "596"}], ",", 
       RowBox[{"799", "\[Rule]", "1004"}], ",", 
       RowBox[{"799", "\[Rule]", "1004"}], ",", 
       RowBox[{"799", "\[Rule]", "800"}], ",", 
       RowBox[{"595", "\[Rule]", "392"}], ",", 
       RowBox[{"595", "\[Rule]", "392"}], ",", 
       RowBox[{"595", "\[Rule]", "800"}], ",", 
       RowBox[{"595", "\[Rule]", "800"}], ",", 
       RowBox[{"595", "\[Rule]", "324"}], ",", 
       RowBox[{"595", "\[Rule]", "324"}], ",", 
       RowBox[{"595", "\[Rule]", "732"}], ",", 
       RowBox[{"595", "\[Rule]", "732"}], ",", 
       RowBox[{"595", "\[Rule]", "596"}], ",", 
       RowBox[{"377", "\[Rule]", "174"}], ",", 
       RowBox[{"377", "\[Rule]", "174"}], ",", 
       RowBox[{"377", "\[Rule]", "582"}], ",", 
       RowBox[{"377", "\[Rule]", "582"}], ",", 
       RowBox[{"377", "\[Rule]", "378"}], ",", 
       RowBox[{"309", "\[Rule]", "174"}], ",", 
       RowBox[{"309", "\[Rule]", "174"}], ",", 
       RowBox[{"309", "\[Rule]", "582"}], ",", 
       RowBox[{"309", "\[Rule]", "582"}], ",", 
       RowBox[{"309", "\[Rule]", "106"}], ",", 
       RowBox[{"309", "\[Rule]", "514"}], ",", 
       RowBox[{"309", "\[Rule]", "310"}], ",", 
       RowBox[{"173", "\[Rule]", "378"}], ",", 
       RowBox[{"173", "\[Rule]", "378"}], ",", 
       RowBox[{"173", "\[Rule]", "310"}], ",", 
       RowBox[{"173", "\[Rule]", "310"}], ",", 
       RowBox[{"173", "\[Rule]", "174"}], ",", 
       RowBox[{"785", "\[Rule]", "582"}], ",", 
       RowBox[{"785", "\[Rule]", "582"}], ",", 
       RowBox[{"785", "\[Rule]", "990"}], ",", 
       RowBox[{"785", "\[Rule]", "990"}], ",", 
       RowBox[{"785", "\[Rule]", "786"}], ",", 
       RowBox[{"717", "\[Rule]", "582"}], ",", 
       RowBox[{"717", "\[Rule]", "582"}], ",", 
       RowBox[{"717", "\[Rule]", "990"}], ",", 
       RowBox[{"717", "\[Rule]", "990"}], ",", 
       RowBox[{"717", "\[Rule]", "514"}], ",", 
       RowBox[{"717", "\[Rule]", "922"}], ",", 
       RowBox[{"717", "\[Rule]", "718"}], ",", 
       RowBox[{"581", "\[Rule]", "378"}], ",", 
       RowBox[{"581", "\[Rule]", "378"}], ",", 
       RowBox[{"581", "\[Rule]", "786"}], ",", 
       RowBox[{"581", "\[Rule]", "786"}], ",", 
       RowBox[{"581", "\[Rule]", "310"}], ",", 
       RowBox[{"581", "\[Rule]", "310"}], ",", 
       RowBox[{"581", "\[Rule]", "718"}], ",", 
       RowBox[{"581", "\[Rule]", "718"}], ",", 
       RowBox[{"581", "\[Rule]", "582"}], ",", 
       RowBox[{"241", "\[Rule]", "106"}], ",", 
       RowBox[{"241", "\[Rule]", "514"}], ",", 
       RowBox[{"241", "\[Rule]", "38"}], ",", 
       RowBox[{"241", "\[Rule]", "38"}], ",", 
       RowBox[{"241", "\[Rule]", "446"}], ",", 
       RowBox[{"241", "\[Rule]", "446"}], ",", 
       RowBox[{"241", "\[Rule]", "242"}], ",", 
       RowBox[{"105", "\[Rule]", "310"}], ",", 
       RowBox[{"105", "\[Rule]", "242"}], ",", 
       RowBox[{"105", "\[Rule]", "106"}], ",", 
       RowBox[{"649", "\[Rule]", "514"}], ",", 
       RowBox[{"649", "\[Rule]", "922"}], ",", 
       RowBox[{"649", "\[Rule]", "446"}], ",", 
       RowBox[{"649", "\[Rule]", "854"}], ",", 
       RowBox[{"649", "\[Rule]", "650"}], ",", 
       RowBox[{"513", "\[Rule]", "310"}], ",", 
       RowBox[{"513", "\[Rule]", "718"}], ",", 
       RowBox[{"513", "\[Rule]", "242"}], ",", 
       RowBox[{"513", "\[Rule]", "650"}], ",", 
       RowBox[{"513", "\[Rule]", "514"}], ",", 
       RowBox[{"11", "\[Rule]", "216"}], ",", 
       RowBox[{"11", "\[Rule]", "216"}], ",", 
       RowBox[{"11", "\[Rule]", "12"}], ",", 
       RowBox[{"19", "\[Rule]", "224"}], ",", 
       RowBox[{"19", "\[Rule]", "224"}], ",", 
       RowBox[{"19", "\[Rule]", "20"}], ",", 
       RowBox[{"29", "\[Rule]", "234"}], ",", 
       RowBox[{"29", "\[Rule]", "234"}], ",", 
       RowBox[{"29", "\[Rule]", "30"}], ",", 
       RowBox[{"419", "\[Rule]", "216"}], ",", 
       RowBox[{"419", "\[Rule]", "216"}], ",", 
       RowBox[{"419", "\[Rule]", "624"}], ",", 
       RowBox[{"419", "\[Rule]", "420"}], ",", 
       RowBox[{"427", "\[Rule]", "224"}], ",", 
       RowBox[{"427", "\[Rule]", "224"}], ",", 
       RowBox[{"427", "\[Rule]", "632"}], ",", 
       RowBox[{"427", "\[Rule]", "428"}], ",", 
       RowBox[{"437", "\[Rule]", "234"}], ",", 
       RowBox[{"437", "\[Rule]", "234"}], ",", 
       RowBox[{"437", "\[Rule]", "642"}], ",", 
       RowBox[{"437", "\[Rule]", "438"}], ",", 
       RowBox[{"37", "\[Rule]", "242"}], ",", 
       RowBox[{"37", "\[Rule]", "242"}], ",", 
       RowBox[{"37", "\[Rule]", "38"}], ",", 
       RowBox[{"445", "\[Rule]", "242"}], ",", 
       RowBox[{"445", "\[Rule]", "242"}], ",", 
       RowBox[{"445", "\[Rule]", "650"}], ",", 
       RowBox[{"445", "\[Rule]", "446"}], ",", 
       RowBox[{"401", "\[Rule]", "198"}], ",", 
       RowBox[{"401", "\[Rule]", "198"}], ",", 
       RowBox[{"401", "\[Rule]", "606"}], ",", 
       RowBox[{"401", "\[Rule]", "606"}], ",", 
       RowBox[{"401", "\[Rule]", "402"}], ",", 
       RowBox[{"197", "\[Rule]", "402"}], ",", 
       RowBox[{"197", "\[Rule]", "402"}], ",", 
       RowBox[{"197", "\[Rule]", "334"}], ",", 
       RowBox[{"197", "\[Rule]", "334"}], ",", 
       RowBox[{"197", "\[Rule]", "198"}], ",", 
       RowBox[{"809", "\[Rule]", "606"}], ",", 
       RowBox[{"809", "\[Rule]", "606"}], ",", 
       RowBox[{"809", "\[Rule]", "1014"}], ",", 
       RowBox[{"809", "\[Rule]", "1014"}], ",", 
       RowBox[{"809", "\[Rule]", "810"}], ",", 
       RowBox[{"605", "\[Rule]", "402"}], ",", 
       RowBox[{"605", "\[Rule]", "402"}], ",", 
       RowBox[{"605", "\[Rule]", "810"}], ",", 
       RowBox[{"605", "\[Rule]", "810"}], ",", 
       RowBox[{"605", "\[Rule]", "334"}], ",", 
       RowBox[{"605", "\[Rule]", "334"}], ",", 
       RowBox[{"605", "\[Rule]", "742"}], ",", 
       RowBox[{"605", "\[Rule]", "742"}], ",", 
       RowBox[{"605", "\[Rule]", "606"}], ",", 
       RowBox[{"387", "\[Rule]", "184"}], ",", 
       RowBox[{"387", "\[Rule]", "184"}], ",", 
       RowBox[{"387", "\[Rule]", "592"}], ",", 
       RowBox[{"387", "\[Rule]", "592"}], ",", 
       RowBox[{"387", "\[Rule]", "388"}], ",", 
       RowBox[{"319", "\[Rule]", "184"}], ",", 
       RowBox[{"319", "\[Rule]", "184"}], ",", 
       RowBox[{"319", "\[Rule]", "592"}], ",", 
       RowBox[{"319", "\[Rule]", "592"}], ",", 
       RowBox[{"319", "\[Rule]", "116"}], ",", 
       RowBox[{"319", "\[Rule]", "524"}], ",", 
       RowBox[{"319", "\[Rule]", "320"}], ",", 
       RowBox[{"183", "\[Rule]", "388"}], ",", 
       RowBox[{"183", "\[Rule]", "388"}], ",", 
       RowBox[{"183", "\[Rule]", "320"}], ",", 
       RowBox[{"183", "\[Rule]", "320"}], ",", 
       RowBox[{"183", "\[Rule]", "184"}], ",", 
       RowBox[{"795", "\[Rule]", "592"}], ",", 
       RowBox[{"795", "\[Rule]", "592"}], ",", 
       RowBox[{"795", "\[Rule]", "1000"}], ",", 
       RowBox[{"795", "\[Rule]", "1000"}], ",", 
       RowBox[{"795", "\[Rule]", "796"}], ",", 
       RowBox[{"727", "\[Rule]", "592"}], ",", 
       RowBox[{"727", "\[Rule]", "592"}], ",", 
       RowBox[{"727", "\[Rule]", "1000"}], ",", 
       RowBox[{"727", "\[Rule]", "1000"}], ",", 
       RowBox[{"727", "\[Rule]", "524"}], ",", 
       RowBox[{"727", "\[Rule]", "524"}], ",", 
       RowBox[{"727", "\[Rule]", "932"}], ",", 
       RowBox[{"727", "\[Rule]", "932"}], ",", 
       RowBox[{"727", "\[Rule]", "728"}], ",", 
       RowBox[{"591", "\[Rule]", "388"}], ",", 
       RowBox[{"591", "\[Rule]", "388"}], ",", 
       RowBox[{"591", "\[Rule]", "796"}], ",", 
       RowBox[{"591", "\[Rule]", "796"}], ",", 
       RowBox[{"591", "\[Rule]", "320"}], ",", 
       RowBox[{"591", "\[Rule]", "320"}], ",", 
       RowBox[{"591", "\[Rule]", "728"}], ",", 
       RowBox[{"591", "\[Rule]", "728"}], ",", 
       RowBox[{"591", "\[Rule]", "592"}], ",", 
       RowBox[{"251", "\[Rule]", "116"}], ",", 
       RowBox[{"251", "\[Rule]", "524"}], ",", 
       RowBox[{"251", "\[Rule]", "48"}], ",", 
       RowBox[{"251", "\[Rule]", "48"}], ",", 
       RowBox[{"251", "\[Rule]", "456"}], ",", 
       RowBox[{"251", "\[Rule]", "456"}], ",", 
       RowBox[{"251", "\[Rule]", "252"}], ",", 
       RowBox[{"115", "\[Rule]", "320"}], ",", 
       RowBox[{"115", "\[Rule]", "252"}], ",", 
       RowBox[{"115", "\[Rule]", "116"}], ",", 
       RowBox[{"659", "\[Rule]", "524"}], ",", 
       RowBox[{"659", "\[Rule]", "524"}], ",", 
       RowBox[{"659", "\[Rule]", "932"}], ",", 
       RowBox[{"659", "\[Rule]", "456"}], ",", 
       RowBox[{"659", "\[Rule]", "660"}], ",", 
       RowBox[{"523", "\[Rule]", "320"}], ",", 
       RowBox[{"523", "\[Rule]", "728"}], ",", 
       RowBox[{"523", "\[Rule]", "728"}], ",", 
       RowBox[{"523", "\[Rule]", "252"}], ",", 
       RowBox[{"523", "\[Rule]", "660"}], ",", 
       RowBox[{"523", "\[Rule]", "660"}], ",", 
       RowBox[{"523", "\[Rule]", "524"}], ",", 
       RowBox[{"47", "\[Rule]", "252"}], ",", 
       RowBox[{"47", "\[Rule]", "252"}], ",", 
       RowBox[{"47", "\[Rule]", "48"}], ",", 
       RowBox[{"455", "\[Rule]", "252"}], ",", 
       RowBox[{"455", "\[Rule]", "252"}], ",", 
       RowBox[{"455", "\[Rule]", "660"}], ",", 
       RowBox[{"455", "\[Rule]", "456"}], ",", 
       RowBox[{"1167", "\[Rule]", "964"}], ",", 
       RowBox[{"1167", "\[Rule]", "964"}], ",", 
       RowBox[{"1167", "\[Rule]", "1168"}], ",", 
       RowBox[{"1189", "\[Rule]", "986"}], ",", 
       RowBox[{"1189", "\[Rule]", "986"}], ",", 
       RowBox[{"1189", "\[Rule]", "1190"}], ",", 
       RowBox[{"1175", "\[Rule]", "972"}], ",", 
       RowBox[{"1175", "\[Rule]", "972"}], ",", 
       RowBox[{"1175", "\[Rule]", "1176"}], ",", 
       RowBox[{"1099", "\[Rule]", "964"}], ",", 
       RowBox[{"1099", "\[Rule]", "964"}], ",", 
       RowBox[{"1099", "\[Rule]", "896"}], ",", 
       RowBox[{"1099", "\[Rule]", "896"}], ",", 
       RowBox[{"1099", "\[Rule]", "1100"}], ",", 
       RowBox[{"1121", "\[Rule]", "986"}], ",", 
       RowBox[{"1121", "\[Rule]", "986"}], ",", 
       RowBox[{"1121", "\[Rule]", "918"}], ",", 
       RowBox[{"1121", "\[Rule]", "918"}], ",", 
       RowBox[{"1121", "\[Rule]", "1122"}], ",", 
       RowBox[{"1107", "\[Rule]", "972"}], ",", 
       RowBox[{"1107", "\[Rule]", "972"}], ",", 
       RowBox[{"1107", "\[Rule]", "904"}], ",", 
       RowBox[{"1107", "\[Rule]", "904"}], ",", 
       RowBox[{"1107", "\[Rule]", "1108"}], ",", 
       RowBox[{"963", "\[Rule]", "760"}], ",", 
       RowBox[{"963", "\[Rule]", "760"}], ",", 
       RowBox[{"963", "\[Rule]", "1168"}], ",", 
       RowBox[{"963", "\[Rule]", "1168"}], ",", 
       RowBox[{"963", "\[Rule]", "692"}], ",", 
       RowBox[{"963", "\[Rule]", "692"}], ",", 
       RowBox[{"963", "\[Rule]", "1100"}], ",", 
       RowBox[{"963", "\[Rule]", "1100"}], ",", 
       RowBox[{"963", "\[Rule]", "964"}], ",", 
       RowBox[{"985", "\[Rule]", "782"}], ",", 
       RowBox[{"985", "\[Rule]", "782"}], ",", 
       RowBox[{"985", "\[Rule]", "1190"}], ",", 
       RowBox[{"985", "\[Rule]", "1190"}], ",", 
       RowBox[{"985", "\[Rule]", "714"}], ",", 
       RowBox[{"985", "\[Rule]", "714"}], ",", 
       RowBox[{"985", "\[Rule]", "1122"}], ",", 
       RowBox[{"985", "\[Rule]", "1122"}], ",", 
       RowBox[{"985", "\[Rule]", "986"}], ",", 
       RowBox[{"971", "\[Rule]", "768"}], ",", 
       RowBox[{"971", "\[Rule]", "768"}], ",", 
       RowBox[{"971", "\[Rule]", "1176"}], ",", 
       RowBox[{"971", "\[Rule]", "1176"}], ",", 
       RowBox[{"971", "\[Rule]", "700"}], ",", 
       RowBox[{"971", "\[Rule]", "700"}], ",", 
       RowBox[{"971", "\[Rule]", "1108"}], ",", 
       RowBox[{"971", "\[Rule]", "1108"}], ",", 
       RowBox[{"971", "\[Rule]", "972"}], ",", 
       RowBox[{"1211", "\[Rule]", "1008"}], ",", 
       RowBox[{"1211", "\[Rule]", "1212"}], ",", 
       RowBox[{"1197", "\[Rule]", "994"}], ",", 
       RowBox[{"1197", "\[Rule]", "994"}], ",", 
       RowBox[{"1197", "\[Rule]", "1198"}], ",", 
       RowBox[{"1143", "\[Rule]", "1008"}], ",", 
       RowBox[{"1143", "\[Rule]", "1008"}], ",", 
       RowBox[{"1143", "\[Rule]", "940"}], ",", 
       RowBox[{"1143", "\[Rule]", "940"}], ",", 
       RowBox[{"1143", "\[Rule]", "1144"}], ",", 
       RowBox[{"1129", "\[Rule]", "994"}], ",", 
       RowBox[{"1129", "\[Rule]", "994"}], ",", 
       RowBox[{"1129", "\[Rule]", "926"}], ",", 
       RowBox[{"1129", "\[Rule]", "926"}], ",", 
       RowBox[{"1129", "\[Rule]", "1130"}], ",", 
       RowBox[{"1007", "\[Rule]", "804"}], ",", 
       RowBox[{"1007", "\[Rule]", "1212"}], ",", 
       RowBox[{"1007", "\[Rule]", "736"}], ",", 
       RowBox[{"1007", "\[Rule]", "736"}], ",", 
       RowBox[{"1007", "\[Rule]", "1144"}], ",", 
       RowBox[{"1007", "\[Rule]", "1144"}], ",", 
       RowBox[{"1007", "\[Rule]", "1008"}], ",", 
       RowBox[{"993", "\[Rule]", "790"}], ",", 
       RowBox[{"993", "\[Rule]", "1198"}], ",", 
       RowBox[{"993", "\[Rule]", "1198"}], ",", 
       RowBox[{"993", "\[Rule]", "722"}], ",", 
       RowBox[{"993", "\[Rule]", "1130"}], ",", 
       RowBox[{"993", "\[Rule]", "1130"}], ",", 
       RowBox[{"993", "\[Rule]", "994"}], ",", 
       RowBox[{"1185", "\[Rule]", "982"}], ",", 
       RowBox[{"1185", "\[Rule]", "982"}], ",", 
       RowBox[{"1185", "\[Rule]", "1186"}], ",", 
       RowBox[{"1117", "\[Rule]", "982"}], ",", 
       RowBox[{"1117", "\[Rule]", "982"}], ",", 
       RowBox[{"1117", "\[Rule]", "914"}], ",", 
       RowBox[{"1117", "\[Rule]", "914"}], ",", 
       RowBox[{"1117", "\[Rule]", "1118"}], ",", 
       RowBox[{"981", "\[Rule]", "778"}], ",", 
       RowBox[{"981", "\[Rule]", "778"}], ",", 
       RowBox[{"981", "\[Rule]", "1186"}], ",", 
       RowBox[{"981", "\[Rule]", "1186"}], ",", 
       RowBox[{"981", "\[Rule]", "710"}], ",", 
       RowBox[{"981", "\[Rule]", "710"}], ",", 
       RowBox[{"981", "\[Rule]", "1118"}], ",", 
       RowBox[{"981", "\[Rule]", "1118"}], ",", 
       RowBox[{"981", "\[Rule]", "982"}], ",", 
       RowBox[{"1031", "\[Rule]", "896"}], ",", 
       RowBox[{"1031", "\[Rule]", "896"}], ",", 
       RowBox[{"1031", "\[Rule]", "828"}], ",", 
       RowBox[{"1031", "\[Rule]", "828"}], ",", 
       RowBox[{"1031", "\[Rule]", "1032"}], ",", 
       RowBox[{"1053", "\[Rule]", "918"}], ",", 
       RowBox[{"1053", "\[Rule]", "918"}], ",", 
       RowBox[{"1053", "\[Rule]", "850"}], ",", 
       RowBox[{"1053", "\[Rule]", "850"}], ",", 
       RowBox[{"1053", "\[Rule]", "1054"}], ",", 
       RowBox[{"1039", "\[Rule]", "904"}], ",", 
       RowBox[{"1039", "\[Rule]", "904"}], ",", 
       RowBox[{"1039", "\[Rule]", "836"}], ",", 
       RowBox[{"1039", "\[Rule]", "836"}], ",", 
       RowBox[{"1039", "\[Rule]", "1040"}], ",", 
       RowBox[{"895", "\[Rule]", "692"}], ",", 
       RowBox[{"895", "\[Rule]", "692"}], ",", 
       RowBox[{"895", "\[Rule]", "1100"}], ",", 
       RowBox[{"895", "\[Rule]", "1100"}], ",", 
       RowBox[{"895", "\[Rule]", "624"}], ",", 
       RowBox[{"895", "\[Rule]", "624"}], ",", 
       RowBox[{"895", "\[Rule]", "1032"}], ",", 
       RowBox[{"895", "\[Rule]", "1032"}], ",", 
       RowBox[{"895", "\[Rule]", "896"}], ",", 
       RowBox[{"917", "\[Rule]", "714"}], ",", 
       RowBox[{"917", "\[Rule]", "714"}], ",", 
       RowBox[{"917", "\[Rule]", "1122"}], ",", 
       RowBox[{"917", "\[Rule]", "1122"}], ",", 
       RowBox[{"917", "\[Rule]", "646"}], ",", 
       RowBox[{"917", "\[Rule]", "646"}], ",", 
       RowBox[{"917", "\[Rule]", "1054"}], ",", 
       RowBox[{"917", "\[Rule]", "1054"}], ",", 
       RowBox[{"917", "\[Rule]", "918"}], ",", 
       RowBox[{"903", "\[Rule]", "700"}], ",", 
       RowBox[{"903", "\[Rule]", "700"}], ",", 
       RowBox[{"903", "\[Rule]", "1108"}], ",", 
       RowBox[{"903", "\[Rule]", "1108"}], ",", 
       RowBox[{"903", "\[Rule]", "632"}], ",", 
       RowBox[{"903", "\[Rule]", "632"}], ",", 
       RowBox[{"903", "\[Rule]", "1040"}], ",", 
       RowBox[{"903", "\[Rule]", "1040"}], ",", 
       RowBox[{"903", "\[Rule]", "904"}], ",", 
       RowBox[{"1075", "\[Rule]", "940"}], ",", 
       RowBox[{"1075", "\[Rule]", "940"}], ",", 
       RowBox[{"1075", "\[Rule]", "872"}], ",", 
       RowBox[{"1075", "\[Rule]", "872"}], ",", 
       RowBox[{"1075", "\[Rule]", "1076"}], ",", 
       RowBox[{"1061", "\[Rule]", "926"}], ",", 
       RowBox[{"1061", "\[Rule]", "926"}], ",", 
       RowBox[{"1061", "\[Rule]", "858"}], ",", 
       RowBox[{"1061", "\[Rule]", "858"}], ",", 
       RowBox[{"1061", "\[Rule]", "1062"}], ",", 
       RowBox[{"939", "\[Rule]", "736"}], ",", 
       RowBox[{"939", "\[Rule]", "736"}], ",", 
       RowBox[{"939", "\[Rule]", "1144"}], ",", 
       RowBox[{"939", "\[Rule]", "1144"}], ",", 
       RowBox[{"939", "\[Rule]", "668"}], ",", 
       RowBox[{"939", "\[Rule]", "668"}], ",", 
       RowBox[{"939", "\[Rule]", "1076"}], ",", 
       RowBox[{"939", "\[Rule]", "1076"}], ",", 
       RowBox[{"939", "\[Rule]", "940"}], ",", 
       RowBox[{"925", "\[Rule]", "722"}], ",", 
       RowBox[{"925", "\[Rule]", "722"}], ",", 
       RowBox[{"925", "\[Rule]", "1130"}], ",", 
       RowBox[{"925", "\[Rule]", "1130"}], ",", 
       RowBox[{"925", "\[Rule]", "654"}], ",", 
       RowBox[{"925", "\[Rule]", "654"}], ",", 
       RowBox[{"925", "\[Rule]", "1062"}], ",", 
       RowBox[{"925", "\[Rule]", "1062"}], ",", 
       RowBox[{"925", "\[Rule]", "926"}], ",", 
       RowBox[{"1049", "\[Rule]", "914"}], ",", 
       RowBox[{"1049", "\[Rule]", "914"}], ",", 
       RowBox[{"1049", "\[Rule]", "846"}], ",", 
       RowBox[{"1049", "\[Rule]", "846"}], ",", 
       RowBox[{"1049", "\[Rule]", "1050"}], ",", 
       RowBox[{"913", "\[Rule]", "710"}], ",", 
       RowBox[{"913", "\[Rule]", "710"}], ",", 
       RowBox[{"913", "\[Rule]", "1118"}], ",", 
       RowBox[{"913", "\[Rule]", "1118"}], ",", 
       RowBox[{"913", "\[Rule]", "642"}], ",", 
       RowBox[{"913", "\[Rule]", "642"}], ",", 
       RowBox[{"913", "\[Rule]", "1050"}], ",", 
       RowBox[{"913", "\[Rule]", "1050"}], ",", 
       RowBox[{"913", "\[Rule]", "914"}], ",", 
       RowBox[{"1221", "\[Rule]", "1018"}], ",", 
       RowBox[{"1221", "\[Rule]", "1222"}], ",", 
       RowBox[{"1153", "\[Rule]", "1018"}], ",", 
       RowBox[{"1153", "\[Rule]", "950"}], ",", 
       RowBox[{"1153", "\[Rule]", "950"}], ",", 
       RowBox[{"1153", "\[Rule]", "1154"}], ",", 
       RowBox[{"1017", "\[Rule]", "814"}], ",", 
       RowBox[{"1017", "\[Rule]", "814"}], ",", 
       RowBox[{"1017", "\[Rule]", "1222"}], ",", 
       RowBox[{"1017", "\[Rule]", "746"}], ",", 
       RowBox[{"1017", "\[Rule]", "746"}], ",", 
       RowBox[{"1017", "\[Rule]", "1154"}], ",", 
       RowBox[{"1017", "\[Rule]", "1018"}], ",", 
       RowBox[{"1207", "\[Rule]", "1004"}], ",", 
       RowBox[{"1207", "\[Rule]", "1004"}], ",", 
       RowBox[{"1207", "\[Rule]", "1208"}], ",", 
       RowBox[{"1139", "\[Rule]", "1004"}], ",", 
       RowBox[{"1139", "\[Rule]", "936"}], ",", 
       RowBox[{"1139", "\[Rule]", "1140"}], ",", 
       RowBox[{"1003", "\[Rule]", "800"}], ",", 
       RowBox[{"1003", "\[Rule]", "800"}], ",", 
       RowBox[{"1003", "\[Rule]", "1208"}], ",", 
       RowBox[{"1003", "\[Rule]", "1208"}], ",", 
       RowBox[{"1003", "\[Rule]", "732"}], ",", 
       RowBox[{"1003", "\[Rule]", "1140"}], ",", 
       RowBox[{"1003", "\[Rule]", "1004"}], ",", 
       RowBox[{"1085", "\[Rule]", "950"}], ",", 
       RowBox[{"1085", "\[Rule]", "950"}], ",", 
       RowBox[{"1085", "\[Rule]", "882"}], ",", 
       RowBox[{"1085", "\[Rule]", "882"}], ",", 
       RowBox[{"1085", "\[Rule]", "1086"}], ",", 
       RowBox[{"949", "\[Rule]", "746"}], ",", 
       RowBox[{"949", "\[Rule]", "746"}], ",", 
       RowBox[{"949", "\[Rule]", "1154"}], ",", 
       RowBox[{"949", "\[Rule]", "1154"}], ",", 
       RowBox[{"949", "\[Rule]", "678"}], ",", 
       RowBox[{"949", "\[Rule]", "678"}], ",", 
       RowBox[{"949", "\[Rule]", "1086"}], ",", 
       RowBox[{"949", "\[Rule]", "1086"}], ",", 
       RowBox[{"949", "\[Rule]", "950"}], ",", 
       RowBox[{"1071", "\[Rule]", "936"}], ",", 
       RowBox[{"1071", "\[Rule]", "936"}], ",", 
       RowBox[{"1071", "\[Rule]", "868"}], ",", 
       RowBox[{"1071", "\[Rule]", "868"}], ",", 
       RowBox[{"1071", "\[Rule]", "1072"}], ",", 
       RowBox[{"935", "\[Rule]", "732"}], ",", 
       RowBox[{"935", "\[Rule]", "1140"}], ",", 
       RowBox[{"935", "\[Rule]", "664"}], ",", 
       RowBox[{"935", "\[Rule]", "664"}], ",", 
       RowBox[{"935", "\[Rule]", "1072"}], ",", 
       RowBox[{"935", "\[Rule]", "1072"}], ",", 
       RowBox[{"935", "\[Rule]", "936"}], ",", 
       RowBox[{"1193", "\[Rule]", "990"}], ",", 
       RowBox[{"1193", "\[Rule]", "990"}], ",", 
       RowBox[{"1193", "\[Rule]", "1194"}], ",", 
       RowBox[{"1125", "\[Rule]", "990"}], ",", 
       RowBox[{"1125", "\[Rule]", "990"}], ",", 
       RowBox[{"1125", "\[Rule]", "922"}], ",", 
       RowBox[{"1125", "\[Rule]", "922"}], ",", 
       RowBox[{"1125", "\[Rule]", "1126"}], ",", 
       RowBox[{"989", "\[Rule]", "786"}], ",", 
       RowBox[{"989", "\[Rule]", "786"}], ",", 
       RowBox[{"989", "\[Rule]", "1194"}], ",", 
       RowBox[{"989", "\[Rule]", "1194"}], ",", 
       RowBox[{"989", "\[Rule]", "718"}], ",", 
       RowBox[{"989", "\[Rule]", "718"}], ",", 
       RowBox[{"989", "\[Rule]", "1126"}], ",", 
       RowBox[{"989", "\[Rule]", "1126"}], ",", 
       RowBox[{"989", "\[Rule]", "990"}], ",", 
       RowBox[{"1057", "\[Rule]", "922"}], ",", 
       RowBox[{"1057", "\[Rule]", "922"}], ",", 
       RowBox[{"1057", "\[Rule]", "854"}], ",", 
       RowBox[{"1057", "\[Rule]", "854"}], ",", 
       RowBox[{"1057", "\[Rule]", "1058"}], ",", 
       RowBox[{"921", "\[Rule]", "718"}], ",", 
       RowBox[{"921", "\[Rule]", "1126"}], ",", 
       RowBox[{"921", "\[Rule]", "1126"}], ",", 
       RowBox[{"921", "\[Rule]", "650"}], ",", 
       RowBox[{"921", "\[Rule]", "1058"}], ",", 
       RowBox[{"921", "\[Rule]", "1058"}], ",", 
       RowBox[{"921", "\[Rule]", "922"}], ",", 
       RowBox[{"827", "\[Rule]", "624"}], ",", 
       RowBox[{"827", "\[Rule]", "1032"}], ",", 
       RowBox[{"827", "\[Rule]", "1032"}], ",", 
       RowBox[{"827", "\[Rule]", "828"}], ",", 
       RowBox[{"849", "\[Rule]", "646"}], ",", 
       RowBox[{"849", "\[Rule]", "1054"}], ",", 
       RowBox[{"849", "\[Rule]", "1054"}], ",", 
       RowBox[{"849", "\[Rule]", "850"}], ",", 
       RowBox[{"835", "\[Rule]", "632"}], ",", 
       RowBox[{"835", "\[Rule]", "1040"}], ",", 
       RowBox[{"835", "\[Rule]", "1040"}], ",", 
       RowBox[{"835", "\[Rule]", "836"}], ",", 
       RowBox[{"871", "\[Rule]", "668"}], ",", 
       RowBox[{"871", "\[Rule]", "1076"}], ",", 
       RowBox[{"871", "\[Rule]", "1076"}], ",", 
       RowBox[{"871", "\[Rule]", "872"}], ",", 
       RowBox[{"857", "\[Rule]", "654"}], ",", 
       RowBox[{"857", "\[Rule]", "1062"}], ",", 
       RowBox[{"857", "\[Rule]", "1062"}], ",", 
       RowBox[{"857", "\[Rule]", "858"}], ",", 
       RowBox[{"845", "\[Rule]", "642"}], ",", 
       RowBox[{"845", "\[Rule]", "1050"}], ",", 
       RowBox[{"845", "\[Rule]", "1050"}], ",", 
       RowBox[{"845", "\[Rule]", "846"}], ",", 
       RowBox[{"881", "\[Rule]", "678"}], ",", 
       RowBox[{"881", "\[Rule]", "1086"}], ",", 
       RowBox[{"881", "\[Rule]", "1086"}], ",", 
       RowBox[{"881", "\[Rule]", "882"}], ",", 
       RowBox[{"867", "\[Rule]", "664"}], ",", 
       RowBox[{"867", "\[Rule]", "1072"}], ",", 
       RowBox[{"867", "\[Rule]", "1072"}], ",", 
       RowBox[{"867", "\[Rule]", "868"}], ",", 
       RowBox[{"853", "\[Rule]", "650"}], ",", 
       RowBox[{"853", "\[Rule]", "1058"}], ",", 
       RowBox[{"853", "\[Rule]", "1058"}], ",", 
       RowBox[{"853", "\[Rule]", "854"}], ",", 
       RowBox[{"1217", "\[Rule]", "1014"}], ",", 
       RowBox[{"1217", "\[Rule]", "1014"}], ",", 
       RowBox[{"1217", "\[Rule]", "1218"}], ",", 
       RowBox[{"1149", "\[Rule]", "1014"}], ",", 
       RowBox[{"1149", "\[Rule]", "1014"}], ",", 
       RowBox[{"1149", "\[Rule]", "946"}], ",", 
       RowBox[{"1149", "\[Rule]", "1150"}], ",", 
       RowBox[{"1013", "\[Rule]", "810"}], ",", 
       RowBox[{"1013", "\[Rule]", "810"}], ",", 
       RowBox[{"1013", "\[Rule]", "1218"}], ",", 
       RowBox[{"1013", "\[Rule]", "1218"}], ",", 
       RowBox[{"1013", "\[Rule]", "742"}], ",", 
       RowBox[{"1013", "\[Rule]", "742"}], ",", 
       RowBox[{"1013", "\[Rule]", "1150"}], ",", 
       RowBox[{"1013", "\[Rule]", "1150"}], ",", 
       RowBox[{"1013", "\[Rule]", "1014"}], ",", 
       RowBox[{"1081", "\[Rule]", "946"}], ",", 
       RowBox[{"1081", "\[Rule]", "878"}], ",", 
       RowBox[{"1081", "\[Rule]", "878"}], ",", 
       RowBox[{"1081", "\[Rule]", "1082"}], ",", 
       RowBox[{"945", "\[Rule]", "742"}], ",", 
       RowBox[{"945", "\[Rule]", "742"}], ",", 
       RowBox[{"945", "\[Rule]", "1150"}], ",", 
       RowBox[{"945", "\[Rule]", "674"}], ",", 
       RowBox[{"945", "\[Rule]", "674"}], ",", 
       RowBox[{"945", "\[Rule]", "1082"}], ",", 
       RowBox[{"945", "\[Rule]", "946"}], ",", 
       RowBox[{"877", "\[Rule]", "674"}], ",", 
       RowBox[{"877", "\[Rule]", "1082"}], ",", 
       RowBox[{"877", "\[Rule]", "1082"}], ",", 
       RowBox[{"877", "\[Rule]", "878"}], ",", 
       RowBox[{"1203", "\[Rule]", "1000"}], ",", 
       RowBox[{"1203", "\[Rule]", "1000"}], ",", 
       RowBox[{"1203", "\[Rule]", "1204"}], ",", 
       RowBox[{"1135", "\[Rule]", "1000"}], ",", 
       RowBox[{"1135", "\[Rule]", "1000"}], ",", 
       RowBox[{"1135", "\[Rule]", "932"}], ",", 
       RowBox[{"1135", "\[Rule]", "932"}], ",", 
       RowBox[{"1135", "\[Rule]", "1136"}], ",", 
       RowBox[{"999", "\[Rule]", "796"}], ",", 
       RowBox[{"999", "\[Rule]", "796"}], ",", 
       RowBox[{"999", "\[Rule]", "1204"}], ",", 
       RowBox[{"999", "\[Rule]", "1204"}], ",", 
       RowBox[{"999", "\[Rule]", "728"}], ",", 
       RowBox[{"999", "\[Rule]", "728"}], ",", 
       RowBox[{"999", "\[Rule]", "1136"}], ",", 
       RowBox[{"999", "\[Rule]", "1136"}], ",", 
       RowBox[{"999", "\[Rule]", "1000"}], ",", 
       RowBox[{"1067", "\[Rule]", "932"}], ",", 
       RowBox[{"1067", "\[Rule]", "864"}], ",", 
       RowBox[{"1067", "\[Rule]", "1068"}], ",", 
       RowBox[{"931", "\[Rule]", "728"}], ",", 
       RowBox[{"931", "\[Rule]", "728"}], ",", 
       RowBox[{"931", "\[Rule]", "1136"}], ",", 
       RowBox[{"931", "\[Rule]", "1136"}], ",", 
       RowBox[{"931", "\[Rule]", "660"}], ",", 
       RowBox[{"931", "\[Rule]", "1068"}], ",", 
       RowBox[{"931", "\[Rule]", "932"}], ",", 
       RowBox[{"863", "\[Rule]", "1068"}], ",", 
       RowBox[{"863", "\[Rule]", "864"}], ",", 
       RowBox[{"397", "\[Rule]", "194"}], ",", 
       RowBox[{"397", "\[Rule]", "194"}], ",", 
       RowBox[{"397", "\[Rule]", "602"}], ",", 
       RowBox[{"397", "\[Rule]", "602"}], ",", 
       RowBox[{"397", "\[Rule]", "398"}], ",", 
       RowBox[{"329", "\[Rule]", "194"}], ",", 
       RowBox[{"329", "\[Rule]", "194"}], ",", 
       RowBox[{"329", "\[Rule]", "602"}], ",", 
       RowBox[{"329", "\[Rule]", "602"}], ",", 
       RowBox[{"329", "\[Rule]", "126"}], ",", 
       RowBox[{"329", "\[Rule]", "534"}], ",", 
       RowBox[{"329", "\[Rule]", "330"}], ",", 
       RowBox[{"193", "\[Rule]", "398"}], ",", 
       RowBox[{"193", "\[Rule]", "398"}], ",", 
       RowBox[{"193", "\[Rule]", "330"}], ",", 
       RowBox[{"193", "\[Rule]", "330"}], ",", 
       RowBox[{"193", "\[Rule]", "194"}], ",", 
       RowBox[{"805", "\[Rule]", "602"}], ",", 
       RowBox[{"805", "\[Rule]", "602"}], ",", 
       RowBox[{"805", "\[Rule]", "1010"}], ",", 
       RowBox[{"805", "\[Rule]", "1010"}], ",", 
       RowBox[{"805", "\[Rule]", "806"}], ",", 
       RowBox[{"737", "\[Rule]", "602"}], ",", 
       RowBox[{"737", "\[Rule]", "602"}], ",", 
       RowBox[{"737", "\[Rule]", "1010"}], ",", 
       RowBox[{"737", "\[Rule]", "1010"}], ",", 
       RowBox[{"737", "\[Rule]", "534"}], ",", 
       RowBox[{"737", "\[Rule]", "534"}], ",", 
       RowBox[{"737", "\[Rule]", "942"}], ",", 
       RowBox[{"737", "\[Rule]", "942"}], ",", 
       RowBox[{"737", "\[Rule]", "738"}], ",", 
       RowBox[{"601", "\[Rule]", "398"}], ",", 
       RowBox[{"601", "\[Rule]", "398"}], ",", 
       RowBox[{"601", "\[Rule]", "806"}], ",", 
       RowBox[{"601", "\[Rule]", "806"}], ",", 
       RowBox[{"601", "\[Rule]", "330"}], ",", 
       RowBox[{"601", "\[Rule]", "330"}], ",", 
       RowBox[{"601", "\[Rule]", "738"}], ",", 
       RowBox[{"601", "\[Rule]", "738"}], ",", 
       RowBox[{"601", "\[Rule]", "602"}], ",", 
       RowBox[{"261", "\[Rule]", "126"}], ",", 
       RowBox[{"261", "\[Rule]", "534"}], ",", 
       RowBox[{"261", "\[Rule]", "58"}], ",", 
       RowBox[{"261", "\[Rule]", "58"}], ",", 
       RowBox[{"261", "\[Rule]", "466"}], ",", 
       RowBox[{"261", "\[Rule]", "466"}], ",", 
       RowBox[{"261", "\[Rule]", "262"}], ",", 
       RowBox[{"125", "\[Rule]", "330"}], ",", 
       RowBox[{"125", "\[Rule]", "262"}], ",", 
       RowBox[{"125", "\[Rule]", "126"}], ",", 
       RowBox[{"669", "\[Rule]", "534"}], ",", 
       RowBox[{"669", "\[Rule]", "534"}], ",", 
       RowBox[{"669", "\[Rule]", "942"}], ",", 
       RowBox[{"669", "\[Rule]", "942"}], ",", 
       RowBox[{"669", "\[Rule]", "466"}], ",", 
       RowBox[{"669", "\[Rule]", "874"}], ",", 
       RowBox[{"669", "\[Rule]", "670"}], ",", 
       RowBox[{"533", "\[Rule]", "330"}], ",", 
       RowBox[{"533", "\[Rule]", "738"}], ",", 
       RowBox[{"533", "\[Rule]", "738"}], ",", 
       RowBox[{"533", "\[Rule]", "262"}], ",", 
       RowBox[{"533", "\[Rule]", "670"}], ",", 
       RowBox[{"533", "\[Rule]", "670"}], ",", 
       RowBox[{"533", "\[Rule]", "534"}], ",", 
       RowBox[{"57", "\[Rule]", "262"}], ",", 
       RowBox[{"57", "\[Rule]", "262"}], ",", 
       RowBox[{"57", "\[Rule]", "58"}], ",", 
       RowBox[{"465", "\[Rule]", "262"}], ",", 
       RowBox[{"465", "\[Rule]", "262"}], ",", 
       RowBox[{"465", "\[Rule]", "670"}], ",", 
       RowBox[{"465", "\[Rule]", "466"}], ",", 
       RowBox[{"1213", "\[Rule]", "1010"}], ",", 
       RowBox[{"1213", "\[Rule]", "1010"}], ",", 
       RowBox[{"1213", "\[Rule]", "1214"}], ",", 
       RowBox[{"1145", "\[Rule]", "1010"}], ",", 
       RowBox[{"1145", "\[Rule]", "1010"}], ",", 
       RowBox[{"1145", "\[Rule]", "942"}], ",", 
       RowBox[{"1145", "\[Rule]", "942"}], ",", 
       RowBox[{"1145", "\[Rule]", "1146"}], ",", 
       RowBox[{"1009", "\[Rule]", "806"}], ",", 
       RowBox[{"1009", "\[Rule]", "806"}], ",", 
       RowBox[{"1009", "\[Rule]", "1214"}], ",", 
       RowBox[{"1009", "\[Rule]", "1214"}], ",", 
       RowBox[{"1009", "\[Rule]", "738"}], ",", 
       RowBox[{"1009", "\[Rule]", "738"}], ",", 
       RowBox[{"1009", "\[Rule]", "1146"}], ",", 
       RowBox[{"1009", "\[Rule]", "1146"}], ",", 
       RowBox[{"1009", "\[Rule]", "1010"}], ",", 
       RowBox[{"1077", "\[Rule]", "942"}], ",", 
       RowBox[{"1077", "\[Rule]", "942"}], ",", 
       RowBox[{"1077", "\[Rule]", "874"}], ",", 
       RowBox[{"1077", "\[Rule]", "1078"}], ",", 
       RowBox[{"941", "\[Rule]", "738"}], ",", 
       RowBox[{"941", "\[Rule]", "738"}], ",", 
       RowBox[{"941", "\[Rule]", "1146"}], ",", 
       RowBox[{"941", "\[Rule]", "1146"}], ",", 
       RowBox[{"941", "\[Rule]", "670"}], ",", 
       RowBox[{"941", "\[Rule]", "670"}], ",", 
       RowBox[{"941", "\[Rule]", "1078"}], ",", 
       RowBox[{"941", "\[Rule]", "1078"}], ",", 
       RowBox[{"941", "\[Rule]", "942"}], ",", 
       RowBox[{"873", "\[Rule]", "670"}], ",", 
       RowBox[{"873", "\[Rule]", "1078"}], ",", 
       RowBox[{"873", "\[Rule]", "874"}], ",", 
       RowBox[{"148", "\[Rule]", "157"}], ",", 
       RowBox[{"148", "\[Rule]", "145"}], ",", 
       RowBox[{"556", "\[Rule]", "565"}], ",", 
       RowBox[{"556", "\[Rule]", "553"}], ",", 
       RowBox[{"352", "\[Rule]", "361"}], ",", 
       RowBox[{"352", "\[Rule]", "349"}], ",", 
       RowBox[{"374", "\[Rule]", "361"}], ",", 
       RowBox[{"374", "\[Rule]", "383"}], ",", 
       RowBox[{"374", "\[Rule]", "371"}], ",", 
       RowBox[{"156", "\[Rule]", "145"}], ",", 
       RowBox[{"156", "\[Rule]", "167"}], ",", 
       RowBox[{"156", "\[Rule]", "157"}], ",", 
       RowBox[{"156", "\[Rule]", "153"}], ",", 
       RowBox[{"564", "\[Rule]", "553"}], ",", 
       RowBox[{"564", "\[Rule]", "575"}], ",", 
       RowBox[{"564", "\[Rule]", "565"}], ",", 
       RowBox[{"564", "\[Rule]", "561"}], ",", 
       RowBox[{"360", "\[Rule]", "349"}], ",", 
       RowBox[{"360", "\[Rule]", "371"}], ",", 
       RowBox[{"360", "\[Rule]", "361"}], ",", 
       RowBox[{"360", "\[Rule]", "357"}], ",", 
       RowBox[{"80", "\[Rule]", "89"}], ",", 
       RowBox[{"80", "\[Rule]", "77"}], ",", 
       RowBox[{"488", "\[Rule]", "497"}], ",", 
       RowBox[{"488", "\[Rule]", "485"}], ",", 
       RowBox[{"284", "\[Rule]", "293"}], ",", 
       RowBox[{"284", "\[Rule]", "281"}], ",", 
       RowBox[{"88", "\[Rule]", "77"}], ",", 
       RowBox[{"88", "\[Rule]", "99"}], ",", 
       RowBox[{"88", "\[Rule]", "89"}], ",", 
       RowBox[{"88", "\[Rule]", "85"}], ",", 
       RowBox[{"496", "\[Rule]", "485"}], ",", 
       RowBox[{"496", "\[Rule]", "507"}], ",", 
       RowBox[{"496", "\[Rule]", "497"}], ",", 
       RowBox[{"496", "\[Rule]", "493"}], ",", 
       RowBox[{"292", "\[Rule]", "281"}], ",", 
       RowBox[{"292", "\[Rule]", "303"}], ",", 
       RowBox[{"292", "\[Rule]", "293"}], ",", 
       RowBox[{"292", "\[Rule]", "289"}], ",", 
       RowBox[{"396", "\[Rule]", "383"}], ",", 
       RowBox[{"396", "\[Rule]", "407"}], ",", 
       RowBox[{"396", "\[Rule]", "393"}], ",", 
       RowBox[{"382", "\[Rule]", "371"}], ",", 
       RowBox[{"382", "\[Rule]", "393"}], ",", 
       RowBox[{"382", "\[Rule]", "383"}], ",", 
       RowBox[{"382", "\[Rule]", "379"}], ",", 
       RowBox[{"166", "\[Rule]", "153"}], ",", 
       RowBox[{"166", "\[Rule]", "175"}], ",", 
       RowBox[{"166", "\[Rule]", "167"}], ",", 
       RowBox[{"166", "\[Rule]", "163"}], ",", 
       RowBox[{"574", "\[Rule]", "561"}], ",", 
       RowBox[{"574", "\[Rule]", "583"}], ",", 
       RowBox[{"574", "\[Rule]", "575"}], ",", 
       RowBox[{"574", "\[Rule]", "571"}], ",", 
       RowBox[{"370", "\[Rule]", "357"}], ",", 
       RowBox[{"370", "\[Rule]", "379"}], ",", 
       RowBox[{"370", "\[Rule]", "371"}], ",", 
       RowBox[{"370", "\[Rule]", "367"}], ",", 
       RowBox[{"98", "\[Rule]", "85"}], ",", 
       RowBox[{"98", "\[Rule]", "107"}], ",", 
       RowBox[{"98", "\[Rule]", "99"}], ",", 
       RowBox[{"98", "\[Rule]", "95"}], ",", 
       RowBox[{"302", "\[Rule]", "289"}], ",", 
       RowBox[{"302", "\[Rule]", "311"}], ",", 
       RowBox[{"302", "\[Rule]", "303"}], ",", 
       RowBox[{"302", "\[Rule]", "299"}], ",", 
       RowBox[{"964", "\[Rule]", "973"}], ",", 
       RowBox[{"964", "\[Rule]", "961"}], ",", 
       RowBox[{"760", "\[Rule]", "769"}], ",", 
       RowBox[{"760", "\[Rule]", "757"}], ",", 
       RowBox[{"782", "\[Rule]", "769"}], ",", 
       RowBox[{"782", "\[Rule]", "791"}], ",", 
       RowBox[{"782", "\[Rule]", "779"}], ",", 
       RowBox[{"972", "\[Rule]", "961"}], ",", 
       RowBox[{"972", "\[Rule]", "983"}], ",", 
       RowBox[{"972", "\[Rule]", "973"}], ",", 
       RowBox[{"972", "\[Rule]", "969"}], ",", 
       RowBox[{"768", "\[Rule]", "757"}], ",", 
       RowBox[{"768", "\[Rule]", "779"}], ",", 
       RowBox[{"768", "\[Rule]", "769"}], ",", 
       RowBox[{"768", "\[Rule]", "765"}], ",", 
       RowBox[{"896", "\[Rule]", "905"}], ",", 
       RowBox[{"896", "\[Rule]", "893"}], ",", 
       RowBox[{"692", "\[Rule]", "701"}], ",", 
       RowBox[{"692", "\[Rule]", "689"}], ",", 
       RowBox[{"904", "\[Rule]", "893"}], ",", 
       RowBox[{"904", "\[Rule]", "915"}], ",", 
       RowBox[{"904", "\[Rule]", "905"}], ",", 
       RowBox[{"904", "\[Rule]", "901"}], ",", 
       RowBox[{"700", "\[Rule]", "689"}], ",", 
       RowBox[{"700", "\[Rule]", "711"}], ",", 
       RowBox[{"700", "\[Rule]", "701"}], ",", 
       RowBox[{"700", "\[Rule]", "697"}], ",", 
       RowBox[{"804", "\[Rule]", "791"}], ",", 
       RowBox[{"804", "\[Rule]", "815"}], ",", 
       RowBox[{"804", "\[Rule]", "801"}], ",", 
       RowBox[{"790", "\[Rule]", "779"}], ",", 
       RowBox[{"790", "\[Rule]", "801"}], ",", 
       RowBox[{"790", "\[Rule]", "791"}], ",", 
       RowBox[{"790", "\[Rule]", "787"}], ",", 
       RowBox[{"982", "\[Rule]", "969"}], ",", 
       RowBox[{"982", "\[Rule]", "991"}], ",", 
       RowBox[{"982", "\[Rule]", "983"}], ",", 
       RowBox[{"982", "\[Rule]", "979"}], ",", 
       RowBox[{"778", "\[Rule]", "765"}], ",", 
       RowBox[{"778", "\[Rule]", "787"}], ",", 
       RowBox[{"778", "\[Rule]", "779"}], ",", 
       RowBox[{"778", "\[Rule]", "775"}], ",", 
       RowBox[{"506", "\[Rule]", "493"}], ",", 
       RowBox[{"506", "\[Rule]", "515"}], ",", 
       RowBox[{"506", "\[Rule]", "507"}], ",", 
       RowBox[{"506", "\[Rule]", "503"}], ",", 
       RowBox[{"914", "\[Rule]", "901"}], ",", 
       RowBox[{"914", "\[Rule]", "923"}], ",", 
       RowBox[{"914", "\[Rule]", "915"}], ",", 
       RowBox[{"914", "\[Rule]", "911"}], ",", 
       RowBox[{"710", "\[Rule]", "697"}], ",", 
       RowBox[{"710", "\[Rule]", "719"}], ",", 
       RowBox[{"710", "\[Rule]", "711"}], ",", 
       RowBox[{"710", "\[Rule]", "707"}], ",", 
       RowBox[{"12", "\[Rule]", "21"}], ",", 
       RowBox[{"12", "\[Rule]", "9"}], ",", 
       RowBox[{"420", "\[Rule]", "429"}], ",", 
       RowBox[{"420", "\[Rule]", "417"}], ",", 
       RowBox[{"216", "\[Rule]", "225"}], ",", 
       RowBox[{"216", "\[Rule]", "213"}], ",", 
       RowBox[{"20", "\[Rule]", "9"}], ",", 
       RowBox[{"20", "\[Rule]", "31"}], ",", 
       RowBox[{"20", "\[Rule]", "21"}], ",", 
       RowBox[{"20", "\[Rule]", "17"}], ",", 
       RowBox[{"428", "\[Rule]", "417"}], ",", 
       RowBox[{"428", "\[Rule]", "439"}], ",", 
       RowBox[{"428", "\[Rule]", "429"}], ",", 
       RowBox[{"428", "\[Rule]", "425"}], ",", 
       RowBox[{"224", "\[Rule]", "213"}], ",", 
       RowBox[{"224", "\[Rule]", "235"}], ",", 
       RowBox[{"224", "\[Rule]", "225"}], ",", 
       RowBox[{"224", "\[Rule]", "221"}], ",", 
       RowBox[{"30", "\[Rule]", "17"}], ",", 
       RowBox[{"30", "\[Rule]", "39"}], ",", 
       RowBox[{"30", "\[Rule]", "31"}], ",", 
       RowBox[{"30", "\[Rule]", "27"}], ",", 
       RowBox[{"438", "\[Rule]", "425"}], ",", 
       RowBox[{"438", "\[Rule]", "447"}], ",", 
       RowBox[{"438", "\[Rule]", "439"}], ",", 
       RowBox[{"438", "\[Rule]", "435"}], ",", 
       RowBox[{"234", "\[Rule]", "221"}], ",", 
       RowBox[{"234", "\[Rule]", "243"}], ",", 
       RowBox[{"234", "\[Rule]", "235"}], ",", 
       RowBox[{"234", "\[Rule]", "231"}], ",", 
       RowBox[{"828", "\[Rule]", "837"}], ",", 
       RowBox[{"828", "\[Rule]", "825"}], ",", 
       RowBox[{"624", "\[Rule]", "633"}], ",", 
       RowBox[{"624", "\[Rule]", "621"}], ",", 
       RowBox[{"836", "\[Rule]", "825"}], ",", 
       RowBox[{"836", "\[Rule]", "847"}], ",", 
       RowBox[{"836", "\[Rule]", "837"}], ",", 
       RowBox[{"836", "\[Rule]", "833"}], ",", 
       RowBox[{"632", "\[Rule]", "621"}], ",", 
       RowBox[{"632", "\[Rule]", "643"}], ",", 
       RowBox[{"632", "\[Rule]", "633"}], ",", 
       RowBox[{"632", "\[Rule]", "629"}], ",", 
       RowBox[{"846", "\[Rule]", "833"}], ",", 
       RowBox[{"846", "\[Rule]", "855"}], ",", 
       RowBox[{"846", "\[Rule]", "847"}], ",", 
       RowBox[{"846", "\[Rule]", "843"}], ",", 
       RowBox[{"642", "\[Rule]", "629"}], ",", 
       RowBox[{"642", "\[Rule]", "651"}], ",", 
       RowBox[{"642", "\[Rule]", "643"}], ",", 
       RowBox[{"642", "\[Rule]", "639"}], ",", 
       RowBox[{"406", "\[Rule]", "393"}], ",", 
       RowBox[{"406", "\[Rule]", "407"}], ",", 
       RowBox[{"406", "\[Rule]", "403"}], ",", 
       RowBox[{"392", "\[Rule]", "379"}], ",", 
       RowBox[{"392", "\[Rule]", "403"}], ",", 
       RowBox[{"392", "\[Rule]", "393"}], ",", 
       RowBox[{"392", "\[Rule]", "389"}], ",", 
       RowBox[{"814", "\[Rule]", "801"}], ",", 
       RowBox[{"814", "\[Rule]", "815"}], ",", 
       RowBox[{"814", "\[Rule]", "811"}], ",", 
       RowBox[{"800", "\[Rule]", "787"}], ",", 
       RowBox[{"800", "\[Rule]", "811"}], ",", 
       RowBox[{"800", "\[Rule]", "801"}], ",", 
       RowBox[{"800", "\[Rule]", "797"}], ",", 
       RowBox[{"174", "\[Rule]", "163"}], ",", 
       RowBox[{"174", "\[Rule]", "185"}], ",", 
       RowBox[{"174", "\[Rule]", "175"}], ",", 
       RowBox[{"174", "\[Rule]", "171"}], ",", 
       RowBox[{"582", "\[Rule]", "571"}], ",", 
       RowBox[{"582", "\[Rule]", "593"}], ",", 
       RowBox[{"582", "\[Rule]", "583"}], ",", 
       RowBox[{"582", "\[Rule]", "579"}], ",", 
       RowBox[{"378", "\[Rule]", "367"}], ",", 
       RowBox[{"378", "\[Rule]", "389"}], ",", 
       RowBox[{"378", "\[Rule]", "379"}], ",", 
       RowBox[{"378", "\[Rule]", "375"}], ",", 
       RowBox[{"106", "\[Rule]", "95"}], ",", 
       RowBox[{"106", "\[Rule]", "117"}], ",", 
       RowBox[{"106", "\[Rule]", "107"}], ",", 
       RowBox[{"106", "\[Rule]", "103"}], ",", 
       RowBox[{"514", "\[Rule]", "503"}], ",", 
       RowBox[{"514", "\[Rule]", "525"}], ",", 
       RowBox[{"514", "\[Rule]", "515"}], ",", 
       RowBox[{"514", "\[Rule]", "511"}], ",", 
       RowBox[{"310", "\[Rule]", "299"}], ",", 
       RowBox[{"310", "\[Rule]", "321"}], ",", 
       RowBox[{"310", "\[Rule]", "311"}], ",", 
       RowBox[{"310", "\[Rule]", "307"}], ",", 
       RowBox[{"990", "\[Rule]", "979"}], ",", 
       RowBox[{"990", "\[Rule]", "1001"}], ",", 
       RowBox[{"990", "\[Rule]", "991"}], ",", 
       RowBox[{"990", "\[Rule]", "987"}], ",", 
       RowBox[{"786", "\[Rule]", "775"}], ",", 
       RowBox[{"786", "\[Rule]", "797"}], ",", 
       RowBox[{"786", "\[Rule]", "787"}], ",", 
       RowBox[{"786", "\[Rule]", "783"}], ",", 
       RowBox[{"922", "\[Rule]", "911"}], ",", 
       RowBox[{"922", "\[Rule]", "933"}], ",", 
       RowBox[{"922", "\[Rule]", "923"}], ",", 
       RowBox[{"922", "\[Rule]", "919"}], ",", 
       RowBox[{"718", "\[Rule]", "707"}], ",", 
       RowBox[{"718", "\[Rule]", "729"}], ",", 
       RowBox[{"718", "\[Rule]", "719"}], ",", 
       RowBox[{"718", "\[Rule]", "715"}], ",", 
       RowBox[{"38", "\[Rule]", "27"}], ",", 
       RowBox[{"38", "\[Rule]", "49"}], ",", 
       RowBox[{"38", "\[Rule]", "39"}], ",", 
       RowBox[{"38", "\[Rule]", "35"}], ",", 
       RowBox[{"446", "\[Rule]", "435"}], ",", 
       RowBox[{"446", "\[Rule]", "457"}], ",", 
       RowBox[{"446", "\[Rule]", "447"}], ",", 
       RowBox[{"446", "\[Rule]", "443"}], ",", 
       RowBox[{"242", "\[Rule]", "231"}], ",", 
       RowBox[{"242", "\[Rule]", "253"}], ",", 
       RowBox[{"242", "\[Rule]", "243"}], ",", 
       RowBox[{"242", "\[Rule]", "239"}], ",", 
       RowBox[{"854", "\[Rule]", "843"}], ",", 
       RowBox[{"854", "\[Rule]", "865"}], ",", 
       RowBox[{"854", "\[Rule]", "855"}], ",", 
       RowBox[{"854", "\[Rule]", "851"}], ",", 
       RowBox[{"650", "\[Rule]", "639"}], ",", 
       RowBox[{"650", "\[Rule]", "661"}], ",", 
       RowBox[{"650", "\[Rule]", "651"}], ",", 
       RowBox[{"650", "\[Rule]", "647"}], ",", 
       RowBox[{"402", "\[Rule]", "389"}], ",", 
       RowBox[{"402", "\[Rule]", "403"}], ",", 
       RowBox[{"402", "\[Rule]", "399"}], ",", 
       RowBox[{"810", "\[Rule]", "797"}], ",", 
       RowBox[{"810", "\[Rule]", "811"}], ",", 
       RowBox[{"810", "\[Rule]", "807"}], ",", 
       RowBox[{"184", "\[Rule]", "171"}], ",", 
       RowBox[{"184", "\[Rule]", "195"}], ",", 
       RowBox[{"184", "\[Rule]", "185"}], ",", 
       RowBox[{"184", "\[Rule]", "181"}], ",", 
       RowBox[{"592", "\[Rule]", "579"}], ",", 
       RowBox[{"592", "\[Rule]", "603"}], ",", 
       RowBox[{"592", "\[Rule]", "593"}], ",", 
       RowBox[{"592", "\[Rule]", "589"}], ",", 
       RowBox[{"388", "\[Rule]", "375"}], ",", 
       RowBox[{"388", "\[Rule]", "399"}], ",", 
       RowBox[{"388", "\[Rule]", "389"}], ",", 
       RowBox[{"388", "\[Rule]", "385"}], ",", 
       RowBox[{"116", "\[Rule]", "103"}], ",", 
       RowBox[{"116", "\[Rule]", "127"}], ",", 
       RowBox[{"116", "\[Rule]", "117"}], ",", 
       RowBox[{"116", "\[Rule]", "113"}], ",", 
       RowBox[{"524", "\[Rule]", "511"}], ",", 
       RowBox[{"524", "\[Rule]", "535"}], ",", 
       RowBox[{"524", "\[Rule]", "525"}], ",", 
       RowBox[{"524", "\[Rule]", "521"}], ",", 
       RowBox[{"320", "\[Rule]", "307"}], ",", 
       RowBox[{"320", "\[Rule]", "331"}], ",", 
       RowBox[{"320", "\[Rule]", "321"}], ",", 
       RowBox[{"320", "\[Rule]", "317"}], ",", 
       RowBox[{"1000", "\[Rule]", "987"}], ",", 
       RowBox[{"1000", "\[Rule]", "1011"}], ",", 
       RowBox[{"1000", "\[Rule]", "1001"}], ",", 
       RowBox[{"1000", "\[Rule]", "997"}], ",", 
       RowBox[{"796", "\[Rule]", "783"}], ",", 
       RowBox[{"796", "\[Rule]", "807"}], ",", 
       RowBox[{"796", "\[Rule]", "797"}], ",", 
       RowBox[{"796", "\[Rule]", "793"}], ",", 
       RowBox[{"932", "\[Rule]", "919"}], ",", 
       RowBox[{"932", "\[Rule]", "943"}], ",", 
       RowBox[{"932", "\[Rule]", "933"}], ",", 
       RowBox[{"932", "\[Rule]", "929"}], ",", 
       RowBox[{"728", "\[Rule]", "715"}], ",", 
       RowBox[{"728", "\[Rule]", "739"}], ",", 
       RowBox[{"728", "\[Rule]", "729"}], ",", 
       RowBox[{"728", "\[Rule]", "725"}], ",", 
       RowBox[{"48", "\[Rule]", "35"}], ",", 
       RowBox[{"48", "\[Rule]", "59"}], ",", 
       RowBox[{"48", "\[Rule]", "49"}], ",", 
       RowBox[{"48", "\[Rule]", "45"}], ",", 
       RowBox[{"456", "\[Rule]", "443"}], ",", 
       RowBox[{"456", "\[Rule]", "467"}], ",", 
       RowBox[{"456", "\[Rule]", "457"}], ",", 
       RowBox[{"456", "\[Rule]", "453"}], ",", 
       RowBox[{"252", "\[Rule]", "239"}], ",", 
       RowBox[{"252", "\[Rule]", "263"}], ",", 
       RowBox[{"252", "\[Rule]", "253"}], ",", 
       RowBox[{"252", "\[Rule]", "249"}], ",", 
       RowBox[{"660", "\[Rule]", "647"}], ",", 
       RowBox[{"660", "\[Rule]", "671"}], ",", 
       RowBox[{"660", "\[Rule]", "661"}], ",", 
       RowBox[{"660", "\[Rule]", "657"}], ",", 
       RowBox[{"1168", "\[Rule]", "1177"}], ",", 
       RowBox[{"1168", "\[Rule]", "1165"}], ",", 
       RowBox[{"1190", "\[Rule]", "1177"}], ",", 
       RowBox[{"1190", "\[Rule]", "1199"}], ",", 
       RowBox[{"1190", "\[Rule]", "1187"}], ",", 
       RowBox[{"1176", "\[Rule]", "1165"}], ",", 
       RowBox[{"1176", "\[Rule]", "1187"}], ",", 
       RowBox[{"1176", "\[Rule]", "1177"}], ",", 
       RowBox[{"1176", "\[Rule]", "1173"}], ",", 
       RowBox[{"1100", "\[Rule]", "1109"}], ",", 
       RowBox[{"1100", "\[Rule]", "1097"}], ",", 
       RowBox[{"1122", "\[Rule]", "1109"}], ",", 
       RowBox[{"1122", "\[Rule]", "1131"}], ",", 
       RowBox[{"1122", "\[Rule]", "1119"}], ",", 
       RowBox[{"1108", "\[Rule]", "1097"}], ",", 
       RowBox[{"1108", "\[Rule]", "1119"}], ",", 
       RowBox[{"1108", "\[Rule]", "1109"}], ",", 
       RowBox[{"1108", "\[Rule]", "1105"}], ",", 
       RowBox[{"1212", "\[Rule]", "1199"}], ",", 
       RowBox[{"1212", "\[Rule]", "1223"}], ",", 
       RowBox[{"1212", "\[Rule]", "1209"}], ",", 
       RowBox[{"1198", "\[Rule]", "1187"}], ",", 
       RowBox[{"1198", "\[Rule]", "1209"}], ",", 
       RowBox[{"1198", "\[Rule]", "1199"}], ",", 
       RowBox[{"1198", "\[Rule]", "1195"}], ",", 
       RowBox[{"1144", "\[Rule]", "1131"}], ",", 
       RowBox[{"1144", "\[Rule]", "1155"}], ",", 
       RowBox[{"1144", "\[Rule]", "1141"}], ",", 
       RowBox[{"1130", "\[Rule]", "1119"}], ",", 
       RowBox[{"1130", "\[Rule]", "1141"}], ",", 
       RowBox[{"1130", "\[Rule]", "1131"}], ",", 
       RowBox[{"1130", "\[Rule]", "1127"}], ",", 
       RowBox[{"1186", "\[Rule]", "1173"}], ",", 
       RowBox[{"1186", "\[Rule]", "1195"}], ",", 
       RowBox[{"1186", "\[Rule]", "1187"}], ",", 
       RowBox[{"1186", "\[Rule]", "1183"}], ",", 
       RowBox[{"1118", "\[Rule]", "1105"}], ",", 
       RowBox[{"1118", "\[Rule]", "1127"}], ",", 
       RowBox[{"1118", "\[Rule]", "1119"}], ",", 
       RowBox[{"1118", "\[Rule]", "1115"}], ",", 
       RowBox[{"1032", "\[Rule]", "1041"}], ",", 
       RowBox[{"1032", "\[Rule]", "1029"}], ",", 
       RowBox[{"1054", "\[Rule]", "1041"}], ",", 
       RowBox[{"1054", "\[Rule]", "1063"}], ",", 
       RowBox[{"1054", "\[Rule]", "1051"}], ",", 
       RowBox[{"1040", "\[Rule]", "1029"}], ",", 
       RowBox[{"1040", "\[Rule]", "1051"}], ",", 
       RowBox[{"1040", "\[Rule]", "1041"}], ",", 
       RowBox[{"1040", "\[Rule]", "1037"}], ",", 
       RowBox[{"1076", "\[Rule]", "1063"}], ",", 
       RowBox[{"1076", "\[Rule]", "1087"}], ",", 
       RowBox[{"1076", "\[Rule]", "1073"}], ",", 
       RowBox[{"1062", "\[Rule]", "1051"}], ",", 
       RowBox[{"1062", "\[Rule]", "1073"}], ",", 
       RowBox[{"1062", "\[Rule]", "1063"}], ",", 
       RowBox[{"1062", "\[Rule]", "1059"}], ",", 
       RowBox[{"1050", "\[Rule]", "1037"}], ",", 
       RowBox[{"1050", "\[Rule]", "1059"}], ",", 
       RowBox[{"1050", "\[Rule]", "1051"}], ",", 
       RowBox[{"1050", "\[Rule]", "1047"}], ",", 
       RowBox[{"1222", "\[Rule]", "1209"}], ",", 
       RowBox[{"1222", "\[Rule]", "1223"}], ",", 
       RowBox[{"1222", "\[Rule]", "1219"}], ",", 
       RowBox[{"1154", "\[Rule]", "1141"}], ",", 
       RowBox[{"1154", "\[Rule]", "1155"}], ",", 
       RowBox[{"1154", "\[Rule]", "1151"}], ",", 
       RowBox[{"1208", "\[Rule]", "1195"}], ",", 
       RowBox[{"1208", "\[Rule]", "1219"}], ",", 
       RowBox[{"1208", "\[Rule]", "1209"}], ",", 
       RowBox[{"1208", "\[Rule]", "1205"}], ",", 
       RowBox[{"1140", "\[Rule]", "1127"}], ",", 
       RowBox[{"1140", "\[Rule]", "1151"}], ",", 
       RowBox[{"1140", "\[Rule]", "1141"}], ",", 
       RowBox[{"1140", "\[Rule]", "1137"}], ",", 
       RowBox[{"1086", "\[Rule]", "1073"}], ",", 
       RowBox[{"1086", "\[Rule]", "1087"}], ",", 
       RowBox[{"1086", "\[Rule]", "1083"}], ",", 
       RowBox[{"1072", "\[Rule]", "1059"}], ",", 
       RowBox[{"1072", "\[Rule]", "1083"}], ",", 
       RowBox[{"1072", "\[Rule]", "1073"}], ",", 
       RowBox[{"1072", "\[Rule]", "1069"}], ",", 
       RowBox[{"1194", "\[Rule]", "1183"}], ",", 
       RowBox[{"1194", "\[Rule]", "1205"}], ",", 
       RowBox[{"1194", "\[Rule]", "1195"}], ",", 
       RowBox[{"1194", "\[Rule]", "1191"}], ",", 
       RowBox[{"1126", "\[Rule]", "1115"}], ",", 
       RowBox[{"1126", "\[Rule]", "1137"}], ",", 
       RowBox[{"1126", "\[Rule]", "1127"}], ",", 
       RowBox[{"1126", "\[Rule]", "1123"}], ",", 
       RowBox[{"1058", "\[Rule]", "1047"}], ",", 
       RowBox[{"1058", "\[Rule]", "1069"}], ",", 
       RowBox[{"1058", "\[Rule]", "1059"}], ",", 
       RowBox[{"1058", "\[Rule]", "1055"}], ",", 
       RowBox[{"1218", "\[Rule]", "1205"}], ",", 
       RowBox[{"1218", "\[Rule]", "1219"}], ",", 
       RowBox[{"1218", "\[Rule]", "1215"}], ",", 
       RowBox[{"1150", "\[Rule]", "1137"}], ",", 
       RowBox[{"1150", "\[Rule]", "1151"}], ",", 
       RowBox[{"1150", "\[Rule]", "1147"}], ",", 
       RowBox[{"1082", "\[Rule]", "1069"}], ",", 
       RowBox[{"1082", "\[Rule]", "1083"}], ",", 
       RowBox[{"1082", "\[Rule]", "1079"}], ",", 
       RowBox[{"1204", "\[Rule]", "1191"}], ",", 
       RowBox[{"1204", "\[Rule]", "1215"}], ",", 
       RowBox[{"1204", "\[Rule]", "1205"}], ",", 
       RowBox[{"1204", "\[Rule]", "1201"}], ",", 
       RowBox[{"1136", "\[Rule]", "1123"}], ",", 
       RowBox[{"1136", "\[Rule]", "1147"}], ",", 
       RowBox[{"1136", "\[Rule]", "1137"}], ",", 
       RowBox[{"1136", "\[Rule]", "1133"}], ",", 
       RowBox[{"864", "\[Rule]", "851"}], ",", 
       RowBox[{"864", "\[Rule]", "875"}], ",", 
       RowBox[{"864", "\[Rule]", "865"}], ",", 
       RowBox[{"864", "\[Rule]", "861"}], ",", 
       RowBox[{"1068", "\[Rule]", "1055"}], ",", 
       RowBox[{"1068", "\[Rule]", "1079"}], ",", 
       RowBox[{"1068", "\[Rule]", "1069"}], ",", 
       RowBox[{"1068", "\[Rule]", "1065"}], ",", 
       RowBox[{"194", "\[Rule]", "181"}], ",", 
       RowBox[{"194", "\[Rule]", "195"}], ",", 
       RowBox[{"602", "\[Rule]", "589"}], ",", 
       RowBox[{"602", "\[Rule]", "603"}], ",", 
       RowBox[{"398", "\[Rule]", "385"}], ",", 
       RowBox[{"398", "\[Rule]", "399"}], ",", 
       RowBox[{"126", "\[Rule]", "113"}], ",", 
       RowBox[{"126", "\[Rule]", "127"}], ",", 
       RowBox[{"534", "\[Rule]", "521"}], ",", 
       RowBox[{"534", "\[Rule]", "535"}], ",", 
       RowBox[{"330", "\[Rule]", "317"}], ",", 
       RowBox[{"330", "\[Rule]", "331"}], ",", 
       RowBox[{"1010", "\[Rule]", "997"}], ",", 
       RowBox[{"1010", "\[Rule]", "1011"}], ",", 
       RowBox[{"806", "\[Rule]", "793"}], ",", 
       RowBox[{"806", "\[Rule]", "807"}], ",", 
       RowBox[{"942", "\[Rule]", "929"}], ",", 
       RowBox[{"942", "\[Rule]", "943"}], ",", 
       RowBox[{"738", "\[Rule]", "725"}], ",", 
       RowBox[{"738", "\[Rule]", "739"}], ",", 
       RowBox[{"58", "\[Rule]", "45"}], ",", 
       RowBox[{"58", "\[Rule]", "59"}], ",", 
       RowBox[{"466", "\[Rule]", "453"}], ",", 
       RowBox[{"466", "\[Rule]", "467"}], ",", 
       RowBox[{"262", "\[Rule]", "249"}], ",", 
       RowBox[{"262", "\[Rule]", "263"}], ",", 
       RowBox[{"874", "\[Rule]", "861"}], ",", 
       RowBox[{"874", "\[Rule]", "875"}], ",", 
       RowBox[{"670", "\[Rule]", "657"}], ",", 
       RowBox[{"670", "\[Rule]", "671"}], ",", 
       RowBox[{"1214", "\[Rule]", "1201"}], ",", 
       RowBox[{"1214", "\[Rule]", "1215"}], ",", 
       RowBox[{"1146", "\[Rule]", "1133"}], ",", 
       RowBox[{"1146", "\[Rule]", "1147"}], ",", 
       RowBox[{"1078", "\[Rule]", "1065"}], ",", 
       RowBox[{"1078", "\[Rule]", "1079"}], ",", 
       RowBox[{"145", "\[Rule]", "350"}], ",", 
       RowBox[{"145", "\[Rule]", "350"}], ",", 
       RowBox[{"145", "\[Rule]", "282"}], ",", 
       RowBox[{"145", "\[Rule]", "282"}], ",", 
       RowBox[{"145", "\[Rule]", "146"}], ",", 
       RowBox[{"553", "\[Rule]", "350"}], ",", 
       RowBox[{"553", "\[Rule]", "350"}], ",", 
       RowBox[{"553", "\[Rule]", "758"}], ",", 
       RowBox[{"553", "\[Rule]", "758"}], ",", 
       RowBox[{"553", "\[Rule]", "282"}], ",", 
       RowBox[{"553", "\[Rule]", "282"}], ",", 
       RowBox[{"553", "\[Rule]", "690"}], ",", 
       RowBox[{"553", "\[Rule]", "690"}], ",", 
       RowBox[{"553", "\[Rule]", "554"}], ",", 
       RowBox[{"361", "\[Rule]", "158"}], ",", 
       RowBox[{"361", "\[Rule]", "158"}], ",", 
       RowBox[{"361", "\[Rule]", "566"}], ",", 
       RowBox[{"361", "\[Rule]", "566"}], ",", 
       RowBox[{"361", "\[Rule]", "362"}], ",", 
       RowBox[{"349", "\[Rule]", "146"}], ",", 
       RowBox[{"349", "\[Rule]", "146"}], ",", 
       RowBox[{"349", "\[Rule]", "554"}], ",", 
       RowBox[{"349", "\[Rule]", "554"}], ",", 
       RowBox[{"349", "\[Rule]", "350"}], ",", 
       RowBox[{"383", "\[Rule]", "180"}], ",", 
       RowBox[{"383", "\[Rule]", "180"}], ",", 
       RowBox[{"383", "\[Rule]", "588"}], ",", 
       RowBox[{"383", "\[Rule]", "588"}], ",", 
       RowBox[{"383", "\[Rule]", "384"}], ",", 
       RowBox[{"371", "\[Rule]", "168"}], ",", 
       RowBox[{"371", "\[Rule]", "168"}], ",", 
       RowBox[{"371", "\[Rule]", "576"}], ",", 
       RowBox[{"371", "\[Rule]", "576"}], ",", 
       RowBox[{"371", "\[Rule]", "372"}], ",", 
       RowBox[{"153", "\[Rule]", "358"}], ",", 
       RowBox[{"153", "\[Rule]", "358"}], ",", 
       RowBox[{"153", "\[Rule]", "290"}], ",", 
       RowBox[{"153", "\[Rule]", "290"}], ",", 
       RowBox[{"153", "\[Rule]", "154"}], ",", 
       RowBox[{"561", "\[Rule]", "358"}], ",", 
       RowBox[{"561", "\[Rule]", "358"}], ",", 
       RowBox[{"561", "\[Rule]", "766"}], ",", 
       RowBox[{"561", "\[Rule]", "766"}], ",", 
       RowBox[{"561", "\[Rule]", "290"}], ",", 
       RowBox[{"561", "\[Rule]", "290"}], ",", 
       RowBox[{"561", "\[Rule]", "698"}], ",", 
       RowBox[{"561", "\[Rule]", "698"}], ",", 
       RowBox[{"561", "\[Rule]", "562"}], ",", 
       RowBox[{"357", "\[Rule]", "154"}], ",", 
       RowBox[{"357", "\[Rule]", "154"}], ",", 
       RowBox[{"357", "\[Rule]", "562"}], ",", 
       RowBox[{"357", "\[Rule]", "562"}], ",", 
       RowBox[{"357", "\[Rule]", "358"}], ",", 
       RowBox[{"77", "\[Rule]", "282"}], ",", 
       RowBox[{"77", "\[Rule]", "214"}], ",", 
       RowBox[{"77", "\[Rule]", "78"}], ",", 
       RowBox[{"485", "\[Rule]", "282"}], ",", 
       RowBox[{"485", "\[Rule]", "690"}], ",", 
       RowBox[{"485", "\[Rule]", "690"}], ",", 
       RowBox[{"485", "\[Rule]", "214"}], ",", 
       RowBox[{"485", "\[Rule]", "622"}], ",", 
       RowBox[{"485", "\[Rule]", "622"}], ",", 
       RowBox[{"485", "\[Rule]", "486"}], ",", 
       RowBox[{"281", "\[Rule]", "146"}], ",", 
       RowBox[{"281", "\[Rule]", "146"}], ",", 
       RowBox[{"281", "\[Rule]", "554"}], ",", 
       RowBox[{"281", "\[Rule]", "554"}], ",", 
       RowBox[{"281", "\[Rule]", "78"}], ",", 
       RowBox[{"281", "\[Rule]", "486"}], ",", 
       RowBox[{"281", "\[Rule]", "282"}], ",", 
       RowBox[{"85", "\[Rule]", "290"}], ",", 
       RowBox[{"85", "\[Rule]", "222"}], ",", 
       RowBox[{"85", "\[Rule]", "86"}], ",", 
       RowBox[{"493", "\[Rule]", "290"}], ",", 
       RowBox[{"493", "\[Rule]", "698"}], ",", 
       RowBox[{"493", "\[Rule]", "698"}], ",", 
       RowBox[{"493", "\[Rule]", "222"}], ",", 
       RowBox[{"493", "\[Rule]", "630"}], ",", 
       RowBox[{"493", "\[Rule]", "630"}], ",", 
       RowBox[{"493", "\[Rule]", "494"}], ",", 
       RowBox[{"289", "\[Rule]", "154"}], ",", 
       RowBox[{"289", "\[Rule]", "154"}], ",", 
       RowBox[{"289", "\[Rule]", "562"}], ",", 
       RowBox[{"289", "\[Rule]", "562"}], ",", 
       RowBox[{"289", "\[Rule]", "86"}], ",", 
       RowBox[{"289", "\[Rule]", "494"}], ",", 
       RowBox[{"289", "\[Rule]", "290"}], ",", 
       RowBox[{"407", "\[Rule]", "204"}], ",", 
       RowBox[{"407", "\[Rule]", "204"}], ",", 
       RowBox[{"407", "\[Rule]", "612"}], ",", 
       RowBox[{"407", "\[Rule]", "612"}], ",", 
       RowBox[{"407", "\[Rule]", "408"}], ",", 
       RowBox[{"393", "\[Rule]", "190"}], ",", 
       RowBox[{"393", "\[Rule]", "190"}], ",", 
       RowBox[{"393", "\[Rule]", "598"}], ",", 
       RowBox[{"393", "\[Rule]", "598"}], ",", 
       RowBox[{"393", "\[Rule]", "394"}], ",", 
       RowBox[{"379", "\[Rule]", "176"}], ",", 
       RowBox[{"379", "\[Rule]", "176"}], ",", 
       RowBox[{"379", "\[Rule]", "584"}], ",", 
       RowBox[{"379", "\[Rule]", "584"}], ",", 
       RowBox[{"379", "\[Rule]", "380"}], ",", 
       RowBox[{"163", "\[Rule]", "368"}], ",", 
       RowBox[{"163", "\[Rule]", "368"}], ",", 
       RowBox[{"163", "\[Rule]", "300"}], ",", 
       RowBox[{"163", "\[Rule]", "300"}], ",", 
       RowBox[{"163", "\[Rule]", "164"}], ",", 
       RowBox[{"571", "\[Rule]", "368"}], ",", 
       RowBox[{"571", "\[Rule]", "368"}], ",", 
       RowBox[{"571", "\[Rule]", "776"}], ",", 
       RowBox[{"571", "\[Rule]", "776"}], ",", 
       RowBox[{"571", "\[Rule]", "300"}], ",", 
       RowBox[{"571", "\[Rule]", "300"}], ",", 
       RowBox[{"571", "\[Rule]", "708"}], ",", 
       RowBox[{"571", "\[Rule]", "708"}], ",", 
       RowBox[{"571", "\[Rule]", "572"}], ",", 
       RowBox[{"367", "\[Rule]", "164"}], ",", 
       RowBox[{"367", "\[Rule]", "164"}], ",", 
       RowBox[{"367", "\[Rule]", "572"}], ",", 
       RowBox[{"367", "\[Rule]", "572"}], ",", 
       RowBox[{"367", "\[Rule]", "368"}], ",", 
       RowBox[{"95", "\[Rule]", "300"}], ",", 
       RowBox[{"95", "\[Rule]", "232"}], ",", 
       RowBox[{"95", "\[Rule]", "96"}], ",", 
       RowBox[{"299", "\[Rule]", "164"}], ",", 
       RowBox[{"299", "\[Rule]", "164"}], ",", 
       RowBox[{"299", "\[Rule]", "572"}], ",", 
       RowBox[{"299", "\[Rule]", "572"}], ",", 
       RowBox[{"299", "\[Rule]", "96"}], ",", 
       RowBox[{"299", "\[Rule]", "504"}], ",", 
       RowBox[{"299", "\[Rule]", "300"}], ",", 
       RowBox[{"961", "\[Rule]", "758"}], ",", 
       RowBox[{"961", "\[Rule]", "758"}], ",", 
       RowBox[{"961", "\[Rule]", "1166"}], ",", 
       RowBox[{"961", "\[Rule]", "1166"}], ",", 
       RowBox[{"961", "\[Rule]", "690"}], ",", 
       RowBox[{"961", "\[Rule]", "690"}], ",", 
       RowBox[{"961", "\[Rule]", "1098"}], ",", 
       RowBox[{"961", "\[Rule]", "1098"}], ",", 
       RowBox[{"961", "\[Rule]", "962"}], ",", 
       RowBox[{"769", "\[Rule]", "566"}], ",", 
       RowBox[{"769", "\[Rule]", "566"}], ",", 
       RowBox[{"769", "\[Rule]", "974"}], ",", 
       RowBox[{"769", "\[Rule]", "974"}], ",", 
       RowBox[{"769", "\[Rule]", "770"}], ",", 
       RowBox[{"757", "\[Rule]", "554"}], ",", 
       RowBox[{"757", "\[Rule]", "554"}], ",", 
       RowBox[{"757", "\[Rule]", "962"}], ",", 
       RowBox[{"757", "\[Rule]", "962"}], ",", 
       RowBox[{"757", "\[Rule]", "758"}], ",", 
       RowBox[{"791", "\[Rule]", "588"}], ",", 
       RowBox[{"791", "\[Rule]", "588"}], ",", 
       RowBox[{"791", "\[Rule]", "996"}], ",", 
       RowBox[{"791", "\[Rule]", "996"}], ",", 
       RowBox[{"791", "\[Rule]", "792"}], ",", 
       RowBox[{"779", "\[Rule]", "576"}], ",", 
       RowBox[{"779", "\[Rule]", "576"}], ",", 
       RowBox[{"779", "\[Rule]", "984"}], ",", 
       RowBox[{"779", "\[Rule]", "984"}], ",", 
       RowBox[{"779", "\[Rule]", "780"}], ",", 
       RowBox[{"969", "\[Rule]", "766"}], ",", 
       RowBox[{"969", "\[Rule]", "766"}], ",", 
       RowBox[{"969", "\[Rule]", "1174"}], ",", 
       RowBox[{"969", "\[Rule]", "1174"}], ",", 
       RowBox[{"969", "\[Rule]", "698"}], ",", 
       RowBox[{"969", "\[Rule]", "698"}], ",", 
       RowBox[{"969", "\[Rule]", "1106"}], ",", 
       RowBox[{"969", "\[Rule]", "1106"}], ",", 
       RowBox[{"969", "\[Rule]", "970"}], ",", 
       RowBox[{"765", "\[Rule]", "562"}], ",", 
       RowBox[{"765", "\[Rule]", "562"}], ",", 
       RowBox[{"765", "\[Rule]", "970"}], ",", 
       RowBox[{"765", "\[Rule]", "970"}], ",", 
       RowBox[{"765", "\[Rule]", "766"}], ",", 
       RowBox[{"893", "\[Rule]", "690"}], ",", 
       RowBox[{"893", "\[Rule]", "690"}], ",", 
       RowBox[{"893", "\[Rule]", "1098"}], ",", 
       RowBox[{"893", "\[Rule]", "1098"}], ",", 
       RowBox[{"893", "\[Rule]", "622"}], ",", 
       RowBox[{"893", "\[Rule]", "622"}], ",", 
       RowBox[{"893", "\[Rule]", "1030"}], ",", 
       RowBox[{"893", "\[Rule]", "1030"}], ",", 
       RowBox[{"893", "\[Rule]", "894"}], ",", 
       RowBox[{"689", "\[Rule]", "554"}], ",", 
       RowBox[{"689", "\[Rule]", "554"}], ",", 
       RowBox[{"689", "\[Rule]", "962"}], ",", 
       RowBox[{"689", "\[Rule]", "962"}], ",", 
       RowBox[{"689", "\[Rule]", "486"}], ",", 
       RowBox[{"689", "\[Rule]", "486"}], ",", 
       RowBox[{"689", "\[Rule]", "894"}], ",", 
       RowBox[{"689", "\[Rule]", "894"}], ",", 
       RowBox[{"689", "\[Rule]", "690"}], ",", 
       RowBox[{"901", "\[Rule]", "698"}], ",", 
       RowBox[{"901", "\[Rule]", "698"}], ",", 
       RowBox[{"901", "\[Rule]", "1106"}], ",", 
       RowBox[{"901", "\[Rule]", "1106"}], ",", 
       RowBox[{"901", "\[Rule]", "630"}], ",", 
       RowBox[{"901", "\[Rule]", "630"}], ",", 
       RowBox[{"901", "\[Rule]", "1038"}], ",", 
       RowBox[{"901", "\[Rule]", "1038"}], ",", 
       RowBox[{"901", "\[Rule]", "902"}], ",", 
       RowBox[{"697", "\[Rule]", "562"}], ",", 
       RowBox[{"697", "\[Rule]", "562"}], ",", 
       RowBox[{"697", "\[Rule]", "970"}], ",", 
       RowBox[{"697", "\[Rule]", "970"}], ",", 
       RowBox[{"697", "\[Rule]", "494"}], ",", 
       RowBox[{"697", "\[Rule]", "494"}], ",", 
       RowBox[{"697", "\[Rule]", "902"}], ",", 
       RowBox[{"697", "\[Rule]", "902"}], ",", 
       RowBox[{"697", "\[Rule]", "698"}], ",", 
       RowBox[{"815", "\[Rule]", "612"}], ",", 
       RowBox[{"815", "\[Rule]", "612"}], ",", 
       RowBox[{"815", "\[Rule]", "1020"}], ",", 
       RowBox[{"815", "\[Rule]", "1020"}], ",", 
       RowBox[{"815", "\[Rule]", "816"}], ",", 
       RowBox[{"801", "\[Rule]", "598"}], ",", 
       RowBox[{"801", "\[Rule]", "598"}], ",", 
       RowBox[{"801", "\[Rule]", "1006"}], ",", 
       RowBox[{"801", "\[Rule]", "1006"}], ",", 
       RowBox[{"801", "\[Rule]", "802"}], ",", 
       RowBox[{"787", "\[Rule]", "584"}], ",", 
       RowBox[{"787", "\[Rule]", "584"}], ",", 
       RowBox[{"787", "\[Rule]", "992"}], ",", 
       RowBox[{"787", "\[Rule]", "992"}], ",", 
       RowBox[{"787", "\[Rule]", "788"}], ",", 
       RowBox[{"979", "\[Rule]", "776"}], ",", 
       RowBox[{"979", "\[Rule]", "776"}], ",", 
       RowBox[{"979", "\[Rule]", "1184"}], ",", 
       RowBox[{"979", "\[Rule]", "1184"}], ",", 
       RowBox[{"979", "\[Rule]", "708"}], ",", 
       RowBox[{"979", "\[Rule]", "708"}], ",", 
       RowBox[{"979", "\[Rule]", "1116"}], ",", 
       RowBox[{"979", "\[Rule]", "1116"}], ",", 
       RowBox[{"979", "\[Rule]", "980"}], ",", 
       RowBox[{"775", "\[Rule]", "572"}], ",", 
       RowBox[{"775", "\[Rule]", "572"}], ",", 
       RowBox[{"775", "\[Rule]", "980"}], ",", 
       RowBox[{"775", "\[Rule]", "980"}], ",", 
       RowBox[{"775", "\[Rule]", "776"}], ",", 
       RowBox[{"503", "\[Rule]", "300"}], ",", 
       RowBox[{"503", "\[Rule]", "708"}], ",", 
       RowBox[{"503", "\[Rule]", "708"}], ",", 
       RowBox[{"503", "\[Rule]", "232"}], ",", 
       RowBox[{"503", "\[Rule]", "640"}], ",", 
       RowBox[{"503", "\[Rule]", "640"}], ",", 
       RowBox[{"503", "\[Rule]", "504"}], ",", 
       RowBox[{"911", "\[Rule]", "708"}], ",", 
       RowBox[{"911", "\[Rule]", "708"}], ",", 
       RowBox[{"911", "\[Rule]", "1116"}], ",", 
       RowBox[{"911", "\[Rule]", "1116"}], ",", 
       RowBox[{"911", "\[Rule]", "640"}], ",", 
       RowBox[{"911", "\[Rule]", "640"}], ",", 
       RowBox[{"911", "\[Rule]", "1048"}], ",", 
       RowBox[{"911", "\[Rule]", "1048"}], ",", 
       RowBox[{"911", "\[Rule]", "912"}], ",", 
       RowBox[{"707", "\[Rule]", "572"}], ",", 
       RowBox[{"707", "\[Rule]", "572"}], ",", 
       RowBox[{"707", "\[Rule]", "980"}], ",", 
       RowBox[{"707", "\[Rule]", "980"}], ",", 
       RowBox[{"707", "\[Rule]", "504"}], ",", 
       RowBox[{"707", "\[Rule]", "504"}], ",", 
       RowBox[{"707", "\[Rule]", "912"}], ",", 
       RowBox[{"707", "\[Rule]", "912"}], ",", 
       RowBox[{"707", "\[Rule]", "708"}], ",", 
       RowBox[{"9", "\[Rule]", "214"}], ",", 
       RowBox[{"9", "\[Rule]", "214"}], ",", 
       RowBox[{"9", "\[Rule]", "10"}], ",", 
       RowBox[{"417", "\[Rule]", "214"}], ",", 
       RowBox[{"417", "\[Rule]", "214"}], ",", 
       RowBox[{"417", "\[Rule]", "622"}], ",", 
       RowBox[{"417", "\[Rule]", "418"}], ",", 
       RowBox[{"213", "\[Rule]", "78"}], ",", 
       RowBox[{"213", "\[Rule]", "486"}], ",", 
       RowBox[{"213", "\[Rule]", "10"}], ",", 
       RowBox[{"213", "\[Rule]", "10"}], ",", 
       RowBox[{"213", "\[Rule]", "418"}], ",", 
       RowBox[{"213", "\[Rule]", "418"}], ",", 
       RowBox[{"213", "\[Rule]", "214"}], ",", 
       RowBox[{"17", "\[Rule]", "222"}], ",", 
       RowBox[{"17", "\[Rule]", "222"}], ",", 
       RowBox[{"17", "\[Rule]", "18"}], ",", 
       RowBox[{"425", "\[Rule]", "222"}], ",", 
       RowBox[{"425", "\[Rule]", "222"}], ",", 
       RowBox[{"425", "\[Rule]", "630"}], ",", 
       RowBox[{"425", "\[Rule]", "426"}], ",", 
       RowBox[{"221", "\[Rule]", "86"}], ",", 
       RowBox[{"221", "\[Rule]", "494"}], ",", 
       RowBox[{"221", "\[Rule]", "18"}], ",", 
       RowBox[{"221", "\[Rule]", "18"}], ",", 
       RowBox[{"221", "\[Rule]", "426"}], ",", 
       RowBox[{"221", "\[Rule]", "426"}], ",", 
       RowBox[{"221", "\[Rule]", "222"}], ",", 
       RowBox[{"27", "\[Rule]", "232"}], ",", 
       RowBox[{"27", "\[Rule]", "232"}], ",", 
       RowBox[{"27", "\[Rule]", "28"}], ",", 
       RowBox[{"435", "\[Rule]", "232"}], ",", 
       RowBox[{"435", "\[Rule]", "232"}], ",", 
       RowBox[{"435", "\[Rule]", "640"}], ",", 
       RowBox[{"435", "\[Rule]", "436"}], ",", 
       RowBox[{"231", "\[Rule]", "96"}], ",", 
       RowBox[{"231", "\[Rule]", "504"}], ",", 
       RowBox[{"231", "\[Rule]", "28"}], ",", 
       RowBox[{"231", "\[Rule]", "28"}], ",", 
       RowBox[{"231", "\[Rule]", "436"}], ",", 
       RowBox[{"231", "\[Rule]", "436"}], ",", 
       RowBox[{"231", "\[Rule]", "232"}], ",", 
       RowBox[{"825", "\[Rule]", "622"}], ",", 
       RowBox[{"825", "\[Rule]", "1030"}], ",", 
       RowBox[{"825", "\[Rule]", "1030"}], ",", 
       RowBox[{"825", "\[Rule]", "826"}], ",", 
       RowBox[{"621", "\[Rule]", "486"}], ",", 
       RowBox[{"621", "\[Rule]", "486"}], ",", 
       RowBox[{"621", "\[Rule]", "894"}], ",", 
       RowBox[{"621", "\[Rule]", "894"}], ",", 
       RowBox[{"621", "\[Rule]", "418"}], ",", 
       RowBox[{"621", "\[Rule]", "826"}], ",", 
       RowBox[{"621", "\[Rule]", "622"}], ",", 
       RowBox[{"833", "\[Rule]", "630"}], ",", 
       RowBox[{"833", "\[Rule]", "1038"}], ",", 
       RowBox[{"833", "\[Rule]", "1038"}], ",", 
       RowBox[{"833", "\[Rule]", "834"}], ",", 
       RowBox[{"629", "\[Rule]", "494"}], ",", 
       RowBox[{"629", "\[Rule]", "494"}], ",", 
       RowBox[{"629", "\[Rule]", "902"}], ",", 
       RowBox[{"629", "\[Rule]", "902"}], ",", 
       RowBox[{"629", "\[Rule]", "426"}], ",", 
       RowBox[{"629", "\[Rule]", "834"}], ",", 
       RowBox[{"629", "\[Rule]", "630"}], ",", 
       RowBox[{"843", "\[Rule]", "640"}], ",", 
       RowBox[{"843", "\[Rule]", "1048"}], ",", 
       RowBox[{"843", "\[Rule]", "1048"}], ",", 
       RowBox[{"843", "\[Rule]", "844"}], ",", 
       RowBox[{"639", "\[Rule]", "504"}], ",", 
       RowBox[{"639", "\[Rule]", "504"}], ",", 
       RowBox[{"639", "\[Rule]", "912"}], ",", 
       RowBox[{"639", "\[Rule]", "912"}], ",", 
       RowBox[{"639", "\[Rule]", "436"}], ",", 
       RowBox[{"639", "\[Rule]", "844"}], ",", 
       RowBox[{"639", "\[Rule]", "640"}], ",", 
       RowBox[{"403", "\[Rule]", "200"}], ",", 
       RowBox[{"403", "\[Rule]", "200"}], ",", 
       RowBox[{"403", "\[Rule]", "608"}], ",", 
       RowBox[{"403", "\[Rule]", "608"}], ",", 
       RowBox[{"403", "\[Rule]", "404"}], ",", 
       RowBox[{"389", "\[Rule]", "186"}], ",", 
       RowBox[{"389", "\[Rule]", "186"}], ",", 
       RowBox[{"389", "\[Rule]", "594"}], ",", 
       RowBox[{"389", "\[Rule]", "594"}], ",", 
       RowBox[{"389", "\[Rule]", "390"}], ",", 
       RowBox[{"811", "\[Rule]", "608"}], ",", 
       RowBox[{"811", "\[Rule]", "608"}], ",", 
       RowBox[{"811", "\[Rule]", "1016"}], ",", 
       RowBox[{"811", "\[Rule]", "1016"}], ",", 
       RowBox[{"811", "\[Rule]", "812"}], ",", 
       RowBox[{"797", "\[Rule]", "594"}], ",", 
       RowBox[{"797", "\[Rule]", "594"}], ",", 
       RowBox[{"797", "\[Rule]", "1002"}], ",", 
       RowBox[{"797", "\[Rule]", "1002"}], ",", 
       RowBox[{"797", "\[Rule]", "798"}], ",", 
       RowBox[{"171", "\[Rule]", "376"}], ",", 
       RowBox[{"171", "\[Rule]", "376"}], ",", 
       RowBox[{"171", "\[Rule]", "308"}], ",", 
       RowBox[{"171", "\[Rule]", "308"}], ",", 
       RowBox[{"171", "\[Rule]", "172"}], ",", 
       RowBox[{"579", "\[Rule]", "376"}], ",", 
       RowBox[{"579", "\[Rule]", "376"}], ",", 
       RowBox[{"579", "\[Rule]", "784"}], ",", 
       RowBox[{"579", "\[Rule]", "784"}], ",", 
       RowBox[{"579", "\[Rule]", "308"}], ",", 
       RowBox[{"579", "\[Rule]", "308"}], ",", 
       RowBox[{"579", "\[Rule]", "716"}], ",", 
       RowBox[{"579", "\[Rule]", "716"}], ",", 
       RowBox[{"579", "\[Rule]", "580"}], ",", 
       RowBox[{"375", "\[Rule]", "172"}], ",", 
       RowBox[{"375", "\[Rule]", "172"}], ",", 
       RowBox[{"375", "\[Rule]", "580"}], ",", 
       RowBox[{"375", "\[Rule]", "580"}], ",", 
       RowBox[{"375", "\[Rule]", "376"}], ",", 
       RowBox[{"103", "\[Rule]", "308"}], ",", 
       RowBox[{"103", "\[Rule]", "240"}], ",", 
       RowBox[{"103", "\[Rule]", "104"}], ",", 
       RowBox[{"511", "\[Rule]", "308"}], ",", 
       RowBox[{"511", "\[Rule]", "716"}], ",", 
       RowBox[{"511", "\[Rule]", "716"}], ",", 
       RowBox[{"511", "\[Rule]", "240"}], ",", 
       RowBox[{"511", "\[Rule]", "648"}], ",", 
       RowBox[{"511", "\[Rule]", "648"}], ",", 
       RowBox[{"511", "\[Rule]", "512"}], ",", 
       RowBox[{"307", "\[Rule]", "172"}], ",", 
       RowBox[{"307", "\[Rule]", "172"}], ",", 
       RowBox[{"307", "\[Rule]", "580"}], ",", 
       RowBox[{"307", "\[Rule]", "580"}], ",", 
       RowBox[{"307", "\[Rule]", "104"}], ",", 
       RowBox[{"307", "\[Rule]", "512"}], ",", 
       RowBox[{"307", "\[Rule]", "308"}], ",", 
       RowBox[{"987", "\[Rule]", "784"}], ",", 
       RowBox[{"987", "\[Rule]", "784"}], ",", 
       RowBox[{"987", "\[Rule]", "1192"}], ",", 
       RowBox[{"987", "\[Rule]", "1192"}], ",", 
       RowBox[{"987", "\[Rule]", "716"}], ",", 
       RowBox[{"987", "\[Rule]", "716"}], ",", 
       RowBox[{"987", "\[Rule]", "1124"}], ",", 
       RowBox[{"987", "\[Rule]", "1124"}], ",", 
       RowBox[{"987", "\[Rule]", "988"}], ",", 
       RowBox[{"783", "\[Rule]", "580"}], ",", 
       RowBox[{"783", "\[Rule]", "580"}], ",", 
       RowBox[{"783", "\[Rule]", "988"}], ",", 
       RowBox[{"783", "\[Rule]", "988"}], ",", 
       RowBox[{"783", "\[Rule]", "784"}], ",", 
       RowBox[{"919", "\[Rule]", "716"}], ",", 
       RowBox[{"919", "\[Rule]", "716"}], ",", 
       RowBox[{"919", "\[Rule]", "1124"}], ",", 
       RowBox[{"919", "\[Rule]", "1124"}], ",", 
       RowBox[{"919", "\[Rule]", "648"}], ",", 
       RowBox[{"919", "\[Rule]", "648"}], ",", 
       RowBox[{"919", "\[Rule]", "1056"}], ",", 
       RowBox[{"919", "\[Rule]", "1056"}], ",", 
       RowBox[{"919", "\[Rule]", "920"}], ",", 
       RowBox[{"715", "\[Rule]", "580"}], ",", 
       RowBox[{"715", "\[Rule]", "580"}], ",", 
       RowBox[{"715", "\[Rule]", "988"}], ",", 
       RowBox[{"715", "\[Rule]", "988"}], ",", 
       RowBox[{"715", "\[Rule]", "512"}], ",", 
       RowBox[{"715", "\[Rule]", "512"}], ",", 
       RowBox[{"715", "\[Rule]", "920"}], ",", 
       RowBox[{"715", "\[Rule]", "920"}], ",", 
       RowBox[{"715", "\[Rule]", "716"}], ",", 
       RowBox[{"35", "\[Rule]", "240"}], ",", 
       RowBox[{"35", "\[Rule]", "240"}], ",", 
       RowBox[{"35", "\[Rule]", "36"}], ",", 
       RowBox[{"443", "\[Rule]", "240"}], ",", 
       RowBox[{"443", "\[Rule]", "240"}], ",", 
       RowBox[{"443", "\[Rule]", "648"}], ",", 
       RowBox[{"443", "\[Rule]", "444"}], ",", 
       RowBox[{"239", "\[Rule]", "104"}], ",", 
       RowBox[{"239", "\[Rule]", "512"}], ",", 
       RowBox[{"239", "\[Rule]", "36"}], ",", 
       RowBox[{"239", "\[Rule]", "36"}], ",", 
       RowBox[{"239", "\[Rule]", "444"}], ",", 
       RowBox[{"239", "\[Rule]", "444"}], ",", 
       RowBox[{"239", "\[Rule]", "240"}], ",", 
       RowBox[{"851", "\[Rule]", "648"}], ",", 
       RowBox[{"851", "\[Rule]", "1056"}], ",", 
       RowBox[{"851", "\[Rule]", "1056"}], ",", 
       RowBox[{"851", "\[Rule]", "852"}], ",", 
       RowBox[{"647", "\[Rule]", "512"}], ",", 
       RowBox[{"647", "\[Rule]", "512"}], ",", 
       RowBox[{"647", "\[Rule]", "920"}], ",", 
       RowBox[{"647", "\[Rule]", "920"}], ",", 
       RowBox[{"647", "\[Rule]", "444"}], ",", 
       RowBox[{"647", "\[Rule]", "852"}], ",", 
       RowBox[{"647", "\[Rule]", "648"}], ",", 
       RowBox[{"399", "\[Rule]", "196"}], ",", 
       RowBox[{"399", "\[Rule]", "196"}], ",", 
       RowBox[{"399", "\[Rule]", "604"}], ",", 
       RowBox[{"399", "\[Rule]", "604"}], ",", 
       RowBox[{"399", "\[Rule]", "400"}], ",", 
       RowBox[{"807", "\[Rule]", "604"}], ",", 
       RowBox[{"807", "\[Rule]", "604"}], ",", 
       RowBox[{"807", "\[Rule]", "1012"}], ",", 
       RowBox[{"807", "\[Rule]", "1012"}], ",", 
       RowBox[{"807", "\[Rule]", "808"}], ",", 
       RowBox[{"181", "\[Rule]", "386"}], ",", 
       RowBox[{"181", "\[Rule]", "386"}], ",", 
       RowBox[{"181", "\[Rule]", "318"}], ",", 
       RowBox[{"181", "\[Rule]", "318"}], ",", 
       RowBox[{"181", "\[Rule]", "182"}], ",", 
       RowBox[{"589", "\[Rule]", "386"}], ",", 
       RowBox[{"589", "\[Rule]", "386"}], ",", 
       RowBox[{"589", "\[Rule]", "794"}], ",", 
       RowBox[{"589", "\[Rule]", "794"}], ",", 
       RowBox[{"589", "\[Rule]", "318"}], ",", 
       RowBox[{"589", "\[Rule]", "318"}], ",", 
       RowBox[{"589", "\[Rule]", "726"}], ",", 
       RowBox[{"589", "\[Rule]", "726"}], ",", 
       RowBox[{"589", "\[Rule]", "590"}], ",", 
       RowBox[{"385", "\[Rule]", "182"}], ",", 
       RowBox[{"385", "\[Rule]", "182"}], ",", 
       RowBox[{"385", "\[Rule]", "590"}], ",", 
       RowBox[{"385", "\[Rule]", "590"}], ",", 
       RowBox[{"385", "\[Rule]", "386"}], ",", 
       RowBox[{"113", "\[Rule]", "318"}], ",", 
       RowBox[{"113", "\[Rule]", "250"}], ",", 
       RowBox[{"113", "\[Rule]", "114"}], ",", 
       RowBox[{"521", "\[Rule]", "318"}], ",", 
       RowBox[{"521", "\[Rule]", "726"}], ",", 
       RowBox[{"521", "\[Rule]", "726"}], ",", 
       RowBox[{"521", "\[Rule]", "250"}], ",", 
       RowBox[{"521", "\[Rule]", "658"}], ",", 
       RowBox[{"521", "\[Rule]", "658"}], ",", 
       RowBox[{"521", "\[Rule]", "522"}], ",", 
       RowBox[{"317", "\[Rule]", "182"}], ",", 
       RowBox[{"317", "\[Rule]", "182"}], ",", 
       RowBox[{"317", "\[Rule]", "590"}], ",", 
       RowBox[{"317", "\[Rule]", "590"}], ",", 
       RowBox[{"317", "\[Rule]", "114"}], ",", 
       RowBox[{"317", "\[Rule]", "522"}], ",", 
       RowBox[{"317", "\[Rule]", "318"}], ",", 
       RowBox[{"997", "\[Rule]", "794"}], ",", 
       RowBox[{"997", "\[Rule]", "794"}], ",", 
       RowBox[{"997", "\[Rule]", "1202"}], ",", 
       RowBox[{"997", "\[Rule]", "1202"}], ",", 
       RowBox[{"997", "\[Rule]", "726"}], ",", 
       RowBox[{"997", "\[Rule]", "726"}], ",", 
       RowBox[{"997", "\[Rule]", "1134"}], ",", 
       RowBox[{"997", "\[Rule]", "1134"}], ",", 
       RowBox[{"997", "\[Rule]", "998"}], ",", 
       RowBox[{"793", "\[Rule]", "590"}], ",", 
       RowBox[{"793", "\[Rule]", "590"}], ",", 
       RowBox[{"793", "\[Rule]", "998"}], ",", 
       RowBox[{"793", "\[Rule]", "998"}], ",", 
       RowBox[{"793", "\[Rule]", "794"}], ",", 
       RowBox[{"929", "\[Rule]", "726"}], ",", 
       RowBox[{"929", "\[Rule]", "726"}], ",", 
       RowBox[{"929", "\[Rule]", "1134"}], ",", 
       RowBox[{"929", "\[Rule]", "1134"}], ",", 
       RowBox[{"929", "\[Rule]", "658"}], ",", 
       RowBox[{"929", "\[Rule]", "658"}], ",", 
       RowBox[{"929", "\[Rule]", "1066"}], ",", 
       RowBox[{"929", "\[Rule]", "1066"}], ",", 
       RowBox[{"929", "\[Rule]", "930"}], ",", 
       RowBox[{"725", "\[Rule]", "590"}], ",", 
       RowBox[{"725", "\[Rule]", "590"}], ",", 
       RowBox[{"725", "\[Rule]", "998"}], ",", 
       RowBox[{"725", "\[Rule]", "998"}], ",", 
       RowBox[{"725", "\[Rule]", "522"}], ",", 
       RowBox[{"725", "\[Rule]", "522"}], ",", 
       RowBox[{"725", "\[Rule]", "930"}], ",", 
       RowBox[{"725", "\[Rule]", "930"}], ",", 
       RowBox[{"725", "\[Rule]", "726"}], ",", 
       RowBox[{"45", "\[Rule]", "250"}], ",", 
       RowBox[{"45", "\[Rule]", "250"}], ",", 
       RowBox[{"45", "\[Rule]", "46"}], ",", 
       RowBox[{"453", "\[Rule]", "250"}], ",", 
       RowBox[{"453", "\[Rule]", "250"}], ",", 
       RowBox[{"453", "\[Rule]", "658"}], ",", 
       RowBox[{"453", "\[Rule]", "454"}], ",", 
       RowBox[{"249", "\[Rule]", "114"}], ",", 
       RowBox[{"249", "\[Rule]", "522"}], ",", 
       RowBox[{"249", "\[Rule]", "46"}], ",", 
       RowBox[{"249", "\[Rule]", "46"}], ",", 
       RowBox[{"249", "\[Rule]", "454"}], ",", 
       RowBox[{"249", "\[Rule]", "454"}], ",", 
       RowBox[{"249", "\[Rule]", "250"}], ",", 
       RowBox[{"657", "\[Rule]", "522"}], ",", 
       RowBox[{"657", "\[Rule]", "522"}], ",", 
       RowBox[{"657", "\[Rule]", "930"}], ",", 
       RowBox[{"657", "\[Rule]", "930"}], ",", 
       RowBox[{"657", "\[Rule]", "454"}], ",", 
       RowBox[{"657", "\[Rule]", "862"}], ",", 
       RowBox[{"657", "\[Rule]", "658"}], ",", 
       RowBox[{"1177", "\[Rule]", "974"}], ",", 
       RowBox[{"1177", "\[Rule]", "974"}], ",", 
       RowBox[{"1177", "\[Rule]", "1178"}], ",", 
       RowBox[{"1165", "\[Rule]", "962"}], ",", 
       RowBox[{"1165", "\[Rule]", "962"}], ",", 
       RowBox[{"1165", "\[Rule]", "1166"}], ",", 
       RowBox[{"1199", "\[Rule]", "996"}], ",", 
       RowBox[{"1199", "\[Rule]", "996"}], ",", 
       RowBox[{"1199", "\[Rule]", "1200"}], ",", 
       RowBox[{"1187", "\[Rule]", "984"}], ",", 
       RowBox[{"1187", "\[Rule]", "984"}], ",", 
       RowBox[{"1187", "\[Rule]", "1188"}], ",", 
       RowBox[{"1173", "\[Rule]", "970"}], ",", 
       RowBox[{"1173", "\[Rule]", "970"}], ",", 
       RowBox[{"1173", "\[Rule]", "1174"}], ",", 
       RowBox[{"1109", "\[Rule]", "974"}], ",", 
       RowBox[{"1109", "\[Rule]", "974"}], ",", 
       RowBox[{"1109", "\[Rule]", "906"}], ",", 
       RowBox[{"1109", "\[Rule]", "906"}], ",", 
       RowBox[{"1109", "\[Rule]", "1110"}], ",", 
       RowBox[{"1097", "\[Rule]", "962"}], ",", 
       RowBox[{"1097", "\[Rule]", "962"}], ",", 
       RowBox[{"1097", "\[Rule]", "894"}], ",", 
       RowBox[{"1097", "\[Rule]", "894"}], ",", 
       RowBox[{"1097", "\[Rule]", "1098"}], ",", 
       RowBox[{"1131", "\[Rule]", "996"}], ",", 
       RowBox[{"1131", "\[Rule]", "996"}], ",", 
       RowBox[{"1131", "\[Rule]", "928"}], ",", 
       RowBox[{"1131", "\[Rule]", "928"}], ",", 
       RowBox[{"1131", "\[Rule]", "1132"}], ",", 
       RowBox[{"1119", "\[Rule]", "984"}], ",", 
       RowBox[{"1119", "\[Rule]", "984"}], ",", 
       RowBox[{"1119", "\[Rule]", "916"}], ",", 
       RowBox[{"1119", "\[Rule]", "916"}], ",", 
       RowBox[{"1119", "\[Rule]", "1120"}], ",", 
       RowBox[{"1105", "\[Rule]", "970"}], ",", 
       RowBox[{"1105", "\[Rule]", "970"}], ",", 
       RowBox[{"1105", "\[Rule]", "902"}], ",", 
       RowBox[{"1105", "\[Rule]", "902"}], ",", 
       RowBox[{"1105", "\[Rule]", "1106"}], ",", 
       RowBox[{"1223", "\[Rule]", "1020"}], ",", 
       RowBox[{"1223", "\[Rule]", "1020"}], ",", 
       RowBox[{"1223", "\[Rule]", "1224"}], ",", 
       RowBox[{"1209", "\[Rule]", "1006"}], ",", 
       RowBox[{"1209", "\[Rule]", "1006"}], ",", 
       RowBox[{"1209", "\[Rule]", "1210"}], ",", 
       RowBox[{"1195", "\[Rule]", "992"}], ",", 
       RowBox[{"1195", "\[Rule]", "992"}], ",", 
       RowBox[{"1195", "\[Rule]", "1196"}], ",", 
       RowBox[{"1155", "\[Rule]", "1020"}], ",", 
       RowBox[{"1155", "\[Rule]", "1020"}], ",", 
       RowBox[{"1155", "\[Rule]", "952"}], ",", 
       RowBox[{"1155", "\[Rule]", "952"}], ",", 
       RowBox[{"1155", "\[Rule]", "1156"}], ",", 
       RowBox[{"1141", "\[Rule]", "1006"}], ",", 
       RowBox[{"1141", "\[Rule]", "1006"}], ",", 
       RowBox[{"1141", "\[Rule]", "938"}], ",", 
       RowBox[{"1141", "\[Rule]", "938"}], ",", 
       RowBox[{"1141", "\[Rule]", "1142"}], ",", 
       RowBox[{"1127", "\[Rule]", "992"}], ",", 
       RowBox[{"1127", "\[Rule]", "992"}], ",", 
       RowBox[{"1127", "\[Rule]", "924"}], ",", 
       RowBox[{"1127", "\[Rule]", "924"}], ",", 
       RowBox[{"1127", "\[Rule]", "1128"}], ",", 
       RowBox[{"1183", "\[Rule]", "980"}], ",", 
       RowBox[{"1183", "\[Rule]", "980"}], ",", 
       RowBox[{"1183", "\[Rule]", "1184"}], ",", 
       RowBox[{"1115", "\[Rule]", "980"}], ",", 
       RowBox[{"1115", "\[Rule]", "980"}], ",", 
       RowBox[{"1115", "\[Rule]", "912"}], ",", 
       RowBox[{"1115", "\[Rule]", "912"}], ",", 
       RowBox[{"1115", "\[Rule]", "1116"}], ",", 
       RowBox[{"1041", "\[Rule]", "906"}], ",", 
       RowBox[{"1041", "\[Rule]", "906"}], ",", 
       RowBox[{"1041", "\[Rule]", "838"}], ",", 
       RowBox[{"1041", "\[Rule]", "838"}], ",", 
       RowBox[{"1041", "\[Rule]", "1042"}], ",", 
       RowBox[{"1029", "\[Rule]", "894"}], ",", 
       RowBox[{"1029", "\[Rule]", "894"}], ",", 
       RowBox[{"1029", "\[Rule]", "826"}], ",", 
       RowBox[{"1029", "\[Rule]", "826"}], ",", 
       RowBox[{"1029", "\[Rule]", "1030"}], ",", 
       RowBox[{"1063", "\[Rule]", "928"}], ",", 
       RowBox[{"1063", "\[Rule]", "928"}], ",", 
       RowBox[{"1063", "\[Rule]", "860"}], ",", 
       RowBox[{"1063", "\[Rule]", "860"}], ",", 
       RowBox[{"1063", "\[Rule]", "1064"}], ",", 
       RowBox[{"1051", "\[Rule]", "916"}], ",", 
       RowBox[{"1051", "\[Rule]", "916"}], ",", 
       RowBox[{"1051", "\[Rule]", "848"}], ",", 
       RowBox[{"1051", "\[Rule]", "848"}], ",", 
       RowBox[{"1051", "\[Rule]", "1052"}], ",", 
       RowBox[{"1037", "\[Rule]", "902"}], ",", 
       RowBox[{"1037", "\[Rule]", "902"}], ",", 
       RowBox[{"1037", "\[Rule]", "834"}], ",", 
       RowBox[{"1037", "\[Rule]", "834"}], ",", 
       RowBox[{"1037", "\[Rule]", "1038"}], ",", 
       RowBox[{"1087", "\[Rule]", "952"}], ",", 
       RowBox[{"1087", "\[Rule]", "952"}], ",", 
       RowBox[{"1087", "\[Rule]", "884"}], ",", 
       RowBox[{"1087", "\[Rule]", "884"}], ",", 
       RowBox[{"1087", "\[Rule]", "1088"}], ",", 
       RowBox[{"1073", "\[Rule]", "938"}], ",", 
       RowBox[{"1073", "\[Rule]", "938"}], ",", 
       RowBox[{"1073", "\[Rule]", "870"}], ",", 
       RowBox[{"1073", "\[Rule]", "870"}], ",", 
       RowBox[{"1073", "\[Rule]", "1074"}], ",", 
       RowBox[{"1059", "\[Rule]", "924"}], ",", 
       RowBox[{"1059", "\[Rule]", "924"}], ",", 
       RowBox[{"1059", "\[Rule]", "856"}], ",", 
       RowBox[{"1059", "\[Rule]", "856"}], ",", 
       RowBox[{"1059", "\[Rule]", "1060"}], ",", 
       RowBox[{"1047", "\[Rule]", "912"}], ",", 
       RowBox[{"1047", "\[Rule]", "912"}], ",", 
       RowBox[{"1047", "\[Rule]", "844"}], ",", 
       RowBox[{"1047", "\[Rule]", "844"}], ",", 
       RowBox[{"1047", "\[Rule]", "1048"}], ",", 
       RowBox[{"1219", "\[Rule]", "1016"}], ",", 
       RowBox[{"1219", "\[Rule]", "1016"}], ",", 
       RowBox[{"1219", "\[Rule]", "1220"}], ",", 
       RowBox[{"1151", "\[Rule]", "1016"}], ",", 
       RowBox[{"1151", "\[Rule]", "1016"}], ",", 
       RowBox[{"1151", "\[Rule]", "948"}], ",", 
       RowBox[{"1151", "\[Rule]", "948"}], ",", 
       RowBox[{"1151", "\[Rule]", "1152"}], ",", 
       RowBox[{"1205", "\[Rule]", "1002"}], ",", 
       RowBox[{"1205", "\[Rule]", "1002"}], ",", 
       RowBox[{"1205", "\[Rule]", "1206"}], ",", 
       RowBox[{"1137", "\[Rule]", "1002"}], ",", 
       RowBox[{"1137", "\[Rule]", "1002"}], ",", 
       RowBox[{"1137", "\[Rule]", "934"}], ",", 
       RowBox[{"1137", "\[Rule]", "934"}], ",", 
       RowBox[{"1137", "\[Rule]", "1138"}], ",", 
       RowBox[{"1083", "\[Rule]", "948"}], ",", 
       RowBox[{"1083", "\[Rule]", "948"}], ",", 
       RowBox[{"1083", "\[Rule]", "880"}], ",", 
       RowBox[{"1083", "\[Rule]", "880"}], ",", 
       RowBox[{"1083", "\[Rule]", "1084"}], ",", 
       RowBox[{"1069", "\[Rule]", "934"}], ",", 
       RowBox[{"1069", "\[Rule]", "934"}], ",", 
       RowBox[{"1069", "\[Rule]", "866"}], ",", 
       RowBox[{"1069", "\[Rule]", "866"}], ",", 
       RowBox[{"1069", "\[Rule]", "1070"}], ",", 
       RowBox[{"1191", "\[Rule]", "988"}], ",", 
       RowBox[{"1191", "\[Rule]", "988"}], ",", 
       RowBox[{"1191", "\[Rule]", "1192"}], ",", 
       RowBox[{"1123", "\[Rule]", "988"}], ",", 
       RowBox[{"1123", "\[Rule]", "988"}], ",", 
       RowBox[{"1123", "\[Rule]", "920"}], ",", 
       RowBox[{"1123", "\[Rule]", "920"}], ",", 
       RowBox[{"1123", "\[Rule]", "1124"}], ",", 
       RowBox[{"1055", "\[Rule]", "920"}], ",", 
       RowBox[{"1055", "\[Rule]", "920"}], ",", 
       RowBox[{"1055", "\[Rule]", "852"}], ",", 
       RowBox[{"1055", "\[Rule]", "852"}], ",", 
       RowBox[{"1055", "\[Rule]", "1056"}], ",", 
       RowBox[{"1215", "\[Rule]", "1012"}], ",", 
       RowBox[{"1215", "\[Rule]", "1012"}], ",", 
       RowBox[{"1215", "\[Rule]", "1216"}], ",", 
       RowBox[{"1147", "\[Rule]", "1012"}], ",", 
       RowBox[{"1147", "\[Rule]", "1012"}], ",", 
       RowBox[{"1147", "\[Rule]", "944"}], ",", 
       RowBox[{"1147", "\[Rule]", "944"}], ",", 
       RowBox[{"1147", "\[Rule]", "1148"}], ",", 
       RowBox[{"1079", "\[Rule]", "944"}], ",", 
       RowBox[{"1079", "\[Rule]", "944"}], ",", 
       RowBox[{"1079", "\[Rule]", "876"}], ",", 
       RowBox[{"1079", "\[Rule]", "876"}], ",", 
       RowBox[{"1079", "\[Rule]", "1080"}], ",", 
       RowBox[{"1201", "\[Rule]", "998"}], ",", 
       RowBox[{"1201", "\[Rule]", "998"}], ",", 
       RowBox[{"1201", "\[Rule]", "1202"}], ",", 
       RowBox[{"1133", "\[Rule]", "998"}], ",", 
       RowBox[{"1133", "\[Rule]", "998"}], ",", 
       RowBox[{"1133", "\[Rule]", "930"}], ",", 
       RowBox[{"1133", "\[Rule]", "930"}], ",", 
       RowBox[{"1133", "\[Rule]", "1134"}], ",", 
       RowBox[{"861", "\[Rule]", "658"}], ",", 
       RowBox[{"861", "\[Rule]", "1066"}], ",", 
       RowBox[{"861", "\[Rule]", "1066"}], ",", 
       RowBox[{"861", "\[Rule]", "862"}], ",", 
       RowBox[{"1065", "\[Rule]", "930"}], ",", 
       RowBox[{"1065", "\[Rule]", "930"}], ",", 
       RowBox[{"1065", "\[Rule]", "862"}], ",", 
       RowBox[{"1065", "\[Rule]", "862"}], ",", 
       RowBox[{"1065", "\[Rule]", "1066"}], ",", 
       RowBox[{"350", "\[Rule]", "359"}], ",", 
       RowBox[{"350", "\[Rule]", "351"}], ",", 
       RowBox[{"350", "\[Rule]", "347"}], ",", 
       RowBox[{"282", "\[Rule]", "291"}], ",", 
       RowBox[{"282", "\[Rule]", "283"}], ",", 
       RowBox[{"282", "\[Rule]", "279"}], ",", 
       RowBox[{"146", "\[Rule]", "155"}], ",", 
       RowBox[{"146", "\[Rule]", "147"}], ",", 
       RowBox[{"146", "\[Rule]", "143"}], ",", 
       RowBox[{"758", "\[Rule]", "767"}], ",", 
       RowBox[{"758", "\[Rule]", "759"}], ",", 
       RowBox[{"758", "\[Rule]", "755"}], ",", 
       RowBox[{"690", "\[Rule]", "699"}], ",", 
       RowBox[{"690", "\[Rule]", "691"}], ",", 
       RowBox[{"690", "\[Rule]", "687"}], ",", 
       RowBox[{"554", "\[Rule]", "563"}], ",", 
       RowBox[{"554", "\[Rule]", "555"}], ",", 
       RowBox[{"554", "\[Rule]", "551"}], ",", 
       RowBox[{"358", "\[Rule]", "347"}], ",", 
       RowBox[{"358", "\[Rule]", "369"}], ",", 
       RowBox[{"358", "\[Rule]", "359"}], ",", 
       RowBox[{"290", "\[Rule]", "279"}], ",", 
       RowBox[{"290", "\[Rule]", "301"}], ",", 
       RowBox[{"290", "\[Rule]", "291"}], ",", 
       RowBox[{"154", "\[Rule]", "143"}], ",", 
       RowBox[{"154", "\[Rule]", "165"}], ",", 
       RowBox[{"154", "\[Rule]", "155"}], ",", 
       RowBox[{"766", "\[Rule]", "755"}], ",", 
       RowBox[{"766", "\[Rule]", "777"}], ",", 
       RowBox[{"766", "\[Rule]", "767"}], ",", 
       RowBox[{"698", "\[Rule]", "687"}], ",", 
       RowBox[{"698", "\[Rule]", "709"}], ",", 
       RowBox[{"698", "\[Rule]", "699"}], ",", 
       RowBox[{"562", "\[Rule]", "551"}], ",", 
       RowBox[{"562", "\[Rule]", "573"}], ",", 
       RowBox[{"562", "\[Rule]", "563"}], ",", 
       RowBox[{"214", "\[Rule]", "223"}], ",", 
       RowBox[{"214", "\[Rule]", "215"}], ",", 
       RowBox[{"214", "\[Rule]", "211"}], ",", 
       RowBox[{"78", "\[Rule]", "87"}], ",", 
       RowBox[{"78", "\[Rule]", "79"}], ",", 
       RowBox[{"78", "\[Rule]", "75"}], ",", 
       RowBox[{"622", "\[Rule]", "631"}], ",", 
       RowBox[{"622", "\[Rule]", "623"}], ",", 
       RowBox[{"622", "\[Rule]", "619"}], ",", 
       RowBox[{"486", "\[Rule]", "495"}], ",", 
       RowBox[{"486", "\[Rule]", "487"}], ",", 
       RowBox[{"486", "\[Rule]", "483"}], ",", 
       RowBox[{"222", "\[Rule]", "211"}], ",", 
       RowBox[{"222", "\[Rule]", "233"}], ",", 
       RowBox[{"222", "\[Rule]", "223"}], ",", 
       RowBox[{"86", "\[Rule]", "75"}], ",", 
       RowBox[{"86", "\[Rule]", "97"}], ",", 
       RowBox[{"86", "\[Rule]", "87"}], ",", 
       RowBox[{"630", "\[Rule]", "619"}], ",", 
       RowBox[{"630", "\[Rule]", "641"}], ",", 
       RowBox[{"630", "\[Rule]", "631"}], ",", 
       RowBox[{"494", "\[Rule]", "483"}], ",", 
       RowBox[{"494", "\[Rule]", "505"}], ",", 
       RowBox[{"494", "\[Rule]", "495"}], ",", 
       RowBox[{"368", "\[Rule]", "377"}], ",", 
       RowBox[{"368", "\[Rule]", "369"}], ",", 
       RowBox[{"368", "\[Rule]", "365"}], ",", 
       RowBox[{"300", "\[Rule]", "309"}], ",", 
       RowBox[{"300", "\[Rule]", "301"}], ",", 
       RowBox[{"300", "\[Rule]", "297"}], ",", 
       RowBox[{"164", "\[Rule]", "173"}], ",", 
       RowBox[{"164", "\[Rule]", "165"}], ",", 
       RowBox[{"164", "\[Rule]", "161"}], ",", 
       RowBox[{"776", "\[Rule]", "785"}], ",", 
       RowBox[{"776", "\[Rule]", "777"}], ",", 
       RowBox[{"776", "\[Rule]", "773"}], ",", 
       RowBox[{"708", "\[Rule]", "717"}], ",", 
       RowBox[{"708", "\[Rule]", "709"}], ",", 
       RowBox[{"708", "\[Rule]", "705"}], ",", 
       RowBox[{"572", "\[Rule]", "581"}], ",", 
       RowBox[{"572", "\[Rule]", "573"}], ",", 
       RowBox[{"572", "\[Rule]", "569"}], ",", 
       RowBox[{"232", "\[Rule]", "241"}], ",", 
       RowBox[{"232", "\[Rule]", "233"}], ",", 
       RowBox[{"232", "\[Rule]", "229"}], ",", 
       RowBox[{"96", "\[Rule]", "105"}], ",", 
       RowBox[{"96", "\[Rule]", "97"}], ",", 
       RowBox[{"96", "\[Rule]", "93"}], ",", 
       RowBox[{"504", "\[Rule]", "513"}], ",", 
       RowBox[{"504", "\[Rule]", "505"}], ",", 
       RowBox[{"504", "\[Rule]", "501"}], ",", 
       RowBox[{"1166", "\[Rule]", "1175"}], ",", 
       RowBox[{"1166", "\[Rule]", "1167"}], ",", 
       RowBox[{"1166", "\[Rule]", "1163"}], ",", 
       RowBox[{"1098", "\[Rule]", "1107"}], ",", 
       RowBox[{"1098", "\[Rule]", "1099"}], ",", 
       RowBox[{"1098", "\[Rule]", "1095"}], ",", 
       RowBox[{"962", "\[Rule]", "971"}], ",", 
       RowBox[{"962", "\[Rule]", "963"}], ",", 
       RowBox[{"962", "\[Rule]", "959"}], ",", 
       RowBox[{"1174", "\[Rule]", "1163"}], ",", 
       RowBox[{"1174", "\[Rule]", "1185"}], ",", 
       RowBox[{"1174", "\[Rule]", "1175"}], ",", 
       RowBox[{"1106", "\[Rule]", "1095"}], ",", 
       RowBox[{"1106", "\[Rule]", "1117"}], ",", 
       RowBox[{"1106", "\[Rule]", "1107"}], ",", 
       RowBox[{"970", "\[Rule]", "959"}], ",", 
       RowBox[{"970", "\[Rule]", "981"}], ",", 
       RowBox[{"970", "\[Rule]", "971"}], ",", 
       RowBox[{"1030", "\[Rule]", "1039"}], ",", 
       RowBox[{"1030", "\[Rule]", "1031"}], ",", 
       RowBox[{"1030", "\[Rule]", "1027"}], ",", 
       RowBox[{"894", "\[Rule]", "903"}], ",", 
       RowBox[{"894", "\[Rule]", "895"}], ",", 
       RowBox[{"894", "\[Rule]", "891"}], ",", 
       RowBox[{"1038", "\[Rule]", "1027"}], ",", 
       RowBox[{"1038", "\[Rule]", "1049"}], ",", 
       RowBox[{"1038", "\[Rule]", "1039"}], ",", 
       RowBox[{"902", "\[Rule]", "891"}], ",", 
       RowBox[{"902", "\[Rule]", "913"}], ",", 
       RowBox[{"902", "\[Rule]", "903"}], ",", 
       RowBox[{"1184", "\[Rule]", "1193"}], ",", 
       RowBox[{"1184", "\[Rule]", "1185"}], ",", 
       RowBox[{"1184", "\[Rule]", "1181"}], ",", 
       RowBox[{"1116", "\[Rule]", "1125"}], ",", 
       RowBox[{"1116", "\[Rule]", "1117"}], ",", 
       RowBox[{"1116", "\[Rule]", "1113"}], ",", 
       RowBox[{"980", "\[Rule]", "989"}], ",", 
       RowBox[{"980", "\[Rule]", "981"}], ",", 
       RowBox[{"980", "\[Rule]", "977"}], ",", 
       RowBox[{"640", "\[Rule]", "649"}], ",", 
       RowBox[{"640", "\[Rule]", "641"}], ",", 
       RowBox[{"640", "\[Rule]", "637"}], ",", 
       RowBox[{"1048", "\[Rule]", "1057"}], ",", 
       RowBox[{"1048", "\[Rule]", "1049"}], ",", 
       RowBox[{"1048", "\[Rule]", "1045"}], ",", 
       RowBox[{"912", "\[Rule]", "921"}], ",", 
       RowBox[{"912", "\[Rule]", "913"}], ",", 
       RowBox[{"912", "\[Rule]", "909"}], ",", 
       RowBox[{"10", "\[Rule]", "19"}], ",", 
       RowBox[{"10", "\[Rule]", "11"}], ",", 
       RowBox[{"10", "\[Rule]", "7"}], ",", 
       RowBox[{"418", "\[Rule]", "427"}], ",", 
       RowBox[{"418", "\[Rule]", "419"}], ",", 
       RowBox[{"418", "\[Rule]", "415"}], ",", 
       RowBox[{"18", "\[Rule]", "7"}], ",", 
       RowBox[{"18", "\[Rule]", "29"}], ",", 
       RowBox[{"18", "\[Rule]", "19"}], ",", 
       RowBox[{"426", "\[Rule]", "415"}], ",", 
       RowBox[{"426", "\[Rule]", "437"}], ",", 
       RowBox[{"426", "\[Rule]", "427"}], ",", 
       RowBox[{"28", "\[Rule]", "37"}], ",", 
       RowBox[{"28", "\[Rule]", "29"}], ",", 
       RowBox[{"28", "\[Rule]", "25"}], ",", 
       RowBox[{"436", "\[Rule]", "445"}], ",", 
       RowBox[{"436", "\[Rule]", "437"}], ",", 
       RowBox[{"436", "\[Rule]", "433"}], ",", 
       RowBox[{"826", "\[Rule]", "835"}], ",", 
       RowBox[{"826", "\[Rule]", "827"}], ",", 
       RowBox[{"826", "\[Rule]", "823"}], ",", 
       RowBox[{"834", "\[Rule]", "823"}], ",", 
       RowBox[{"834", "\[Rule]", "845"}], ",", 
       RowBox[{"834", "\[Rule]", "835"}], ",", 
       RowBox[{"844", "\[Rule]", "853"}], ",", 
       RowBox[{"844", "\[Rule]", "845"}], ",", 
       RowBox[{"844", "\[Rule]", "841"}], ",", 
       RowBox[{"376", "\[Rule]", "365"}], ",", 
       RowBox[{"376", "\[Rule]", "387"}], ",", 
       RowBox[{"376", "\[Rule]", "377"}], ",", 
       RowBox[{"308", "\[Rule]", "297"}], ",", 
       RowBox[{"308", "\[Rule]", "319"}], ",", 
       RowBox[{"308", "\[Rule]", "309"}], ",", 
       RowBox[{"172", "\[Rule]", "161"}], ",", 
       RowBox[{"172", "\[Rule]", "183"}], ",", 
       RowBox[{"172", "\[Rule]", "173"}], ",", 
       RowBox[{"784", "\[Rule]", "773"}], ",", 
       RowBox[{"784", "\[Rule]", "795"}], ",", 
       RowBox[{"784", "\[Rule]", "785"}], ",", 
       RowBox[{"716", "\[Rule]", "705"}], ",", 
       RowBox[{"716", "\[Rule]", "727"}], ",", 
       RowBox[{"716", "\[Rule]", "717"}], ",", 
       RowBox[{"580", "\[Rule]", "569"}], ",", 
       RowBox[{"580", "\[Rule]", "591"}], ",", 
       RowBox[{"580", "\[Rule]", "581"}], ",", 
       RowBox[{"240", "\[Rule]", "229"}], ",", 
       RowBox[{"240", "\[Rule]", "251"}], ",", 
       RowBox[{"240", "\[Rule]", "241"}], ",", 
       RowBox[{"104", "\[Rule]", "93"}], ",", 
       RowBox[{"104", "\[Rule]", "115"}], ",", 
       RowBox[{"104", "\[Rule]", "105"}], ",", 
       RowBox[{"648", "\[Rule]", "637"}], ",", 
       RowBox[{"648", "\[Rule]", "659"}], ",", 
       RowBox[{"648", "\[Rule]", "649"}], ",", 
       RowBox[{"512", "\[Rule]", "501"}], ",", 
       RowBox[{"512", "\[Rule]", "523"}], ",", 
       RowBox[{"512", "\[Rule]", "513"}], ",", 
       RowBox[{"1192", "\[Rule]", "1181"}], ",", 
       RowBox[{"1192", "\[Rule]", "1203"}], ",", 
       RowBox[{"1192", "\[Rule]", "1193"}], ",", 
       RowBox[{"1124", "\[Rule]", "1113"}], ",", 
       RowBox[{"1124", "\[Rule]", "1135"}], ",", 
       RowBox[{"1124", "\[Rule]", "1125"}], ",", 
       RowBox[{"988", "\[Rule]", "977"}], ",", 
       RowBox[{"988", "\[Rule]", "999"}], ",", 
       RowBox[{"988", "\[Rule]", "989"}], ",", 
       RowBox[{"1056", "\[Rule]", "1045"}], ",", 
       RowBox[{"1056", "\[Rule]", "1067"}], ",", 
       RowBox[{"1056", "\[Rule]", "1057"}], ",", 
       RowBox[{"920", "\[Rule]", "909"}], ",", 
       RowBox[{"920", "\[Rule]", "931"}], ",", 
       RowBox[{"920", "\[Rule]", "921"}], ",", 
       RowBox[{"36", "\[Rule]", "25"}], ",", 
       RowBox[{"36", "\[Rule]", "47"}], ",", 
       RowBox[{"36", "\[Rule]", "37"}], ",", 
       RowBox[{"444", "\[Rule]", "433"}], ",", 
       RowBox[{"444", "\[Rule]", "455"}], ",", 
       RowBox[{"444", "\[Rule]", "445"}], ",", 
       RowBox[{"852", "\[Rule]", "841"}], ",", 
       RowBox[{"852", "\[Rule]", "863"}], ",", 
       RowBox[{"852", "\[Rule]", "853"}], ",", 
       RowBox[{"386", "\[Rule]", "397"}], ",", 
       RowBox[{"386", "\[Rule]", "387"}], ",", 
       RowBox[{"318", "\[Rule]", "329"}], ",", 
       RowBox[{"318", "\[Rule]", "319"}], ",", 
       RowBox[{"182", "\[Rule]", "193"}], ",", 
       RowBox[{"182", "\[Rule]", "183"}], ",", 
       RowBox[{"794", "\[Rule]", "805"}], ",", 
       RowBox[{"794", "\[Rule]", "795"}], ",", 
       RowBox[{"726", "\[Rule]", "737"}], ",", 
       RowBox[{"726", "\[Rule]", "727"}], ",", 
       RowBox[{"590", "\[Rule]", "601"}], ",", 
       RowBox[{"590", "\[Rule]", "591"}], ",", 
       RowBox[{"250", "\[Rule]", "261"}], ",", 
       RowBox[{"250", "\[Rule]", "251"}], ",", 
       RowBox[{"114", "\[Rule]", "125"}], ",", 
       RowBox[{"114", "\[Rule]", "115"}], ",", 
       RowBox[{"658", "\[Rule]", "669"}], ",", 
       RowBox[{"658", "\[Rule]", "659"}], ",", 
       RowBox[{"522", "\[Rule]", "533"}], ",", 
       RowBox[{"522", "\[Rule]", "523"}], ",", 
       RowBox[{"1202", "\[Rule]", "1213"}], ",", 
       RowBox[{"1202", "\[Rule]", "1203"}], ",", 
       RowBox[{"1134", "\[Rule]", "1145"}], ",", 
       RowBox[{"1134", "\[Rule]", "1135"}], ",", 
       RowBox[{"998", "\[Rule]", "1009"}], ",", 
       RowBox[{"998", "\[Rule]", "999"}], ",", 
       RowBox[{"1066", "\[Rule]", "1077"}], ",", 
       RowBox[{"1066", "\[Rule]", "1067"}], ",", 
       RowBox[{"930", "\[Rule]", "941"}], ",", 
       RowBox[{"930", "\[Rule]", "931"}], ",", 
       RowBox[{"46", "\[Rule]", "57"}], ",", 
       RowBox[{"46", "\[Rule]", "47"}], ",", 
       RowBox[{"454", "\[Rule]", "465"}], ",", 
       RowBox[{"454", "\[Rule]", "455"}], ",", 
       RowBox[{"862", "\[Rule]", "873"}], ",", 
       RowBox[{"862", "\[Rule]", "863"}], ",", 
       RowBox[{"347", "\[Rule]", "144"}], ",", 
       RowBox[{"347", "\[Rule]", "144"}], ",", 
       RowBox[{"347", "\[Rule]", "552"}], ",", 
       RowBox[{"347", "\[Rule]", "552"}], ",", 
       RowBox[{"347", "\[Rule]", "348"}], ",", 
       RowBox[{"279", "\[Rule]", "144"}], ",", 
       RowBox[{"279", "\[Rule]", "552"}], ",", 
       RowBox[{"279", "\[Rule]", "552"}], ",", 
       RowBox[{"279", "\[Rule]", "484"}], ",", 
       RowBox[{"279", "\[Rule]", "280"}], ",", 
       RowBox[{"143", "\[Rule]", "348"}], ",", 
       RowBox[{"143", "\[Rule]", "348"}], ",", 
       RowBox[{"143", "\[Rule]", "280"}], ",", 
       RowBox[{"143", "\[Rule]", "144"}], ",", 
       RowBox[{"755", "\[Rule]", "552"}], ",", 
       RowBox[{"755", "\[Rule]", "552"}], ",", 
       RowBox[{"755", "\[Rule]", "960"}], ",", 
       RowBox[{"755", "\[Rule]", "960"}], ",", 
       RowBox[{"755", "\[Rule]", "756"}], ",", 
       RowBox[{"687", "\[Rule]", "552"}], ",", 
       RowBox[{"687", "\[Rule]", "552"}], ",", 
       RowBox[{"687", "\[Rule]", "960"}], ",", 
       RowBox[{"687", "\[Rule]", "960"}], ",", 
       RowBox[{"687", "\[Rule]", "484"}], ",", 
       RowBox[{"687", "\[Rule]", "484"}], ",", 
       RowBox[{"687", "\[Rule]", "892"}], ",", 
       RowBox[{"687", "\[Rule]", "892"}], ",", 
       RowBox[{"687", "\[Rule]", "688"}], ",", 
       RowBox[{"551", "\[Rule]", "348"}], ",", 
       RowBox[{"551", "\[Rule]", "348"}], ",", 
       RowBox[{"551", "\[Rule]", "756"}], ",", 
       RowBox[{"551", "\[Rule]", "756"}], ",", 
       RowBox[{"551", "\[Rule]", "280"}], ",", 
       RowBox[{"551", "\[Rule]", "280"}], ",", 
       RowBox[{"551", "\[Rule]", "688"}], ",", 
       RowBox[{"551", "\[Rule]", "688"}], ",", 
       RowBox[{"551", "\[Rule]", "552"}], ",", 
       RowBox[{"211", "\[Rule]", "76"}], ",", 
       RowBox[{"211", "\[Rule]", "484"}], ",", 
       RowBox[{"211", "\[Rule]", "8"}], ",", 
       RowBox[{"211", "\[Rule]", "8"}], ",", 
       RowBox[{"211", "\[Rule]", "416"}], ",", 
       RowBox[{"211", "\[Rule]", "416"}], ",", 
       RowBox[{"211", "\[Rule]", "212"}], ",", 
       RowBox[{"75", "\[Rule]", "212"}], ",", 
       RowBox[{"75", "\[Rule]", "76"}], ",", 
       RowBox[{"619", "\[Rule]", "484"}], ",", 
       RowBox[{"619", "\[Rule]", "484"}], ",", 
       RowBox[{"619", "\[Rule]", "892"}], ",", 
       RowBox[{"619", "\[Rule]", "892"}], ",", 
       RowBox[{"619", "\[Rule]", "416"}], ",", 
       RowBox[{"619", "\[Rule]", "824"}], ",", 
       RowBox[{"619", "\[Rule]", "620"}], ",", 
       RowBox[{"483", "\[Rule]", "280"}], ",", 
       RowBox[{"483", "\[Rule]", "688"}], ",", 
       RowBox[{"483", "\[Rule]", "688"}], ",", 
       RowBox[{"483", "\[Rule]", "212"}], ",", 
       RowBox[{"483", "\[Rule]", "620"}], ",", 
       RowBox[{"483", "\[Rule]", "620"}], ",", 
       RowBox[{"483", "\[Rule]", "484"}], ",", 
       RowBox[{"365", "\[Rule]", "162"}], ",", 
       RowBox[{"365", "\[Rule]", "162"}], ",", 
       RowBox[{"365", "\[Rule]", "570"}], ",", 
       RowBox[{"365", "\[Rule]", "570"}], ",", 
       RowBox[{"365", "\[Rule]", "366"}], ",", 
       RowBox[{"297", "\[Rule]", "162"}], ",", 
       RowBox[{"297", "\[Rule]", "162"}], ",", 
       RowBox[{"297", "\[Rule]", "570"}], ",", 
       RowBox[{"297", "\[Rule]", "570"}], ",", 
       RowBox[{"297", "\[Rule]", "94"}], ",", 
       RowBox[{"297", "\[Rule]", "502"}], ",", 
       RowBox[{"297", "\[Rule]", "298"}], ",", 
       RowBox[{"161", "\[Rule]", "366"}], ",", 
       RowBox[{"161", "\[Rule]", "366"}], ",", 
       RowBox[{"161", "\[Rule]", "298"}], ",", 
       RowBox[{"161", "\[Rule]", "298"}], ",", 
       RowBox[{"161", "\[Rule]", "162"}], ",", 
       RowBox[{"773", "\[Rule]", "570"}], ",", 
       RowBox[{"773", "\[Rule]", "570"}], ",", 
       RowBox[{"773", "\[Rule]", "978"}], ",", 
       RowBox[{"773", "\[Rule]", "978"}], ",", 
       RowBox[{"773", "\[Rule]", "774"}], ",", 
       RowBox[{"705", "\[Rule]", "570"}], ",", 
       RowBox[{"705", "\[Rule]", "570"}], ",", 
       RowBox[{"705", "\[Rule]", "978"}], ",", 
       RowBox[{"705", "\[Rule]", "978"}], ",", 
       RowBox[{"705", "\[Rule]", "502"}], ",", 
       RowBox[{"705", "\[Rule]", "502"}], ",", 
       RowBox[{"705", "\[Rule]", "910"}], ",", 
       RowBox[{"705", "\[Rule]", "910"}], ",", 
       RowBox[{"705", "\[Rule]", "706"}], ",", 
       RowBox[{"569", "\[Rule]", "366"}], ",", 
       RowBox[{"569", "\[Rule]", "366"}], ",", 
       RowBox[{"569", "\[Rule]", "774"}], ",", 
       RowBox[{"569", "\[Rule]", "774"}], ",", 
       RowBox[{"569", "\[Rule]", "298"}], ",", 
       RowBox[{"569", "\[Rule]", "298"}], ",", 
       RowBox[{"569", "\[Rule]", "706"}], ",", 
       RowBox[{"569", "\[Rule]", "706"}], ",", 
       RowBox[{"569", "\[Rule]", "570"}], ",", 
       RowBox[{"229", "\[Rule]", "94"}], ",", 
       RowBox[{"229", "\[Rule]", "26"}], ",", 
       RowBox[{"229", "\[Rule]", "26"}], ",", 
       RowBox[{"229", "\[Rule]", "434"}], ",", 
       RowBox[{"229", "\[Rule]", "230"}], ",", 
       RowBox[{"93", "\[Rule]", "298"}], ",", 
       RowBox[{"93", "\[Rule]", "230"}], ",", 
       RowBox[{"93", "\[Rule]", "94"}], ",", 
       RowBox[{"501", "\[Rule]", "298"}], ",", 
       RowBox[{"501", "\[Rule]", "706"}], ",", 
       RowBox[{"501", "\[Rule]", "706"}], ",", 
       RowBox[{"501", "\[Rule]", "638"}], ",", 
       RowBox[{"501", "\[Rule]", "502"}], ",", 
       RowBox[{"1163", "\[Rule]", "960"}], ",", 
       RowBox[{"1163", "\[Rule]", "960"}], ",", 
       RowBox[{"1163", "\[Rule]", "1164"}], ",", 
       RowBox[{"1095", "\[Rule]", "960"}], ",", 
       RowBox[{"1095", "\[Rule]", "960"}], ",", 
       RowBox[{"1095", "\[Rule]", "892"}], ",", 
       RowBox[{"1095", "\[Rule]", "892"}], ",", 
       RowBox[{"1095", "\[Rule]", "1096"}], ",", 
       RowBox[{"959", "\[Rule]", "756"}], ",", 
       RowBox[{"959", "\[Rule]", "756"}], ",", 
       RowBox[{"959", "\[Rule]", "1164"}], ",", 
       RowBox[{"959", "\[Rule]", "1164"}], ",", 
       RowBox[{"959", "\[Rule]", "688"}], ",", 
       RowBox[{"959", "\[Rule]", "688"}], ",", 
       RowBox[{"959", "\[Rule]", "1096"}], ",", 
       RowBox[{"959", "\[Rule]", "1096"}], ",", 
       RowBox[{"959", "\[Rule]", "960"}], ",", 
       RowBox[{"1027", "\[Rule]", "892"}], ",", 
       RowBox[{"1027", "\[Rule]", "892"}], ",", 
       RowBox[{"1027", "\[Rule]", "824"}], ",", 
       RowBox[{"1027", "\[Rule]", "824"}], ",", 
       RowBox[{"1027", "\[Rule]", "1028"}], ",", 
       RowBox[{"891", "\[Rule]", "688"}], ",", 
       RowBox[{"891", "\[Rule]", "688"}], ",", 
       RowBox[{"891", "\[Rule]", "1096"}], ",", 
       RowBox[{"891", "\[Rule]", "1096"}], ",", 
       RowBox[{"891", "\[Rule]", "620"}], ",", 
       RowBox[{"891", "\[Rule]", "620"}], ",", 
       RowBox[{"891", "\[Rule]", "1028"}], ",", 
       RowBox[{"891", "\[Rule]", "1028"}], ",", 
       RowBox[{"891", "\[Rule]", "892"}], ",", 
       RowBox[{"1181", "\[Rule]", "978"}], ",", 
       RowBox[{"1181", "\[Rule]", "978"}], ",", 
       RowBox[{"1181", "\[Rule]", "1182"}], ",", 
       RowBox[{"1113", "\[Rule]", "978"}], ",", 
       RowBox[{"1113", "\[Rule]", "978"}], ",", 
       RowBox[{"1113", "\[Rule]", "910"}], ",", 
       RowBox[{"1113", "\[Rule]", "910"}], ",", 
       RowBox[{"1113", "\[Rule]", "1114"}], ",", 
       RowBox[{"977", "\[Rule]", "774"}], ",", 
       RowBox[{"977", "\[Rule]", "774"}], ",", 
       RowBox[{"977", "\[Rule]", "1182"}], ",", 
       RowBox[{"977", "\[Rule]", "1182"}], ",", 
       RowBox[{"977", "\[Rule]", "706"}], ",", 
       RowBox[{"977", "\[Rule]", "706"}], ",", 
       RowBox[{"977", "\[Rule]", "1114"}], ",", 
       RowBox[{"977", "\[Rule]", "1114"}], ",", 
       RowBox[{"977", "\[Rule]", "978"}], ",", 
       RowBox[{"637", "\[Rule]", "502"}], ",", 
       RowBox[{"637", "\[Rule]", "910"}], ",", 
       RowBox[{"637", "\[Rule]", "910"}], ",", 
       RowBox[{"637", "\[Rule]", "842"}], ",", 
       RowBox[{"637", "\[Rule]", "638"}], ",", 
       RowBox[{"1045", "\[Rule]", "910"}], ",", 
       RowBox[{"1045", "\[Rule]", "910"}], ",", 
       RowBox[{"1045", "\[Rule]", "842"}], ",", 
       RowBox[{"1045", "\[Rule]", "842"}], ",", 
       RowBox[{"1045", "\[Rule]", "1046"}], ",", 
       RowBox[{"909", "\[Rule]", "706"}], ",", 
       RowBox[{"909", "\[Rule]", "706"}], ",", 
       RowBox[{"909", "\[Rule]", "1114"}], ",", 
       RowBox[{"909", "\[Rule]", "1114"}], ",", 
       RowBox[{"909", "\[Rule]", "638"}], ",", 
       RowBox[{"909", "\[Rule]", "638"}], ",", 
       RowBox[{"909", "\[Rule]", "1046"}], ",", 
       RowBox[{"909", "\[Rule]", "1046"}], ",", 
       RowBox[{"909", "\[Rule]", "910"}], ",", 
       RowBox[{"7", "\[Rule]", "212"}], ",", 
       RowBox[{"7", "\[Rule]", "212"}], ",", 
       RowBox[{"7", "\[Rule]", "8"}], ",", 
       RowBox[{"415", "\[Rule]", "212"}], ",", 
       RowBox[{"415", "\[Rule]", "212"}], ",", 
       RowBox[{"415", "\[Rule]", "620"}], ",", 
       RowBox[{"415", "\[Rule]", "416"}], ",", 
       RowBox[{"25", "\[Rule]", "230"}], ",", 
       RowBox[{"25", "\[Rule]", "230"}], ",", 
       RowBox[{"25", "\[Rule]", "26"}], ",", 
       RowBox[{"433", "\[Rule]", "230"}], ",", 
       RowBox[{"433", "\[Rule]", "434"}], ",", 
       RowBox[{"823", "\[Rule]", "620"}], ",", 
       RowBox[{"823", "\[Rule]", "1028"}], ",", 
       RowBox[{"823", "\[Rule]", "1028"}], ",", 
       RowBox[{"823", "\[Rule]", "824"}], ",", 
       RowBox[{"841", "\[Rule]", "638"}], ",", 
       RowBox[{"841", "\[Rule]", "1046"}], ",", 
       RowBox[{"841", "\[Rule]", "1046"}], ",", 
       RowBox[{"841", "\[Rule]", "842"}], ",", 
       RowBox[{"144", "\[Rule]", "153"}], ",", 
       RowBox[{"144", "\[Rule]", "145"}], ",", 
       RowBox[{"144", "\[Rule]", "141"}], ",", 
       RowBox[{"552", "\[Rule]", "561"}], ",", 
       RowBox[{"552", "\[Rule]", "553"}], ",", 
       RowBox[{"552", "\[Rule]", "549"}], ",", 
       RowBox[{"348", "\[Rule]", "357"}], ",", 
       RowBox[{"348", "\[Rule]", "349"}], ",", 
       RowBox[{"348", "\[Rule]", "345"}], ",", 
       RowBox[{"484", "\[Rule]", "493"}], ",", 
       RowBox[{"484", "\[Rule]", "485"}], ",", 
       RowBox[{"484", "\[Rule]", "481"}], ",", 
       RowBox[{"280", "\[Rule]", "289"}], ",", 
       RowBox[{"280", "\[Rule]", "281"}], ",", 
       RowBox[{"280", "\[Rule]", "277"}], ",", 
       RowBox[{"960", "\[Rule]", "969"}], ",", 
       RowBox[{"960", "\[Rule]", "961"}], ",", 
       RowBox[{"960", "\[Rule]", "957"}], ",", 
       RowBox[{"756", "\[Rule]", "765"}], ",", 
       RowBox[{"756", "\[Rule]", "757"}], ",", 
       RowBox[{"756", "\[Rule]", "753"}], ",", 
       RowBox[{"892", "\[Rule]", "901"}], ",", 
       RowBox[{"892", "\[Rule]", "893"}], ",", 
       RowBox[{"892", "\[Rule]", "889"}], ",", 
       RowBox[{"688", "\[Rule]", "697"}], ",", 
       RowBox[{"688", "\[Rule]", "689"}], ",", 
       RowBox[{"688", "\[Rule]", "685"}], ",", 
       RowBox[{"76", "\[Rule]", "85"}], ",", 
       RowBox[{"76", "\[Rule]", "77"}], ",", 
       RowBox[{"76", "\[Rule]", "73"}], ",", 
       RowBox[{"8", "\[Rule]", "17"}], ",", 
       RowBox[{"8", "\[Rule]", "9"}], ",", 
       RowBox[{"8", "\[Rule]", "5"}], ",", 
       RowBox[{"416", "\[Rule]", "425"}], ",", 
       RowBox[{"416", "\[Rule]", "417"}], ",", 
       RowBox[{"416", "\[Rule]", "413"}], ",", 
       RowBox[{"212", "\[Rule]", "221"}], ",", 
       RowBox[{"212", "\[Rule]", "213"}], ",", 
       RowBox[{"212", "\[Rule]", "209"}], ",", 
       RowBox[{"824", "\[Rule]", "833"}], ",", 
       RowBox[{"824", "\[Rule]", "825"}], ",", 
       RowBox[{"824", "\[Rule]", "821"}], ",", 
       RowBox[{"620", "\[Rule]", "629"}], ",", 
       RowBox[{"620", "\[Rule]", "621"}], ",", 
       RowBox[{"620", "\[Rule]", "617"}], ",", 
       RowBox[{"162", "\[Rule]", "151"}], ",", 
       RowBox[{"162", "\[Rule]", "171"}], ",", 
       RowBox[{"162", "\[Rule]", "163"}], ",", 
       RowBox[{"162", "\[Rule]", "159"}], ",", 
       RowBox[{"570", "\[Rule]", "559"}], ",", 
       RowBox[{"570", "\[Rule]", "579"}], ",", 
       RowBox[{"570", "\[Rule]", "571"}], ",", 
       RowBox[{"570", "\[Rule]", "567"}], ",", 
       RowBox[{"366", "\[Rule]", "355"}], ",", 
       RowBox[{"366", "\[Rule]", "375"}], ",", 
       RowBox[{"366", "\[Rule]", "367"}], ",", 
       RowBox[{"366", "\[Rule]", "363"}], ",", 
       RowBox[{"94", "\[Rule]", "83"}], ",", 
       RowBox[{"94", "\[Rule]", "103"}], ",", 
       RowBox[{"94", "\[Rule]", "95"}], ",", 
       RowBox[{"94", "\[Rule]", "91"}], ",", 
       RowBox[{"502", "\[Rule]", "491"}], ",", 
       RowBox[{"502", "\[Rule]", "511"}], ",", 
       RowBox[{"502", "\[Rule]", "503"}], ",", 
       RowBox[{"502", "\[Rule]", "499"}], ",", 
       RowBox[{"298", "\[Rule]", "287"}], ",", 
       RowBox[{"298", "\[Rule]", "307"}], ",", 
       RowBox[{"298", "\[Rule]", "299"}], ",", 
       RowBox[{"298", "\[Rule]", "295"}], ",", 
       RowBox[{"978", "\[Rule]", "967"}], ",", 
       RowBox[{"978", "\[Rule]", "987"}], ",", 
       RowBox[{"978", "\[Rule]", "979"}], ",", 
       RowBox[{"978", "\[Rule]", "975"}], ",", 
       RowBox[{"774", "\[Rule]", "763"}], ",", 
       RowBox[{"774", "\[Rule]", "783"}], ",", 
       RowBox[{"774", "\[Rule]", "775"}], ",", 
       RowBox[{"774", "\[Rule]", "771"}], ",", 
       RowBox[{"910", "\[Rule]", "899"}], ",", 
       RowBox[{"910", "\[Rule]", "919"}], ",", 
       RowBox[{"910", "\[Rule]", "911"}], ",", 
       RowBox[{"910", "\[Rule]", "907"}], ",", 
       RowBox[{"706", "\[Rule]", "695"}], ",", 
       RowBox[{"706", "\[Rule]", "715"}], ",", 
       RowBox[{"706", "\[Rule]", "707"}], ",", 
       RowBox[{"706", "\[Rule]", "703"}], ",", 
       RowBox[{"26", "\[Rule]", "15"}], ",", 
       RowBox[{"26", "\[Rule]", "35"}], ",", 
       RowBox[{"26", "\[Rule]", "27"}], ",", 
       RowBox[{"26", "\[Rule]", "23"}], ",", 
       RowBox[{"434", "\[Rule]", "423"}], ",", 
       RowBox[{"434", "\[Rule]", "443"}], ",", 
       RowBox[{"434", "\[Rule]", "435"}], ",", 
       RowBox[{"434", "\[Rule]", "431"}], ",", 
       RowBox[{"230", "\[Rule]", "219"}], ",", 
       RowBox[{"230", "\[Rule]", "239"}], ",", 
       RowBox[{"230", "\[Rule]", "231"}], ",", 
       RowBox[{"230", "\[Rule]", "227"}], ",", 
       RowBox[{"638", "\[Rule]", "627"}], ",", 
       RowBox[{"638", "\[Rule]", "647"}], ",", 
       RowBox[{"638", "\[Rule]", "639"}], ",", 
       RowBox[{"638", "\[Rule]", "635"}], ",", 
       RowBox[{"1164", "\[Rule]", "1173"}], ",", 
       RowBox[{"1164", "\[Rule]", "1165"}], ",", 
       RowBox[{"1164", "\[Rule]", "1161"}], ",", 
       RowBox[{"1096", "\[Rule]", "1105"}], ",", 
       RowBox[{"1096", "\[Rule]", "1097"}], ",", 
       RowBox[{"1096", "\[Rule]", "1093"}], ",", 
       RowBox[{"1028", "\[Rule]", "1037"}], ",", 
       RowBox[{"1028", "\[Rule]", "1029"}], ",", 
       RowBox[{"1028", "\[Rule]", "1025"}], ",", 
       RowBox[{"1182", "\[Rule]", "1171"}], ",", 
       RowBox[{"1182", "\[Rule]", "1191"}], ",", 
       RowBox[{"1182", "\[Rule]", "1183"}], ",", 
       RowBox[{"1182", "\[Rule]", "1179"}], ",", 
       RowBox[{"1114", "\[Rule]", "1103"}], ",", 
       RowBox[{"1114", "\[Rule]", "1123"}], ",", 
       RowBox[{"1114", "\[Rule]", "1115"}], ",", 
       RowBox[{"1114", "\[Rule]", "1111"}], ",", 
       RowBox[{"842", "\[Rule]", "831"}], ",", 
       RowBox[{"842", "\[Rule]", "851"}], ",", 
       RowBox[{"842", "\[Rule]", "843"}], ",", 
       RowBox[{"842", "\[Rule]", "839"}], ",", 
       RowBox[{"1046", "\[Rule]", "1035"}], ",", 
       RowBox[{"1046", "\[Rule]", "1055"}], ",", 
       RowBox[{"1046", "\[Rule]", "1047"}], ",", 
       RowBox[{"1046", "\[Rule]", "1043"}], ",", 
       RowBox[{"141", "\[Rule]", "346"}], ",", 
       RowBox[{"141", "\[Rule]", "346"}], ",", 
       RowBox[{"141", "\[Rule]", "278"}], ",", 
       RowBox[{"141", "\[Rule]", "278"}], ",", 
       RowBox[{"141", "\[Rule]", "142"}], ",", 
       RowBox[{"549", "\[Rule]", "346"}], ",", 
       RowBox[{"549", "\[Rule]", "346"}], ",", 
       RowBox[{"549", "\[Rule]", "754"}], ",", 
       RowBox[{"549", "\[Rule]", "754"}], ",", 
       RowBox[{"549", "\[Rule]", "278"}], ",", 
       RowBox[{"549", "\[Rule]", "278"}], ",", 
       RowBox[{"549", "\[Rule]", "686"}], ",", 
       RowBox[{"549", "\[Rule]", "686"}], ",", 
       RowBox[{"549", "\[Rule]", "550"}], ",", 
       RowBox[{"345", "\[Rule]", "142"}], ",", 
       RowBox[{"345", "\[Rule]", "142"}], ",", 
       RowBox[{"345", "\[Rule]", "550"}], ",", 
       RowBox[{"345", "\[Rule]", "550"}], ",", 
       RowBox[{"345", "\[Rule]", "346"}], ",", 
       RowBox[{"481", "\[Rule]", "278"}], ",", 
       RowBox[{"481", "\[Rule]", "686"}], ",", 
       RowBox[{"481", "\[Rule]", "686"}], ",", 
       RowBox[{"481", "\[Rule]", "210"}], ",", 
       RowBox[{"481", "\[Rule]", "618"}], ",", 
       RowBox[{"481", "\[Rule]", "618"}], ",", 
       RowBox[{"481", "\[Rule]", "482"}], ",", 
       RowBox[{"277", "\[Rule]", "142"}], ",", 
       RowBox[{"277", "\[Rule]", "142"}], ",", 
       RowBox[{"277", "\[Rule]", "550"}], ",", 
       RowBox[{"277", "\[Rule]", "550"}], ",", 
       RowBox[{"277", "\[Rule]", "74"}], ",", 
       RowBox[{"277", "\[Rule]", "482"}], ",", 
       RowBox[{"277", "\[Rule]", "278"}], ",", 
       RowBox[{"957", "\[Rule]", "754"}], ",", 
       RowBox[{"957", "\[Rule]", "754"}], ",", 
       RowBox[{"957", "\[Rule]", "1162"}], ",", 
       RowBox[{"957", "\[Rule]", "1162"}], ",", 
       RowBox[{"957", "\[Rule]", "686"}], ",", 
       RowBox[{"957", "\[Rule]", "686"}], ",", 
       RowBox[{"957", "\[Rule]", "1094"}], ",", 
       RowBox[{"957", "\[Rule]", "1094"}], ",", 
       RowBox[{"957", "\[Rule]", "958"}], ",", 
       RowBox[{"753", "\[Rule]", "550"}], ",", 
       RowBox[{"753", "\[Rule]", "550"}], ",", 
       RowBox[{"753", "\[Rule]", "958"}], ",", 
       RowBox[{"753", "\[Rule]", "958"}], ",", 
       RowBox[{"753", "\[Rule]", "754"}], ",", 
       RowBox[{"889", "\[Rule]", "686"}], ",", 
       RowBox[{"889", "\[Rule]", "686"}], ",", 
       RowBox[{"889", "\[Rule]", "1094"}], ",", 
       RowBox[{"889", "\[Rule]", "1094"}], ",", 
       RowBox[{"889", "\[Rule]", "618"}], ",", 
       RowBox[{"889", "\[Rule]", "618"}], ",", 
       RowBox[{"889", "\[Rule]", "1026"}], ",", 
       RowBox[{"889", "\[Rule]", "1026"}], ",", 
       RowBox[{"889", "\[Rule]", "890"}], ",", 
       RowBox[{"685", "\[Rule]", "550"}], ",", 
       RowBox[{"685", "\[Rule]", "550"}], ",", 
       RowBox[{"685", "\[Rule]", "958"}], ",", 
       RowBox[{"685", "\[Rule]", "958"}], ",", 
       RowBox[{"685", "\[Rule]", "482"}], ",", 
       RowBox[{"685", "\[Rule]", "482"}], ",", 
       RowBox[{"685", "\[Rule]", "890"}], ",", 
       RowBox[{"685", "\[Rule]", "890"}], ",", 
       RowBox[{"685", "\[Rule]", "686"}], ",", 
       RowBox[{"73", "\[Rule]", "278"}], ",", 
       RowBox[{"73", "\[Rule]", "210"}], ",", 
       RowBox[{"73", "\[Rule]", "74"}], ",", 
       RowBox[{"5", "\[Rule]", "210"}], ",", 
       RowBox[{"5", "\[Rule]", "210"}], ",", 
       RowBox[{"5", "\[Rule]", "6"}], ",", 
       RowBox[{"413", "\[Rule]", "210"}], ",", 
       RowBox[{"413", "\[Rule]", "210"}], ",", 
       RowBox[{"413", "\[Rule]", "618"}], ",", 
       RowBox[{"413", "\[Rule]", "414"}], ",", 
       RowBox[{"209", "\[Rule]", "74"}], ",", 
       RowBox[{"209", "\[Rule]", "482"}], ",", 
       RowBox[{"209", "\[Rule]", "6"}], ",", 
       RowBox[{"209", "\[Rule]", "6"}], ",", 
       RowBox[{"209", "\[Rule]", "414"}], ",", 
       RowBox[{"209", "\[Rule]", "414"}], ",", 
       RowBox[{"209", "\[Rule]", "210"}], ",", 
       RowBox[{"821", "\[Rule]", "618"}], ",", 
       RowBox[{"821", "\[Rule]", "1026"}], ",", 
       RowBox[{"821", "\[Rule]", "1026"}], ",", 
       RowBox[{"821", "\[Rule]", "822"}], ",", 
       RowBox[{"617", "\[Rule]", "482"}], ",", 
       RowBox[{"617", "\[Rule]", "482"}], ",", 
       RowBox[{"617", "\[Rule]", "890"}], ",", 
       RowBox[{"617", "\[Rule]", "890"}], ",", 
       RowBox[{"617", "\[Rule]", "414"}], ",", 
       RowBox[{"617", "\[Rule]", "822"}], ",", 
       RowBox[{"617", "\[Rule]", "618"}], ",", 
       RowBox[{"151", "\[Rule]", "356"}], ",", 
       RowBox[{"151", "\[Rule]", "356"}], ",", 
       RowBox[{"151", "\[Rule]", "288"}], ",", 
       RowBox[{"151", "\[Rule]", "288"}], ",", 
       RowBox[{"151", "\[Rule]", "152"}], ",", 
       RowBox[{"159", "\[Rule]", "364"}], ",", 
       RowBox[{"159", "\[Rule]", "364"}], ",", 
       RowBox[{"159", "\[Rule]", "296"}], ",", 
       RowBox[{"159", "\[Rule]", "296"}], ",", 
       RowBox[{"159", "\[Rule]", "160"}], ",", 
       RowBox[{"559", "\[Rule]", "356"}], ",", 
       RowBox[{"559", "\[Rule]", "356"}], ",", 
       RowBox[{"559", "\[Rule]", "764"}], ",", 
       RowBox[{"559", "\[Rule]", "764"}], ",", 
       RowBox[{"559", "\[Rule]", "288"}], ",", 
       RowBox[{"559", "\[Rule]", "288"}], ",", 
       RowBox[{"559", "\[Rule]", "696"}], ",", 
       RowBox[{"559", "\[Rule]", "696"}], ",", 
       RowBox[{"559", "\[Rule]", "560"}], ",", 
       RowBox[{"567", "\[Rule]", "364"}], ",", 
       RowBox[{"567", "\[Rule]", "364"}], ",", 
       RowBox[{"567", "\[Rule]", "772"}], ",", 
       RowBox[{"567", "\[Rule]", "772"}], ",", 
       RowBox[{"567", "\[Rule]", "296"}], ",", 
       RowBox[{"567", "\[Rule]", "296"}], ",", 
       RowBox[{"567", "\[Rule]", "704"}], ",", 
       RowBox[{"567", "\[Rule]", "704"}], ",", 
       RowBox[{"567", "\[Rule]", "568"}], ",", 
       RowBox[{"355", "\[Rule]", "152"}], ",", 
       RowBox[{"355", "\[Rule]", "152"}], ",", 
       RowBox[{"355", "\[Rule]", "560"}], ",", 
       RowBox[{"355", "\[Rule]", "560"}], ",", 
       RowBox[{"355", "\[Rule]", "356"}], ",", 
       RowBox[{"363", "\[Rule]", "160"}], ",", 
       RowBox[{"363", "\[Rule]", "160"}], ",", 
       RowBox[{"363", "\[Rule]", "568"}], ",", 
       RowBox[{"363", "\[Rule]", "568"}], ",", 
       RowBox[{"363", "\[Rule]", "364"}], ",", 
       RowBox[{"83", "\[Rule]", "288"}], ",", 
       RowBox[{"83", "\[Rule]", "220"}], ",", 
       RowBox[{"83", "\[Rule]", "84"}], ",", 
       RowBox[{"91", "\[Rule]", "296"}], ",", 
       RowBox[{"91", "\[Rule]", "228"}], ",", 
       RowBox[{"91", "\[Rule]", "92"}], ",", 
       RowBox[{"491", "\[Rule]", "288"}], ",", 
       RowBox[{"491", "\[Rule]", "696"}], ",", 
       RowBox[{"491", "\[Rule]", "696"}], ",", 
       RowBox[{"491", "\[Rule]", "220"}], ",", 
       RowBox[{"491", "\[Rule]", "628"}], ",", 
       RowBox[{"491", "\[Rule]", "628"}], ",", 
       RowBox[{"491", "\[Rule]", "492"}], ",", 
       RowBox[{"499", "\[Rule]", "296"}], ",", 
       RowBox[{"499", "\[Rule]", "704"}], ",", 
       RowBox[{"499", "\[Rule]", "704"}], ",", 
       RowBox[{"499", "\[Rule]", "228"}], ",", 
       RowBox[{"499", "\[Rule]", "636"}], ",", 
       RowBox[{"499", "\[Rule]", "636"}], ",", 
       RowBox[{"499", "\[Rule]", "500"}], ",", 
       RowBox[{"287", "\[Rule]", "152"}], ",", 
       RowBox[{"287", "\[Rule]", "152"}], ",", 
       RowBox[{"287", "\[Rule]", "560"}], ",", 
       RowBox[{"287", "\[Rule]", "560"}], ",", 
       RowBox[{"287", "\[Rule]", "84"}], ",", 
       RowBox[{"287", "\[Rule]", "492"}], ",", 
       RowBox[{"287", "\[Rule]", "288"}], ",", 
       RowBox[{"295", "\[Rule]", "160"}], ",", 
       RowBox[{"295", "\[Rule]", "160"}], ",", 
       RowBox[{"295", "\[Rule]", "568"}], ",", 
       RowBox[{"295", "\[Rule]", "568"}], ",", 
       RowBox[{"295", "\[Rule]", "92"}], ",", 
       RowBox[{"295", "\[Rule]", "500"}], ",", 
       RowBox[{"295", "\[Rule]", "296"}], ",", 
       RowBox[{"967", "\[Rule]", "764"}], ",", 
       RowBox[{"967", "\[Rule]", "764"}], ",", 
       RowBox[{"967", "\[Rule]", "1172"}], ",", 
       RowBox[{"967", "\[Rule]", "1172"}], ",", 
       RowBox[{"967", "\[Rule]", "696"}], ",", 
       RowBox[{"967", "\[Rule]", "696"}], ",", 
       RowBox[{"967", "\[Rule]", "1104"}], ",", 
       RowBox[{"967", "\[Rule]", "1104"}], ",", 
       RowBox[{"967", "\[Rule]", "968"}], ",", 
       RowBox[{"975", "\[Rule]", "772"}], ",", 
       RowBox[{"975", "\[Rule]", "772"}], ",", 
       RowBox[{"975", "\[Rule]", "1180"}], ",", 
       RowBox[{"975", "\[Rule]", "1180"}], ",", 
       RowBox[{"975", "\[Rule]", "704"}], ",", 
       RowBox[{"975", "\[Rule]", "704"}], ",", 
       RowBox[{"975", "\[Rule]", "1112"}], ",", 
       RowBox[{"975", "\[Rule]", "1112"}], ",", 
       RowBox[{"975", "\[Rule]", "976"}], ",", 
       RowBox[{"763", "\[Rule]", "560"}], ",", 
       RowBox[{"763", "\[Rule]", "560"}], ",", 
       RowBox[{"763", "\[Rule]", "968"}], ",", 
       RowBox[{"763", "\[Rule]", "968"}], ",", 
       RowBox[{"763", "\[Rule]", "764"}], ",", 
       RowBox[{"771", "\[Rule]", "568"}], ",", 
       RowBox[{"771", "\[Rule]", "568"}], ",", 
       RowBox[{"771", "\[Rule]", "976"}], ",", 
       RowBox[{"771", "\[Rule]", "976"}], ",", 
       RowBox[{"771", "\[Rule]", "772"}], ",", 
       RowBox[{"899", "\[Rule]", "696"}], ",", 
       RowBox[{"899", "\[Rule]", "696"}], ",", 
       RowBox[{"899", "\[Rule]", "1104"}], ",", 
       RowBox[{"899", "\[Rule]", "1104"}], ",", 
       RowBox[{"899", "\[Rule]", "628"}], ",", 
       RowBox[{"899", "\[Rule]", "628"}], ",", 
       RowBox[{"899", "\[Rule]", "1036"}], ",", 
       RowBox[{"899", "\[Rule]", "1036"}], ",", 
       RowBox[{"899", "\[Rule]", "900"}], ",", 
       RowBox[{"907", "\[Rule]", "704"}], ",", 
       RowBox[{"907", "\[Rule]", "704"}], ",", 
       RowBox[{"907", "\[Rule]", "1112"}], ",", 
       RowBox[{"907", "\[Rule]", "1112"}], ",", 
       RowBox[{"907", "\[Rule]", "636"}], ",", 
       RowBox[{"907", "\[Rule]", "636"}], ",", 
       RowBox[{"907", "\[Rule]", "1044"}], ",", 
       RowBox[{"907", "\[Rule]", "1044"}], ",", 
       RowBox[{"907", "\[Rule]", "908"}], ",", 
       RowBox[{"695", "\[Rule]", "560"}], ",", 
       RowBox[{"695", "\[Rule]", "560"}], ",", 
       RowBox[{"695", "\[Rule]", "968"}], ",", 
       RowBox[{"695", "\[Rule]", "968"}], ",", 
       RowBox[{"695", "\[Rule]", "492"}], ",", 
       RowBox[{"695", "\[Rule]", "492"}], ",", 
       RowBox[{"695", "\[Rule]", "900"}], ",", 
       RowBox[{"695", "\[Rule]", "900"}], ",", 
       RowBox[{"695", "\[Rule]", "696"}], ",", 
       RowBox[{"703", "\[Rule]", "568"}], ",", 
       RowBox[{"703", "\[Rule]", "568"}], ",", 
       RowBox[{"703", "\[Rule]", "976"}], ",", 
       RowBox[{"703", "\[Rule]", "976"}], ",", 
       RowBox[{"703", "\[Rule]", "500"}], ",", 
       RowBox[{"703", "\[Rule]", "500"}], ",", 
       RowBox[{"703", "\[Rule]", "908"}], ",", 
       RowBox[{"703", "\[Rule]", "908"}], ",", 
       RowBox[{"703", "\[Rule]", "704"}], ",", 
       RowBox[{"15", "\[Rule]", "220"}], ",", 
       RowBox[{"15", "\[Rule]", "220"}], ",", 
       RowBox[{"15", "\[Rule]", "16"}], ",", 
       RowBox[{"23", "\[Rule]", "228"}], ",", 
       RowBox[{"23", "\[Rule]", "228"}], ",", 
       RowBox[{"23", "\[Rule]", "24"}], ",", 
       RowBox[{"423", "\[Rule]", "220"}], ",", 
       RowBox[{"423", "\[Rule]", "220"}], ",", 
       RowBox[{"423", "\[Rule]", "628"}], ",", 
       RowBox[{"423", "\[Rule]", "424"}], ",", 
       RowBox[{"431", "\[Rule]", "228"}], ",", 
       RowBox[{"431", "\[Rule]", "228"}], ",", 
       RowBox[{"431", "\[Rule]", "636"}], ",", 
       RowBox[{"431", "\[Rule]", "432"}], ",", 
       RowBox[{"219", "\[Rule]", "84"}], ",", 
       RowBox[{"219", "\[Rule]", "492"}], ",", 
       RowBox[{"219", "\[Rule]", "16"}], ",", 
       RowBox[{"219", "\[Rule]", "16"}], ",", 
       RowBox[{"219", "\[Rule]", "424"}], ",", 
       RowBox[{"219", "\[Rule]", "424"}], ",", 
       RowBox[{"219", "\[Rule]", "220"}], ",", 
       RowBox[{"227", "\[Rule]", "92"}], ",", 
       RowBox[{"227", "\[Rule]", "500"}], ",", 
       RowBox[{"227", "\[Rule]", "24"}], ",", 
       RowBox[{"227", "\[Rule]", "24"}], ",", 
       RowBox[{"227", "\[Rule]", "432"}], ",", 
       RowBox[{"227", "\[Rule]", "432"}], ",", 
       RowBox[{"227", "\[Rule]", "228"}], ",", 
       RowBox[{"627", "\[Rule]", "492"}], ",", 
       RowBox[{"627", "\[Rule]", "492"}], ",", 
       RowBox[{"627", "\[Rule]", "900"}], ",", 
       RowBox[{"627", "\[Rule]", "900"}], ",", 
       RowBox[{"627", "\[Rule]", "424"}], ",", 
       RowBox[{"627", "\[Rule]", "832"}], ",", 
       RowBox[{"627", "\[Rule]", "628"}], ",", 
       RowBox[{"635", "\[Rule]", "500"}], ",", 
       RowBox[{"635", "\[Rule]", "500"}], ",", 
       RowBox[{"635", "\[Rule]", "908"}], ",", 
       RowBox[{"635", "\[Rule]", "908"}], ",", 
       RowBox[{"635", "\[Rule]", "432"}], ",", 
       RowBox[{"635", "\[Rule]", "840"}], ",", 
       RowBox[{"635", "\[Rule]", "636"}], ",", 
       RowBox[{"1161", "\[Rule]", "958"}], ",", 
       RowBox[{"1161", "\[Rule]", "958"}], ",", 
       RowBox[{"1161", "\[Rule]", "1162"}], ",", 
       RowBox[{"1093", "\[Rule]", "958"}], ",", 
       RowBox[{"1093", "\[Rule]", "958"}], ",", 
       RowBox[{"1093", "\[Rule]", "890"}], ",", 
       RowBox[{"1093", "\[Rule]", "890"}], ",", 
       RowBox[{"1093", "\[Rule]", "1094"}], ",", 
       RowBox[{"1025", "\[Rule]", "890"}], ",", 
       RowBox[{"1025", "\[Rule]", "890"}], ",", 
       RowBox[{"1025", "\[Rule]", "822"}], ",", 
       RowBox[{"1025", "\[Rule]", "822"}], ",", 
       RowBox[{"1025", "\[Rule]", "1026"}], ",", 
       RowBox[{"1171", "\[Rule]", "968"}], ",", 
       RowBox[{"1171", "\[Rule]", "968"}], ",", 
       RowBox[{"1171", "\[Rule]", "1172"}], ",", 
       RowBox[{"1179", "\[Rule]", "976"}], ",", 
       RowBox[{"1179", "\[Rule]", "976"}], ",", 
       RowBox[{"1179", "\[Rule]", "1180"}], ",", 
       RowBox[{"1103", "\[Rule]", "968"}], ",", 
       RowBox[{"1103", "\[Rule]", "968"}], ",", 
       RowBox[{"1103", "\[Rule]", "900"}], ",", 
       RowBox[{"1103", "\[Rule]", "900"}], ",", 
       RowBox[{"1103", "\[Rule]", "1104"}], ",", 
       RowBox[{"1111", "\[Rule]", "976"}], ",", 
       RowBox[{"1111", "\[Rule]", "976"}], ",", 
       RowBox[{"1111", "\[Rule]", "908"}], ",", 
       RowBox[{"1111", "\[Rule]", "908"}], ",", 
       RowBox[{"1111", "\[Rule]", "1112"}], ",", 
       RowBox[{"831", "\[Rule]", "628"}], ",", 
       RowBox[{"831", "\[Rule]", "1036"}], ",", 
       RowBox[{"831", "\[Rule]", "1036"}], ",", 
       RowBox[{"831", "\[Rule]", "832"}], ",", 
       RowBox[{"839", "\[Rule]", "636"}], ",", 
       RowBox[{"839", "\[Rule]", "1044"}], ",", 
       RowBox[{"839", "\[Rule]", "1044"}], ",", 
       RowBox[{"839", "\[Rule]", "840"}], ",", 
       RowBox[{"1035", "\[Rule]", "900"}], ",", 
       RowBox[{"1035", "\[Rule]", "900"}], ",", 
       RowBox[{"1035", "\[Rule]", "832"}], ",", 
       RowBox[{"1035", "\[Rule]", "832"}], ",", 
       RowBox[{"1035", "\[Rule]", "1036"}], ",", 
       RowBox[{"1043", "\[Rule]", "908"}], ",", 
       RowBox[{"1043", "\[Rule]", "908"}], ",", 
       RowBox[{"1043", "\[Rule]", "840"}], ",", 
       RowBox[{"1043", "\[Rule]", "840"}], ",", 
       RowBox[{"1043", "\[Rule]", "1044"}], ",", 
       RowBox[{"346", "\[Rule]", "347"}], ",", 
       RowBox[{"346", "\[Rule]", "343"}], ",", 
       RowBox[{"278", "\[Rule]", "279"}], ",", 
       RowBox[{"278", "\[Rule]", "275"}], ",", 
       RowBox[{"142", "\[Rule]", "143"}], ",", 
       RowBox[{"142", "\[Rule]", "139"}], ",", 
       RowBox[{"754", "\[Rule]", "755"}], ",", 
       RowBox[{"754", "\[Rule]", "751"}], ",", 
       RowBox[{"686", "\[Rule]", "687"}], ",", 
       RowBox[{"686", "\[Rule]", "683"}], ",", 
       RowBox[{"550", "\[Rule]", "551"}], ",", 
       RowBox[{"550", "\[Rule]", "547"}], ",", 
       RowBox[{"210", "\[Rule]", "211"}], ",", 
       RowBox[{"210", "\[Rule]", "207"}], ",", 
       RowBox[{"618", "\[Rule]", "619"}], ",", 
       RowBox[{"618", "\[Rule]", "615"}], ",", 
       RowBox[{"482", "\[Rule]", "483"}], ",", 
       RowBox[{"482", "\[Rule]", "479"}], ",", 
       RowBox[{"74", "\[Rule]", "75"}], ",", 
       RowBox[{"74", "\[Rule]", "71"}], ",", 
       RowBox[{"1162", "\[Rule]", "1163"}], ",", 
       RowBox[{"1162", "\[Rule]", "1159"}], ",", 
       RowBox[{"1094", "\[Rule]", "1095"}], ",", 
       RowBox[{"1094", "\[Rule]", "1091"}], ",", 
       RowBox[{"958", "\[Rule]", "959"}], ",", 
       RowBox[{"958", "\[Rule]", "955"}], ",", 
       RowBox[{"1026", "\[Rule]", "1027"}], ",", 
       RowBox[{"1026", "\[Rule]", "1023"}], ",", 
       RowBox[{"890", "\[Rule]", "891"}], ",", 
       RowBox[{"890", "\[Rule]", "887"}], ",", 
       RowBox[{"6", "\[Rule]", "7"}], ",", 
       RowBox[{"6", "\[Rule]", "3"}], ",", 
       RowBox[{"414", "\[Rule]", "415"}], ",", 
       RowBox[{"414", "\[Rule]", "411"}], ",", 
       RowBox[{"822", "\[Rule]", "823"}], ",", 
       RowBox[{"822", "\[Rule]", "819"}], ",", 
       RowBox[{"356", "\[Rule]", "343"}], ",", 
       RowBox[{"356", "\[Rule]", "365"}], ",", 
       RowBox[{"356", "\[Rule]", "353"}], ",", 
       RowBox[{"288", "\[Rule]", "275"}], ",", 
       RowBox[{"288", "\[Rule]", "297"}], ",", 
       RowBox[{"288", "\[Rule]", "285"}], ",", 
       RowBox[{"152", "\[Rule]", "139"}], ",", 
       RowBox[{"152", "\[Rule]", "161"}], ",", 
       RowBox[{"152", "\[Rule]", "149"}], ",", 
       RowBox[{"364", "\[Rule]", "353"}], ",", 
       RowBox[{"364", "\[Rule]", "365"}], ",", 
       RowBox[{"296", "\[Rule]", "285"}], ",", 
       RowBox[{"296", "\[Rule]", "297"}], ",", 
       RowBox[{"160", "\[Rule]", "149"}], ",", 
       RowBox[{"160", "\[Rule]", "161"}], ",", 
       RowBox[{"764", "\[Rule]", "751"}], ",", 
       RowBox[{"764", "\[Rule]", "773"}], ",", 
       RowBox[{"764", "\[Rule]", "761"}], ",", 
       RowBox[{"696", "\[Rule]", "683"}], ",", 
       RowBox[{"696", "\[Rule]", "705"}], ",", 
       RowBox[{"696", "\[Rule]", "693"}], ",", 
       RowBox[{"560", "\[Rule]", "547"}], ",", 
       RowBox[{"560", "\[Rule]", "569"}], ",", 
       RowBox[{"560", "\[Rule]", "557"}], ",", 
       RowBox[{"772", "\[Rule]", "761"}], ",", 
       RowBox[{"772", "\[Rule]", "773"}], ",", 
       RowBox[{"704", "\[Rule]", "693"}], ",", 
       RowBox[{"704", "\[Rule]", "705"}], ",", 
       RowBox[{"568", "\[Rule]", "557"}], ",", 
       RowBox[{"568", "\[Rule]", "569"}], ",", 
       RowBox[{"220", "\[Rule]", "207"}], ",", 
       RowBox[{"220", "\[Rule]", "229"}], ",", 
       RowBox[{"220", "\[Rule]", "217"}], ",", 
       RowBox[{"84", "\[Rule]", "71"}], ",", 
       RowBox[{"84", "\[Rule]", "93"}], ",", 
       RowBox[{"84", "\[Rule]", "81"}], ",", 
       RowBox[{"228", "\[Rule]", "217"}], ",", 
       RowBox[{"228", "\[Rule]", "229"}], ",", 
       RowBox[{"92", "\[Rule]", "81"}], ",", 
       RowBox[{"92", "\[Rule]", "93"}], ",", 
       RowBox[{"628", "\[Rule]", "615"}], ",", 
       RowBox[{"628", "\[Rule]", "637"}], ",", 
       RowBox[{"628", "\[Rule]", "625"}], ",", 
       RowBox[{"492", "\[Rule]", "479"}], ",", 
       RowBox[{"492", "\[Rule]", "501"}], ",", 
       RowBox[{"492", "\[Rule]", "489"}], ",", 
       RowBox[{"636", "\[Rule]", "625"}], ",", 
       RowBox[{"636", "\[Rule]", "637"}], ",", 
       RowBox[{"500", "\[Rule]", "489"}], ",", 
       RowBox[{"500", "\[Rule]", "501"}], ",", 
       RowBox[{"1172", "\[Rule]", "1159"}], ",", 
       RowBox[{"1172", "\[Rule]", "1181"}], ",", 
       RowBox[{"1172", "\[Rule]", "1169"}], ",", 
       RowBox[{"1104", "\[Rule]", "1091"}], ",", 
       RowBox[{"1104", "\[Rule]", "1113"}], ",", 
       RowBox[{"1104", "\[Rule]", "1101"}], ",", 
       RowBox[{"968", "\[Rule]", "955"}], ",", 
       RowBox[{"968", "\[Rule]", "977"}], ",", 
       RowBox[{"968", "\[Rule]", "965"}], ",", 
       RowBox[{"1180", "\[Rule]", "1169"}], ",", 
       RowBox[{"1180", "\[Rule]", "1181"}], ",", 
       RowBox[{"1112", "\[Rule]", "1101"}], ",", 
       RowBox[{"1112", "\[Rule]", "1113"}], ",", 
       RowBox[{"976", "\[Rule]", "965"}], ",", 
       RowBox[{"976", "\[Rule]", "977"}], ",", 
       RowBox[{"1036", "\[Rule]", "1023"}], ",", 
       RowBox[{"1036", "\[Rule]", "1045"}], ",", 
       RowBox[{"1036", "\[Rule]", "1033"}], ",", 
       RowBox[{"900", "\[Rule]", "887"}], ",", 
       RowBox[{"900", "\[Rule]", "909"}], ",", 
       RowBox[{"900", "\[Rule]", "897"}], ",", 
       RowBox[{"1044", "\[Rule]", "1033"}], ",", 
       RowBox[{"1044", "\[Rule]", "1045"}], ",", 
       RowBox[{"908", "\[Rule]", "897"}], ",", 
       RowBox[{"908", "\[Rule]", "909"}], ",", 
       RowBox[{"16", "\[Rule]", "3"}], ",", 
       RowBox[{"16", "\[Rule]", "25"}], ",", 
       RowBox[{"16", "\[Rule]", "13"}], ",", 
       RowBox[{"24", "\[Rule]", "13"}], ",", 
       RowBox[{"24", "\[Rule]", "25"}], ",", 
       RowBox[{"424", "\[Rule]", "411"}], ",", 
       RowBox[{"424", "\[Rule]", "433"}], ",", 
       RowBox[{"424", "\[Rule]", "421"}], ",", 
       RowBox[{"432", "\[Rule]", "421"}], ",", 
       RowBox[{"432", "\[Rule]", "433"}], ",", 
       RowBox[{"832", "\[Rule]", "819"}], ",", 
       RowBox[{"832", "\[Rule]", "841"}], ",", 
       RowBox[{"832", "\[Rule]", "829"}], ",", 
       RowBox[{"840", "\[Rule]", "829"}], ",", 
       RowBox[{"840", "\[Rule]", "841"}], ",", 
       RowBox[{"343", "\[Rule]", "140"}], ",", 
       RowBox[{"343", "\[Rule]", "140"}], ",", 
       RowBox[{"343", "\[Rule]", "548"}], ",", 
       RowBox[{"343", "\[Rule]", "548"}], ",", 
       RowBox[{"343", "\[Rule]", "344"}], ",", 
       RowBox[{"275", "\[Rule]", "140"}], ",", 
       RowBox[{"275", "\[Rule]", "140"}], ",", 
       RowBox[{"275", "\[Rule]", "548"}], ",", 
       RowBox[{"275", "\[Rule]", "548"}], ",", 
       RowBox[{"275", "\[Rule]", "72"}], ",", 
       RowBox[{"275", "\[Rule]", "480"}], ",", 
       RowBox[{"275", "\[Rule]", "276"}], ",", 
       RowBox[{"139", "\[Rule]", "344"}], ",", 
       RowBox[{"139", "\[Rule]", "344"}], ",", 
       RowBox[{"139", "\[Rule]", "276"}], ",", 
       RowBox[{"139", "\[Rule]", "276"}], ",", 
       RowBox[{"139", "\[Rule]", "140"}], ",", 
       RowBox[{"751", "\[Rule]", "548"}], ",", 
       RowBox[{"751", "\[Rule]", "548"}], ",", 
       RowBox[{"751", "\[Rule]", "956"}], ",", 
       RowBox[{"751", "\[Rule]", "956"}], ",", 
       RowBox[{"751", "\[Rule]", "752"}], ",", 
       RowBox[{"683", "\[Rule]", "548"}], ",", 
       RowBox[{"683", "\[Rule]", "548"}], ",", 
       RowBox[{"683", "\[Rule]", "956"}], ",", 
       RowBox[{"683", "\[Rule]", "956"}], ",", 
       RowBox[{"683", "\[Rule]", "480"}], ",", 
       RowBox[{"683", "\[Rule]", "480"}], ",", 
       RowBox[{"683", "\[Rule]", "888"}], ",", 
       RowBox[{"683", "\[Rule]", "888"}], ",", 
       RowBox[{"683", "\[Rule]", "684"}], ",", 
       RowBox[{"547", "\[Rule]", "344"}], ",", 
       RowBox[{"547", "\[Rule]", "344"}], ",", 
       RowBox[{"547", "\[Rule]", "752"}], ",", 
       RowBox[{"547", "\[Rule]", "752"}], ",", 
       RowBox[{"547", "\[Rule]", "276"}], ",", 
       RowBox[{"547", "\[Rule]", "276"}], ",", 
       RowBox[{"547", "\[Rule]", "684"}], ",", 
       RowBox[{"547", "\[Rule]", "684"}], ",", 
       RowBox[{"547", "\[Rule]", "548"}], ",", 
       RowBox[{"207", "\[Rule]", "480"}], ",", 
       RowBox[{"207", "\[Rule]", "4"}], ",", 
       RowBox[{"207", "\[Rule]", "412"}], ",", 
       RowBox[{"207", "\[Rule]", "412"}], ",", 
       RowBox[{"207", "\[Rule]", "208"}], ",", 
       RowBox[{"615", "\[Rule]", "480"}], ",", 
       RowBox[{"615", "\[Rule]", "480"}], ",", 
       RowBox[{"615", "\[Rule]", "888"}], ",", 
       RowBox[{"615", "\[Rule]", "888"}], ",", 
       RowBox[{"615", "\[Rule]", "412"}], ",", 
       RowBox[{"615", "\[Rule]", "820"}], ",", 
       RowBox[{"615", "\[Rule]", "616"}], ",", 
       RowBox[{"479", "\[Rule]", "276"}], ",", 
       RowBox[{"479", "\[Rule]", "684"}], ",", 
       RowBox[{"479", "\[Rule]", "684"}], ",", 
       RowBox[{"479", "\[Rule]", "208"}], ",", 
       RowBox[{"479", "\[Rule]", "616"}], ",", 
       RowBox[{"479", "\[Rule]", "616"}], ",", 
       RowBox[{"479", "\[Rule]", "480"}], ",", 
       RowBox[{"71", "\[Rule]", "276"}], ",", 
       RowBox[{"71", "\[Rule]", "72"}], ",", 
       RowBox[{"1159", "\[Rule]", "956"}], ",", 
       RowBox[{"1159", "\[Rule]", "956"}], ",", 
       RowBox[{"1159", "\[Rule]", "1160"}], ",", 
       RowBox[{"1091", "\[Rule]", "956"}], ",", 
       RowBox[{"1091", "\[Rule]", "956"}], ",", 
       RowBox[{"1091", "\[Rule]", "888"}], ",", 
       RowBox[{"1091", "\[Rule]", "888"}], ",", 
       RowBox[{"1091", "\[Rule]", "1092"}], ",", 
       RowBox[{"955", "\[Rule]", "752"}], ",", 
       RowBox[{"955", "\[Rule]", "752"}], ",", 
       RowBox[{"955", "\[Rule]", "1160"}], ",", 
       RowBox[{"955", "\[Rule]", "1160"}], ",", 
       RowBox[{"955", "\[Rule]", "684"}], ",", 
       RowBox[{"955", "\[Rule]", "684"}], ",", 
       RowBox[{"955", "\[Rule]", "1092"}], ",", 
       RowBox[{"955", "\[Rule]", "1092"}], ",", 
       RowBox[{"955", "\[Rule]", "956"}], ",", 
       RowBox[{"1023", "\[Rule]", "888"}], ",", 
       RowBox[{"1023", "\[Rule]", "888"}], ",", 
       RowBox[{"1023", "\[Rule]", "820"}], ",", 
       RowBox[{"1023", "\[Rule]", "820"}], ",", 
       RowBox[{"1023", "\[Rule]", "1024"}], ",", 
       RowBox[{"887", "\[Rule]", "684"}], ",", 
       RowBox[{"887", "\[Rule]", "684"}], ",", 
       RowBox[{"887", "\[Rule]", "1092"}], ",", 
       RowBox[{"887", "\[Rule]", "1092"}], ",", 
       RowBox[{"887", "\[Rule]", "616"}], ",", 
       RowBox[{"887", "\[Rule]", "616"}], ",", 
       RowBox[{"887", "\[Rule]", "1024"}], ",", 
       RowBox[{"887", "\[Rule]", "1024"}], ",", 
       RowBox[{"887", "\[Rule]", "888"}], ",", 
       RowBox[{"3", "\[Rule]", "208"}], ",", 
       RowBox[{"3", "\[Rule]", "4"}], ",", 
       RowBox[{"411", "\[Rule]", "208"}], ",", 
       RowBox[{"411", "\[Rule]", "208"}], ",", 
       RowBox[{"411", "\[Rule]", "616"}], ",", 
       RowBox[{"411", "\[Rule]", "412"}], ",", 
       RowBox[{"819", "\[Rule]", "616"}], ",", 
       RowBox[{"819", "\[Rule]", "1024"}], ",", 
       RowBox[{"819", "\[Rule]", "1024"}], ",", 
       RowBox[{"819", "\[Rule]", "820"}], ",", 
       RowBox[{"353", "\[Rule]", "150"}], ",", 
       RowBox[{"353", "\[Rule]", "150"}], ",", 
       RowBox[{"353", "\[Rule]", "558"}], ",", 
       RowBox[{"353", "\[Rule]", "558"}], ",", 
       RowBox[{"353", "\[Rule]", "354"}], ",", 
       RowBox[{"285", "\[Rule]", "150"}], ",", 
       RowBox[{"285", "\[Rule]", "150"}], ",", 
       RowBox[{"285", "\[Rule]", "558"}], ",", 
       RowBox[{"285", "\[Rule]", "558"}], ",", 
       RowBox[{"285", "\[Rule]", "82"}], ",", 
       RowBox[{"285", "\[Rule]", "490"}], ",", 
       RowBox[{"285", "\[Rule]", "286"}], ",", 
       RowBox[{"149", "\[Rule]", "354"}], ",", 
       RowBox[{"149", "\[Rule]", "354"}], ",", 
       RowBox[{"149", "\[Rule]", "286"}], ",", 
       RowBox[{"149", "\[Rule]", "286"}], ",", 
       RowBox[{"149", "\[Rule]", "150"}], ",", 
       RowBox[{"761", "\[Rule]", "558"}], ",", 
       RowBox[{"761", "\[Rule]", "558"}], ",", 
       RowBox[{"761", "\[Rule]", "966"}], ",", 
       RowBox[{"761", "\[Rule]", "966"}], ",", 
       RowBox[{"761", "\[Rule]", "762"}], ",", 
       RowBox[{"693", "\[Rule]", "558"}], ",", 
       RowBox[{"693", "\[Rule]", "558"}], ",", 
       RowBox[{"693", "\[Rule]", "966"}], ",", 
       RowBox[{"693", "\[Rule]", "966"}], ",", 
       RowBox[{"693", "\[Rule]", "490"}], ",", 
       RowBox[{"693", "\[Rule]", "490"}], ",", 
       RowBox[{"693", "\[Rule]", "898"}], ",", 
       RowBox[{"693", "\[Rule]", "898"}], ",", 
       RowBox[{"693", "\[Rule]", "694"}], ",", 
       RowBox[{"557", "\[Rule]", "354"}], ",", 
       RowBox[{"557", "\[Rule]", "354"}], ",", 
       RowBox[{"557", "\[Rule]", "762"}], ",", 
       RowBox[{"557", "\[Rule]", "762"}], ",", 
       RowBox[{"557", "\[Rule]", "286"}], ",", 
       RowBox[{"557", "\[Rule]", "286"}], ",", 
       RowBox[{"557", "\[Rule]", "694"}], ",", 
       RowBox[{"557", "\[Rule]", "694"}], ",", 
       RowBox[{"557", "\[Rule]", "558"}], ",", 
       RowBox[{"217", "\[Rule]", "82"}], ",", 
       RowBox[{"217", "\[Rule]", "490"}], ",", 
       RowBox[{"217", "\[Rule]", "14"}], ",", 
       RowBox[{"217", "\[Rule]", "422"}], ",", 
       RowBox[{"217", "\[Rule]", "218"}], ",", 
       RowBox[{"81", "\[Rule]", "286"}], ",", 
       RowBox[{"81", "\[Rule]", "218"}], ",", 
       RowBox[{"81", "\[Rule]", "82"}], ",", 
       RowBox[{"625", "\[Rule]", "490"}], ",", 
       RowBox[{"625", "\[Rule]", "490"}], ",", 
       RowBox[{"625", "\[Rule]", "898"}], ",", 
       RowBox[{"625", "\[Rule]", "898"}], ",", 
       RowBox[{"625", "\[Rule]", "422"}], ",", 
       RowBox[{"625", "\[Rule]", "830"}], ",", 
       RowBox[{"625", "\[Rule]", "626"}], ",", 
       RowBox[{"489", "\[Rule]", "286"}], ",", 
       RowBox[{"489", "\[Rule]", "694"}], ",", 
       RowBox[{"489", "\[Rule]", "694"}], ",", 
       RowBox[{"489", "\[Rule]", "218"}], ",", 
       RowBox[{"489", "\[Rule]", "626"}], ",", 
       RowBox[{"489", "\[Rule]", "626"}], ",", 
       RowBox[{"489", "\[Rule]", "490"}], ",", 
       RowBox[{"1169", "\[Rule]", "966"}], ",", 
       RowBox[{"1169", "\[Rule]", "966"}], ",", 
       RowBox[{"1169", "\[Rule]", "1170"}], ",", 
       RowBox[{"1101", "\[Rule]", "966"}], ",", 
       RowBox[{"1101", "\[Rule]", "966"}], ",", 
       RowBox[{"1101", "\[Rule]", "898"}], ",", 
       RowBox[{"1101", "\[Rule]", "898"}], ",", 
       RowBox[{"1101", "\[Rule]", "1102"}], ",", 
       RowBox[{"965", "\[Rule]", "762"}], ",", 
       RowBox[{"965", "\[Rule]", "762"}], ",", 
       RowBox[{"965", "\[Rule]", "1170"}], ",", 
       RowBox[{"965", "\[Rule]", "1170"}], ",", 
       RowBox[{"965", "\[Rule]", "694"}], ",", 
       RowBox[{"965", "\[Rule]", "694"}], ",", 
       RowBox[{"965", "\[Rule]", "1102"}], ",", 
       RowBox[{"965", "\[Rule]", "1102"}], ",", 
       RowBox[{"965", "\[Rule]", "966"}], ",", 
       RowBox[{"1033", "\[Rule]", "898"}], ",", 
       RowBox[{"1033", "\[Rule]", "898"}], ",", 
       RowBox[{"1033", "\[Rule]", "830"}], ",", 
       RowBox[{"1033", "\[Rule]", "830"}], ",", 
       RowBox[{"1033", "\[Rule]", "1034"}], ",", 
       RowBox[{"897", "\[Rule]", "694"}], ",", 
       RowBox[{"897", "\[Rule]", "694"}], ",", 
       RowBox[{"897", "\[Rule]", "1102"}], ",", 
       RowBox[{"897", "\[Rule]", "1102"}], ",", 
       RowBox[{"897", "\[Rule]", "626"}], ",", 
       RowBox[{"897", "\[Rule]", "626"}], ",", 
       RowBox[{"897", "\[Rule]", "1034"}], ",", 
       RowBox[{"897", "\[Rule]", "1034"}], ",", 
       RowBox[{"897", "\[Rule]", "898"}], ",", 
       RowBox[{"13", "\[Rule]", "218"}], ",", 
       RowBox[{"13", "\[Rule]", "14"}], ",", 
       RowBox[{"421", "\[Rule]", "218"}], ",", 
       RowBox[{"421", "\[Rule]", "626"}], ",", 
       RowBox[{"421", "\[Rule]", "422"}], ",", 
       RowBox[{"829", "\[Rule]", "626"}], ",", 
       RowBox[{"829", "\[Rule]", "1034"}], ",", 
       RowBox[{"829", "\[Rule]", "1034"}], ",", 
       RowBox[{"829", "\[Rule]", "830"}], ",", 
       RowBox[{"140", "\[Rule]", "151"}], ",", 
       RowBox[{"140", "\[Rule]", "141"}], ",", 
       RowBox[{"140", "\[Rule]", "137"}], ",", 
       RowBox[{"548", "\[Rule]", "559"}], ",", 
       RowBox[{"548", "\[Rule]", "549"}], ",", 
       RowBox[{"548", "\[Rule]", "545"}], ",", 
       RowBox[{"344", "\[Rule]", "355"}], ",", 
       RowBox[{"344", "\[Rule]", "345"}], ",", 
       RowBox[{"344", "\[Rule]", "341"}], ",", 
       RowBox[{"72", "\[Rule]", "83"}], ",", 
       RowBox[{"72", "\[Rule]", "73"}], ",", 
       RowBox[{"72", "\[Rule]", "69"}], ",", 
       RowBox[{"480", "\[Rule]", "491"}], ",", 
       RowBox[{"480", "\[Rule]", "481"}], ",", 
       RowBox[{"480", "\[Rule]", "477"}], ",", 
       RowBox[{"276", "\[Rule]", "287"}], ",", 
       RowBox[{"276", "\[Rule]", "277"}], ",", 
       RowBox[{"276", "\[Rule]", "273"}], ",", 
       RowBox[{"956", "\[Rule]", "967"}], ",", 
       RowBox[{"956", "\[Rule]", "957"}], ",", 
       RowBox[{"956", "\[Rule]", "953"}], ",", 
       RowBox[{"752", "\[Rule]", "763"}], ",", 
       RowBox[{"752", "\[Rule]", "753"}], ",", 
       RowBox[{"752", "\[Rule]", "749"}], ",", 
       RowBox[{"888", "\[Rule]", "899"}], ",", 
       RowBox[{"888", "\[Rule]", "889"}], ",", 
       RowBox[{"888", "\[Rule]", "885"}], ",", 
       RowBox[{"684", "\[Rule]", "695"}], ",", 
       RowBox[{"684", "\[Rule]", "685"}], ",", 
       RowBox[{"684", "\[Rule]", "681"}], ",", 
       RowBox[{"4", "\[Rule]", "15"}], ",", 
       RowBox[{"4", "\[Rule]", "5"}], ",", 
       RowBox[{"4", "\[Rule]", "1"}], ",", 
       RowBox[{"412", "\[Rule]", "423"}], ",", 
       RowBox[{"412", "\[Rule]", "413"}], ",", 
       RowBox[{"412", "\[Rule]", "409"}], ",", 
       RowBox[{"208", "\[Rule]", "219"}], ",", 
       RowBox[{"208", "\[Rule]", "209"}], ",", 
       RowBox[{"208", "\[Rule]", "205"}], ",", 
       RowBox[{"820", "\[Rule]", "831"}], ",", 
       RowBox[{"820", "\[Rule]", "821"}], ",", 
       RowBox[{"820", "\[Rule]", "817"}], ",", 
       RowBox[{"616", "\[Rule]", "627"}], ",", 
       RowBox[{"616", "\[Rule]", "617"}], ",", 
       RowBox[{"616", "\[Rule]", "613"}], ",", 
       RowBox[{"1160", "\[Rule]", "1171"}], ",", 
       RowBox[{"1160", "\[Rule]", "1161"}], ",", 
       RowBox[{"1160", "\[Rule]", "1157"}], ",", 
       RowBox[{"1092", "\[Rule]", "1103"}], ",", 
       RowBox[{"1092", "\[Rule]", "1093"}], ",", 
       RowBox[{"1092", "\[Rule]", "1089"}], ",", 
       RowBox[{"1024", "\[Rule]", "1035"}], ",", 
       RowBox[{"1024", "\[Rule]", "1025"}], ",", 
       RowBox[{"1024", "\[Rule]", "1021"}], ",", 
       RowBox[{"150", "\[Rule]", "137"}], ",", 
       RowBox[{"150", "\[Rule]", "159"}], ",", 
       RowBox[{"150", "\[Rule]", "151"}], ",", 
       RowBox[{"558", "\[Rule]", "545"}], ",", 
       RowBox[{"558", "\[Rule]", "567"}], ",", 
       RowBox[{"558", "\[Rule]", "559"}], ",", 
       RowBox[{"354", "\[Rule]", "341"}], ",", 
       RowBox[{"354", "\[Rule]", "363"}], ",", 
       RowBox[{"354", "\[Rule]", "355"}], ",", 
       RowBox[{"82", "\[Rule]", "69"}], ",", 
       RowBox[{"82", "\[Rule]", "91"}], ",", 
       RowBox[{"82", "\[Rule]", "83"}], ",", 
       RowBox[{"490", "\[Rule]", "477"}], ",", 
       RowBox[{"490", "\[Rule]", "499"}], ",", 
       RowBox[{"490", "\[Rule]", "491"}], ",", 
       RowBox[{"286", "\[Rule]", "273"}], ",", 
       RowBox[{"286", "\[Rule]", "295"}], ",", 
       RowBox[{"286", "\[Rule]", "287"}], ",", 
       RowBox[{"966", "\[Rule]", "953"}], ",", 
       RowBox[{"966", "\[Rule]", "975"}], ",", 
       RowBox[{"966", "\[Rule]", "967"}], ",", 
       RowBox[{"762", "\[Rule]", "749"}], ",", 
       RowBox[{"762", "\[Rule]", "771"}], ",", 
       RowBox[{"762", "\[Rule]", "763"}], ",", 
       RowBox[{"898", "\[Rule]", "885"}], ",", 
       RowBox[{"898", "\[Rule]", "907"}], ",", 
       RowBox[{"898", "\[Rule]", "899"}], ",", 
       RowBox[{"694", "\[Rule]", "681"}], ",", 
       RowBox[{"694", "\[Rule]", "703"}], ",", 
       RowBox[{"694", "\[Rule]", "695"}], ",", 
       RowBox[{"14", "\[Rule]", "1"}], ",", 
       RowBox[{"14", "\[Rule]", "23"}], ",", 
       RowBox[{"14", "\[Rule]", "15"}], ",", 
       RowBox[{"422", "\[Rule]", "409"}], ",", 
       RowBox[{"422", "\[Rule]", "431"}], ",", 
       RowBox[{"422", "\[Rule]", "423"}], ",", 
       RowBox[{"218", "\[Rule]", "205"}], ",", 
       RowBox[{"218", "\[Rule]", "227"}], ",", 
       RowBox[{"218", "\[Rule]", "219"}], ",", 
       RowBox[{"830", "\[Rule]", "817"}], ",", 
       RowBox[{"830", "\[Rule]", "839"}], ",", 
       RowBox[{"830", "\[Rule]", "831"}], ",", 
       RowBox[{"626", "\[Rule]", "613"}], ",", 
       RowBox[{"626", "\[Rule]", "635"}], ",", 
       RowBox[{"626", "\[Rule]", "627"}], ",", 
       RowBox[{"1170", "\[Rule]", "1157"}], ",", 
       RowBox[{"1170", "\[Rule]", "1179"}], ",", 
       RowBox[{"1170", "\[Rule]", "1171"}], ",", 
       RowBox[{"1102", "\[Rule]", "1089"}], ",", 
       RowBox[{"1102", "\[Rule]", "1111"}], ",", 
       RowBox[{"1102", "\[Rule]", "1103"}], ",", 
       RowBox[{"1034", "\[Rule]", "1021"}], ",", 
       RowBox[{"1034", "\[Rule]", "1043"}], ",", 
       RowBox[{"1034", "\[Rule]", "1035"}], ",", 
       RowBox[{"137", "\[Rule]", "342"}], ",", 
       RowBox[{"137", "\[Rule]", "342"}], ",", 
       RowBox[{"137", "\[Rule]", "274"}], ",", 
       RowBox[{"137", "\[Rule]", "274"}], ",", 
       RowBox[{"137", "\[Rule]", "138"}], ",", 
       RowBox[{"545", "\[Rule]", "342"}], ",", 
       RowBox[{"545", "\[Rule]", "342"}], ",", 
       RowBox[{"545", "\[Rule]", "750"}], ",", 
       RowBox[{"545", "\[Rule]", "750"}], ",", 
       RowBox[{"545", "\[Rule]", "274"}], ",", 
       RowBox[{"545", "\[Rule]", "274"}], ",", 
       RowBox[{"545", "\[Rule]", "682"}], ",", 
       RowBox[{"545", "\[Rule]", "682"}], ",", 
       RowBox[{"545", "\[Rule]", "546"}], ",", 
       RowBox[{"341", "\[Rule]", "138"}], ",", 
       RowBox[{"341", "\[Rule]", "138"}], ",", 
       RowBox[{"341", "\[Rule]", "546"}], ",", 
       RowBox[{"341", "\[Rule]", "546"}], ",", 
       RowBox[{"341", "\[Rule]", "342"}], ",", 
       RowBox[{"69", "\[Rule]", "274"}], ",", 
       RowBox[{"69", "\[Rule]", "206"}], ",", 
       RowBox[{"69", "\[Rule]", "70"}], ",", 
       RowBox[{"477", "\[Rule]", "274"}], ",", 
       RowBox[{"477", "\[Rule]", "682"}], ",", 
       RowBox[{"477", "\[Rule]", "682"}], ",", 
       RowBox[{"477", "\[Rule]", "206"}], ",", 
       RowBox[{"477", "\[Rule]", "614"}], ",", 
       RowBox[{"477", "\[Rule]", "614"}], ",", 
       RowBox[{"477", "\[Rule]", "478"}], ",", 
       RowBox[{"273", "\[Rule]", "138"}], ",", 
       RowBox[{"273", "\[Rule]", "138"}], ",", 
       RowBox[{"273", "\[Rule]", "546"}], ",", 
       RowBox[{"273", "\[Rule]", "546"}], ",", 
       RowBox[{"273", "\[Rule]", "70"}], ",", 
       RowBox[{"273", "\[Rule]", "478"}], ",", 
       RowBox[{"273", "\[Rule]", "274"}], ",", 
       RowBox[{"953", "\[Rule]", "750"}], ",", 
       RowBox[{"953", "\[Rule]", "750"}], ",", 
       RowBox[{"953", "\[Rule]", "1158"}], ",", 
       RowBox[{"953", "\[Rule]", "1158"}], ",", 
       RowBox[{"953", "\[Rule]", "682"}], ",", 
       RowBox[{"953", "\[Rule]", "682"}], ",", 
       RowBox[{"953", "\[Rule]", "1090"}], ",", 
       RowBox[{"953", "\[Rule]", "1090"}], ",", 
       RowBox[{"953", "\[Rule]", "954"}], ",", 
       RowBox[{"749", "\[Rule]", "546"}], ",", 
       RowBox[{"749", "\[Rule]", "546"}], ",", 
       RowBox[{"749", "\[Rule]", "954"}], ",", 
       RowBox[{"749", "\[Rule]", "954"}], ",", 
       RowBox[{"749", "\[Rule]", "750"}], ",", 
       RowBox[{"885", "\[Rule]", "682"}], ",", 
       RowBox[{"885", "\[Rule]", "682"}], ",", 
       RowBox[{"885", "\[Rule]", "1090"}], ",", 
       RowBox[{"885", "\[Rule]", "1090"}], ",", 
       RowBox[{"885", "\[Rule]", "614"}], ",", 
       RowBox[{"885", "\[Rule]", "614"}], ",", 
       RowBox[{"885", "\[Rule]", "1022"}], ",", 
       RowBox[{"885", "\[Rule]", "1022"}], ",", 
       RowBox[{"885", "\[Rule]", "886"}], ",", 
       RowBox[{"681", "\[Rule]", "546"}], ",", 
       RowBox[{"681", "\[Rule]", "546"}], ",", 
       RowBox[{"681", "\[Rule]", "954"}], ",", 
       RowBox[{"681", "\[Rule]", "954"}], ",", 
       RowBox[{"681", "\[Rule]", "478"}], ",", 
       RowBox[{"681", "\[Rule]", "478"}], ",", 
       RowBox[{"681", "\[Rule]", "886"}], ",", 
       RowBox[{"681", "\[Rule]", "886"}], ",", 
       RowBox[{"681", "\[Rule]", "682"}], ",", 
       RowBox[{"1", "\[Rule]", "206"}], ",", 
       RowBox[{"1", "\[Rule]", "206"}], ",", 
       RowBox[{"1", "\[Rule]", "2"}], ",", 
       RowBox[{"409", "\[Rule]", "206"}], ",", 
       RowBox[{"409", "\[Rule]", "206"}], ",", 
       RowBox[{"409", "\[Rule]", "614"}], ",", 
       RowBox[{"409", "\[Rule]", "410"}], ",", 
       RowBox[{"205", "\[Rule]", "70"}], ",", 
       RowBox[{"205", "\[Rule]", "478"}], ",", 
       RowBox[{"205", "\[Rule]", "2"}], ",", 
       RowBox[{"205", "\[Rule]", "2"}], ",", 
       RowBox[{"205", "\[Rule]", "410"}], ",", 
       RowBox[{"205", "\[Rule]", "410"}], ",", 
       RowBox[{"205", "\[Rule]", "206"}], ",", 
       RowBox[{"817", "\[Rule]", "614"}], ",", 
       RowBox[{"817", "\[Rule]", "1022"}], ",", 
       RowBox[{"817", "\[Rule]", "1022"}], ",", 
       RowBox[{"817", "\[Rule]", "818"}], ",", 
       RowBox[{"613", "\[Rule]", "478"}], ",", 
       RowBox[{"613", "\[Rule]", "478"}], ",", 
       RowBox[{"613", "\[Rule]", "886"}], ",", 
       RowBox[{"613", "\[Rule]", "886"}], ",", 
       RowBox[{"613", "\[Rule]", "410"}], ",", 
       RowBox[{"613", "\[Rule]", "818"}], ",", 
       RowBox[{"613", "\[Rule]", "614"}], ",", 
       RowBox[{"1157", "\[Rule]", "954"}], ",", 
       RowBox[{"1157", "\[Rule]", "954"}], ",", 
       RowBox[{"1157", "\[Rule]", "1158"}], ",", 
       RowBox[{"1089", "\[Rule]", "954"}], ",", 
       RowBox[{"1089", "\[Rule]", "954"}], ",", 
       RowBox[{"1089", "\[Rule]", "886"}], ",", 
       RowBox[{"1089", "\[Rule]", "886"}], ",", 
       RowBox[{"1089", "\[Rule]", "1090"}], ",", 
       RowBox[{"1021", "\[Rule]", "886"}], ",", 
       RowBox[{"1021", "\[Rule]", "886"}], ",", 
       RowBox[{"1021", "\[Rule]", "818"}], ",", 
       RowBox[{"1021", "\[Rule]", "818"}], ",", 
       RowBox[{"1021", "\[Rule]", "1022"}], ",", 
       RowBox[{"342", "\[Rule]", "353"}], ",", 
       RowBox[{"342", "\[Rule]", "343"}], ",", 
       RowBox[{"274", "\[Rule]", "285"}], ",", 
       RowBox[{"274", "\[Rule]", "275"}], ",", 
       RowBox[{"138", "\[Rule]", "149"}], ",", 
       RowBox[{"138", "\[Rule]", "139"}], ",", 
       RowBox[{"750", "\[Rule]", "761"}], ",", 
       RowBox[{"750", "\[Rule]", "751"}], ",", 
       RowBox[{"682", "\[Rule]", "693"}], ",", 
       RowBox[{"682", "\[Rule]", "683"}], ",", 
       RowBox[{"546", "\[Rule]", "557"}], ",", 
       RowBox[{"546", "\[Rule]", "547"}], ",", 
       RowBox[{"206", "\[Rule]", "217"}], ",", 
       RowBox[{"206", "\[Rule]", "207"}], ",", 
       RowBox[{"70", "\[Rule]", "81"}], ",", 
       RowBox[{"70", "\[Rule]", "71"}], ",", 
       RowBox[{"614", "\[Rule]", "625"}], ",", 
       RowBox[{"614", "\[Rule]", "615"}], ",", 
       RowBox[{"478", "\[Rule]", "489"}], ",", 
       RowBox[{"478", "\[Rule]", "479"}], ",", 
       RowBox[{"1158", "\[Rule]", "1169"}], ",", 
       RowBox[{"1158", "\[Rule]", "1159"}], ",", 
       RowBox[{"1090", "\[Rule]", "1101"}], ",", 
       RowBox[{"1090", "\[Rule]", "1091"}], ",", 
       RowBox[{"954", "\[Rule]", "965"}], ",", 
       RowBox[{"954", "\[Rule]", "955"}], ",", 
       RowBox[{"1022", "\[Rule]", "1033"}], ",", 
       RowBox[{"1022", "\[Rule]", "1023"}], ",", 
       RowBox[{"886", "\[Rule]", "897"}], ",", 
       RowBox[{"886", "\[Rule]", "887"}], ",", 
       RowBox[{"2", "\[Rule]", "13"}], ",", 
       RowBox[{"2", "\[Rule]", "3"}], ",", 
       RowBox[{"410", "\[Rule]", "421"}], ",", 
       RowBox[{"410", "\[Rule]", "411"}], ",", 
       RowBox[{"818", "\[Rule]", "829"}], ",", 
       RowBox[{"818", "\[Rule]", "819"}]}], "}"}], ",", 
     RowBox[{"EdgeWeight", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "c", ",", "d", ",", "i", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "i", ",", "c", ",", "d", ",", "i", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "c", ",", "g", ",", "i", ",", "c", ",", "g", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", 
        "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "e", ",", "f", ",", "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "e", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", 
        "c", ",", "d", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "b", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "i", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "c", ",", "g", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", 
        "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "i", ",", "b", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "i", ",", "b", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "b", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "i", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "b", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "d", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "f", ",", "i", ",", 
        "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "g", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "e", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "i", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "e", ",", "f", ",", "g", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "d", ",", 
        "e", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "g", ",", "i", ",", "b", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "a", ",", "c", ",", "e", ",", "g", ",", "i", ",", "c", ",", "d", ",", 
        "i", ",", "c", ",", "d", ",", "i", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", "f", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", 
        "e", ",", "f", ",", "i", ",", "e", ",", "f", ",", "i", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "i", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "f", ",", 
        "i", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "e", ",", "f", ",", "g", ",", "i", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "e", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "i", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "e", ",", 
        "f", ",", "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "e", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "d", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "i", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "i", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "c", ",", "d", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", "g", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "b", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "e", ",", "f", ",", "i", ",", "e", ",", 
        "f", ",", "i", ",", "e", ",", "f", ",", "i", ",", "e", ",", "f", ",", 
        "i", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "e", ",", "f", ",", "i", ",", "e", ",", "f", ",", "i", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "h", ",", "i", ",", "c", ",", "d", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "e", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "b", ",", "e", ",", "f", ",", "g", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "c", ",", "d", ",", 
        "i", ",", "b", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "i", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "c", ",", "d", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "g", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "c", ",", "g", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "e", ",", "f", ",", "i", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "i", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "b", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "i", ",", "a", ",", "c", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "i", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "c", ",", "d", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u"}], "}"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"init7", "=", 
   RowBox[{"{", "67", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bad7", "=", 
   RowBox[{"{", 
    RowBox[{
    "2", ",", "74", ",", "146", ",", "220", ",", "290", ",", "362", ",", 
     "432", ",", "504", ",", "576", ",", "648", ",", "720", ",", "792", ",", 
     "862", ",", "934", ",", "1006", ",", "1080", ",", "1152", ",", "1224", 
     ",", "1", ",", "73", ",", "145", ",", "219", ",", "289", ",", "361", ",",
      "431", ",", "503", ",", "575", ",", "647", ",", "719", ",", "791", ",", 
     "861", ",", "933", ",", "1005", ",", "1079", ",", "1151", ",", "1223"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lag7", "=", "15"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"graphical7", "=", "0"}], ";"}]}], "Input",
 CellChangeTimes->{{3.679290280863879*^9, 3.679290334241673*^9}, {
   3.679290504696708*^9, 3.67929051929695*^9}, {3.679290627540678*^9, 
   3.679290646162645*^9}, {3.679290676691043*^9, 3.679290749174502*^9}, {
   3.67929089973089*^9, 3.679290911059611*^9}, {3.679290948233796*^9, 
   3.679290990883844*^9}, {3.679291164264686*^9, 3.679291210405404*^9}, {
   3.679296297585969*^9, 3.679296312880332*^9}, {3.679297255110785*^9, 
   3.67929728224135*^9}, {3.679298728331581*^9, 3.679298875905641*^9}, 
   3.679298940274908*^9, {3.679299134034567*^9, 3.679299184389367*^9}, {
   3.679303531395106*^9, 3.679303544554354*^9}, {3.679303608922887*^9, 
   3.679303639506028*^9}, {3.679303980910127*^9, 3.679303986325524*^9}, {
   3.679335615401274*^9, 3.679335623430876*^9}, {3.679335744327502*^9, 
   3.679335766784133*^9}, 3.679335823213298*^9, {3.679335983824042*^9, 
   3.679335984261932*^9}, 3.679345060627506*^9, {3.679345101558879*^9, 
   3.679345112772768*^9}, 3.679345479078967*^9, 3.679349498904059*^9, 
   3.679349536594214*^9, {3.679349600050577*^9, 3.67934962905582*^9}, 
   3.679349661608243*^9, {3.679351400809895*^9, 3.679351401467813*^9}, {
   3.679351450028281*^9, 3.679351451046861*^9}, {3.679351510988296*^9, 
   3.679351511620798*^9}, {3.679351634514476*^9, 3.679351635015629*^9}, 
   3.683091811391354*^9, {3.683092894743585*^9, 3.683092894834948*^9}, {
   3.68603364313111*^9, 3.686033643305373*^9}, {3.686033963132012*^9, 
   3.686033963385147*^9}, {3.686038456625434*^9, 3.686038457152603*^9}, 
   3.686039476145979*^9, {3.686039765194613*^9, 3.686039765777108*^9}, {
   3.6860400079460697`*^9, 3.686040011873623*^9}, {3.6860456182789392`*^9, 
   3.6860456186205263`*^9}, {3.686046033270814*^9, 3.68604603343496*^9}, 
   3.686068229925735*^9, 3.686068578190002*^9, {3.6930354502060337`*^9, 
   3.693035455589672*^9}, {3.693035680711351*^9, 3.693035683406238*^9}, {
   3.693035735036788*^9, 3.693035830541695*^9}, {3.69303629913402*^9, 
   3.693036299316936*^9}, 3.6930368977904654`*^9, {3.693036958021305*^9, 
   3.693036958205016*^9}, {3.693096257624858*^9, 3.6930962579203043`*^9}, 
   3.693096438641191*^9, {3.693099997930475*^9, 3.6931000619528418`*^9}, {
   3.693100093414904*^9, 3.69310009410213*^9}, {3.693100136989324*^9, 
   3.6931001692070017`*^9}, {3.693383532273486*^9, 3.693383535249345*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"main", "[", 
  RowBox[{"g7", ",", "init7", ",", "bad7", ",", "lag7", ",", "graphical7"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.679223865677226*^9, 3.679223877308047*^9}, {
  3.679223948966332*^9, 3.679223952257859*^9}, {3.679224829422299*^9, 
  3.679224842926139*^9}, {3.679225385070814*^9, 3.679225388900379*^9}, {
  3.679226561934965*^9, 3.679226582765519*^9}, {3.67922688451364*^9, 
  3.679226886812034*^9}, {3.679290582191699*^9, 3.679290588477742*^9}, {
  3.679291707467694*^9, 3.679291709084998*^9}, {3.679296205829566*^9, 
  3.679296205956924*^9}, {3.67929627826369*^9, 3.679296282866345*^9}, {
  3.679296323611739*^9, 3.679296324755156*^9}, {3.679299162275336*^9, 
  3.679299190372951*^9}, {3.686033072949698*^9, 3.686033074275885*^9}, {
  3.6930354614304457`*^9, 3.693035463013753*^9}, {3.6930356921493187`*^9, 
  3.6930356940860233`*^9}, {3.693035833924752*^9, 3.693035847231703*^9}, {
  3.693100016998357*^9, 3.69310004784734*^9}}],

Cell[CellGroupData[{

Cell[BoxData["\<\"Under delay = 0 :\"\>"], "Print",
 CellChangeTimes->{3.694056040101156*^9, 3.694147913285348*^9, 
  3.714821126518798*^9}],

Cell[BoxData["\<\"(*hidden for the sake of space*)\"\>"], "Print",
 CellChangeTimes->{3.694056040101156*^9, 3.694147913285348*^9, 
  3.714821126519608*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Under delay = \"\>", "\[InvisibleSpace]", "1", 
   "\[InvisibleSpace]", "\<\" :\"\>"}],
  SequenceForm["Under delay = ", 1, " :"],
  Editable->False]], "Print",
 CellChangeTimes->{3.694056040101156*^9, 3.694147913285348*^9, 
  3.714821126520398*^9}],

Cell[BoxData["\<\"(*hidden for the sake of space*)\"\>"], "Print",
 CellChangeTimes->{3.694056040101156*^9, 3.694147913285348*^9, 
  3.7148211273573027`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Under delay = \"\>", "\[InvisibleSpace]", "2", 
   "\[InvisibleSpace]", "\<\" :\"\>"}],
  SequenceForm["Under delay = ", 2, " :"],
  Editable->False]], "Print",
 CellChangeTimes->{3.694056040101156*^9, 3.694147913285348*^9, 
  3.714821127358549*^9}],

Cell[BoxData["\<\"(*hidden for the sake of space*)\"\>"], "Print",
 CellChangeTimes->{3.694056040101156*^9, 3.694147913285348*^9, 
  3.714821129565278*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Under delay = \"\>", "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\" :\"\>"}],
  SequenceForm["Under delay = ", 3, " :"],
  Editable->False]], "Print",
 CellChangeTimes->{3.694056040101156*^9, 3.694147913285348*^9, 
  3.7148211296215*^9}],

Cell[BoxData["\<\"(*hidden for the sake of space*)\"\>"], "Print",
 CellChangeTimes->{3.694056040101156*^9, 3.694147913285348*^9, 
  3.714821134752824*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Not possible for sure-winning anymore under delay=\"\>", 
   "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\" with uncontrollable states \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "578", ",", "586", ",", "1008", ",", "994", ",", "722", ",", "1018", ",", 
     "1004", ",", "936", ",", "732", ",", "946", ",", "158", ",", "372", ",", 
     "168", ",", "780", ",", "802", ",", "380", ",", "176", ",", "788", ",", 
     "584", ",", "1200", ",", "1188", ",", "1210", ",", "1142", ",", "1196", 
     ",", "1128", ",", "992", ",", "1060", ",", "924", ",", "856", ",", 
     "1220", ",", "1206", ",", "1138", ",", "1070", ",", "866", ",", "876", 
     ",", "148", ",", "352", ",", "374", ",", "156", ",", "564", ",", "360", 
     ",", "292", ",", "382", ",", "166", ",", "574", ",", "370", ",", "302", 
     ",", "782", ",", "804", ",", "790", ",", "506", ",", "710", ",", "514", 
     ",", "922", ",", "718", ",", "854", ",", "650", ",", "932", ",", "660", 
     ",", "1212", ",", "1198", ",", "1222", ",", "1154", ",", "1208", ",", 
     "1140", ",", "1072", ",", "1058", ",", "1150", ",", "1082", ",", "864", 
     ",", "1068", ",", "874", ",", "1078", ",", "350", ",", "358", ",", "154",
      ",", "368", ",", "164", ",", "640", ",", "1048", ",", "28", ",", "436", 
     ",", "844", ",", "1056", ",", "36", ",", "444", ",", "852", ",", "1066", 
     ",", "144", ",", "280", ",", "76", ",", "502", ",", "26", ",", "434", 
     ",", "230", ",", "638", ",", "842", ",", "6", ",", "16", ",", "24", ",", 
     "424", ",", "72", ",", "4", ",", "208", ",", "14", ",", "422", ",", 
     "218", ",", "304", ",", "170", ",", "316", ",", "178", ",", "326", ",", 
     "102", ",", "110", ",", "510", ",", "518", ",", "306", ",", "314", ",", 
     "312", ",", "188", ",", "336", ",", "596", ",", "734", ",", "744", ",", 
     "120", ",", "528", ",", "324", ",", "236", ",", "244", ",", "100", ",", 
     "108", ",", "98", ",", "712", ",", "982", ",", "778", ",", "986", ",", 
     "918", ",", "714", ",", "644", ",", "1120", ",", "1052", ",", "916", ",",
      "914", ",", "32", ",", "40", ",", "30", ",", "652", ",", "450", ",", 
     "460", ",", "926", ",", "724", ",", "656", ",", "858", ",", "666", ",", 
     "868", ",", "676", ",", "654", ",", "664", ",", "448", ",", "440", ",", 
     "438", ",", "34", ",", "42", ",", "442", ",", "238", ",", "246", ",", 
     "52", ",", "256", ",", "248", ",", "112", ",", "258", ",", "122", ",", 
     "268", ",", "132", ",", "508", ",", "532", ",", "542", ",", "520", ",", 
     "530", ",", "124", ",", "134", ",", "516", ",", "540", ",", "44", ",", 
     "54", ",", "64", ",", "452", ",", "462", ",", "56", ",", "464", ",", 
     "260", ",", "66", ",", "474", ",", "270", ",", "272", ",", "68", ",", 
     "472", ",", "234", ",", "67"}], "}"}], 
   "\[InvisibleSpace]", "\<\".\\n\"\>"}],
  SequenceForm[
  "Not possible for sure-winning anymore under delay=", 3, 
   " with uncontrollable states ", CompressedData["
1:eJwV0l9klXEYwPFfp5kkM5lMZuo4F5mZSSYzkzWZdJEk00WOYzKZlZnJzDGZ
XSSZTHLMro45ksyRmTkXk1lJJklyJOkiyaSLJJP0eS6+vs+/93nf9/e+xws3
L43vSym9wEAmpfP4uT+lL3gr3uNdVPBRXuVls5MuqvAheRYz8lV5i3jI3GpD
SmVsYApPMIrP+jle4mFsidcwgS4U1MawaFfeziksiU/ZOSrOoYgVtX61CXEX
mmIvjmBPvq2XQUm+w1f4LpdjN9fc6ym2cQfrmEQ3siiiF3nznXyDe/ia3ddR
cv9bXOZZ+1r12sTP1C6YPSbPyWvyy/IO+YK8Nfr8m49ylb9yMc7eXKO4OeZQ
0Rtil6Y3aMKKWp27+TH3cZXPxXPxOP6JG+07yb04jZr6xXgW9U/4httxLx5U
3xX/wgjGUMBLvfee6SDqeIhXanPIx/tiUe1BvK/5E2jHPf3ndr7Gst47+QKu
iks8wmW+j0fYNLeONWRd34EN8Y84p/j2SPI/cebIiKfj3+M5/sst9rTjAA5j
Rn0+zk7chk5xD85gy/xOnEucKzdgQFyP/wjNGJR/4O98Fv8Bfv1fDw==
   "], ".\n"],
  Editable->False]], "Print",
 CellChangeTimes->{3.694056040101156*^9, 3.694147913285348*^9, 
  3.714821134814818*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Computation time under increasing delays : \\n\"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "2.064000000000007`", ",", "2.9040000000000106`", ",", 
     "5.116000000000014`", ",", "10.304000000000002`"}], "}"}]}],
  SequenceForm[
  "Computation time under increasing delays : \n", {2.064000000000007, 
   2.9040000000000106`, 5.116000000000014, 10.304000000000002`}],
  Editable->False]], "Print",
 CellChangeTimes->{3.694056040101156*^9, 3.694147913285348*^9, 
  3.7148211348163033`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Escp. 7 x 7", "Subsection",
 CellChangeTimes->{{3.725591996157341*^9, 3.725591999972456*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"g8", "=", 
   RowBox[{"Graph", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"93", "\[Rule]", "470"}], ",", 
       RowBox[{"93", "\[Rule]", "470"}], ",", 
       RowBox[{"93", "\[Rule]", "94"}], ",", 
       RowBox[{"470", "\[Rule]", "455"}], ",", 
       RowBox[{"470", "\[Rule]", "467"}], ",", 
       RowBox[{"94", "\[Rule]", "79"}], ",", 
       RowBox[{"94", "\[Rule]", "91"}], ",", 
       RowBox[{"455", "\[Rule]", "174"}], ",", 
       RowBox[{"455", "\[Rule]", "832"}], ",", 
       RowBox[{"455", "\[Rule]", "80"}], ",", 
       RowBox[{"455", "\[Rule]", "80"}], ",", 
       RowBox[{"455", "\[Rule]", "738"}], ",", 
       RowBox[{"455", "\[Rule]", "738"}], ",", 
       RowBox[{"455", "\[Rule]", "456"}], ",", 
       RowBox[{"467", "\[Rule]", "186"}], ",", 
       RowBox[{"467", "\[Rule]", "844"}], ",", 
       RowBox[{"467", "\[Rule]", "92"}], ",", 
       RowBox[{"467", "\[Rule]", "92"}], ",", 
       RowBox[{"467", "\[Rule]", "750"}], ",", 
       RowBox[{"467", "\[Rule]", "750"}], ",", 
       RowBox[{"467", "\[Rule]", "468"}], ",", 
       RowBox[{"79", "\[Rule]", "456"}], ",", 
       RowBox[{"79", "\[Rule]", "456"}], ",", 
       RowBox[{"79", "\[Rule]", "80"}], ",", 
       RowBox[{"91", "\[Rule]", "468"}], ",", 
       RowBox[{"91", "\[Rule]", "468"}], ",", 
       RowBox[{"91", "\[Rule]", "92"}], ",", 
       RowBox[{"174", "\[Rule]", "159"}], ",", 
       RowBox[{"174", "\[Rule]", "187"}], ",", 
       RowBox[{"174", "\[Rule]", "171"}], ",", 
       RowBox[{"832", "\[Rule]", "817"}], ",", 
       RowBox[{"832", "\[Rule]", "845"}], ",", 
       RowBox[{"832", "\[Rule]", "829"}], ",", 
       RowBox[{"80", "\[Rule]", "65"}], ",", 
       RowBox[{"80", "\[Rule]", "93"}], ",", 
       RowBox[{"80", "\[Rule]", "77"}], ",", 
       RowBox[{"738", "\[Rule]", "723"}], ",", 
       RowBox[{"738", "\[Rule]", "751"}], ",", 
       RowBox[{"738", "\[Rule]", "735"}], ",", 
       RowBox[{"456", "\[Rule]", "441"}], ",", 
       RowBox[{"456", "\[Rule]", "469"}], ",", 
       RowBox[{"456", "\[Rule]", "453"}], ",", 
       RowBox[{"186", "\[Rule]", "171"}], ",", 
       RowBox[{"186", "\[Rule]", "187"}], ",", 
       RowBox[{"186", "\[Rule]", "183"}], ",", 
       RowBox[{"844", "\[Rule]", "829"}], ",", 
       RowBox[{"844", "\[Rule]", "845"}], ",", 
       RowBox[{"844", "\[Rule]", "841"}], ",", 
       RowBox[{"92", "\[Rule]", "77"}], ",", 
       RowBox[{"92", "\[Rule]", "93"}], ",", 
       RowBox[{"92", "\[Rule]", "89"}], ",", 
       RowBox[{"750", "\[Rule]", "735"}], ",", 
       RowBox[{"750", "\[Rule]", "751"}], ",", 
       RowBox[{"750", "\[Rule]", "747"}], ",", 
       RowBox[{"468", "\[Rule]", "453"}], ",", 
       RowBox[{"468", "\[Rule]", "469"}], ",", 
       RowBox[{"468", "\[Rule]", "465"}], ",", 
       RowBox[{"159", "\[Rule]", "536"}], ",", 
       RowBox[{"159", "\[Rule]", "442"}], ",", 
       RowBox[{"159", "\[Rule]", "160"}], ",", 
       RowBox[{"187", "\[Rule]", "564"}], ",", 
       RowBox[{"187", "\[Rule]", "470"}], ",", 
       RowBox[{"187", "\[Rule]", "188"}], ",", 
       RowBox[{"171", "\[Rule]", "548"}], ",", 
       RowBox[{"171", "\[Rule]", "454"}], ",", 
       RowBox[{"171", "\[Rule]", "172"}], ",", 
       RowBox[{"817", "\[Rule]", "536"}], ",", 
       RowBox[{"817", "\[Rule]", "1194"}], ",", 
       RowBox[{"817", "\[Rule]", "1194"}], ",", 
       RowBox[{"817", "\[Rule]", "442"}], ",", 
       RowBox[{"817", "\[Rule]", "1100"}], ",", 
       RowBox[{"817", "\[Rule]", "1100"}], ",", 
       RowBox[{"817", "\[Rule]", "818"}], ",", 
       RowBox[{"845", "\[Rule]", "564"}], ",", 
       RowBox[{"845", "\[Rule]", "1222"}], ",", 
       RowBox[{"845", "\[Rule]", "1222"}], ",", 
       RowBox[{"845", "\[Rule]", "470"}], ",", 
       RowBox[{"845", "\[Rule]", "1128"}], ",", 
       RowBox[{"845", "\[Rule]", "1128"}], ",", 
       RowBox[{"845", "\[Rule]", "846"}], ",", 
       RowBox[{"829", "\[Rule]", "548"}], ",", 
       RowBox[{"829", "\[Rule]", "1206"}], ",", 
       RowBox[{"829", "\[Rule]", "1206"}], ",", 
       RowBox[{"829", "\[Rule]", "454"}], ",", 
       RowBox[{"829", "\[Rule]", "1112"}], ",", 
       RowBox[{"829", "\[Rule]", "1112"}], ",", 
       RowBox[{"829", "\[Rule]", "830"}], ",", 
       RowBox[{"65", "\[Rule]", "442"}], ",", 
       RowBox[{"65", "\[Rule]", "442"}], ",", 
       RowBox[{"65", "\[Rule]", "66"}], ",", 
       RowBox[{"77", "\[Rule]", "454"}], ",", 
       RowBox[{"77", "\[Rule]", "454"}], ",", 
       RowBox[{"77", "\[Rule]", "78"}], ",", 
       RowBox[{"723", "\[Rule]", "442"}], ",", 
       RowBox[{"723", "\[Rule]", "442"}], ",", 
       RowBox[{"723", "\[Rule]", "1100"}], ",", 
       RowBox[{"723", "\[Rule]", "724"}], ",", 
       RowBox[{"751", "\[Rule]", "470"}], ",", 
       RowBox[{"751", "\[Rule]", "470"}], ",", 
       RowBox[{"751", "\[Rule]", "1128"}], ",", 
       RowBox[{"751", "\[Rule]", "752"}], ",", 
       RowBox[{"735", "\[Rule]", "454"}], ",", 
       RowBox[{"735", "\[Rule]", "454"}], ",", 
       RowBox[{"735", "\[Rule]", "1112"}], ",", 
       RowBox[{"735", "\[Rule]", "736"}], ",", 
       RowBox[{"441", "\[Rule]", "160"}], ",", 
       RowBox[{"441", "\[Rule]", "818"}], ",", 
       RowBox[{"441", "\[Rule]", "66"}], ",", 
       RowBox[{"441", "\[Rule]", "66"}], ",", 
       RowBox[{"441", "\[Rule]", "724"}], ",", 
       RowBox[{"441", "\[Rule]", "724"}], ",", 
       RowBox[{"441", "\[Rule]", "442"}], ",", 
       RowBox[{"469", "\[Rule]", "188"}], ",", 
       RowBox[{"469", "\[Rule]", "846"}], ",", 
       RowBox[{"469", "\[Rule]", "94"}], ",", 
       RowBox[{"469", "\[Rule]", "94"}], ",", 
       RowBox[{"469", "\[Rule]", "752"}], ",", 
       RowBox[{"469", "\[Rule]", "752"}], ",", 
       RowBox[{"469", "\[Rule]", "470"}], ",", 
       RowBox[{"453", "\[Rule]", "172"}], ",", 
       RowBox[{"453", "\[Rule]", "830"}], ",", 
       RowBox[{"453", "\[Rule]", "78"}], ",", 
       RowBox[{"453", "\[Rule]", "78"}], ",", 
       RowBox[{"453", "\[Rule]", "736"}], ",", 
       RowBox[{"453", "\[Rule]", "736"}], ",", 
       RowBox[{"453", "\[Rule]", "454"}], ",", 
       RowBox[{"183", "\[Rule]", "560"}], ",", 
       RowBox[{"183", "\[Rule]", "466"}], ",", 
       RowBox[{"183", "\[Rule]", "184"}], ",", 
       RowBox[{"841", "\[Rule]", "560"}], ",", 
       RowBox[{"841", "\[Rule]", "1218"}], ",", 
       RowBox[{"841", "\[Rule]", "1218"}], ",", 
       RowBox[{"841", "\[Rule]", "466"}], ",", 
       RowBox[{"841", "\[Rule]", "1124"}], ",", 
       RowBox[{"841", "\[Rule]", "1124"}], ",", 
       RowBox[{"841", "\[Rule]", "842"}], ",", 
       RowBox[{"89", "\[Rule]", "466"}], ",", 
       RowBox[{"89", "\[Rule]", "466"}], ",", 
       RowBox[{"89", "\[Rule]", "90"}], ",", 
       RowBox[{"747", "\[Rule]", "466"}], ",", 
       RowBox[{"747", "\[Rule]", "466"}], ",", 
       RowBox[{"747", "\[Rule]", "1124"}], ",", 
       RowBox[{"747", "\[Rule]", "748"}], ",", 
       RowBox[{"465", "\[Rule]", "184"}], ",", 
       RowBox[{"465", "\[Rule]", "842"}], ",", 
       RowBox[{"465", "\[Rule]", "90"}], ",", 
       RowBox[{"465", "\[Rule]", "90"}], ",", 
       RowBox[{"465", "\[Rule]", "748"}], ",", 
       RowBox[{"465", "\[Rule]", "748"}], ",", 
       RowBox[{"465", "\[Rule]", "466"}], ",", 
       RowBox[{"536", "\[Rule]", "521"}], ",", 
       RowBox[{"536", "\[Rule]", "549"}], ",", 
       RowBox[{"536", "\[Rule]", "533"}], ",", 
       RowBox[{"442", "\[Rule]", "427"}], ",", 
       RowBox[{"442", "\[Rule]", "455"}], ",", 
       RowBox[{"442", "\[Rule]", "439"}], ",", 
       RowBox[{"160", "\[Rule]", "145"}], ",", 
       RowBox[{"160", "\[Rule]", "173"}], ",", 
       RowBox[{"160", "\[Rule]", "157"}], ",", 
       RowBox[{"564", "\[Rule]", "549"}], ",", 
       RowBox[{"564", "\[Rule]", "561"}], ",", 
       RowBox[{"188", "\[Rule]", "173"}], ",", 
       RowBox[{"188", "\[Rule]", "185"}], ",", 
       RowBox[{"548", "\[Rule]", "533"}], ",", 
       RowBox[{"548", "\[Rule]", "561"}], ",", 
       RowBox[{"548", "\[Rule]", "549"}], ",", 
       RowBox[{"548", "\[Rule]", "545"}], ",", 
       RowBox[{"454", "\[Rule]", "439"}], ",", 
       RowBox[{"454", "\[Rule]", "467"}], ",", 
       RowBox[{"454", "\[Rule]", "455"}], ",", 
       RowBox[{"454", "\[Rule]", "451"}], ",", 
       RowBox[{"172", "\[Rule]", "157"}], ",", 
       RowBox[{"172", "\[Rule]", "185"}], ",", 
       RowBox[{"172", "\[Rule]", "173"}], ",", 
       RowBox[{"172", "\[Rule]", "169"}], ",", 
       RowBox[{"1194", "\[Rule]", "1179"}], ",", 
       RowBox[{"1194", "\[Rule]", "1207"}], ",", 
       RowBox[{"1194", "\[Rule]", "1191"}], ",", 
       RowBox[{"1100", "\[Rule]", "1085"}], ",", 
       RowBox[{"1100", "\[Rule]", "1113"}], ",", 
       RowBox[{"1100", "\[Rule]", "1097"}], ",", 
       RowBox[{"818", "\[Rule]", "803"}], ",", 
       RowBox[{"818", "\[Rule]", "831"}], ",", 
       RowBox[{"818", "\[Rule]", "815"}], ",", 
       RowBox[{"1222", "\[Rule]", "1207"}], ",", 
       RowBox[{"1222", "\[Rule]", "1219"}], ",", 
       RowBox[{"1128", "\[Rule]", "1113"}], ",", 
       RowBox[{"1128", "\[Rule]", "1125"}], ",", 
       RowBox[{"846", "\[Rule]", "831"}], ",", 
       RowBox[{"846", "\[Rule]", "843"}], ",", 
       RowBox[{"1206", "\[Rule]", "1191"}], ",", 
       RowBox[{"1206", "\[Rule]", "1219"}], ",", 
       RowBox[{"1206", "\[Rule]", "1207"}], ",", 
       RowBox[{"1206", "\[Rule]", "1203"}], ",", 
       RowBox[{"1112", "\[Rule]", "1097"}], ",", 
       RowBox[{"1112", "\[Rule]", "1125"}], ",", 
       RowBox[{"1112", "\[Rule]", "1113"}], ",", 
       RowBox[{"1112", "\[Rule]", "1109"}], ",", 
       RowBox[{"830", "\[Rule]", "815"}], ",", 
       RowBox[{"830", "\[Rule]", "843"}], ",", 
       RowBox[{"830", "\[Rule]", "831"}], ",", 
       RowBox[{"830", "\[Rule]", "827"}], ",", 
       RowBox[{"66", "\[Rule]", "51"}], ",", 
       RowBox[{"66", "\[Rule]", "79"}], ",", 
       RowBox[{"66", "\[Rule]", "63"}], ",", 
       RowBox[{"78", "\[Rule]", "63"}], ",", 
       RowBox[{"78", "\[Rule]", "91"}], ",", 
       RowBox[{"78", "\[Rule]", "79"}], ",", 
       RowBox[{"78", "\[Rule]", "75"}], ",", 
       RowBox[{"724", "\[Rule]", "709"}], ",", 
       RowBox[{"724", "\[Rule]", "737"}], ",", 
       RowBox[{"724", "\[Rule]", "721"}], ",", 
       RowBox[{"752", "\[Rule]", "737"}], ",", 
       RowBox[{"752", "\[Rule]", "749"}], ",", 
       RowBox[{"736", "\[Rule]", "721"}], ",", 
       RowBox[{"736", "\[Rule]", "749"}], ",", 
       RowBox[{"736", "\[Rule]", "737"}], ",", 
       RowBox[{"736", "\[Rule]", "733"}], ",", 
       RowBox[{"560", "\[Rule]", "545"}], ",", 
       RowBox[{"560", "\[Rule]", "561"}], ",", 
       RowBox[{"560", "\[Rule]", "557"}], ",", 
       RowBox[{"466", "\[Rule]", "451"}], ",", 
       RowBox[{"466", "\[Rule]", "467"}], ",", 
       RowBox[{"466", "\[Rule]", "463"}], ",", 
       RowBox[{"184", "\[Rule]", "169"}], ",", 
       RowBox[{"184", "\[Rule]", "185"}], ",", 
       RowBox[{"184", "\[Rule]", "181"}], ",", 
       RowBox[{"1218", "\[Rule]", "1203"}], ",", 
       RowBox[{"1218", "\[Rule]", "1219"}], ",", 
       RowBox[{"1218", "\[Rule]", "1215"}], ",", 
       RowBox[{"1124", "\[Rule]", "1109"}], ",", 
       RowBox[{"1124", "\[Rule]", "1125"}], ",", 
       RowBox[{"1124", "\[Rule]", "1121"}], ",", 
       RowBox[{"842", "\[Rule]", "827"}], ",", 
       RowBox[{"842", "\[Rule]", "843"}], ",", 
       RowBox[{"842", "\[Rule]", "839"}], ",", 
       RowBox[{"90", "\[Rule]", "75"}], ",", 
       RowBox[{"90", "\[Rule]", "91"}], ",", 
       RowBox[{"90", "\[Rule]", "87"}], ",", 
       RowBox[{"748", "\[Rule]", "733"}], ",", 
       RowBox[{"748", "\[Rule]", "749"}], ",", 
       RowBox[{"748", "\[Rule]", "745"}], ",", 
       RowBox[{"521", "\[Rule]", "240"}], ",", 
       RowBox[{"521", "\[Rule]", "240"}], ",", 
       RowBox[{"521", "\[Rule]", "898"}], ",", 
       RowBox[{"521", "\[Rule]", "898"}], ",", 
       RowBox[{"521", "\[Rule]", "146"}], ",", 
       RowBox[{"521", "\[Rule]", "804"}], ",", 
       RowBox[{"521", "\[Rule]", "522"}], ",", 
       RowBox[{"549", "\[Rule]", "268"}], ",", 
       RowBox[{"549", "\[Rule]", "268"}], ",", 
       RowBox[{"549", "\[Rule]", "926"}], ",", 
       RowBox[{"549", "\[Rule]", "926"}], ",", 
       RowBox[{"549", "\[Rule]", "174"}], ",", 
       RowBox[{"549", "\[Rule]", "832"}], ",", 
       RowBox[{"549", "\[Rule]", "550"}], ",", 
       RowBox[{"533", "\[Rule]", "252"}], ",", 
       RowBox[{"533", "\[Rule]", "252"}], ",", 
       RowBox[{"533", "\[Rule]", "910"}], ",", 
       RowBox[{"533", "\[Rule]", "910"}], ",", 
       RowBox[{"533", "\[Rule]", "158"}], ",", 
       RowBox[{"533", "\[Rule]", "816"}], ",", 
       RowBox[{"533", "\[Rule]", "534"}], ",", 
       RowBox[{"427", "\[Rule]", "146"}], ",", 
       RowBox[{"427", "\[Rule]", "804"}], ",", 
       RowBox[{"427", "\[Rule]", "52"}], ",", 
       RowBox[{"427", "\[Rule]", "52"}], ",", 
       RowBox[{"427", "\[Rule]", "710"}], ",", 
       RowBox[{"427", "\[Rule]", "710"}], ",", 
       RowBox[{"427", "\[Rule]", "428"}], ",", 
       RowBox[{"439", "\[Rule]", "158"}], ",", 
       RowBox[{"439", "\[Rule]", "816"}], ",", 
       RowBox[{"439", "\[Rule]", "64"}], ",", 
       RowBox[{"439", "\[Rule]", "64"}], ",", 
       RowBox[{"439", "\[Rule]", "722"}], ",", 
       RowBox[{"439", "\[Rule]", "722"}], ",", 
       RowBox[{"439", "\[Rule]", "440"}], ",", 
       RowBox[{"145", "\[Rule]", "522"}], ",", 
       RowBox[{"145", "\[Rule]", "428"}], ",", 
       RowBox[{"145", "\[Rule]", "146"}], ",", 
       RowBox[{"173", "\[Rule]", "550"}], ",", 
       RowBox[{"173", "\[Rule]", "456"}], ",", 
       RowBox[{"173", "\[Rule]", "174"}], ",", 
       RowBox[{"157", "\[Rule]", "534"}], ",", 
       RowBox[{"157", "\[Rule]", "440"}], ",", 
       RowBox[{"157", "\[Rule]", "158"}], ",", 
       RowBox[{"561", "\[Rule]", "280"}], ",", 
       RowBox[{"561", "\[Rule]", "280"}], ",", 
       RowBox[{"561", "\[Rule]", "938"}], ",", 
       RowBox[{"561", "\[Rule]", "938"}], ",", 
       RowBox[{"561", "\[Rule]", "186"}], ",", 
       RowBox[{"561", "\[Rule]", "844"}], ",", 
       RowBox[{"561", "\[Rule]", "562"}], ",", 
       RowBox[{"185", "\[Rule]", "562"}], ",", 
       RowBox[{"185", "\[Rule]", "468"}], ",", 
       RowBox[{"185", "\[Rule]", "186"}], ",", 
       RowBox[{"545", "\[Rule]", "264"}], ",", 
       RowBox[{"545", "\[Rule]", "264"}], ",", 
       RowBox[{"545", "\[Rule]", "922"}], ",", 
       RowBox[{"545", "\[Rule]", "922"}], ",", 
       RowBox[{"545", "\[Rule]", "170"}], ",", 
       RowBox[{"545", "\[Rule]", "828"}], ",", 
       RowBox[{"545", "\[Rule]", "546"}], ",", 
       RowBox[{"451", "\[Rule]", "170"}], ",", 
       RowBox[{"451", "\[Rule]", "828"}], ",", 
       RowBox[{"451", "\[Rule]", "76"}], ",", 
       RowBox[{"451", "\[Rule]", "76"}], ",", 
       RowBox[{"451", "\[Rule]", "734"}], ",", 
       RowBox[{"451", "\[Rule]", "734"}], ",", 
       RowBox[{"451", "\[Rule]", "452"}], ",", 
       RowBox[{"169", "\[Rule]", "546"}], ",", 
       RowBox[{"169", "\[Rule]", "452"}], ",", 
       RowBox[{"169", "\[Rule]", "170"}], ",", 
       RowBox[{"1179", "\[Rule]", "898"}], ",", 
       RowBox[{"1179", "\[Rule]", "898"}], ",", 
       RowBox[{"1179", "\[Rule]", "1556"}], ",", 
       RowBox[{"1179", "\[Rule]", "1556"}], ",", 
       RowBox[{"1179", "\[Rule]", "804"}], ",", 
       RowBox[{"1179", "\[Rule]", "804"}], ",", 
       RowBox[{"1179", "\[Rule]", "1462"}], ",", 
       RowBox[{"1179", "\[Rule]", "1462"}], ",", 
       RowBox[{"1179", "\[Rule]", "1180"}], ",", 
       RowBox[{"1207", "\[Rule]", "926"}], ",", 
       RowBox[{"1207", "\[Rule]", "926"}], ",", 
       RowBox[{"1207", "\[Rule]", "1584"}], ",", 
       RowBox[{"1207", "\[Rule]", "1584"}], ",", 
       RowBox[{"1207", "\[Rule]", "832"}], ",", 
       RowBox[{"1207", "\[Rule]", "832"}], ",", 
       RowBox[{"1207", "\[Rule]", "1490"}], ",", 
       RowBox[{"1207", "\[Rule]", "1490"}], ",", 
       RowBox[{"1207", "\[Rule]", "1208"}], ",", 
       RowBox[{"1191", "\[Rule]", "910"}], ",", 
       RowBox[{"1191", "\[Rule]", "910"}], ",", 
       RowBox[{"1191", "\[Rule]", "1568"}], ",", 
       RowBox[{"1191", "\[Rule]", "1568"}], ",", 
       RowBox[{"1191", "\[Rule]", "816"}], ",", 
       RowBox[{"1191", "\[Rule]", "816"}], ",", 
       RowBox[{"1191", "\[Rule]", "1474"}], ",", 
       RowBox[{"1191", "\[Rule]", "1474"}], ",", 
       RowBox[{"1191", "\[Rule]", "1192"}], ",", 
       RowBox[{"1085", "\[Rule]", "804"}], ",", 
       RowBox[{"1085", "\[Rule]", "804"}], ",", 
       RowBox[{"1085", "\[Rule]", "1462"}], ",", 
       RowBox[{"1085", "\[Rule]", "1462"}], ",", 
       RowBox[{"1085", "\[Rule]", "710"}], ",", 
       RowBox[{"1085", "\[Rule]", "1368"}], ",", 
       RowBox[{"1085", "\[Rule]", "1086"}], ",", 
       RowBox[{"1113", "\[Rule]", "832"}], ",", 
       RowBox[{"1113", "\[Rule]", "832"}], ",", 
       RowBox[{"1113", "\[Rule]", "1490"}], ",", 
       RowBox[{"1113", "\[Rule]", "1490"}], ",", 
       RowBox[{"1113", "\[Rule]", "738"}], ",", 
       RowBox[{"1113", "\[Rule]", "1396"}], ",", 
       RowBox[{"1113", "\[Rule]", "1114"}], ",", 
       RowBox[{"1097", "\[Rule]", "816"}], ",", 
       RowBox[{"1097", "\[Rule]", "816"}], ",", 
       RowBox[{"1097", "\[Rule]", "1474"}], ",", 
       RowBox[{"1097", "\[Rule]", "1474"}], ",", 
       RowBox[{"1097", "\[Rule]", "722"}], ",", 
       RowBox[{"1097", "\[Rule]", "1380"}], ",", 
       RowBox[{"1097", "\[Rule]", "1098"}], ",", 
       RowBox[{"803", "\[Rule]", "522"}], ",", 
       RowBox[{"803", "\[Rule]", "1180"}], ",", 
       RowBox[{"803", "\[Rule]", "1180"}], ",", 
       RowBox[{"803", "\[Rule]", "428"}], ",", 
       RowBox[{"803", "\[Rule]", "1086"}], ",", 
       RowBox[{"803", "\[Rule]", "1086"}], ",", 
       RowBox[{"803", "\[Rule]", "804"}], ",", 
       RowBox[{"831", "\[Rule]", "550"}], ",", 
       RowBox[{"831", "\[Rule]", "1208"}], ",", 
       RowBox[{"831", "\[Rule]", "1208"}], ",", 
       RowBox[{"831", "\[Rule]", "456"}], ",", 
       RowBox[{"831", "\[Rule]", "1114"}], ",", 
       RowBox[{"831", "\[Rule]", "1114"}], ",", 
       RowBox[{"831", "\[Rule]", "832"}], ",", 
       RowBox[{"815", "\[Rule]", "534"}], ",", 
       RowBox[{"815", "\[Rule]", "1192"}], ",", 
       RowBox[{"815", "\[Rule]", "1192"}], ",", 
       RowBox[{"815", "\[Rule]", "440"}], ",", 
       RowBox[{"815", "\[Rule]", "1098"}], ",", 
       RowBox[{"815", "\[Rule]", "1098"}], ",", 
       RowBox[{"815", "\[Rule]", "816"}], ",", 
       RowBox[{"1219", "\[Rule]", "938"}], ",", 
       RowBox[{"1219", "\[Rule]", "938"}], ",", 
       RowBox[{"1219", "\[Rule]", "1596"}], ",", 
       RowBox[{"1219", "\[Rule]", "1596"}], ",", 
       RowBox[{"1219", "\[Rule]", "844"}], ",", 
       RowBox[{"1219", "\[Rule]", "844"}], ",", 
       RowBox[{"1219", "\[Rule]", "1502"}], ",", 
       RowBox[{"1219", "\[Rule]", "1502"}], ",", 
       RowBox[{"1219", "\[Rule]", "1220"}], ",", 
       RowBox[{"1125", "\[Rule]", "844"}], ",", 
       RowBox[{"1125", "\[Rule]", "844"}], ",", 
       RowBox[{"1125", "\[Rule]", "1502"}], ",", 
       RowBox[{"1125", "\[Rule]", "1502"}], ",", 
       RowBox[{"1125", "\[Rule]", "750"}], ",", 
       RowBox[{"1125", "\[Rule]", "1408"}], ",", 
       RowBox[{"1125", "\[Rule]", "1126"}], ",", 
       RowBox[{"843", "\[Rule]", "562"}], ",", 
       RowBox[{"843", "\[Rule]", "1220"}], ",", 
       RowBox[{"843", "\[Rule]", "1220"}], ",", 
       RowBox[{"843", "\[Rule]", "468"}], ",", 
       RowBox[{"843", "\[Rule]", "1126"}], ",", 
       RowBox[{"843", "\[Rule]", "1126"}], ",", 
       RowBox[{"843", "\[Rule]", "844"}], ",", 
       RowBox[{"1203", "\[Rule]", "922"}], ",", 
       RowBox[{"1203", "\[Rule]", "922"}], ",", 
       RowBox[{"1203", "\[Rule]", "1580"}], ",", 
       RowBox[{"1203", "\[Rule]", "1580"}], ",", 
       RowBox[{"1203", "\[Rule]", "828"}], ",", 
       RowBox[{"1203", "\[Rule]", "828"}], ",", 
       RowBox[{"1203", "\[Rule]", "1486"}], ",", 
       RowBox[{"1203", "\[Rule]", "1486"}], ",", 
       RowBox[{"1203", "\[Rule]", "1204"}], ",", 
       RowBox[{"1109", "\[Rule]", "828"}], ",", 
       RowBox[{"1109", "\[Rule]", "828"}], ",", 
       RowBox[{"1109", "\[Rule]", "1486"}], ",", 
       RowBox[{"1109", "\[Rule]", "1486"}], ",", 
       RowBox[{"1109", "\[Rule]", "734"}], ",", 
       RowBox[{"1109", "\[Rule]", "1392"}], ",", 
       RowBox[{"1109", "\[Rule]", "1110"}], ",", 
       RowBox[{"827", "\[Rule]", "546"}], ",", 
       RowBox[{"827", "\[Rule]", "1204"}], ",", 
       RowBox[{"827", "\[Rule]", "1204"}], ",", 
       RowBox[{"827", "\[Rule]", "452"}], ",", 
       RowBox[{"827", "\[Rule]", "1110"}], ",", 
       RowBox[{"827", "\[Rule]", "1110"}], ",", 
       RowBox[{"827", "\[Rule]", "828"}], ",", 
       RowBox[{"51", "\[Rule]", "428"}], ",", 
       RowBox[{"51", "\[Rule]", "428"}], ",", 
       RowBox[{"51", "\[Rule]", "52"}], ",", 
       RowBox[{"63", "\[Rule]", "440"}], ",", 
       RowBox[{"63", "\[Rule]", "440"}], ",", 
       RowBox[{"63", "\[Rule]", "64"}], ",", 
       RowBox[{"75", "\[Rule]", "452"}], ",", 
       RowBox[{"75", "\[Rule]", "452"}], ",", 
       RowBox[{"75", "\[Rule]", "76"}], ",", 
       RowBox[{"709", "\[Rule]", "428"}], ",", 
       RowBox[{"709", "\[Rule]", "428"}], ",", 
       RowBox[{"709", "\[Rule]", "1086"}], ",", 
       RowBox[{"709", "\[Rule]", "710"}], ",", 
       RowBox[{"737", "\[Rule]", "456"}], ",", 
       RowBox[{"737", "\[Rule]", "456"}], ",", 
       RowBox[{"737", "\[Rule]", "1114"}], ",", 
       RowBox[{"737", "\[Rule]", "738"}], ",", 
       RowBox[{"721", "\[Rule]", "440"}], ",", 
       RowBox[{"721", "\[Rule]", "440"}], ",", 
       RowBox[{"721", "\[Rule]", "1098"}], ",", 
       RowBox[{"721", "\[Rule]", "722"}], ",", 
       RowBox[{"749", "\[Rule]", "468"}], ",", 
       RowBox[{"749", "\[Rule]", "468"}], ",", 
       RowBox[{"749", "\[Rule]", "1126"}], ",", 
       RowBox[{"749", "\[Rule]", "750"}], ",", 
       RowBox[{"733", "\[Rule]", "452"}], ",", 
       RowBox[{"733", "\[Rule]", "452"}], ",", 
       RowBox[{"733", "\[Rule]", "1110"}], ",", 
       RowBox[{"733", "\[Rule]", "734"}], ",", 
       RowBox[{"557", "\[Rule]", "276"}], ",", 
       RowBox[{"557", "\[Rule]", "276"}], ",", 
       RowBox[{"557", "\[Rule]", "934"}], ",", 
       RowBox[{"557", "\[Rule]", "934"}], ",", 
       RowBox[{"557", "\[Rule]", "182"}], ",", 
       RowBox[{"557", "\[Rule]", "840"}], ",", 
       RowBox[{"557", "\[Rule]", "558"}], ",", 
       RowBox[{"463", "\[Rule]", "182"}], ",", 
       RowBox[{"463", "\[Rule]", "840"}], ",", 
       RowBox[{"463", "\[Rule]", "88"}], ",", 
       RowBox[{"463", "\[Rule]", "88"}], ",", 
       RowBox[{"463", "\[Rule]", "746"}], ",", 
       RowBox[{"463", "\[Rule]", "746"}], ",", 
       RowBox[{"463", "\[Rule]", "464"}], ",", 
       RowBox[{"181", "\[Rule]", "558"}], ",", 
       RowBox[{"181", "\[Rule]", "464"}], ",", 
       RowBox[{"181", "\[Rule]", "182"}], ",", 
       RowBox[{"1215", "\[Rule]", "934"}], ",", 
       RowBox[{"1215", "\[Rule]", "934"}], ",", 
       RowBox[{"1215", "\[Rule]", "1592"}], ",", 
       RowBox[{"1215", "\[Rule]", "1592"}], ",", 
       RowBox[{"1215", "\[Rule]", "840"}], ",", 
       RowBox[{"1215", "\[Rule]", "840"}], ",", 
       RowBox[{"1215", "\[Rule]", "1498"}], ",", 
       RowBox[{"1215", "\[Rule]", "1498"}], ",", 
       RowBox[{"1215", "\[Rule]", "1216"}], ",", 
       RowBox[{"1121", "\[Rule]", "840"}], ",", 
       RowBox[{"1121", "\[Rule]", "840"}], ",", 
       RowBox[{"1121", "\[Rule]", "1498"}], ",", 
       RowBox[{"1121", "\[Rule]", "1498"}], ",", 
       RowBox[{"1121", "\[Rule]", "746"}], ",", 
       RowBox[{"1121", "\[Rule]", "1404"}], ",", 
       RowBox[{"1121", "\[Rule]", "1122"}], ",", 
       RowBox[{"839", "\[Rule]", "558"}], ",", 
       RowBox[{"839", "\[Rule]", "1216"}], ",", 
       RowBox[{"839", "\[Rule]", "1216"}], ",", 
       RowBox[{"839", "\[Rule]", "464"}], ",", 
       RowBox[{"839", "\[Rule]", "1122"}], ",", 
       RowBox[{"839", "\[Rule]", "1122"}], ",", 
       RowBox[{"839", "\[Rule]", "840"}], ",", 
       RowBox[{"87", "\[Rule]", "464"}], ",", 
       RowBox[{"87", "\[Rule]", "464"}], ",", 
       RowBox[{"87", "\[Rule]", "88"}], ",", 
       RowBox[{"745", "\[Rule]", "464"}], ",", 
       RowBox[{"745", "\[Rule]", "464"}], ",", 
       RowBox[{"745", "\[Rule]", "1122"}], ",", 
       RowBox[{"745", "\[Rule]", "746"}], ",", 
       RowBox[{"240", "\[Rule]", "227"}], ",", 
       RowBox[{"240", "\[Rule]", "253"}], ",", 
       RowBox[{"240", "\[Rule]", "237"}], ",", 
       RowBox[{"898", "\[Rule]", "885"}], ",", 
       RowBox[{"898", "\[Rule]", "911"}], ",", 
       RowBox[{"898", "\[Rule]", "895"}], ",", 
       RowBox[{"146", "\[Rule]", "133"}], ",", 
       RowBox[{"146", "\[Rule]", "159"}], ",", 
       RowBox[{"146", "\[Rule]", "143"}], ",", 
       RowBox[{"804", "\[Rule]", "791"}], ",", 
       RowBox[{"804", "\[Rule]", "817"}], ",", 
       RowBox[{"804", "\[Rule]", "801"}], ",", 
       RowBox[{"522", "\[Rule]", "509"}], ",", 
       RowBox[{"522", "\[Rule]", "535"}], ",", 
       RowBox[{"522", "\[Rule]", "519"}], ",", 
       RowBox[{"268", "\[Rule]", "253"}], ",", 
       RowBox[{"268", "\[Rule]", "281"}], ",", 
       RowBox[{"268", "\[Rule]", "265"}], ",", 
       RowBox[{"926", "\[Rule]", "911"}], ",", 
       RowBox[{"926", "\[Rule]", "939"}], ",", 
       RowBox[{"926", "\[Rule]", "923"}], ",", 
       RowBox[{"550", "\[Rule]", "535"}], ",", 
       RowBox[{"550", "\[Rule]", "563"}], ",", 
       RowBox[{"550", "\[Rule]", "547"}], ",", 
       RowBox[{"252", "\[Rule]", "237"}], ",", 
       RowBox[{"252", "\[Rule]", "265"}], ",", 
       RowBox[{"252", "\[Rule]", "253"}], ",", 
       RowBox[{"252", "\[Rule]", "249"}], ",", 
       RowBox[{"910", "\[Rule]", "895"}], ",", 
       RowBox[{"910", "\[Rule]", "923"}], ",", 
       RowBox[{"910", "\[Rule]", "911"}], ",", 
       RowBox[{"910", "\[Rule]", "907"}], ",", 
       RowBox[{"158", "\[Rule]", "143"}], ",", 
       RowBox[{"158", "\[Rule]", "171"}], ",", 
       RowBox[{"158", "\[Rule]", "159"}], ",", 
       RowBox[{"158", "\[Rule]", "155"}], ",", 
       RowBox[{"816", "\[Rule]", "801"}], ",", 
       RowBox[{"816", "\[Rule]", "829"}], ",", 
       RowBox[{"816", "\[Rule]", "817"}], ",", 
       RowBox[{"816", "\[Rule]", "813"}], ",", 
       RowBox[{"534", "\[Rule]", "519"}], ",", 
       RowBox[{"534", "\[Rule]", "547"}], ",", 
       RowBox[{"534", "\[Rule]", "535"}], ",", 
       RowBox[{"534", "\[Rule]", "531"}], ",", 
       RowBox[{"52", "\[Rule]", "39"}], ",", 
       RowBox[{"52", "\[Rule]", "65"}], ",", 
       RowBox[{"52", "\[Rule]", "49"}], ",", 
       RowBox[{"710", "\[Rule]", "697"}], ",", 
       RowBox[{"710", "\[Rule]", "723"}], ",", 
       RowBox[{"710", "\[Rule]", "707"}], ",", 
       RowBox[{"428", "\[Rule]", "415"}], ",", 
       RowBox[{"428", "\[Rule]", "441"}], ",", 
       RowBox[{"428", "\[Rule]", "425"}], ",", 
       RowBox[{"64", "\[Rule]", "49"}], ",", 
       RowBox[{"64", "\[Rule]", "77"}], ",", 
       RowBox[{"64", "\[Rule]", "65"}], ",", 
       RowBox[{"64", "\[Rule]", "61"}], ",", 
       RowBox[{"722", "\[Rule]", "707"}], ",", 
       RowBox[{"722", "\[Rule]", "735"}], ",", 
       RowBox[{"722", "\[Rule]", "723"}], ",", 
       RowBox[{"722", "\[Rule]", "719"}], ",", 
       RowBox[{"440", "\[Rule]", "425"}], ",", 
       RowBox[{"440", "\[Rule]", "453"}], ",", 
       RowBox[{"440", "\[Rule]", "441"}], ",", 
       RowBox[{"440", "\[Rule]", "437"}], ",", 
       RowBox[{"280", "\[Rule]", "265"}], ",", 
       RowBox[{"280", "\[Rule]", "281"}], ",", 
       RowBox[{"280", "\[Rule]", "277"}], ",", 
       RowBox[{"938", "\[Rule]", "923"}], ",", 
       RowBox[{"938", "\[Rule]", "939"}], ",", 
       RowBox[{"938", "\[Rule]", "935"}], ",", 
       RowBox[{"562", "\[Rule]", "547"}], ",", 
       RowBox[{"562", "\[Rule]", "563"}], ",", 
       RowBox[{"562", "\[Rule]", "559"}], ",", 
       RowBox[{"264", "\[Rule]", "249"}], ",", 
       RowBox[{"264", "\[Rule]", "277"}], ",", 
       RowBox[{"264", "\[Rule]", "265"}], ",", 
       RowBox[{"264", "\[Rule]", "261"}], ",", 
       RowBox[{"922", "\[Rule]", "907"}], ",", 
       RowBox[{"922", "\[Rule]", "935"}], ",", 
       RowBox[{"922", "\[Rule]", "923"}], ",", 
       RowBox[{"922", "\[Rule]", "919"}], ",", 
       RowBox[{"170", "\[Rule]", "155"}], ",", 
       RowBox[{"170", "\[Rule]", "183"}], ",", 
       RowBox[{"170", "\[Rule]", "171"}], ",", 
       RowBox[{"170", "\[Rule]", "167"}], ",", 
       RowBox[{"828", "\[Rule]", "813"}], ",", 
       RowBox[{"828", "\[Rule]", "841"}], ",", 
       RowBox[{"828", "\[Rule]", "829"}], ",", 
       RowBox[{"828", "\[Rule]", "825"}], ",", 
       RowBox[{"546", "\[Rule]", "531"}], ",", 
       RowBox[{"546", "\[Rule]", "559"}], ",", 
       RowBox[{"546", "\[Rule]", "547"}], ",", 
       RowBox[{"546", "\[Rule]", "543"}], ",", 
       RowBox[{"76", "\[Rule]", "61"}], ",", 
       RowBox[{"76", "\[Rule]", "89"}], ",", 
       RowBox[{"76", "\[Rule]", "77"}], ",", 
       RowBox[{"76", "\[Rule]", "73"}], ",", 
       RowBox[{"734", "\[Rule]", "719"}], ",", 
       RowBox[{"734", "\[Rule]", "747"}], ",", 
       RowBox[{"734", "\[Rule]", "735"}], ",", 
       RowBox[{"734", "\[Rule]", "731"}], ",", 
       RowBox[{"452", "\[Rule]", "437"}], ",", 
       RowBox[{"452", "\[Rule]", "465"}], ",", 
       RowBox[{"452", "\[Rule]", "453"}], ",", 
       RowBox[{"452", "\[Rule]", "449"}], ",", 
       RowBox[{"1556", "\[Rule]", "1543"}], ",", 
       RowBox[{"1556", "\[Rule]", "1569"}], ",", 
       RowBox[{"1556", "\[Rule]", "1553"}], ",", 
       RowBox[{"1462", "\[Rule]", "1449"}], ",", 
       RowBox[{"1462", "\[Rule]", "1475"}], ",", 
       RowBox[{"1462", "\[Rule]", "1459"}], ",", 
       RowBox[{"1180", "\[Rule]", "1167"}], ",", 
       RowBox[{"1180", "\[Rule]", "1193"}], ",", 
       RowBox[{"1180", "\[Rule]", "1177"}], ",", 
       RowBox[{"1584", "\[Rule]", "1569"}], ",", 
       RowBox[{"1584", "\[Rule]", "1597"}], ",", 
       RowBox[{"1584", "\[Rule]", "1581"}], ",", 
       RowBox[{"1490", "\[Rule]", "1475"}], ",", 
       RowBox[{"1490", "\[Rule]", "1503"}], ",", 
       RowBox[{"1490", "\[Rule]", "1487"}], ",", 
       RowBox[{"1208", "\[Rule]", "1193"}], ",", 
       RowBox[{"1208", "\[Rule]", "1221"}], ",", 
       RowBox[{"1208", "\[Rule]", "1205"}], ",", 
       RowBox[{"1568", "\[Rule]", "1553"}], ",", 
       RowBox[{"1568", "\[Rule]", "1581"}], ",", 
       RowBox[{"1568", "\[Rule]", "1569"}], ",", 
       RowBox[{"1568", "\[Rule]", "1565"}], ",", 
       RowBox[{"1474", "\[Rule]", "1459"}], ",", 
       RowBox[{"1474", "\[Rule]", "1487"}], ",", 
       RowBox[{"1474", "\[Rule]", "1475"}], ",", 
       RowBox[{"1474", "\[Rule]", "1471"}], ",", 
       RowBox[{"1192", "\[Rule]", "1177"}], ",", 
       RowBox[{"1192", "\[Rule]", "1205"}], ",", 
       RowBox[{"1192", "\[Rule]", "1193"}], ",", 
       RowBox[{"1192", "\[Rule]", "1189"}], ",", 
       RowBox[{"1368", "\[Rule]", "1355"}], ",", 
       RowBox[{"1368", "\[Rule]", "1381"}], ",", 
       RowBox[{"1368", "\[Rule]", "1365"}], ",", 
       RowBox[{"1086", "\[Rule]", "1073"}], ",", 
       RowBox[{"1086", "\[Rule]", "1099"}], ",", 
       RowBox[{"1086", "\[Rule]", "1083"}], ",", 
       RowBox[{"1396", "\[Rule]", "1381"}], ",", 
       RowBox[{"1396", "\[Rule]", "1409"}], ",", 
       RowBox[{"1396", "\[Rule]", "1393"}], ",", 
       RowBox[{"1114", "\[Rule]", "1099"}], ",", 
       RowBox[{"1114", "\[Rule]", "1127"}], ",", 
       RowBox[{"1114", "\[Rule]", "1111"}], ",", 
       RowBox[{"1380", "\[Rule]", "1365"}], ",", 
       RowBox[{"1380", "\[Rule]", "1393"}], ",", 
       RowBox[{"1380", "\[Rule]", "1381"}], ",", 
       RowBox[{"1380", "\[Rule]", "1377"}], ",", 
       RowBox[{"1098", "\[Rule]", "1083"}], ",", 
       RowBox[{"1098", "\[Rule]", "1111"}], ",", 
       RowBox[{"1098", "\[Rule]", "1099"}], ",", 
       RowBox[{"1098", "\[Rule]", "1095"}], ",", 
       RowBox[{"1596", "\[Rule]", "1581"}], ",", 
       RowBox[{"1596", "\[Rule]", "1597"}], ",", 
       RowBox[{"1596", "\[Rule]", "1593"}], ",", 
       RowBox[{"1502", "\[Rule]", "1487"}], ",", 
       RowBox[{"1502", "\[Rule]", "1503"}], ",", 
       RowBox[{"1502", "\[Rule]", "1499"}], ",", 
       RowBox[{"1220", "\[Rule]", "1205"}], ",", 
       RowBox[{"1220", "\[Rule]", "1221"}], ",", 
       RowBox[{"1220", "\[Rule]", "1217"}], ",", 
       RowBox[{"1408", "\[Rule]", "1393"}], ",", 
       RowBox[{"1408", "\[Rule]", "1409"}], ",", 
       RowBox[{"1408", "\[Rule]", "1405"}], ",", 
       RowBox[{"1126", "\[Rule]", "1111"}], ",", 
       RowBox[{"1126", "\[Rule]", "1127"}], ",", 
       RowBox[{"1126", "\[Rule]", "1123"}], ",", 
       RowBox[{"1580", "\[Rule]", "1565"}], ",", 
       RowBox[{"1580", "\[Rule]", "1593"}], ",", 
       RowBox[{"1580", "\[Rule]", "1581"}], ",", 
       RowBox[{"1580", "\[Rule]", "1577"}], ",", 
       RowBox[{"1486", "\[Rule]", "1471"}], ",", 
       RowBox[{"1486", "\[Rule]", "1499"}], ",", 
       RowBox[{"1486", "\[Rule]", "1487"}], ",", 
       RowBox[{"1486", "\[Rule]", "1483"}], ",", 
       RowBox[{"1204", "\[Rule]", "1189"}], ",", 
       RowBox[{"1204", "\[Rule]", "1217"}], ",", 
       RowBox[{"1204", "\[Rule]", "1205"}], ",", 
       RowBox[{"1204", "\[Rule]", "1201"}], ",", 
       RowBox[{"1392", "\[Rule]", "1377"}], ",", 
       RowBox[{"1392", "\[Rule]", "1405"}], ",", 
       RowBox[{"1392", "\[Rule]", "1393"}], ",", 
       RowBox[{"1392", "\[Rule]", "1389"}], ",", 
       RowBox[{"1110", "\[Rule]", "1095"}], ",", 
       RowBox[{"1110", "\[Rule]", "1123"}], ",", 
       RowBox[{"1110", "\[Rule]", "1111"}], ",", 
       RowBox[{"1110", "\[Rule]", "1107"}], ",", 
       RowBox[{"276", "\[Rule]", "261"}], ",", 
       RowBox[{"276", "\[Rule]", "277"}], ",", 
       RowBox[{"276", "\[Rule]", "273"}], ",", 
       RowBox[{"934", "\[Rule]", "919"}], ",", 
       RowBox[{"934", "\[Rule]", "935"}], ",", 
       RowBox[{"934", "\[Rule]", "931"}], ",", 
       RowBox[{"182", "\[Rule]", "167"}], ",", 
       RowBox[{"182", "\[Rule]", "183"}], ",", 
       RowBox[{"182", "\[Rule]", "179"}], ",", 
       RowBox[{"840", "\[Rule]", "825"}], ",", 
       RowBox[{"840", "\[Rule]", "841"}], ",", 
       RowBox[{"840", "\[Rule]", "837"}], ",", 
       RowBox[{"558", "\[Rule]", "543"}], ",", 
       RowBox[{"558", "\[Rule]", "559"}], ",", 
       RowBox[{"558", "\[Rule]", "555"}], ",", 
       RowBox[{"88", "\[Rule]", "73"}], ",", 
       RowBox[{"88", "\[Rule]", "89"}], ",", 
       RowBox[{"88", "\[Rule]", "85"}], ",", 
       RowBox[{"746", "\[Rule]", "731"}], ",", 
       RowBox[{"746", "\[Rule]", "747"}], ",", 
       RowBox[{"746", "\[Rule]", "743"}], ",", 
       RowBox[{"464", "\[Rule]", "449"}], ",", 
       RowBox[{"464", "\[Rule]", "465"}], ",", 
       RowBox[{"464", "\[Rule]", "461"}], ",", 
       RowBox[{"1592", "\[Rule]", "1577"}], ",", 
       RowBox[{"1592", "\[Rule]", "1593"}], ",", 
       RowBox[{"1592", "\[Rule]", "1589"}], ",", 
       RowBox[{"1498", "\[Rule]", "1483"}], ",", 
       RowBox[{"1498", "\[Rule]", "1499"}], ",", 
       RowBox[{"1498", "\[Rule]", "1495"}], ",", 
       RowBox[{"1216", "\[Rule]", "1201"}], ",", 
       RowBox[{"1216", "\[Rule]", "1217"}], ",", 
       RowBox[{"1216", "\[Rule]", "1213"}], ",", 
       RowBox[{"1404", "\[Rule]", "1389"}], ",", 
       RowBox[{"1404", "\[Rule]", "1405"}], ",", 
       RowBox[{"1404", "\[Rule]", "1401"}], ",", 
       RowBox[{"1122", "\[Rule]", "1107"}], ",", 
       RowBox[{"1122", "\[Rule]", "1123"}], ",", 
       RowBox[{"1122", "\[Rule]", "1119"}], ",", 
       RowBox[{"227", "\[Rule]", "604"}], ",", 
       RowBox[{"227", "\[Rule]", "604"}], ",", 
       RowBox[{"227", "\[Rule]", "510"}], ",", 
       RowBox[{"227", "\[Rule]", "510"}], ",", 
       RowBox[{"227", "\[Rule]", "228"}], ",", 
       RowBox[{"253", "\[Rule]", "630"}], ",", 
       RowBox[{"253", "\[Rule]", "630"}], ",", 
       RowBox[{"253", "\[Rule]", "536"}], ",", 
       RowBox[{"253", "\[Rule]", "536"}], ",", 
       RowBox[{"253", "\[Rule]", "254"}], ",", 
       RowBox[{"237", "\[Rule]", "614"}], ",", 
       RowBox[{"237", "\[Rule]", "614"}], ",", 
       RowBox[{"237", "\[Rule]", "520"}], ",", 
       RowBox[{"237", "\[Rule]", "520"}], ",", 
       RowBox[{"237", "\[Rule]", "238"}], ",", 
       RowBox[{"885", "\[Rule]", "604"}], ",", 
       RowBox[{"885", "\[Rule]", "604"}], ",", 
       RowBox[{"885", "\[Rule]", "1262"}], ",", 
       RowBox[{"885", "\[Rule]", "1262"}], ",", 
       RowBox[{"885", "\[Rule]", "510"}], ",", 
       RowBox[{"885", "\[Rule]", "510"}], ",", 
       RowBox[{"885", "\[Rule]", "1168"}], ",", 
       RowBox[{"885", "\[Rule]", "1168"}], ",", 
       RowBox[{"885", "\[Rule]", "886"}], ",", 
       RowBox[{"911", "\[Rule]", "630"}], ",", 
       RowBox[{"911", "\[Rule]", "630"}], ",", 
       RowBox[{"911", "\[Rule]", "1288"}], ",", 
       RowBox[{"911", "\[Rule]", "1288"}], ",", 
       RowBox[{"911", "\[Rule]", "536"}], ",", 
       RowBox[{"911", "\[Rule]", "536"}], ",", 
       RowBox[{"911", "\[Rule]", "1194"}], ",", 
       RowBox[{"911", "\[Rule]", "1194"}], ",", 
       RowBox[{"911", "\[Rule]", "912"}], ",", 
       RowBox[{"895", "\[Rule]", "614"}], ",", 
       RowBox[{"895", "\[Rule]", "614"}], ",", 
       RowBox[{"895", "\[Rule]", "1272"}], ",", 
       RowBox[{"895", "\[Rule]", "1272"}], ",", 
       RowBox[{"895", "\[Rule]", "520"}], ",", 
       RowBox[{"895", "\[Rule]", "520"}], ",", 
       RowBox[{"895", "\[Rule]", "1178"}], ",", 
       RowBox[{"895", "\[Rule]", "1178"}], ",", 
       RowBox[{"895", "\[Rule]", "896"}], ",", 
       RowBox[{"133", "\[Rule]", "510"}], ",", 
       RowBox[{"133", "\[Rule]", "416"}], ",", 
       RowBox[{"133", "\[Rule]", "134"}], ",", 
       RowBox[{"143", "\[Rule]", "520"}], ",", 
       RowBox[{"143", "\[Rule]", "426"}], ",", 
       RowBox[{"143", "\[Rule]", "144"}], ",", 
       RowBox[{"791", "\[Rule]", "510"}], ",", 
       RowBox[{"791", "\[Rule]", "1168"}], ",", 
       RowBox[{"791", "\[Rule]", "1168"}], ",", 
       RowBox[{"791", "\[Rule]", "416"}], ",", 
       RowBox[{"791", "\[Rule]", "1074"}], ",", 
       RowBox[{"791", "\[Rule]", "1074"}], ",", 
       RowBox[{"791", "\[Rule]", "792"}], ",", 
       RowBox[{"801", "\[Rule]", "520"}], ",", 
       RowBox[{"801", "\[Rule]", "1178"}], ",", 
       RowBox[{"801", "\[Rule]", "1178"}], ",", 
       RowBox[{"801", "\[Rule]", "426"}], ",", 
       RowBox[{"801", "\[Rule]", "1084"}], ",", 
       RowBox[{"801", "\[Rule]", "1084"}], ",", 
       RowBox[{"801", "\[Rule]", "802"}], ",", 
       RowBox[{"509", "\[Rule]", "228"}], ",", 
       RowBox[{"509", "\[Rule]", "228"}], ",", 
       RowBox[{"509", "\[Rule]", "886"}], ",", 
       RowBox[{"509", "\[Rule]", "886"}], ",", 
       RowBox[{"509", "\[Rule]", "134"}], ",", 
       RowBox[{"509", "\[Rule]", "792"}], ",", 
       RowBox[{"509", "\[Rule]", "510"}], ",", 
       RowBox[{"535", "\[Rule]", "254"}], ",", 
       RowBox[{"535", "\[Rule]", "254"}], ",", 
       RowBox[{"535", "\[Rule]", "912"}], ",", 
       RowBox[{"535", "\[Rule]", "912"}], ",", 
       RowBox[{"535", "\[Rule]", "160"}], ",", 
       RowBox[{"535", "\[Rule]", "818"}], ",", 
       RowBox[{"535", "\[Rule]", "536"}], ",", 
       RowBox[{"519", "\[Rule]", "238"}], ",", 
       RowBox[{"519", "\[Rule]", "238"}], ",", 
       RowBox[{"519", "\[Rule]", "896"}], ",", 
       RowBox[{"519", "\[Rule]", "896"}], ",", 
       RowBox[{"519", "\[Rule]", "144"}], ",", 
       RowBox[{"519", "\[Rule]", "802"}], ",", 
       RowBox[{"519", "\[Rule]", "520"}], ",", 
       RowBox[{"281", "\[Rule]", "658"}], ",", 
       RowBox[{"281", "\[Rule]", "658"}], ",", 
       RowBox[{"281", "\[Rule]", "564"}], ",", 
       RowBox[{"281", "\[Rule]", "564"}], ",", 
       RowBox[{"281", "\[Rule]", "282"}], ",", 
       RowBox[{"265", "\[Rule]", "642"}], ",", 
       RowBox[{"265", "\[Rule]", "642"}], ",", 
       RowBox[{"265", "\[Rule]", "548"}], ",", 
       RowBox[{"265", "\[Rule]", "548"}], ",", 
       RowBox[{"265", "\[Rule]", "266"}], ",", 
       RowBox[{"939", "\[Rule]", "658"}], ",", 
       RowBox[{"939", "\[Rule]", "658"}], ",", 
       RowBox[{"939", "\[Rule]", "1316"}], ",", 
       RowBox[{"939", "\[Rule]", "1316"}], ",", 
       RowBox[{"939", "\[Rule]", "564"}], ",", 
       RowBox[{"939", "\[Rule]", "564"}], ",", 
       RowBox[{"939", "\[Rule]", "1222"}], ",", 
       RowBox[{"939", "\[Rule]", "1222"}], ",", 
       RowBox[{"939", "\[Rule]", "940"}], ",", 
       RowBox[{"923", "\[Rule]", "642"}], ",", 
       RowBox[{"923", "\[Rule]", "642"}], ",", 
       RowBox[{"923", "\[Rule]", "1300"}], ",", 
       RowBox[{"923", "\[Rule]", "1300"}], ",", 
       RowBox[{"923", "\[Rule]", "548"}], ",", 
       RowBox[{"923", "\[Rule]", "548"}], ",", 
       RowBox[{"923", "\[Rule]", "1206"}], ",", 
       RowBox[{"923", "\[Rule]", "1206"}], ",", 
       RowBox[{"923", "\[Rule]", "924"}], ",", 
       RowBox[{"563", "\[Rule]", "282"}], ",", 
       RowBox[{"563", "\[Rule]", "282"}], ",", 
       RowBox[{"563", "\[Rule]", "940"}], ",", 
       RowBox[{"563", "\[Rule]", "940"}], ",", 
       RowBox[{"563", "\[Rule]", "188"}], ",", 
       RowBox[{"563", "\[Rule]", "846"}], ",", 
       RowBox[{"563", "\[Rule]", "564"}], ",", 
       RowBox[{"547", "\[Rule]", "266"}], ",", 
       RowBox[{"547", "\[Rule]", "266"}], ",", 
       RowBox[{"547", "\[Rule]", "924"}], ",", 
       RowBox[{"547", "\[Rule]", "924"}], ",", 
       RowBox[{"547", "\[Rule]", "172"}], ",", 
       RowBox[{"547", "\[Rule]", "830"}], ",", 
       RowBox[{"547", "\[Rule]", "548"}], ",", 
       RowBox[{"249", "\[Rule]", "626"}], ",", 
       RowBox[{"249", "\[Rule]", "626"}], ",", 
       RowBox[{"249", "\[Rule]", "532"}], ",", 
       RowBox[{"249", "\[Rule]", "532"}], ",", 
       RowBox[{"249", "\[Rule]", "250"}], ",", 
       RowBox[{"907", "\[Rule]", "626"}], ",", 
       RowBox[{"907", "\[Rule]", "626"}], ",", 
       RowBox[{"907", "\[Rule]", "1284"}], ",", 
       RowBox[{"907", "\[Rule]", "1284"}], ",", 
       RowBox[{"907", "\[Rule]", "532"}], ",", 
       RowBox[{"907", "\[Rule]", "532"}], ",", 
       RowBox[{"907", "\[Rule]", "1190"}], ",", 
       RowBox[{"907", "\[Rule]", "1190"}], ",", 
       RowBox[{"907", "\[Rule]", "908"}], ",", 
       RowBox[{"155", "\[Rule]", "532"}], ",", 
       RowBox[{"155", "\[Rule]", "438"}], ",", 
       RowBox[{"155", "\[Rule]", "156"}], ",", 
       RowBox[{"813", "\[Rule]", "532"}], ",", 
       RowBox[{"813", "\[Rule]", "1190"}], ",", 
       RowBox[{"813", "\[Rule]", "1190"}], ",", 
       RowBox[{"813", "\[Rule]", "438"}], ",", 
       RowBox[{"813", "\[Rule]", "1096"}], ",", 
       RowBox[{"813", "\[Rule]", "1096"}], ",", 
       RowBox[{"813", "\[Rule]", "814"}], ",", 
       RowBox[{"531", "\[Rule]", "250"}], ",", 
       RowBox[{"531", "\[Rule]", "250"}], ",", 
       RowBox[{"531", "\[Rule]", "908"}], ",", 
       RowBox[{"531", "\[Rule]", "908"}], ",", 
       RowBox[{"531", "\[Rule]", "156"}], ",", 
       RowBox[{"531", "\[Rule]", "814"}], ",", 
       RowBox[{"531", "\[Rule]", "532"}], ",", 
       RowBox[{"39", "\[Rule]", "416"}], ",", 
       RowBox[{"39", "\[Rule]", "416"}], ",", 
       RowBox[{"39", "\[Rule]", "40"}], ",", 
       RowBox[{"49", "\[Rule]", "426"}], ",", 
       RowBox[{"49", "\[Rule]", "426"}], ",", 
       RowBox[{"49", "\[Rule]", "50"}], ",", 
       RowBox[{"697", "\[Rule]", "416"}], ",", 
       RowBox[{"697", "\[Rule]", "416"}], ",", 
       RowBox[{"697", "\[Rule]", "1074"}], ",", 
       RowBox[{"697", "\[Rule]", "698"}], ",", 
       RowBox[{"707", "\[Rule]", "426"}], ",", 
       RowBox[{"707", "\[Rule]", "426"}], ",", 
       RowBox[{"707", "\[Rule]", "1084"}], ",", 
       RowBox[{"707", "\[Rule]", "708"}], ",", 
       RowBox[{"415", "\[Rule]", "134"}], ",", 
       RowBox[{"415", "\[Rule]", "792"}], ",", 
       RowBox[{"415", "\[Rule]", "40"}], ",", 
       RowBox[{"415", "\[Rule]", "40"}], ",", 
       RowBox[{"415", "\[Rule]", "698"}], ",", 
       RowBox[{"415", "\[Rule]", "698"}], ",", 
       RowBox[{"415", "\[Rule]", "416"}], ",", 
       RowBox[{"425", "\[Rule]", "144"}], ",", 
       RowBox[{"425", "\[Rule]", "802"}], ",", 
       RowBox[{"425", "\[Rule]", "50"}], ",", 
       RowBox[{"425", "\[Rule]", "50"}], ",", 
       RowBox[{"425", "\[Rule]", "708"}], ",", 
       RowBox[{"425", "\[Rule]", "708"}], ",", 
       RowBox[{"425", "\[Rule]", "426"}], ",", 
       RowBox[{"61", "\[Rule]", "438"}], ",", 
       RowBox[{"61", "\[Rule]", "438"}], ",", 
       RowBox[{"61", "\[Rule]", "62"}], ",", 
       RowBox[{"719", "\[Rule]", "438"}], ",", 
       RowBox[{"719", "\[Rule]", "438"}], ",", 
       RowBox[{"719", "\[Rule]", "1096"}], ",", 
       RowBox[{"719", "\[Rule]", "720"}], ",", 
       RowBox[{"437", "\[Rule]", "156"}], ",", 
       RowBox[{"437", "\[Rule]", "814"}], ",", 
       RowBox[{"437", "\[Rule]", "62"}], ",", 
       RowBox[{"437", "\[Rule]", "62"}], ",", 
       RowBox[{"437", "\[Rule]", "720"}], ",", 
       RowBox[{"437", "\[Rule]", "720"}], ",", 
       RowBox[{"437", "\[Rule]", "438"}], ",", 
       RowBox[{"277", "\[Rule]", "654"}], ",", 
       RowBox[{"277", "\[Rule]", "654"}], ",", 
       RowBox[{"277", "\[Rule]", "560"}], ",", 
       RowBox[{"277", "\[Rule]", "560"}], ",", 
       RowBox[{"277", "\[Rule]", "278"}], ",", 
       RowBox[{"935", "\[Rule]", "654"}], ",", 
       RowBox[{"935", "\[Rule]", "654"}], ",", 
       RowBox[{"935", "\[Rule]", "1312"}], ",", 
       RowBox[{"935", "\[Rule]", "1312"}], ",", 
       RowBox[{"935", "\[Rule]", "560"}], ",", 
       RowBox[{"935", "\[Rule]", "560"}], ",", 
       RowBox[{"935", "\[Rule]", "1218"}], ",", 
       RowBox[{"935", "\[Rule]", "1218"}], ",", 
       RowBox[{"935", "\[Rule]", "936"}], ",", 
       RowBox[{"559", "\[Rule]", "278"}], ",", 
       RowBox[{"559", "\[Rule]", "278"}], ",", 
       RowBox[{"559", "\[Rule]", "936"}], ",", 
       RowBox[{"559", "\[Rule]", "936"}], ",", 
       RowBox[{"559", "\[Rule]", "184"}], ",", 
       RowBox[{"559", "\[Rule]", "842"}], ",", 
       RowBox[{"559", "\[Rule]", "560"}], ",", 
       RowBox[{"261", "\[Rule]", "638"}], ",", 
       RowBox[{"261", "\[Rule]", "638"}], ",", 
       RowBox[{"261", "\[Rule]", "544"}], ",", 
       RowBox[{"261", "\[Rule]", "544"}], ",", 
       RowBox[{"261", "\[Rule]", "262"}], ",", 
       RowBox[{"919", "\[Rule]", "638"}], ",", 
       RowBox[{"919", "\[Rule]", "638"}], ",", 
       RowBox[{"919", "\[Rule]", "1296"}], ",", 
       RowBox[{"919", "\[Rule]", "1296"}], ",", 
       RowBox[{"919", "\[Rule]", "544"}], ",", 
       RowBox[{"919", "\[Rule]", "544"}], ",", 
       RowBox[{"919", "\[Rule]", "1202"}], ",", 
       RowBox[{"919", "\[Rule]", "1202"}], ",", 
       RowBox[{"919", "\[Rule]", "920"}], ",", 
       RowBox[{"167", "\[Rule]", "544"}], ",", 
       RowBox[{"167", "\[Rule]", "450"}], ",", 
       RowBox[{"167", "\[Rule]", "168"}], ",", 
       RowBox[{"825", "\[Rule]", "544"}], ",", 
       RowBox[{"825", "\[Rule]", "1202"}], ",", 
       RowBox[{"825", "\[Rule]", "1202"}], ",", 
       RowBox[{"825", "\[Rule]", "450"}], ",", 
       RowBox[{"825", "\[Rule]", "1108"}], ",", 
       RowBox[{"825", "\[Rule]", "1108"}], ",", 
       RowBox[{"825", "\[Rule]", "826"}], ",", 
       RowBox[{"543", "\[Rule]", "262"}], ",", 
       RowBox[{"543", "\[Rule]", "262"}], ",", 
       RowBox[{"543", "\[Rule]", "920"}], ",", 
       RowBox[{"543", "\[Rule]", "920"}], ",", 
       RowBox[{"543", "\[Rule]", "168"}], ",", 
       RowBox[{"543", "\[Rule]", "826"}], ",", 
       RowBox[{"543", "\[Rule]", "544"}], ",", 
       RowBox[{"73", "\[Rule]", "450"}], ",", 
       RowBox[{"73", "\[Rule]", "450"}], ",", 
       RowBox[{"73", "\[Rule]", "74"}], ",", 
       RowBox[{"731", "\[Rule]", "450"}], ",", 
       RowBox[{"731", "\[Rule]", "450"}], ",", 
       RowBox[{"731", "\[Rule]", "1108"}], ",", 
       RowBox[{"731", "\[Rule]", "732"}], ",", 
       RowBox[{"449", "\[Rule]", "168"}], ",", 
       RowBox[{"449", "\[Rule]", "826"}], ",", 
       RowBox[{"449", "\[Rule]", "74"}], ",", 
       RowBox[{"449", "\[Rule]", "74"}], ",", 
       RowBox[{"449", "\[Rule]", "732"}], ",", 
       RowBox[{"449", "\[Rule]", "732"}], ",", 
       RowBox[{"449", "\[Rule]", "450"}], ",", 
       RowBox[{"1543", "\[Rule]", "1262"}], ",", 
       RowBox[{"1543", "\[Rule]", "1262"}], ",", 
       RowBox[{"1543", "\[Rule]", "1920"}], ",", 
       RowBox[{"1543", "\[Rule]", "1920"}], ",", 
       RowBox[{"1543", "\[Rule]", "1168"}], ",", 
       RowBox[{"1543", "\[Rule]", "1168"}], ",", 
       RowBox[{"1543", "\[Rule]", "1826"}], ",", 
       RowBox[{"1543", "\[Rule]", "1826"}], ",", 
       RowBox[{"1543", "\[Rule]", "1544"}], ",", 
       RowBox[{"1569", "\[Rule]", "1288"}], ",", 
       RowBox[{"1569", "\[Rule]", "1288"}], ",", 
       RowBox[{"1569", "\[Rule]", "1946"}], ",", 
       RowBox[{"1569", "\[Rule]", "1946"}], ",", 
       RowBox[{"1569", "\[Rule]", "1194"}], ",", 
       RowBox[{"1569", "\[Rule]", "1194"}], ",", 
       RowBox[{"1569", "\[Rule]", "1852"}], ",", 
       RowBox[{"1569", "\[Rule]", "1852"}], ",", 
       RowBox[{"1569", "\[Rule]", "1570"}], ",", 
       RowBox[{"1553", "\[Rule]", "1272"}], ",", 
       RowBox[{"1553", "\[Rule]", "1272"}], ",", 
       RowBox[{"1553", "\[Rule]", "1930"}], ",", 
       RowBox[{"1553", "\[Rule]", "1930"}], ",", 
       RowBox[{"1553", "\[Rule]", "1178"}], ",", 
       RowBox[{"1553", "\[Rule]", "1178"}], ",", 
       RowBox[{"1553", "\[Rule]", "1836"}], ",", 
       RowBox[{"1553", "\[Rule]", "1836"}], ",", 
       RowBox[{"1553", "\[Rule]", "1554"}], ",", 
       RowBox[{"1449", "\[Rule]", "1168"}], ",", 
       RowBox[{"1449", "\[Rule]", "1168"}], ",", 
       RowBox[{"1449", "\[Rule]", "1826"}], ",", 
       RowBox[{"1449", "\[Rule]", "1826"}], ",", 
       RowBox[{"1449", "\[Rule]", "1074"}], ",", 
       RowBox[{"1449", "\[Rule]", "1074"}], ",", 
       RowBox[{"1449", "\[Rule]", "1732"}], ",", 
       RowBox[{"1449", "\[Rule]", "1732"}], ",", 
       RowBox[{"1449", "\[Rule]", "1450"}], ",", 
       RowBox[{"1475", "\[Rule]", "1194"}], ",", 
       RowBox[{"1475", "\[Rule]", "1194"}], ",", 
       RowBox[{"1475", "\[Rule]", "1852"}], ",", 
       RowBox[{"1475", "\[Rule]", "1852"}], ",", 
       RowBox[{"1475", "\[Rule]", "1100"}], ",", 
       RowBox[{"1475", "\[Rule]", "1100"}], ",", 
       RowBox[{"1475", "\[Rule]", "1758"}], ",", 
       RowBox[{"1475", "\[Rule]", "1758"}], ",", 
       RowBox[{"1475", "\[Rule]", "1476"}], ",", 
       RowBox[{"1459", "\[Rule]", "1178"}], ",", 
       RowBox[{"1459", "\[Rule]", "1178"}], ",", 
       RowBox[{"1459", "\[Rule]", "1836"}], ",", 
       RowBox[{"1459", "\[Rule]", "1836"}], ",", 
       RowBox[{"1459", "\[Rule]", "1084"}], ",", 
       RowBox[{"1459", "\[Rule]", "1084"}], ",", 
       RowBox[{"1459", "\[Rule]", "1742"}], ",", 
       RowBox[{"1459", "\[Rule]", "1742"}], ",", 
       RowBox[{"1459", "\[Rule]", "1460"}], ",", 
       RowBox[{"1167", "\[Rule]", "886"}], ",", 
       RowBox[{"1167", "\[Rule]", "886"}], ",", 
       RowBox[{"1167", "\[Rule]", "1544"}], ",", 
       RowBox[{"1167", "\[Rule]", "1544"}], ",", 
       RowBox[{"1167", "\[Rule]", "792"}], ",", 
       RowBox[{"1167", "\[Rule]", "792"}], ",", 
       RowBox[{"1167", "\[Rule]", "1450"}], ",", 
       RowBox[{"1167", "\[Rule]", "1450"}], ",", 
       RowBox[{"1167", "\[Rule]", "1168"}], ",", 
       RowBox[{"1193", "\[Rule]", "912"}], ",", 
       RowBox[{"1193", "\[Rule]", "912"}], ",", 
       RowBox[{"1193", "\[Rule]", "1570"}], ",", 
       RowBox[{"1193", "\[Rule]", "1570"}], ",", 
       RowBox[{"1193", "\[Rule]", "818"}], ",", 
       RowBox[{"1193", "\[Rule]", "818"}], ",", 
       RowBox[{"1193", "\[Rule]", "1476"}], ",", 
       RowBox[{"1193", "\[Rule]", "1476"}], ",", 
       RowBox[{"1193", "\[Rule]", "1194"}], ",", 
       RowBox[{"1177", "\[Rule]", "896"}], ",", 
       RowBox[{"1177", "\[Rule]", "896"}], ",", 
       RowBox[{"1177", "\[Rule]", "1554"}], ",", 
       RowBox[{"1177", "\[Rule]", "1554"}], ",", 
       RowBox[{"1177", "\[Rule]", "802"}], ",", 
       RowBox[{"1177", "\[Rule]", "802"}], ",", 
       RowBox[{"1177", "\[Rule]", "1460"}], ",", 
       RowBox[{"1177", "\[Rule]", "1460"}], ",", 
       RowBox[{"1177", "\[Rule]", "1178"}], ",", 
       RowBox[{"1597", "\[Rule]", "1316"}], ",", 
       RowBox[{"1597", "\[Rule]", "1316"}], ",", 
       RowBox[{"1597", "\[Rule]", "1974"}], ",", 
       RowBox[{"1597", "\[Rule]", "1974"}], ",", 
       RowBox[{"1597", "\[Rule]", "1222"}], ",", 
       RowBox[{"1597", "\[Rule]", "1222"}], ",", 
       RowBox[{"1597", "\[Rule]", "1880"}], ",", 
       RowBox[{"1597", "\[Rule]", "1880"}], ",", 
       RowBox[{"1597", "\[Rule]", "1598"}], ",", 
       RowBox[{"1581", "\[Rule]", "1300"}], ",", 
       RowBox[{"1581", "\[Rule]", "1300"}], ",", 
       RowBox[{"1581", "\[Rule]", "1958"}], ",", 
       RowBox[{"1581", "\[Rule]", "1958"}], ",", 
       RowBox[{"1581", "\[Rule]", "1206"}], ",", 
       RowBox[{"1581", "\[Rule]", "1206"}], ",", 
       RowBox[{"1581", "\[Rule]", "1864"}], ",", 
       RowBox[{"1581", "\[Rule]", "1864"}], ",", 
       RowBox[{"1581", "\[Rule]", "1582"}], ",", 
       RowBox[{"1503", "\[Rule]", "1222"}], ",", 
       RowBox[{"1503", "\[Rule]", "1222"}], ",", 
       RowBox[{"1503", "\[Rule]", "1880"}], ",", 
       RowBox[{"1503", "\[Rule]", "1880"}], ",", 
       RowBox[{"1503", "\[Rule]", "1128"}], ",", 
       RowBox[{"1503", "\[Rule]", "1128"}], ",", 
       RowBox[{"1503", "\[Rule]", "1786"}], ",", 
       RowBox[{"1503", "\[Rule]", "1786"}], ",", 
       RowBox[{"1503", "\[Rule]", "1504"}], ",", 
       RowBox[{"1487", "\[Rule]", "1206"}], ",", 
       RowBox[{"1487", "\[Rule]", "1206"}], ",", 
       RowBox[{"1487", "\[Rule]", "1864"}], ",", 
       RowBox[{"1487", "\[Rule]", "1864"}], ",", 
       RowBox[{"1487", "\[Rule]", "1112"}], ",", 
       RowBox[{"1487", "\[Rule]", "1112"}], ",", 
       RowBox[{"1487", "\[Rule]", "1770"}], ",", 
       RowBox[{"1487", "\[Rule]", "1770"}], ",", 
       RowBox[{"1487", "\[Rule]", "1488"}], ",", 
       RowBox[{"1221", "\[Rule]", "940"}], ",", 
       RowBox[{"1221", "\[Rule]", "940"}], ",", 
       RowBox[{"1221", "\[Rule]", "1598"}], ",", 
       RowBox[{"1221", "\[Rule]", "1598"}], ",", 
       RowBox[{"1221", "\[Rule]", "846"}], ",", 
       RowBox[{"1221", "\[Rule]", "846"}], ",", 
       RowBox[{"1221", "\[Rule]", "1504"}], ",", 
       RowBox[{"1221", "\[Rule]", "1504"}], ",", 
       RowBox[{"1221", "\[Rule]", "1222"}], ",", 
       RowBox[{"1205", "\[Rule]", "924"}], ",", 
       RowBox[{"1205", "\[Rule]", "924"}], ",", 
       RowBox[{"1205", "\[Rule]", "1582"}], ",", 
       RowBox[{"1205", "\[Rule]", "1582"}], ",", 
       RowBox[{"1205", "\[Rule]", "830"}], ",", 
       RowBox[{"1205", "\[Rule]", "830"}], ",", 
       RowBox[{"1205", "\[Rule]", "1488"}], ",", 
       RowBox[{"1205", "\[Rule]", "1488"}], ",", 
       RowBox[{"1205", "\[Rule]", "1206"}], ",", 
       RowBox[{"1565", "\[Rule]", "1284"}], ",", 
       RowBox[{"1565", "\[Rule]", "1284"}], ",", 
       RowBox[{"1565", "\[Rule]", "1942"}], ",", 
       RowBox[{"1565", "\[Rule]", "1942"}], ",", 
       RowBox[{"1565", "\[Rule]", "1190"}], ",", 
       RowBox[{"1565", "\[Rule]", "1190"}], ",", 
       RowBox[{"1565", "\[Rule]", "1848"}], ",", 
       RowBox[{"1565", "\[Rule]", "1848"}], ",", 
       RowBox[{"1565", "\[Rule]", "1566"}], ",", 
       RowBox[{"1471", "\[Rule]", "1190"}], ",", 
       RowBox[{"1471", "\[Rule]", "1190"}], ",", 
       RowBox[{"1471", "\[Rule]", "1848"}], ",", 
       RowBox[{"1471", "\[Rule]", "1848"}], ",", 
       RowBox[{"1471", "\[Rule]", "1096"}], ",", 
       RowBox[{"1471", "\[Rule]", "1096"}], ",", 
       RowBox[{"1471", "\[Rule]", "1754"}], ",", 
       RowBox[{"1471", "\[Rule]", "1754"}], ",", 
       RowBox[{"1471", "\[Rule]", "1472"}], ",", 
       RowBox[{"1189", "\[Rule]", "908"}], ",", 
       RowBox[{"1189", "\[Rule]", "908"}], ",", 
       RowBox[{"1189", "\[Rule]", "1566"}], ",", 
       RowBox[{"1189", "\[Rule]", "1566"}], ",", 
       RowBox[{"1189", "\[Rule]", "814"}], ",", 
       RowBox[{"1189", "\[Rule]", "814"}], ",", 
       RowBox[{"1189", "\[Rule]", "1472"}], ",", 
       RowBox[{"1189", "\[Rule]", "1472"}], ",", 
       RowBox[{"1189", "\[Rule]", "1190"}], ",", 
       RowBox[{"1355", "\[Rule]", "1074"}], ",", 
       RowBox[{"1355", "\[Rule]", "1732"}], ",", 
       RowBox[{"1355", "\[Rule]", "1732"}], ",", 
       RowBox[{"1355", "\[Rule]", "1356"}], ",", 
       RowBox[{"1381", "\[Rule]", "1100"}], ",", 
       RowBox[{"1381", "\[Rule]", "1758"}], ",", 
       RowBox[{"1381", "\[Rule]", "1758"}], ",", 
       RowBox[{"1381", "\[Rule]", "1382"}], ",", 
       RowBox[{"1365", "\[Rule]", "1084"}], ",", 
       RowBox[{"1365", "\[Rule]", "1742"}], ",", 
       RowBox[{"1365", "\[Rule]", "1742"}], ",", 
       RowBox[{"1365", "\[Rule]", "1366"}], ",", 
       RowBox[{"1073", "\[Rule]", "792"}], ",", 
       RowBox[{"1073", "\[Rule]", "792"}], ",", 
       RowBox[{"1073", "\[Rule]", "1450"}], ",", 
       RowBox[{"1073", "\[Rule]", "1450"}], ",", 
       RowBox[{"1073", "\[Rule]", "698"}], ",", 
       RowBox[{"1073", "\[Rule]", "1356"}], ",", 
       RowBox[{"1073", "\[Rule]", "1074"}], ",", 
       RowBox[{"1099", "\[Rule]", "818"}], ",", 
       RowBox[{"1099", "\[Rule]", "818"}], ",", 
       RowBox[{"1099", "\[Rule]", "1476"}], ",", 
       RowBox[{"1099", "\[Rule]", "1476"}], ",", 
       RowBox[{"1099", "\[Rule]", "724"}], ",", 
       RowBox[{"1099", "\[Rule]", "1382"}], ",", 
       RowBox[{"1099", "\[Rule]", "1100"}], ",", 
       RowBox[{"1083", "\[Rule]", "802"}], ",", 
       RowBox[{"1083", "\[Rule]", "802"}], ",", 
       RowBox[{"1083", "\[Rule]", "1460"}], ",", 
       RowBox[{"1083", "\[Rule]", "1460"}], ",", 
       RowBox[{"1083", "\[Rule]", "708"}], ",", 
       RowBox[{"1083", "\[Rule]", "1366"}], ",", 
       RowBox[{"1083", "\[Rule]", "1084"}], ",", 
       RowBox[{"1409", "\[Rule]", "1128"}], ",", 
       RowBox[{"1409", "\[Rule]", "1786"}], ",", 
       RowBox[{"1409", "\[Rule]", "1786"}], ",", 
       RowBox[{"1409", "\[Rule]", "1410"}], ",", 
       RowBox[{"1393", "\[Rule]", "1112"}], ",", 
       RowBox[{"1393", "\[Rule]", "1770"}], ",", 
       RowBox[{"1393", "\[Rule]", "1770"}], ",", 
       RowBox[{"1393", "\[Rule]", "1394"}], ",", 
       RowBox[{"1127", "\[Rule]", "846"}], ",", 
       RowBox[{"1127", "\[Rule]", "846"}], ",", 
       RowBox[{"1127", "\[Rule]", "1504"}], ",", 
       RowBox[{"1127", "\[Rule]", "1504"}], ",", 
       RowBox[{"1127", "\[Rule]", "752"}], ",", 
       RowBox[{"1127", "\[Rule]", "1410"}], ",", 
       RowBox[{"1127", "\[Rule]", "1128"}], ",", 
       RowBox[{"1111", "\[Rule]", "830"}], ",", 
       RowBox[{"1111", "\[Rule]", "830"}], ",", 
       RowBox[{"1111", "\[Rule]", "1488"}], ",", 
       RowBox[{"1111", "\[Rule]", "1488"}], ",", 
       RowBox[{"1111", "\[Rule]", "736"}], ",", 
       RowBox[{"1111", "\[Rule]", "1394"}], ",", 
       RowBox[{"1111", "\[Rule]", "1112"}], ",", 
       RowBox[{"1377", "\[Rule]", "1096"}], ",", 
       RowBox[{"1377", "\[Rule]", "1754"}], ",", 
       RowBox[{"1377", "\[Rule]", "1754"}], ",", 
       RowBox[{"1377", "\[Rule]", "1378"}], ",", 
       RowBox[{"1095", "\[Rule]", "814"}], ",", 
       RowBox[{"1095", "\[Rule]", "814"}], ",", 
       RowBox[{"1095", "\[Rule]", "1472"}], ",", 
       RowBox[{"1095", "\[Rule]", "1472"}], ",", 
       RowBox[{"1095", "\[Rule]", "720"}], ",", 
       RowBox[{"1095", "\[Rule]", "1378"}], ",", 
       RowBox[{"1095", "\[Rule]", "1096"}], ",", 
       RowBox[{"1593", "\[Rule]", "1312"}], ",", 
       RowBox[{"1593", "\[Rule]", "1312"}], ",", 
       RowBox[{"1593", "\[Rule]", "1970"}], ",", 
       RowBox[{"1593", "\[Rule]", "1970"}], ",", 
       RowBox[{"1593", "\[Rule]", "1218"}], ",", 
       RowBox[{"1593", "\[Rule]", "1218"}], ",", 
       RowBox[{"1593", "\[Rule]", "1876"}], ",", 
       RowBox[{"1593", "\[Rule]", "1876"}], ",", 
       RowBox[{"1593", "\[Rule]", "1594"}], ",", 
       RowBox[{"1499", "\[Rule]", "1218"}], ",", 
       RowBox[{"1499", "\[Rule]", "1218"}], ",", 
       RowBox[{"1499", "\[Rule]", "1876"}], ",", 
       RowBox[{"1499", "\[Rule]", "1876"}], ",", 
       RowBox[{"1499", "\[Rule]", "1124"}], ",", 
       RowBox[{"1499", "\[Rule]", "1124"}], ",", 
       RowBox[{"1499", "\[Rule]", "1782"}], ",", 
       RowBox[{"1499", "\[Rule]", "1782"}], ",", 
       RowBox[{"1499", "\[Rule]", "1500"}], ",", 
       RowBox[{"1217", "\[Rule]", "936"}], ",", 
       RowBox[{"1217", "\[Rule]", "936"}], ",", 
       RowBox[{"1217", "\[Rule]", "1594"}], ",", 
       RowBox[{"1217", "\[Rule]", "1594"}], ",", 
       RowBox[{"1217", "\[Rule]", "842"}], ",", 
       RowBox[{"1217", "\[Rule]", "842"}], ",", 
       RowBox[{"1217", "\[Rule]", "1500"}], ",", 
       RowBox[{"1217", "\[Rule]", "1500"}], ",", 
       RowBox[{"1217", "\[Rule]", "1218"}], ",", 
       RowBox[{"1405", "\[Rule]", "1124"}], ",", 
       RowBox[{"1405", "\[Rule]", "1782"}], ",", 
       RowBox[{"1405", "\[Rule]", "1782"}], ",", 
       RowBox[{"1405", "\[Rule]", "1406"}], ",", 
       RowBox[{"1123", "\[Rule]", "842"}], ",", 
       RowBox[{"1123", "\[Rule]", "842"}], ",", 
       RowBox[{"1123", "\[Rule]", "1500"}], ",", 
       RowBox[{"1123", "\[Rule]", "1500"}], ",", 
       RowBox[{"1123", "\[Rule]", "748"}], ",", 
       RowBox[{"1123", "\[Rule]", "1406"}], ",", 
       RowBox[{"1123", "\[Rule]", "1124"}], ",", 
       RowBox[{"1577", "\[Rule]", "1296"}], ",", 
       RowBox[{"1577", "\[Rule]", "1296"}], ",", 
       RowBox[{"1577", "\[Rule]", "1954"}], ",", 
       RowBox[{"1577", "\[Rule]", "1954"}], ",", 
       RowBox[{"1577", "\[Rule]", "1202"}], ",", 
       RowBox[{"1577", "\[Rule]", "1202"}], ",", 
       RowBox[{"1577", "\[Rule]", "1860"}], ",", 
       RowBox[{"1577", "\[Rule]", "1860"}], ",", 
       RowBox[{"1577", "\[Rule]", "1578"}], ",", 
       RowBox[{"1483", "\[Rule]", "1202"}], ",", 
       RowBox[{"1483", "\[Rule]", "1202"}], ",", 
       RowBox[{"1483", "\[Rule]", "1860"}], ",", 
       RowBox[{"1483", "\[Rule]", "1860"}], ",", 
       RowBox[{"1483", "\[Rule]", "1108"}], ",", 
       RowBox[{"1483", "\[Rule]", "1108"}], ",", 
       RowBox[{"1483", "\[Rule]", "1766"}], ",", 
       RowBox[{"1483", "\[Rule]", "1766"}], ",", 
       RowBox[{"1483", "\[Rule]", "1484"}], ",", 
       RowBox[{"1201", "\[Rule]", "920"}], ",", 
       RowBox[{"1201", "\[Rule]", "920"}], ",", 
       RowBox[{"1201", "\[Rule]", "1578"}], ",", 
       RowBox[{"1201", "\[Rule]", "1578"}], ",", 
       RowBox[{"1201", "\[Rule]", "826"}], ",", 
       RowBox[{"1201", "\[Rule]", "826"}], ",", 
       RowBox[{"1201", "\[Rule]", "1484"}], ",", 
       RowBox[{"1201", "\[Rule]", "1484"}], ",", 
       RowBox[{"1201", "\[Rule]", "1202"}], ",", 
       RowBox[{"1389", "\[Rule]", "1108"}], ",", 
       RowBox[{"1389", "\[Rule]", "1766"}], ",", 
       RowBox[{"1389", "\[Rule]", "1766"}], ",", 
       RowBox[{"1389", "\[Rule]", "1390"}], ",", 
       RowBox[{"1107", "\[Rule]", "826"}], ",", 
       RowBox[{"1107", "\[Rule]", "826"}], ",", 
       RowBox[{"1107", "\[Rule]", "1484"}], ",", 
       RowBox[{"1107", "\[Rule]", "1484"}], ",", 
       RowBox[{"1107", "\[Rule]", "732"}], ",", 
       RowBox[{"1107", "\[Rule]", "1390"}], ",", 
       RowBox[{"1107", "\[Rule]", "1108"}], ",", 
       RowBox[{"273", "\[Rule]", "650"}], ",", 
       RowBox[{"273", "\[Rule]", "650"}], ",", 
       RowBox[{"273", "\[Rule]", "556"}], ",", 
       RowBox[{"273", "\[Rule]", "556"}], ",", 
       RowBox[{"273", "\[Rule]", "274"}], ",", 
       RowBox[{"931", "\[Rule]", "650"}], ",", 
       RowBox[{"931", "\[Rule]", "650"}], ",", 
       RowBox[{"931", "\[Rule]", "1308"}], ",", 
       RowBox[{"931", "\[Rule]", "1308"}], ",", 
       RowBox[{"931", "\[Rule]", "556"}], ",", 
       RowBox[{"931", "\[Rule]", "556"}], ",", 
       RowBox[{"931", "\[Rule]", "1214"}], ",", 
       RowBox[{"931", "\[Rule]", "1214"}], ",", 
       RowBox[{"931", "\[Rule]", "932"}], ",", 
       RowBox[{"179", "\[Rule]", "556"}], ",", 
       RowBox[{"179", "\[Rule]", "462"}], ",", 
       RowBox[{"179", "\[Rule]", "180"}], ",", 
       RowBox[{"837", "\[Rule]", "556"}], ",", 
       RowBox[{"837", "\[Rule]", "1214"}], ",", 
       RowBox[{"837", "\[Rule]", "1214"}], ",", 
       RowBox[{"837", "\[Rule]", "462"}], ",", 
       RowBox[{"837", "\[Rule]", "1120"}], ",", 
       RowBox[{"837", "\[Rule]", "1120"}], ",", 
       RowBox[{"837", "\[Rule]", "838"}], ",", 
       RowBox[{"555", "\[Rule]", "274"}], ",", 
       RowBox[{"555", "\[Rule]", "274"}], ",", 
       RowBox[{"555", "\[Rule]", "932"}], ",", 
       RowBox[{"555", "\[Rule]", "932"}], ",", 
       RowBox[{"555", "\[Rule]", "180"}], ",", 
       RowBox[{"555", "\[Rule]", "838"}], ",", 
       RowBox[{"555", "\[Rule]", "556"}], ",", 
       RowBox[{"85", "\[Rule]", "462"}], ",", 
       RowBox[{"85", "\[Rule]", "462"}], ",", 
       RowBox[{"85", "\[Rule]", "86"}], ",", 
       RowBox[{"743", "\[Rule]", "462"}], ",", 
       RowBox[{"743", "\[Rule]", "462"}], ",", 
       RowBox[{"743", "\[Rule]", "1120"}], ",", 
       RowBox[{"743", "\[Rule]", "744"}], ",", 
       RowBox[{"461", "\[Rule]", "180"}], ",", 
       RowBox[{"461", "\[Rule]", "838"}], ",", 
       RowBox[{"461", "\[Rule]", "86"}], ",", 
       RowBox[{"461", "\[Rule]", "86"}], ",", 
       RowBox[{"461", "\[Rule]", "744"}], ",", 
       RowBox[{"461", "\[Rule]", "744"}], ",", 
       RowBox[{"461", "\[Rule]", "462"}], ",", 
       RowBox[{"1589", "\[Rule]", "1308"}], ",", 
       RowBox[{"1589", "\[Rule]", "1308"}], ",", 
       RowBox[{"1589", "\[Rule]", "1966"}], ",", 
       RowBox[{"1589", "\[Rule]", "1966"}], ",", 
       RowBox[{"1589", "\[Rule]", "1214"}], ",", 
       RowBox[{"1589", "\[Rule]", "1214"}], ",", 
       RowBox[{"1589", "\[Rule]", "1872"}], ",", 
       RowBox[{"1589", "\[Rule]", "1872"}], ",", 
       RowBox[{"1589", "\[Rule]", "1590"}], ",", 
       RowBox[{"1495", "\[Rule]", "1214"}], ",", 
       RowBox[{"1495", "\[Rule]", "1214"}], ",", 
       RowBox[{"1495", "\[Rule]", "1872"}], ",", 
       RowBox[{"1495", "\[Rule]", "1872"}], ",", 
       RowBox[{"1495", "\[Rule]", "1120"}], ",", 
       RowBox[{"1495", "\[Rule]", "1120"}], ",", 
       RowBox[{"1495", "\[Rule]", "1778"}], ",", 
       RowBox[{"1495", "\[Rule]", "1778"}], ",", 
       RowBox[{"1495", "\[Rule]", "1496"}], ",", 
       RowBox[{"1213", "\[Rule]", "932"}], ",", 
       RowBox[{"1213", "\[Rule]", "932"}], ",", 
       RowBox[{"1213", "\[Rule]", "1590"}], ",", 
       RowBox[{"1213", "\[Rule]", "1590"}], ",", 
       RowBox[{"1213", "\[Rule]", "838"}], ",", 
       RowBox[{"1213", "\[Rule]", "838"}], ",", 
       RowBox[{"1213", "\[Rule]", "1496"}], ",", 
       RowBox[{"1213", "\[Rule]", "1496"}], ",", 
       RowBox[{"1213", "\[Rule]", "1214"}], ",", 
       RowBox[{"1401", "\[Rule]", "1120"}], ",", 
       RowBox[{"1401", "\[Rule]", "1778"}], ",", 
       RowBox[{"1401", "\[Rule]", "1778"}], ",", 
       RowBox[{"1401", "\[Rule]", "1402"}], ",", 
       RowBox[{"1119", "\[Rule]", "838"}], ",", 
       RowBox[{"1119", "\[Rule]", "838"}], ",", 
       RowBox[{"1119", "\[Rule]", "1496"}], ",", 
       RowBox[{"1119", "\[Rule]", "1496"}], ",", 
       RowBox[{"1119", "\[Rule]", "744"}], ",", 
       RowBox[{"1119", "\[Rule]", "1402"}], ",", 
       RowBox[{"1119", "\[Rule]", "1120"}], ",", 
       RowBox[{"604", "\[Rule]", "589"}], ",", 
       RowBox[{"604", "\[Rule]", "615"}], ",", 
       RowBox[{"604", "\[Rule]", "601"}], ",", 
       RowBox[{"510", "\[Rule]", "495"}], ",", 
       RowBox[{"510", "\[Rule]", "521"}], ",", 
       RowBox[{"510", "\[Rule]", "507"}], ",", 
       RowBox[{"228", "\[Rule]", "213"}], ",", 
       RowBox[{"228", "\[Rule]", "239"}], ",", 
       RowBox[{"228", "\[Rule]", "225"}], ",", 
       RowBox[{"630", "\[Rule]", "615"}], ",", 
       RowBox[{"630", "\[Rule]", "643"}], ",", 
       RowBox[{"630", "\[Rule]", "627"}], ",", 
       RowBox[{"254", "\[Rule]", "239"}], ",", 
       RowBox[{"254", "\[Rule]", "267"}], ",", 
       RowBox[{"254", "\[Rule]", "251"}], ",", 
       RowBox[{"614", "\[Rule]", "601"}], ",", 
       RowBox[{"614", "\[Rule]", "627"}], ",", 
       RowBox[{"614", "\[Rule]", "615"}], ",", 
       RowBox[{"614", "\[Rule]", "611"}], ",", 
       RowBox[{"520", "\[Rule]", "507"}], ",", 
       RowBox[{"520", "\[Rule]", "533"}], ",", 
       RowBox[{"520", "\[Rule]", "521"}], ",", 
       RowBox[{"520", "\[Rule]", "517"}], ",", 
       RowBox[{"238", "\[Rule]", "225"}], ",", 
       RowBox[{"238", "\[Rule]", "251"}], ",", 
       RowBox[{"238", "\[Rule]", "239"}], ",", 
       RowBox[{"238", "\[Rule]", "235"}], ",", 
       RowBox[{"1262", "\[Rule]", "1247"}], ",", 
       RowBox[{"1262", "\[Rule]", "1273"}], ",", 
       RowBox[{"1262", "\[Rule]", "1259"}], ",", 
       RowBox[{"1168", "\[Rule]", "1153"}], ",", 
       RowBox[{"1168", "\[Rule]", "1179"}], ",", 
       RowBox[{"1168", "\[Rule]", "1165"}], ",", 
       RowBox[{"886", "\[Rule]", "871"}], ",", 
       RowBox[{"886", "\[Rule]", "897"}], ",", 
       RowBox[{"886", "\[Rule]", "883"}], ",", 
       RowBox[{"1288", "\[Rule]", "1273"}], ",", 
       RowBox[{"1288", "\[Rule]", "1301"}], ",", 
       RowBox[{"1288", "\[Rule]", "1285"}], ",", 
       RowBox[{"912", "\[Rule]", "897"}], ",", 
       RowBox[{"912", "\[Rule]", "925"}], ",", 
       RowBox[{"912", "\[Rule]", "909"}], ",", 
       RowBox[{"1272", "\[Rule]", "1259"}], ",", 
       RowBox[{"1272", "\[Rule]", "1285"}], ",", 
       RowBox[{"1272", "\[Rule]", "1273"}], ",", 
       RowBox[{"1272", "\[Rule]", "1269"}], ",", 
       RowBox[{"1178", "\[Rule]", "1165"}], ",", 
       RowBox[{"1178", "\[Rule]", "1191"}], ",", 
       RowBox[{"1178", "\[Rule]", "1179"}], ",", 
       RowBox[{"1178", "\[Rule]", "1175"}], ",", 
       RowBox[{"896", "\[Rule]", "883"}], ",", 
       RowBox[{"896", "\[Rule]", "909"}], ",", 
       RowBox[{"896", "\[Rule]", "897"}], ",", 
       RowBox[{"896", "\[Rule]", "893"}], ",", 
       RowBox[{"416", "\[Rule]", "401"}], ",", 
       RowBox[{"416", "\[Rule]", "427"}], ",", 
       RowBox[{"416", "\[Rule]", "413"}], ",", 
       RowBox[{"134", "\[Rule]", "119"}], ",", 
       RowBox[{"134", "\[Rule]", "145"}], ",", 
       RowBox[{"134", "\[Rule]", "131"}], ",", 
       RowBox[{"426", "\[Rule]", "413"}], ",", 
       RowBox[{"426", "\[Rule]", "439"}], ",", 
       RowBox[{"426", "\[Rule]", "427"}], ",", 
       RowBox[{"426", "\[Rule]", "423"}], ",", 
       RowBox[{"144", "\[Rule]", "131"}], ",", 
       RowBox[{"144", "\[Rule]", "157"}], ",", 
       RowBox[{"144", "\[Rule]", "145"}], ",", 
       RowBox[{"144", "\[Rule]", "141"}], ",", 
       RowBox[{"1074", "\[Rule]", "1059"}], ",", 
       RowBox[{"1074", "\[Rule]", "1085"}], ",", 
       RowBox[{"1074", "\[Rule]", "1071"}], ",", 
       RowBox[{"792", "\[Rule]", "777"}], ",", 
       RowBox[{"792", "\[Rule]", "803"}], ",", 
       RowBox[{"792", "\[Rule]", "789"}], ",", 
       RowBox[{"1084", "\[Rule]", "1071"}], ",", 
       RowBox[{"1084", "\[Rule]", "1097"}], ",", 
       RowBox[{"1084", "\[Rule]", "1085"}], ",", 
       RowBox[{"1084", "\[Rule]", "1081"}], ",", 
       RowBox[{"802", "\[Rule]", "789"}], ",", 
       RowBox[{"802", "\[Rule]", "815"}], ",", 
       RowBox[{"802", "\[Rule]", "803"}], ",", 
       RowBox[{"802", "\[Rule]", "799"}], ",", 
       RowBox[{"658", "\[Rule]", "643"}], ",", 
       RowBox[{"658", "\[Rule]", "655"}], ",", 
       RowBox[{"282", "\[Rule]", "267"}], ",", 
       RowBox[{"282", "\[Rule]", "279"}], ",", 
       RowBox[{"642", "\[Rule]", "627"}], ",", 
       RowBox[{"642", "\[Rule]", "655"}], ",", 
       RowBox[{"642", "\[Rule]", "643"}], ",", 
       RowBox[{"642", "\[Rule]", "639"}], ",", 
       RowBox[{"266", "\[Rule]", "251"}], ",", 
       RowBox[{"266", "\[Rule]", "279"}], ",", 
       RowBox[{"266", "\[Rule]", "267"}], ",", 
       RowBox[{"266", "\[Rule]", "263"}], ",", 
       RowBox[{"1316", "\[Rule]", "1301"}], ",", 
       RowBox[{"1316", "\[Rule]", "1313"}], ",", 
       RowBox[{"940", "\[Rule]", "925"}], ",", 
       RowBox[{"940", "\[Rule]", "937"}], ",", 
       RowBox[{"1300", "\[Rule]", "1285"}], ",", 
       RowBox[{"1300", "\[Rule]", "1313"}], ",", 
       RowBox[{"1300", "\[Rule]", "1301"}], ",", 
       RowBox[{"1300", "\[Rule]", "1297"}], ",", 
       RowBox[{"924", "\[Rule]", "909"}], ",", 
       RowBox[{"924", "\[Rule]", "937"}], ",", 
       RowBox[{"924", "\[Rule]", "925"}], ",", 
       RowBox[{"924", "\[Rule]", "921"}], ",", 
       RowBox[{"626", "\[Rule]", "611"}], ",", 
       RowBox[{"626", "\[Rule]", "639"}], ",", 
       RowBox[{"626", "\[Rule]", "627"}], ",", 
       RowBox[{"626", "\[Rule]", "623"}], ",", 
       RowBox[{"532", "\[Rule]", "517"}], ",", 
       RowBox[{"532", "\[Rule]", "545"}], ",", 
       RowBox[{"532", "\[Rule]", "533"}], ",", 
       RowBox[{"532", "\[Rule]", "529"}], ",", 
       RowBox[{"250", "\[Rule]", "235"}], ",", 
       RowBox[{"250", "\[Rule]", "263"}], ",", 
       RowBox[{"250", "\[Rule]", "251"}], ",", 
       RowBox[{"250", "\[Rule]", "247"}], ",", 
       RowBox[{"1284", "\[Rule]", "1269"}], ",", 
       RowBox[{"1284", "\[Rule]", "1297"}], ",", 
       RowBox[{"1284", "\[Rule]", "1285"}], ",", 
       RowBox[{"1284", "\[Rule]", "1281"}], ",", 
       RowBox[{"1190", "\[Rule]", "1175"}], ",", 
       RowBox[{"1190", "\[Rule]", "1203"}], ",", 
       RowBox[{"1190", "\[Rule]", "1191"}], ",", 
       RowBox[{"1190", "\[Rule]", "1187"}], ",", 
       RowBox[{"908", "\[Rule]", "893"}], ",", 
       RowBox[{"908", "\[Rule]", "921"}], ",", 
       RowBox[{"908", "\[Rule]", "909"}], ",", 
       RowBox[{"908", "\[Rule]", "905"}], ",", 
       RowBox[{"438", "\[Rule]", "423"}], ",", 
       RowBox[{"438", "\[Rule]", "451"}], ",", 
       RowBox[{"438", "\[Rule]", "439"}], ",", 
       RowBox[{"438", "\[Rule]", "435"}], ",", 
       RowBox[{"156", "\[Rule]", "141"}], ",", 
       RowBox[{"156", "\[Rule]", "169"}], ",", 
       RowBox[{"156", "\[Rule]", "157"}], ",", 
       RowBox[{"156", "\[Rule]", "153"}], ",", 
       RowBox[{"1096", "\[Rule]", "1081"}], ",", 
       RowBox[{"1096", "\[Rule]", "1109"}], ",", 
       RowBox[{"1096", "\[Rule]", "1097"}], ",", 
       RowBox[{"1096", "\[Rule]", "1093"}], ",", 
       RowBox[{"814", "\[Rule]", "799"}], ",", 
       RowBox[{"814", "\[Rule]", "827"}], ",", 
       RowBox[{"814", "\[Rule]", "815"}], ",", 
       RowBox[{"814", "\[Rule]", "811"}], ",", 
       RowBox[{"40", "\[Rule]", "25"}], ",", 
       RowBox[{"40", "\[Rule]", "51"}], ",", 
       RowBox[{"40", "\[Rule]", "37"}], ",", 
       RowBox[{"50", "\[Rule]", "37"}], ",", 
       RowBox[{"50", "\[Rule]", "63"}], ",", 
       RowBox[{"50", "\[Rule]", "51"}], ",", 
       RowBox[{"50", "\[Rule]", "47"}], ",", 
       RowBox[{"698", "\[Rule]", "683"}], ",", 
       RowBox[{"698", "\[Rule]", "709"}], ",", 
       RowBox[{"698", "\[Rule]", "695"}], ",", 
       RowBox[{"708", "\[Rule]", "695"}], ",", 
       RowBox[{"708", "\[Rule]", "721"}], ",", 
       RowBox[{"708", "\[Rule]", "709"}], ",", 
       RowBox[{"708", "\[Rule]", "705"}], ",", 
       RowBox[{"62", "\[Rule]", "47"}], ",", 
       RowBox[{"62", "\[Rule]", "75"}], ",", 
       RowBox[{"62", "\[Rule]", "63"}], ",", 
       RowBox[{"62", "\[Rule]", "59"}], ",", 
       RowBox[{"720", "\[Rule]", "705"}], ",", 
       RowBox[{"720", "\[Rule]", "733"}], ",", 
       RowBox[{"720", "\[Rule]", "721"}], ",", 
       RowBox[{"720", "\[Rule]", "717"}], ",", 
       RowBox[{"654", "\[Rule]", "639"}], ",", 
       RowBox[{"654", "\[Rule]", "655"}], ",", 
       RowBox[{"654", "\[Rule]", "651"}], ",", 
       RowBox[{"278", "\[Rule]", "263"}], ",", 
       RowBox[{"278", "\[Rule]", "279"}], ",", 
       RowBox[{"278", "\[Rule]", "275"}], ",", 
       RowBox[{"1312", "\[Rule]", "1297"}], ",", 
       RowBox[{"1312", "\[Rule]", "1313"}], ",", 
       RowBox[{"1312", "\[Rule]", "1309"}], ",", 
       RowBox[{"936", "\[Rule]", "921"}], ",", 
       RowBox[{"936", "\[Rule]", "937"}], ",", 
       RowBox[{"936", "\[Rule]", "933"}], ",", 
       RowBox[{"638", "\[Rule]", "623"}], ",", 
       RowBox[{"638", "\[Rule]", "651"}], ",", 
       RowBox[{"638", "\[Rule]", "639"}], ",", 
       RowBox[{"638", "\[Rule]", "635"}], ",", 
       RowBox[{"544", "\[Rule]", "529"}], ",", 
       RowBox[{"544", "\[Rule]", "557"}], ",", 
       RowBox[{"544", "\[Rule]", "545"}], ",", 
       RowBox[{"544", "\[Rule]", "541"}], ",", 
       RowBox[{"262", "\[Rule]", "247"}], ",", 
       RowBox[{"262", "\[Rule]", "275"}], ",", 
       RowBox[{"262", "\[Rule]", "263"}], ",", 
       RowBox[{"262", "\[Rule]", "259"}], ",", 
       RowBox[{"1296", "\[Rule]", "1281"}], ",", 
       RowBox[{"1296", "\[Rule]", "1309"}], ",", 
       RowBox[{"1296", "\[Rule]", "1297"}], ",", 
       RowBox[{"1296", "\[Rule]", "1293"}], ",", 
       RowBox[{"1202", "\[Rule]", "1187"}], ",", 
       RowBox[{"1202", "\[Rule]", "1215"}], ",", 
       RowBox[{"1202", "\[Rule]", "1203"}], ",", 
       RowBox[{"1202", "\[Rule]", "1199"}], ",", 
       RowBox[{"920", "\[Rule]", "905"}], ",", 
       RowBox[{"920", "\[Rule]", "933"}], ",", 
       RowBox[{"920", "\[Rule]", "921"}], ",", 
       RowBox[{"920", "\[Rule]", "917"}], ",", 
       RowBox[{"450", "\[Rule]", "435"}], ",", 
       RowBox[{"450", "\[Rule]", "463"}], ",", 
       RowBox[{"450", "\[Rule]", "451"}], ",", 
       RowBox[{"450", "\[Rule]", "447"}], ",", 
       RowBox[{"168", "\[Rule]", "153"}], ",", 
       RowBox[{"168", "\[Rule]", "181"}], ",", 
       RowBox[{"168", "\[Rule]", "169"}], ",", 
       RowBox[{"168", "\[Rule]", "165"}], ",", 
       RowBox[{"1108", "\[Rule]", "1093"}], ",", 
       RowBox[{"1108", "\[Rule]", "1121"}], ",", 
       RowBox[{"1108", "\[Rule]", "1109"}], ",", 
       RowBox[{"1108", "\[Rule]", "1105"}], ",", 
       RowBox[{"826", "\[Rule]", "811"}], ",", 
       RowBox[{"826", "\[Rule]", "839"}], ",", 
       RowBox[{"826", "\[Rule]", "827"}], ",", 
       RowBox[{"826", "\[Rule]", "823"}], ",", 
       RowBox[{"74", "\[Rule]", "59"}], ",", 
       RowBox[{"74", "\[Rule]", "87"}], ",", 
       RowBox[{"74", "\[Rule]", "75"}], ",", 
       RowBox[{"74", "\[Rule]", "71"}], ",", 
       RowBox[{"732", "\[Rule]", "717"}], ",", 
       RowBox[{"732", "\[Rule]", "745"}], ",", 
       RowBox[{"732", "\[Rule]", "733"}], ",", 
       RowBox[{"732", "\[Rule]", "729"}], ",", 
       RowBox[{"1920", "\[Rule]", "1905"}], ",", 
       RowBox[{"1920", "\[Rule]", "1931"}], ",", 
       RowBox[{"1920", "\[Rule]", "1917"}], ",", 
       RowBox[{"1826", "\[Rule]", "1811"}], ",", 
       RowBox[{"1826", "\[Rule]", "1837"}], ",", 
       RowBox[{"1826", "\[Rule]", "1823"}], ",", 
       RowBox[{"1544", "\[Rule]", "1529"}], ",", 
       RowBox[{"1544", "\[Rule]", "1555"}], ",", 
       RowBox[{"1544", "\[Rule]", "1541"}], ",", 
       RowBox[{"1946", "\[Rule]", "1931"}], ",", 
       RowBox[{"1946", "\[Rule]", "1959"}], ",", 
       RowBox[{"1946", "\[Rule]", "1943"}], ",", 
       RowBox[{"1852", "\[Rule]", "1837"}], ",", 
       RowBox[{"1852", "\[Rule]", "1865"}], ",", 
       RowBox[{"1852", "\[Rule]", "1849"}], ",", 
       RowBox[{"1570", "\[Rule]", "1555"}], ",", 
       RowBox[{"1570", "\[Rule]", "1583"}], ",", 
       RowBox[{"1570", "\[Rule]", "1567"}], ",", 
       RowBox[{"1930", "\[Rule]", "1917"}], ",", 
       RowBox[{"1930", "\[Rule]", "1943"}], ",", 
       RowBox[{"1930", "\[Rule]", "1931"}], ",", 
       RowBox[{"1930", "\[Rule]", "1927"}], ",", 
       RowBox[{"1836", "\[Rule]", "1823"}], ",", 
       RowBox[{"1836", "\[Rule]", "1849"}], ",", 
       RowBox[{"1836", "\[Rule]", "1837"}], ",", 
       RowBox[{"1836", "\[Rule]", "1833"}], ",", 
       RowBox[{"1554", "\[Rule]", "1541"}], ",", 
       RowBox[{"1554", "\[Rule]", "1567"}], ",", 
       RowBox[{"1554", "\[Rule]", "1555"}], ",", 
       RowBox[{"1554", "\[Rule]", "1551"}], ",", 
       RowBox[{"1732", "\[Rule]", "1717"}], ",", 
       RowBox[{"1732", "\[Rule]", "1743"}], ",", 
       RowBox[{"1732", "\[Rule]", "1729"}], ",", 
       RowBox[{"1450", "\[Rule]", "1435"}], ",", 
       RowBox[{"1450", "\[Rule]", "1461"}], ",", 
       RowBox[{"1450", "\[Rule]", "1447"}], ",", 
       RowBox[{"1758", "\[Rule]", "1743"}], ",", 
       RowBox[{"1758", "\[Rule]", "1771"}], ",", 
       RowBox[{"1758", "\[Rule]", "1755"}], ",", 
       RowBox[{"1476", "\[Rule]", "1461"}], ",", 
       RowBox[{"1476", "\[Rule]", "1489"}], ",", 
       RowBox[{"1476", "\[Rule]", "1473"}], ",", 
       RowBox[{"1742", "\[Rule]", "1729"}], ",", 
       RowBox[{"1742", "\[Rule]", "1755"}], ",", 
       RowBox[{"1742", "\[Rule]", "1743"}], ",", 
       RowBox[{"1742", "\[Rule]", "1739"}], ",", 
       RowBox[{"1460", "\[Rule]", "1447"}], ",", 
       RowBox[{"1460", "\[Rule]", "1473"}], ",", 
       RowBox[{"1460", "\[Rule]", "1461"}], ",", 
       RowBox[{"1460", "\[Rule]", "1457"}], ",", 
       RowBox[{"1974", "\[Rule]", "1959"}], ",", 
       RowBox[{"1974", "\[Rule]", "1971"}], ",", 
       RowBox[{"1880", "\[Rule]", "1865"}], ",", 
       RowBox[{"1880", "\[Rule]", "1877"}], ",", 
       RowBox[{"1598", "\[Rule]", "1583"}], ",", 
       RowBox[{"1598", "\[Rule]", "1595"}], ",", 
       RowBox[{"1958", "\[Rule]", "1943"}], ",", 
       RowBox[{"1958", "\[Rule]", "1971"}], ",", 
       RowBox[{"1958", "\[Rule]", "1959"}], ",", 
       RowBox[{"1958", "\[Rule]", "1955"}], ",", 
       RowBox[{"1864", "\[Rule]", "1849"}], ",", 
       RowBox[{"1864", "\[Rule]", "1877"}], ",", 
       RowBox[{"1864", "\[Rule]", "1865"}], ",", 
       RowBox[{"1864", "\[Rule]", "1861"}], ",", 
       RowBox[{"1582", "\[Rule]", "1567"}], ",", 
       RowBox[{"1582", "\[Rule]", "1595"}], ",", 
       RowBox[{"1582", "\[Rule]", "1583"}], ",", 
       RowBox[{"1582", "\[Rule]", "1579"}], ",", 
       RowBox[{"1786", "\[Rule]", "1771"}], ",", 
       RowBox[{"1786", "\[Rule]", "1783"}], ",", 
       RowBox[{"1504", "\[Rule]", "1489"}], ",", 
       RowBox[{"1504", "\[Rule]", "1501"}], ",", 
       RowBox[{"1770", "\[Rule]", "1755"}], ",", 
       RowBox[{"1770", "\[Rule]", "1783"}], ",", 
       RowBox[{"1770", "\[Rule]", "1771"}], ",", 
       RowBox[{"1770", "\[Rule]", "1767"}], ",", 
       RowBox[{"1488", "\[Rule]", "1473"}], ",", 
       RowBox[{"1488", "\[Rule]", "1501"}], ",", 
       RowBox[{"1488", "\[Rule]", "1489"}], ",", 
       RowBox[{"1488", "\[Rule]", "1485"}], ",", 
       RowBox[{"1942", "\[Rule]", "1927"}], ",", 
       RowBox[{"1942", "\[Rule]", "1955"}], ",", 
       RowBox[{"1942", "\[Rule]", "1943"}], ",", 
       RowBox[{"1942", "\[Rule]", "1939"}], ",", 
       RowBox[{"1848", "\[Rule]", "1833"}], ",", 
       RowBox[{"1848", "\[Rule]", "1861"}], ",", 
       RowBox[{"1848", "\[Rule]", "1849"}], ",", 
       RowBox[{"1848", "\[Rule]", "1845"}], ",", 
       RowBox[{"1566", "\[Rule]", "1551"}], ",", 
       RowBox[{"1566", "\[Rule]", "1579"}], ",", 
       RowBox[{"1566", "\[Rule]", "1567"}], ",", 
       RowBox[{"1566", "\[Rule]", "1563"}], ",", 
       RowBox[{"1754", "\[Rule]", "1739"}], ",", 
       RowBox[{"1754", "\[Rule]", "1767"}], ",", 
       RowBox[{"1754", "\[Rule]", "1755"}], ",", 
       RowBox[{"1754", "\[Rule]", "1751"}], ",", 
       RowBox[{"1472", "\[Rule]", "1457"}], ",", 
       RowBox[{"1472", "\[Rule]", "1485"}], ",", 
       RowBox[{"1472", "\[Rule]", "1473"}], ",", 
       RowBox[{"1472", "\[Rule]", "1469"}], ",", 
       RowBox[{"1356", "\[Rule]", "1341"}], ",", 
       RowBox[{"1356", "\[Rule]", "1367"}], ",", 
       RowBox[{"1356", "\[Rule]", "1353"}], ",", 
       RowBox[{"1382", "\[Rule]", "1367"}], ",", 
       RowBox[{"1382", "\[Rule]", "1395"}], ",", 
       RowBox[{"1382", "\[Rule]", "1379"}], ",", 
       RowBox[{"1366", "\[Rule]", "1353"}], ",", 
       RowBox[{"1366", "\[Rule]", "1379"}], ",", 
       RowBox[{"1366", "\[Rule]", "1367"}], ",", 
       RowBox[{"1366", "\[Rule]", "1363"}], ",", 
       RowBox[{"1410", "\[Rule]", "1395"}], ",", 
       RowBox[{"1410", "\[Rule]", "1407"}], ",", 
       RowBox[{"1394", "\[Rule]", "1379"}], ",", 
       RowBox[{"1394", "\[Rule]", "1407"}], ",", 
       RowBox[{"1394", "\[Rule]", "1395"}], ",", 
       RowBox[{"1394", "\[Rule]", "1391"}], ",", 
       RowBox[{"1378", "\[Rule]", "1363"}], ",", 
       RowBox[{"1378", "\[Rule]", "1391"}], ",", 
       RowBox[{"1378", "\[Rule]", "1379"}], ",", 
       RowBox[{"1378", "\[Rule]", "1375"}], ",", 
       RowBox[{"1970", "\[Rule]", "1955"}], ",", 
       RowBox[{"1970", "\[Rule]", "1971"}], ",", 
       RowBox[{"1970", "\[Rule]", "1967"}], ",", 
       RowBox[{"1876", "\[Rule]", "1861"}], ",", 
       RowBox[{"1876", "\[Rule]", "1877"}], ",", 
       RowBox[{"1876", "\[Rule]", "1873"}], ",", 
       RowBox[{"1594", "\[Rule]", "1579"}], ",", 
       RowBox[{"1594", "\[Rule]", "1595"}], ",", 
       RowBox[{"1594", "\[Rule]", "1591"}], ",", 
       RowBox[{"1782", "\[Rule]", "1767"}], ",", 
       RowBox[{"1782", "\[Rule]", "1783"}], ",", 
       RowBox[{"1782", "\[Rule]", "1779"}], ",", 
       RowBox[{"1500", "\[Rule]", "1485"}], ",", 
       RowBox[{"1500", "\[Rule]", "1501"}], ",", 
       RowBox[{"1500", "\[Rule]", "1497"}], ",", 
       RowBox[{"1406", "\[Rule]", "1391"}], ",", 
       RowBox[{"1406", "\[Rule]", "1407"}], ",", 
       RowBox[{"1406", "\[Rule]", "1403"}], ",", 
       RowBox[{"1954", "\[Rule]", "1939"}], ",", 
       RowBox[{"1954", "\[Rule]", "1967"}], ",", 
       RowBox[{"1954", "\[Rule]", "1955"}], ",", 
       RowBox[{"1954", "\[Rule]", "1951"}], ",", 
       RowBox[{"1860", "\[Rule]", "1845"}], ",", 
       RowBox[{"1860", "\[Rule]", "1873"}], ",", 
       RowBox[{"1860", "\[Rule]", "1861"}], ",", 
       RowBox[{"1860", "\[Rule]", "1857"}], ",", 
       RowBox[{"1578", "\[Rule]", "1563"}], ",", 
       RowBox[{"1578", "\[Rule]", "1591"}], ",", 
       RowBox[{"1578", "\[Rule]", "1579"}], ",", 
       RowBox[{"1578", "\[Rule]", "1575"}], ",", 
       RowBox[{"1766", "\[Rule]", "1751"}], ",", 
       RowBox[{"1766", "\[Rule]", "1779"}], ",", 
       RowBox[{"1766", "\[Rule]", "1767"}], ",", 
       RowBox[{"1766", "\[Rule]", "1763"}], ",", 
       RowBox[{"1484", "\[Rule]", "1469"}], ",", 
       RowBox[{"1484", "\[Rule]", "1497"}], ",", 
       RowBox[{"1484", "\[Rule]", "1485"}], ",", 
       RowBox[{"1484", "\[Rule]", "1481"}], ",", 
       RowBox[{"1390", "\[Rule]", "1375"}], ",", 
       RowBox[{"1390", "\[Rule]", "1403"}], ",", 
       RowBox[{"1390", "\[Rule]", "1391"}], ",", 
       RowBox[{"1390", "\[Rule]", "1387"}], ",", 
       RowBox[{"650", "\[Rule]", "635"}], ",", 
       RowBox[{"650", "\[Rule]", "651"}], ",", 
       RowBox[{"650", "\[Rule]", "647"}], ",", 
       RowBox[{"556", "\[Rule]", "541"}], ",", 
       RowBox[{"556", "\[Rule]", "557"}], ",", 
       RowBox[{"556", "\[Rule]", "553"}], ",", 
       RowBox[{"274", "\[Rule]", "259"}], ",", 
       RowBox[{"274", "\[Rule]", "275"}], ",", 
       RowBox[{"274", "\[Rule]", "271"}], ",", 
       RowBox[{"1308", "\[Rule]", "1293"}], ",", 
       RowBox[{"1308", "\[Rule]", "1309"}], ",", 
       RowBox[{"1308", "\[Rule]", "1305"}], ",", 
       RowBox[{"1214", "\[Rule]", "1199"}], ",", 
       RowBox[{"1214", "\[Rule]", "1215"}], ",", 
       RowBox[{"1214", "\[Rule]", "1211"}], ",", 
       RowBox[{"932", "\[Rule]", "917"}], ",", 
       RowBox[{"932", "\[Rule]", "933"}], ",", 
       RowBox[{"932", "\[Rule]", "929"}], ",", 
       RowBox[{"462", "\[Rule]", "447"}], ",", 
       RowBox[{"462", "\[Rule]", "463"}], ",", 
       RowBox[{"462", "\[Rule]", "459"}], ",", 
       RowBox[{"180", "\[Rule]", "165"}], ",", 
       RowBox[{"180", "\[Rule]", "181"}], ",", 
       RowBox[{"180", "\[Rule]", "177"}], ",", 
       RowBox[{"1120", "\[Rule]", "1105"}], ",", 
       RowBox[{"1120", "\[Rule]", "1121"}], ",", 
       RowBox[{"1120", "\[Rule]", "1117"}], ",", 
       RowBox[{"838", "\[Rule]", "823"}], ",", 
       RowBox[{"838", "\[Rule]", "839"}], ",", 
       RowBox[{"838", "\[Rule]", "835"}], ",", 
       RowBox[{"86", "\[Rule]", "71"}], ",", 
       RowBox[{"86", "\[Rule]", "87"}], ",", 
       RowBox[{"86", "\[Rule]", "83"}], ",", 
       RowBox[{"744", "\[Rule]", "729"}], ",", 
       RowBox[{"744", "\[Rule]", "745"}], ",", 
       RowBox[{"744", "\[Rule]", "741"}], ",", 
       RowBox[{"1966", "\[Rule]", "1951"}], ",", 
       RowBox[{"1966", "\[Rule]", "1967"}], ",", 
       RowBox[{"1966", "\[Rule]", "1963"}], ",", 
       RowBox[{"1872", "\[Rule]", "1857"}], ",", 
       RowBox[{"1872", "\[Rule]", "1873"}], ",", 
       RowBox[{"1872", "\[Rule]", "1869"}], ",", 
       RowBox[{"1590", "\[Rule]", "1575"}], ",", 
       RowBox[{"1590", "\[Rule]", "1591"}], ",", 
       RowBox[{"1590", "\[Rule]", "1587"}], ",", 
       RowBox[{"1778", "\[Rule]", "1763"}], ",", 
       RowBox[{"1778", "\[Rule]", "1779"}], ",", 
       RowBox[{"1778", "\[Rule]", "1775"}], ",", 
       RowBox[{"1496", "\[Rule]", "1481"}], ",", 
       RowBox[{"1496", "\[Rule]", "1497"}], ",", 
       RowBox[{"1496", "\[Rule]", "1493"}], ",", 
       RowBox[{"1402", "\[Rule]", "1387"}], ",", 
       RowBox[{"1402", "\[Rule]", "1403"}], ",", 
       RowBox[{"1402", "\[Rule]", "1399"}], ",", 
       RowBox[{"589", "\[Rule]", "308"}], ",", 
       RowBox[{"589", "\[Rule]", "966"}], ",", 
       RowBox[{"589", "\[Rule]", "214"}], ",", 
       RowBox[{"589", "\[Rule]", "214"}], ",", 
       RowBox[{"589", "\[Rule]", "872"}], ",", 
       RowBox[{"589", "\[Rule]", "872"}], ",", 
       RowBox[{"589", "\[Rule]", "590"}], ",", 
       RowBox[{"615", "\[Rule]", "334"}], ",", 
       RowBox[{"615", "\[Rule]", "334"}], ",", 
       RowBox[{"615", "\[Rule]", "992"}], ",", 
       RowBox[{"615", "\[Rule]", "992"}], ",", 
       RowBox[{"615", "\[Rule]", "240"}], ",", 
       RowBox[{"615", "\[Rule]", "240"}], ",", 
       RowBox[{"615", "\[Rule]", "898"}], ",", 
       RowBox[{"615", "\[Rule]", "898"}], ",", 
       RowBox[{"615", "\[Rule]", "616"}], ",", 
       RowBox[{"601", "\[Rule]", "320"}], ",", 
       RowBox[{"601", "\[Rule]", "320"}], ",", 
       RowBox[{"601", "\[Rule]", "978"}], ",", 
       RowBox[{"601", "\[Rule]", "226"}], ",", 
       RowBox[{"601", "\[Rule]", "226"}], ",", 
       RowBox[{"601", "\[Rule]", "884"}], ",", 
       RowBox[{"601", "\[Rule]", "602"}], ",", 
       RowBox[{"495", "\[Rule]", "214"}], ",", 
       RowBox[{"495", "\[Rule]", "214"}], ",", 
       RowBox[{"495", "\[Rule]", "872"}], ",", 
       RowBox[{"495", "\[Rule]", "872"}], ",", 
       RowBox[{"495", "\[Rule]", "120"}], ",", 
       RowBox[{"495", "\[Rule]", "778"}], ",", 
       RowBox[{"495", "\[Rule]", "496"}], ",", 
       RowBox[{"507", "\[Rule]", "226"}], ",", 
       RowBox[{"507", "\[Rule]", "226"}], ",", 
       RowBox[{"507", "\[Rule]", "884"}], ",", 
       RowBox[{"507", "\[Rule]", "884"}], ",", 
       RowBox[{"507", "\[Rule]", "132"}], ",", 
       RowBox[{"507", "\[Rule]", "790"}], ",", 
       RowBox[{"507", "\[Rule]", "508"}], ",", 
       RowBox[{"213", "\[Rule]", "590"}], ",", 
       RowBox[{"213", "\[Rule]", "590"}], ",", 
       RowBox[{"213", "\[Rule]", "496"}], ",", 
       RowBox[{"213", "\[Rule]", "496"}], ",", 
       RowBox[{"213", "\[Rule]", "214"}], ",", 
       RowBox[{"239", "\[Rule]", "616"}], ",", 
       RowBox[{"239", "\[Rule]", "616"}], ",", 
       RowBox[{"239", "\[Rule]", "522"}], ",", 
       RowBox[{"239", "\[Rule]", "522"}], ",", 
       RowBox[{"239", "\[Rule]", "240"}], ",", 
       RowBox[{"225", "\[Rule]", "602"}], ",", 
       RowBox[{"225", "\[Rule]", "602"}], ",", 
       RowBox[{"225", "\[Rule]", "508"}], ",", 
       RowBox[{"225", "\[Rule]", "508"}], ",", 
       RowBox[{"225", "\[Rule]", "226"}], ",", 
       RowBox[{"643", "\[Rule]", "362"}], ",", 
       RowBox[{"643", "\[Rule]", "362"}], ",", 
       RowBox[{"643", "\[Rule]", "1020"}], ",", 
       RowBox[{"643", "\[Rule]", "1020"}], ",", 
       RowBox[{"643", "\[Rule]", "268"}], ",", 
       RowBox[{"643", "\[Rule]", "268"}], ",", 
       RowBox[{"643", "\[Rule]", "926"}], ",", 
       RowBox[{"643", "\[Rule]", "926"}], ",", 
       RowBox[{"643", "\[Rule]", "644"}], ",", 
       RowBox[{"627", "\[Rule]", "346"}], ",", 
       RowBox[{"627", "\[Rule]", "346"}], ",", 
       RowBox[{"627", "\[Rule]", "1004"}], ",", 
       RowBox[{"627", "\[Rule]", "1004"}], ",", 
       RowBox[{"627", "\[Rule]", "252"}], ",", 
       RowBox[{"627", "\[Rule]", "252"}], ",", 
       RowBox[{"627", "\[Rule]", "910"}], ",", 
       RowBox[{"627", "\[Rule]", "910"}], ",", 
       RowBox[{"627", "\[Rule]", "628"}], ",", 
       RowBox[{"267", "\[Rule]", "644"}], ",", 
       RowBox[{"267", "\[Rule]", "644"}], ",", 
       RowBox[{"267", "\[Rule]", "550"}], ",", 
       RowBox[{"267", "\[Rule]", "550"}], ",", 
       RowBox[{"267", "\[Rule]", "268"}], ",", 
       RowBox[{"251", "\[Rule]", "628"}], ",", 
       RowBox[{"251", "\[Rule]", "628"}], ",", 
       RowBox[{"251", "\[Rule]", "534"}], ",", 
       RowBox[{"251", "\[Rule]", "534"}], ",", 
       RowBox[{"251", "\[Rule]", "252"}], ",", 
       RowBox[{"611", "\[Rule]", "330"}], ",", 
       RowBox[{"611", "\[Rule]", "330"}], ",", 
       RowBox[{"611", "\[Rule]", "988"}], ",", 
       RowBox[{"611", "\[Rule]", "988"}], ",", 
       RowBox[{"611", "\[Rule]", "236"}], ",", 
       RowBox[{"611", "\[Rule]", "236"}], ",", 
       RowBox[{"611", "\[Rule]", "894"}], ",", 
       RowBox[{"611", "\[Rule]", "894"}], ",", 
       RowBox[{"611", "\[Rule]", "612"}], ",", 
       RowBox[{"517", "\[Rule]", "236"}], ",", 
       RowBox[{"517", "\[Rule]", "236"}], ",", 
       RowBox[{"517", "\[Rule]", "894"}], ",", 
       RowBox[{"517", "\[Rule]", "894"}], ",", 
       RowBox[{"517", "\[Rule]", "142"}], ",", 
       RowBox[{"517", "\[Rule]", "800"}], ",", 
       RowBox[{"517", "\[Rule]", "518"}], ",", 
       RowBox[{"235", "\[Rule]", "612"}], ",", 
       RowBox[{"235", "\[Rule]", "612"}], ",", 
       RowBox[{"235", "\[Rule]", "518"}], ",", 
       RowBox[{"235", "\[Rule]", "518"}], ",", 
       RowBox[{"235", "\[Rule]", "236"}], ",", 
       RowBox[{"1247", "\[Rule]", "966"}], ",", 
       RowBox[{"1247", "\[Rule]", "966"}], ",", 
       RowBox[{"1247", "\[Rule]", "1624"}], ",", 
       RowBox[{"1247", "\[Rule]", "1624"}], ",", 
       RowBox[{"1247", "\[Rule]", "872"}], ",", 
       RowBox[{"1247", "\[Rule]", "872"}], ",", 
       RowBox[{"1247", "\[Rule]", "1530"}], ",", 
       RowBox[{"1247", "\[Rule]", "1530"}], ",", 
       RowBox[{"1247", "\[Rule]", "1248"}], ",", 
       RowBox[{"1273", "\[Rule]", "992"}], ",", 
       RowBox[{"1273", "\[Rule]", "1650"}], ",", 
       RowBox[{"1273", "\[Rule]", "898"}], ",", 
       RowBox[{"1273", "\[Rule]", "898"}], ",", 
       RowBox[{"1273", "\[Rule]", "1556"}], ",", 
       RowBox[{"1273", "\[Rule]", "1556"}], ",", 
       RowBox[{"1273", "\[Rule]", "1274"}], ",", 
       RowBox[{"1259", "\[Rule]", "978"}], ",", 
       RowBox[{"1259", "\[Rule]", "1636"}], ",", 
       RowBox[{"1259", "\[Rule]", "1636"}], ",", 
       RowBox[{"1259", "\[Rule]", "884"}], ",", 
       RowBox[{"1259", "\[Rule]", "1542"}], ",", 
       RowBox[{"1259", "\[Rule]", "1542"}], ",", 
       RowBox[{"1259", "\[Rule]", "1260"}], ",", 
       RowBox[{"1153", "\[Rule]", "872"}], ",", 
       RowBox[{"1153", "\[Rule]", "872"}], ",", 
       RowBox[{"1153", "\[Rule]", "1530"}], ",", 
       RowBox[{"1153", "\[Rule]", "1530"}], ",", 
       RowBox[{"1153", "\[Rule]", "778"}], ",", 
       RowBox[{"1153", "\[Rule]", "778"}], ",", 
       RowBox[{"1153", "\[Rule]", "1436"}], ",", 
       RowBox[{"1153", "\[Rule]", "1436"}], ",", 
       RowBox[{"1153", "\[Rule]", "1154"}], ",", 
       RowBox[{"1165", "\[Rule]", "884"}], ",", 
       RowBox[{"1165", "\[Rule]", "884"}], ",", 
       RowBox[{"1165", "\[Rule]", "1542"}], ",", 
       RowBox[{"1165", "\[Rule]", "1542"}], ",", 
       RowBox[{"1165", "\[Rule]", "790"}], ",", 
       RowBox[{"1165", "\[Rule]", "790"}], ",", 
       RowBox[{"1165", "\[Rule]", "1448"}], ",", 
       RowBox[{"1165", "\[Rule]", "1448"}], ",", 
       RowBox[{"1165", "\[Rule]", "1166"}], ",", 
       RowBox[{"871", "\[Rule]", "590"}], ",", 
       RowBox[{"871", "\[Rule]", "590"}], ",", 
       RowBox[{"871", "\[Rule]", "1248"}], ",", 
       RowBox[{"871", "\[Rule]", "1248"}], ",", 
       RowBox[{"871", "\[Rule]", "496"}], ",", 
       RowBox[{"871", "\[Rule]", "496"}], ",", 
       RowBox[{"871", "\[Rule]", "1154"}], ",", 
       RowBox[{"871", "\[Rule]", "1154"}], ",", 
       RowBox[{"871", "\[Rule]", "872"}], ",", 
       RowBox[{"897", "\[Rule]", "616"}], ",", 
       RowBox[{"897", "\[Rule]", "616"}], ",", 
       RowBox[{"897", "\[Rule]", "1274"}], ",", 
       RowBox[{"897", "\[Rule]", "1274"}], ",", 
       RowBox[{"897", "\[Rule]", "522"}], ",", 
       RowBox[{"897", "\[Rule]", "522"}], ",", 
       RowBox[{"897", "\[Rule]", "1180"}], ",", 
       RowBox[{"897", "\[Rule]", "1180"}], ",", 
       RowBox[{"897", "\[Rule]", "898"}], ",", 
       RowBox[{"883", "\[Rule]", "602"}], ",", 
       RowBox[{"883", "\[Rule]", "1260"}], ",", 
       RowBox[{"883", "\[Rule]", "508"}], ",", 
       RowBox[{"883", "\[Rule]", "508"}], ",", 
       RowBox[{"883", "\[Rule]", "1166"}], ",", 
       RowBox[{"883", "\[Rule]", "1166"}], ",", 
       RowBox[{"883", "\[Rule]", "884"}], ",", 
       RowBox[{"1301", "\[Rule]", "1020"}], ",", 
       RowBox[{"1301", "\[Rule]", "1020"}], ",", 
       RowBox[{"1301", "\[Rule]", "1678"}], ",", 
       RowBox[{"1301", "\[Rule]", "1678"}], ",", 
       RowBox[{"1301", "\[Rule]", "926"}], ",", 
       RowBox[{"1301", "\[Rule]", "926"}], ",", 
       RowBox[{"1301", "\[Rule]", "1584"}], ",", 
       RowBox[{"1301", "\[Rule]", "1584"}], ",", 
       RowBox[{"1301", "\[Rule]", "1302"}], ",", 
       RowBox[{"1285", "\[Rule]", "1004"}], ",", 
       RowBox[{"1285", "\[Rule]", "1004"}], ",", 
       RowBox[{"1285", "\[Rule]", "1662"}], ",", 
       RowBox[{"1285", "\[Rule]", "910"}], ",", 
       RowBox[{"1285", "\[Rule]", "910"}], ",", 
       RowBox[{"1285", "\[Rule]", "1568"}], ",", 
       RowBox[{"1285", "\[Rule]", "1286"}], ",", 
       RowBox[{"925", "\[Rule]", "644"}], ",", 
       RowBox[{"925", "\[Rule]", "644"}], ",", 
       RowBox[{"925", "\[Rule]", "1302"}], ",", 
       RowBox[{"925", "\[Rule]", "1302"}], ",", 
       RowBox[{"925", "\[Rule]", "550"}], ",", 
       RowBox[{"925", "\[Rule]", "550"}], ",", 
       RowBox[{"925", "\[Rule]", "1208"}], ",", 
       RowBox[{"925", "\[Rule]", "1208"}], ",", 
       RowBox[{"925", "\[Rule]", "926"}], ",", 
       RowBox[{"909", "\[Rule]", "628"}], ",", 
       RowBox[{"909", "\[Rule]", "628"}], ",", 
       RowBox[{"909", "\[Rule]", "1286"}], ",", 
       RowBox[{"909", "\[Rule]", "1286"}], ",", 
       RowBox[{"909", "\[Rule]", "534"}], ",", 
       RowBox[{"909", "\[Rule]", "534"}], ",", 
       RowBox[{"909", "\[Rule]", "1192"}], ",", 
       RowBox[{"909", "\[Rule]", "1192"}], ",", 
       RowBox[{"909", "\[Rule]", "910"}], ",", 
       RowBox[{"1269", "\[Rule]", "988"}], ",", 
       RowBox[{"1269", "\[Rule]", "988"}], ",", 
       RowBox[{"1269", "\[Rule]", "1646"}], ",", 
       RowBox[{"1269", "\[Rule]", "1646"}], ",", 
       RowBox[{"1269", "\[Rule]", "894"}], ",", 
       RowBox[{"1269", "\[Rule]", "1552"}], ",", 
       RowBox[{"1269", "\[Rule]", "1270"}], ",", 
       RowBox[{"1175", "\[Rule]", "894"}], ",", 
       RowBox[{"1175", "\[Rule]", "1552"}], ",", 
       RowBox[{"1175", "\[Rule]", "800"}], ",", 
       RowBox[{"1175", "\[Rule]", "800"}], ",", 
       RowBox[{"1175", "\[Rule]", "1458"}], ",", 
       RowBox[{"1175", "\[Rule]", "1458"}], ",", 
       RowBox[{"1175", "\[Rule]", "1176"}], ",", 
       RowBox[{"893", "\[Rule]", "612"}], ",", 
       RowBox[{"893", "\[Rule]", "612"}], ",", 
       RowBox[{"893", "\[Rule]", "1270"}], ",", 
       RowBox[{"893", "\[Rule]", "518"}], ",", 
       RowBox[{"893", "\[Rule]", "518"}], ",", 
       RowBox[{"893", "\[Rule]", "1176"}], ",", 
       RowBox[{"893", "\[Rule]", "894"}], ",", 
       RowBox[{"401", "\[Rule]", "120"}], ",", 
       RowBox[{"401", "\[Rule]", "778"}], ",", 
       RowBox[{"401", "\[Rule]", "26"}], ",", 
       RowBox[{"401", "\[Rule]", "26"}], ",", 
       RowBox[{"401", "\[Rule]", "684"}], ",", 
       RowBox[{"401", "\[Rule]", "684"}], ",", 
       RowBox[{"401", "\[Rule]", "402"}], ",", 
       RowBox[{"413", "\[Rule]", "132"}], ",", 
       RowBox[{"413", "\[Rule]", "790"}], ",", 
       RowBox[{"413", "\[Rule]", "38"}], ",", 
       RowBox[{"413", "\[Rule]", "38"}], ",", 
       RowBox[{"413", "\[Rule]", "696"}], ",", 
       RowBox[{"413", "\[Rule]", "696"}], ",", 
       RowBox[{"413", "\[Rule]", "414"}], ",", 
       RowBox[{"119", "\[Rule]", "496"}], ",", 
       RowBox[{"119", "\[Rule]", "402"}], ",", 
       RowBox[{"119", "\[Rule]", "120"}], ",", 
       RowBox[{"131", "\[Rule]", "508"}], ",", 
       RowBox[{"131", "\[Rule]", "414"}], ",", 
       RowBox[{"131", "\[Rule]", "132"}], ",", 
       RowBox[{"423", "\[Rule]", "142"}], ",", 
       RowBox[{"423", "\[Rule]", "800"}], ",", 
       RowBox[{"423", "\[Rule]", "48"}], ",", 
       RowBox[{"423", "\[Rule]", "48"}], ",", 
       RowBox[{"423", "\[Rule]", "706"}], ",", 
       RowBox[{"423", "\[Rule]", "706"}], ",", 
       RowBox[{"423", "\[Rule]", "424"}], ",", 
       RowBox[{"141", "\[Rule]", "518"}], ",", 
       RowBox[{"141", "\[Rule]", "424"}], ",", 
       RowBox[{"141", "\[Rule]", "142"}], ",", 
       RowBox[{"1059", "\[Rule]", "778"}], ",", 
       RowBox[{"1059", "\[Rule]", "778"}], ",", 
       RowBox[{"1059", "\[Rule]", "1436"}], ",", 
       RowBox[{"1059", "\[Rule]", "1436"}], ",", 
       RowBox[{"1059", "\[Rule]", "684"}], ",", 
       RowBox[{"1059", "\[Rule]", "1342"}], ",", 
       RowBox[{"1059", "\[Rule]", "1060"}], ",", 
       RowBox[{"1071", "\[Rule]", "790"}], ",", 
       RowBox[{"1071", "\[Rule]", "790"}], ",", 
       RowBox[{"1071", "\[Rule]", "1448"}], ",", 
       RowBox[{"1071", "\[Rule]", "1448"}], ",", 
       RowBox[{"1071", "\[Rule]", "696"}], ",", 
       RowBox[{"1071", "\[Rule]", "1354"}], ",", 
       RowBox[{"1071", "\[Rule]", "1072"}], ",", 
       RowBox[{"777", "\[Rule]", "496"}], ",", 
       RowBox[{"777", "\[Rule]", "1154"}], ",", 
       RowBox[{"777", "\[Rule]", "1154"}], ",", 
       RowBox[{"777", "\[Rule]", "402"}], ",", 
       RowBox[{"777", "\[Rule]", "1060"}], ",", 
       RowBox[{"777", "\[Rule]", "1060"}], ",", 
       RowBox[{"777", "\[Rule]", "778"}], ",", 
       RowBox[{"789", "\[Rule]", "508"}], ",", 
       RowBox[{"789", "\[Rule]", "1166"}], ",", 
       RowBox[{"789", "\[Rule]", "1166"}], ",", 
       RowBox[{"789", "\[Rule]", "414"}], ",", 
       RowBox[{"789", "\[Rule]", "1072"}], ",", 
       RowBox[{"789", "\[Rule]", "1072"}], ",", 
       RowBox[{"789", "\[Rule]", "790"}], ",", 
       RowBox[{"1081", "\[Rule]", "800"}], ",", 
       RowBox[{"1081", "\[Rule]", "800"}], ",", 
       RowBox[{"1081", "\[Rule]", "1458"}], ",", 
       RowBox[{"1081", "\[Rule]", "1458"}], ",", 
       RowBox[{"1081", "\[Rule]", "706"}], ",", 
       RowBox[{"1081", "\[Rule]", "1364"}], ",", 
       RowBox[{"1081", "\[Rule]", "1082"}], ",", 
       RowBox[{"799", "\[Rule]", "518"}], ",", 
       RowBox[{"799", "\[Rule]", "1176"}], ",", 
       RowBox[{"799", "\[Rule]", "1176"}], ",", 
       RowBox[{"799", "\[Rule]", "424"}], ",", 
       RowBox[{"799", "\[Rule]", "1082"}], ",", 
       RowBox[{"799", "\[Rule]", "1082"}], ",", 
       RowBox[{"799", "\[Rule]", "800"}], ",", 
       RowBox[{"655", "\[Rule]", "374"}], ",", 
       RowBox[{"655", "\[Rule]", "374"}], ",", 
       RowBox[{"655", "\[Rule]", "1032"}], ",", 
       RowBox[{"655", "\[Rule]", "1032"}], ",", 
       RowBox[{"655", "\[Rule]", "280"}], ",", 
       RowBox[{"655", "\[Rule]", "280"}], ",", 
       RowBox[{"655", "\[Rule]", "938"}], ",", 
       RowBox[{"655", "\[Rule]", "938"}], ",", 
       RowBox[{"655", "\[Rule]", "656"}], ",", 
       RowBox[{"279", "\[Rule]", "656"}], ",", 
       RowBox[{"279", "\[Rule]", "656"}], ",", 
       RowBox[{"279", "\[Rule]", "562"}], ",", 
       RowBox[{"279", "\[Rule]", "562"}], ",", 
       RowBox[{"279", "\[Rule]", "280"}], ",", 
       RowBox[{"639", "\[Rule]", "358"}], ",", 
       RowBox[{"639", "\[Rule]", "358"}], ",", 
       RowBox[{"639", "\[Rule]", "1016"}], ",", 
       RowBox[{"639", "\[Rule]", "1016"}], ",", 
       RowBox[{"639", "\[Rule]", "264"}], ",", 
       RowBox[{"639", "\[Rule]", "264"}], ",", 
       RowBox[{"639", "\[Rule]", "922"}], ",", 
       RowBox[{"639", "\[Rule]", "922"}], ",", 
       RowBox[{"639", "\[Rule]", "640"}], ",", 
       RowBox[{"263", "\[Rule]", "640"}], ",", 
       RowBox[{"263", "\[Rule]", "640"}], ",", 
       RowBox[{"263", "\[Rule]", "546"}], ",", 
       RowBox[{"263", "\[Rule]", "546"}], ",", 
       RowBox[{"263", "\[Rule]", "264"}], ",", 
       RowBox[{"1313", "\[Rule]", "1032"}], ",", 
       RowBox[{"1313", "\[Rule]", "1032"}], ",", 
       RowBox[{"1313", "\[Rule]", "1690"}], ",", 
       RowBox[{"1313", "\[Rule]", "1690"}], ",", 
       RowBox[{"1313", "\[Rule]", "938"}], ",", 
       RowBox[{"1313", "\[Rule]", "938"}], ",", 
       RowBox[{"1313", "\[Rule]", "1596"}], ",", 
       RowBox[{"1313", "\[Rule]", "1596"}], ",", 
       RowBox[{"1313", "\[Rule]", "1314"}], ",", 
       RowBox[{"937", "\[Rule]", "656"}], ",", 
       RowBox[{"937", "\[Rule]", "656"}], ",", 
       RowBox[{"937", "\[Rule]", "1314"}], ",", 
       RowBox[{"937", "\[Rule]", "1314"}], ",", 
       RowBox[{"937", "\[Rule]", "562"}], ",", 
       RowBox[{"937", "\[Rule]", "562"}], ",", 
       RowBox[{"937", "\[Rule]", "1220"}], ",", 
       RowBox[{"937", "\[Rule]", "1220"}], ",", 
       RowBox[{"937", "\[Rule]", "938"}], ",", 
       RowBox[{"1297", "\[Rule]", "1016"}], ",", 
       RowBox[{"1297", "\[Rule]", "1016"}], ",", 
       RowBox[{"1297", "\[Rule]", "1674"}], ",", 
       RowBox[{"1297", "\[Rule]", "1674"}], ",", 
       RowBox[{"1297", "\[Rule]", "922"}], ",", 
       RowBox[{"1297", "\[Rule]", "922"}], ",", 
       RowBox[{"1297", "\[Rule]", "1580"}], ",", 
       RowBox[{"1297", "\[Rule]", "1580"}], ",", 
       RowBox[{"1297", "\[Rule]", "1298"}], ",", 
       RowBox[{"921", "\[Rule]", "640"}], ",", 
       RowBox[{"921", "\[Rule]", "640"}], ",", 
       RowBox[{"921", "\[Rule]", "1298"}], ",", 
       RowBox[{"921", "\[Rule]", "1298"}], ",", 
       RowBox[{"921", "\[Rule]", "546"}], ",", 
       RowBox[{"921", "\[Rule]", "546"}], ",", 
       RowBox[{"921", "\[Rule]", "1204"}], ",", 
       RowBox[{"921", "\[Rule]", "1204"}], ",", 
       RowBox[{"921", "\[Rule]", "922"}], ",", 
       RowBox[{"623", "\[Rule]", "342"}], ",", 
       RowBox[{"623", "\[Rule]", "342"}], ",", 
       RowBox[{"623", "\[Rule]", "1000"}], ",", 
       RowBox[{"623", "\[Rule]", "1000"}], ",", 
       RowBox[{"623", "\[Rule]", "248"}], ",", 
       RowBox[{"623", "\[Rule]", "248"}], ",", 
       RowBox[{"623", "\[Rule]", "906"}], ",", 
       RowBox[{"623", "\[Rule]", "906"}], ",", 
       RowBox[{"623", "\[Rule]", "624"}], ",", 
       RowBox[{"529", "\[Rule]", "248"}], ",", 
       RowBox[{"529", "\[Rule]", "248"}], ",", 
       RowBox[{"529", "\[Rule]", "906"}], ",", 
       RowBox[{"529", "\[Rule]", "906"}], ",", 
       RowBox[{"529", "\[Rule]", "154"}], ",", 
       RowBox[{"529", "\[Rule]", "812"}], ",", 
       RowBox[{"529", "\[Rule]", "530"}], ",", 
       RowBox[{"247", "\[Rule]", "624"}], ",", 
       RowBox[{"247", "\[Rule]", "624"}], ",", 
       RowBox[{"247", "\[Rule]", "530"}], ",", 
       RowBox[{"247", "\[Rule]", "530"}], ",", 
       RowBox[{"247", "\[Rule]", "248"}], ",", 
       RowBox[{"1281", "\[Rule]", "1000"}], ",", 
       RowBox[{"1281", "\[Rule]", "1000"}], ",", 
       RowBox[{"1281", "\[Rule]", "1658"}], ",", 
       RowBox[{"1281", "\[Rule]", "1658"}], ",", 
       RowBox[{"1281", "\[Rule]", "906"}], ",", 
       RowBox[{"1281", "\[Rule]", "906"}], ",", 
       RowBox[{"1281", "\[Rule]", "1564"}], ",", 
       RowBox[{"1281", "\[Rule]", "1564"}], ",", 
       RowBox[{"1281", "\[Rule]", "1282"}], ",", 
       RowBox[{"1187", "\[Rule]", "906"}], ",", 
       RowBox[{"1187", "\[Rule]", "906"}], ",", 
       RowBox[{"1187", "\[Rule]", "1564"}], ",", 
       RowBox[{"1187", "\[Rule]", "812"}], ",", 
       RowBox[{"1187", "\[Rule]", "812"}], ",", 
       RowBox[{"1187", "\[Rule]", "1470"}], ",", 
       RowBox[{"1187", "\[Rule]", "1188"}], ",", 
       RowBox[{"905", "\[Rule]", "624"}], ",", 
       RowBox[{"905", "\[Rule]", "624"}], ",", 
       RowBox[{"905", "\[Rule]", "1282"}], ",", 
       RowBox[{"905", "\[Rule]", "1282"}], ",", 
       RowBox[{"905", "\[Rule]", "530"}], ",", 
       RowBox[{"905", "\[Rule]", "530"}], ",", 
       RowBox[{"905", "\[Rule]", "1188"}], ",", 
       RowBox[{"905", "\[Rule]", "1188"}], ",", 
       RowBox[{"905", "\[Rule]", "906"}], ",", 
       RowBox[{"435", "\[Rule]", "154"}], ",", 
       RowBox[{"435", "\[Rule]", "812"}], ",", 
       RowBox[{"435", "\[Rule]", "60"}], ",", 
       RowBox[{"435", "\[Rule]", "60"}], ",", 
       RowBox[{"435", "\[Rule]", "718"}], ",", 
       RowBox[{"435", "\[Rule]", "718"}], ",", 
       RowBox[{"435", "\[Rule]", "436"}], ",", 
       RowBox[{"153", "\[Rule]", "530"}], ",", 
       RowBox[{"153", "\[Rule]", "436"}], ",", 
       RowBox[{"153", "\[Rule]", "154"}], ",", 
       RowBox[{"1093", "\[Rule]", "812"}], ",", 
       RowBox[{"1093", "\[Rule]", "812"}], ",", 
       RowBox[{"1093", "\[Rule]", "1470"}], ",", 
       RowBox[{"1093", "\[Rule]", "1470"}], ",", 
       RowBox[{"1093", "\[Rule]", "718"}], ",", 
       RowBox[{"1093", "\[Rule]", "1376"}], ",", 
       RowBox[{"1093", "\[Rule]", "1094"}], ",", 
       RowBox[{"811", "\[Rule]", "530"}], ",", 
       RowBox[{"811", "\[Rule]", "1188"}], ",", 
       RowBox[{"811", "\[Rule]", "1188"}], ",", 
       RowBox[{"811", "\[Rule]", "436"}], ",", 
       RowBox[{"811", "\[Rule]", "1094"}], ",", 
       RowBox[{"811", "\[Rule]", "1094"}], ",", 
       RowBox[{"811", "\[Rule]", "812"}], ",", 
       RowBox[{"25", "\[Rule]", "402"}], ",", 
       RowBox[{"25", "\[Rule]", "402"}], ",", 
       RowBox[{"25", "\[Rule]", "26"}], ",", 
       RowBox[{"37", "\[Rule]", "414"}], ",", 
       RowBox[{"37", "\[Rule]", "414"}], ",", 
       RowBox[{"37", "\[Rule]", "38"}], ",", 
       RowBox[{"47", "\[Rule]", "424"}], ",", 
       RowBox[{"47", "\[Rule]", "424"}], ",", 
       RowBox[{"47", "\[Rule]", "48"}], ",", 
       RowBox[{"683", "\[Rule]", "402"}], ",", 
       RowBox[{"683", "\[Rule]", "402"}], ",", 
       RowBox[{"683", "\[Rule]", "1060"}], ",", 
       RowBox[{"683", "\[Rule]", "684"}], ",", 
       RowBox[{"695", "\[Rule]", "414"}], ",", 
       RowBox[{"695", "\[Rule]", "414"}], ",", 
       RowBox[{"695", "\[Rule]", "1072"}], ",", 
       RowBox[{"695", "\[Rule]", "696"}], ",", 
       RowBox[{"705", "\[Rule]", "424"}], ",", 
       RowBox[{"705", "\[Rule]", "424"}], ",", 
       RowBox[{"705", "\[Rule]", "1082"}], ",", 
       RowBox[{"705", "\[Rule]", "706"}], ",", 
       RowBox[{"59", "\[Rule]", "436"}], ",", 
       RowBox[{"59", "\[Rule]", "436"}], ",", 
       RowBox[{"59", "\[Rule]", "60"}], ",", 
       RowBox[{"717", "\[Rule]", "436"}], ",", 
       RowBox[{"717", "\[Rule]", "436"}], ",", 
       RowBox[{"717", "\[Rule]", "1094"}], ",", 
       RowBox[{"717", "\[Rule]", "718"}], ",", 
       RowBox[{"651", "\[Rule]", "370"}], ",", 
       RowBox[{"651", "\[Rule]", "370"}], ",", 
       RowBox[{"651", "\[Rule]", "1028"}], ",", 
       RowBox[{"651", "\[Rule]", "1028"}], ",", 
       RowBox[{"651", "\[Rule]", "276"}], ",", 
       RowBox[{"651", "\[Rule]", "276"}], ",", 
       RowBox[{"651", "\[Rule]", "934"}], ",", 
       RowBox[{"651", "\[Rule]", "934"}], ",", 
       RowBox[{"651", "\[Rule]", "652"}], ",", 
       RowBox[{"275", "\[Rule]", "652"}], ",", 
       RowBox[{"275", "\[Rule]", "652"}], ",", 
       RowBox[{"275", "\[Rule]", "558"}], ",", 
       RowBox[{"275", "\[Rule]", "558"}], ",", 
       RowBox[{"275", "\[Rule]", "276"}], ",", 
       RowBox[{"1309", "\[Rule]", "1028"}], ",", 
       RowBox[{"1309", "\[Rule]", "1028"}], ",", 
       RowBox[{"1309", "\[Rule]", "1686"}], ",", 
       RowBox[{"1309", "\[Rule]", "1686"}], ",", 
       RowBox[{"1309", "\[Rule]", "934"}], ",", 
       RowBox[{"1309", "\[Rule]", "934"}], ",", 
       RowBox[{"1309", "\[Rule]", "1592"}], ",", 
       RowBox[{"1309", "\[Rule]", "1592"}], ",", 
       RowBox[{"1309", "\[Rule]", "1310"}], ",", 
       RowBox[{"933", "\[Rule]", "652"}], ",", 
       RowBox[{"933", "\[Rule]", "652"}], ",", 
       RowBox[{"933", "\[Rule]", "1310"}], ",", 
       RowBox[{"933", "\[Rule]", "1310"}], ",", 
       RowBox[{"933", "\[Rule]", "558"}], ",", 
       RowBox[{"933", "\[Rule]", "558"}], ",", 
       RowBox[{"933", "\[Rule]", "1216"}], ",", 
       RowBox[{"933", "\[Rule]", "1216"}], ",", 
       RowBox[{"933", "\[Rule]", "934"}], ",", 
       RowBox[{"635", "\[Rule]", "354"}], ",", 
       RowBox[{"635", "\[Rule]", "354"}], ",", 
       RowBox[{"635", "\[Rule]", "1012"}], ",", 
       RowBox[{"635", "\[Rule]", "1012"}], ",", 
       RowBox[{"635", "\[Rule]", "260"}], ",", 
       RowBox[{"635", "\[Rule]", "260"}], ",", 
       RowBox[{"635", "\[Rule]", "918"}], ",", 
       RowBox[{"635", "\[Rule]", "918"}], ",", 
       RowBox[{"635", "\[Rule]", "636"}], ",", 
       RowBox[{"541", "\[Rule]", "260"}], ",", 
       RowBox[{"541", "\[Rule]", "260"}], ",", 
       RowBox[{"541", "\[Rule]", "918"}], ",", 
       RowBox[{"541", "\[Rule]", "918"}], ",", 
       RowBox[{"541", "\[Rule]", "166"}], ",", 
       RowBox[{"541", "\[Rule]", "824"}], ",", 
       RowBox[{"541", "\[Rule]", "542"}], ",", 
       RowBox[{"259", "\[Rule]", "636"}], ",", 
       RowBox[{"259", "\[Rule]", "636"}], ",", 
       RowBox[{"259", "\[Rule]", "542"}], ",", 
       RowBox[{"259", "\[Rule]", "542"}], ",", 
       RowBox[{"259", "\[Rule]", "260"}], ",", 
       RowBox[{"1293", "\[Rule]", "1012"}], ",", 
       RowBox[{"1293", "\[Rule]", "1012"}], ",", 
       RowBox[{"1293", "\[Rule]", "1670"}], ",", 
       RowBox[{"1293", "\[Rule]", "1670"}], ",", 
       RowBox[{"1293", "\[Rule]", "918"}], ",", 
       RowBox[{"1293", "\[Rule]", "918"}], ",", 
       RowBox[{"1293", "\[Rule]", "1576"}], ",", 
       RowBox[{"1293", "\[Rule]", "1576"}], ",", 
       RowBox[{"1293", "\[Rule]", "1294"}], ",", 
       RowBox[{"1199", "\[Rule]", "918"}], ",", 
       RowBox[{"1199", "\[Rule]", "918"}], ",", 
       RowBox[{"1199", "\[Rule]", "1576"}], ",", 
       RowBox[{"1199", "\[Rule]", "1576"}], ",", 
       RowBox[{"1199", "\[Rule]", "824"}], ",", 
       RowBox[{"1199", "\[Rule]", "824"}], ",", 
       RowBox[{"1199", "\[Rule]", "1482"}], ",", 
       RowBox[{"1199", "\[Rule]", "1482"}], ",", 
       RowBox[{"1199", "\[Rule]", "1200"}], ",", 
       RowBox[{"917", "\[Rule]", "636"}], ",", 
       RowBox[{"917", "\[Rule]", "636"}], ",", 
       RowBox[{"917", "\[Rule]", "1294"}], ",", 
       RowBox[{"917", "\[Rule]", "1294"}], ",", 
       RowBox[{"917", "\[Rule]", "542"}], ",", 
       RowBox[{"917", "\[Rule]", "542"}], ",", 
       RowBox[{"917", "\[Rule]", "1200"}], ",", 
       RowBox[{"917", "\[Rule]", "1200"}], ",", 
       RowBox[{"917", "\[Rule]", "918"}], ",", 
       RowBox[{"447", "\[Rule]", "166"}], ",", 
       RowBox[{"447", "\[Rule]", "824"}], ",", 
       RowBox[{"447", "\[Rule]", "72"}], ",", 
       RowBox[{"447", "\[Rule]", "72"}], ",", 
       RowBox[{"447", "\[Rule]", "730"}], ",", 
       RowBox[{"447", "\[Rule]", "730"}], ",", 
       RowBox[{"447", "\[Rule]", "448"}], ",", 
       RowBox[{"165", "\[Rule]", "542"}], ",", 
       RowBox[{"165", "\[Rule]", "448"}], ",", 
       RowBox[{"165", "\[Rule]", "166"}], ",", 
       RowBox[{"1105", "\[Rule]", "824"}], ",", 
       RowBox[{"1105", "\[Rule]", "824"}], ",", 
       RowBox[{"1105", "\[Rule]", "1482"}], ",", 
       RowBox[{"1105", "\[Rule]", "1482"}], ",", 
       RowBox[{"1105", "\[Rule]", "730"}], ",", 
       RowBox[{"1105", "\[Rule]", "1388"}], ",", 
       RowBox[{"1105", "\[Rule]", "1106"}], ",", 
       RowBox[{"823", "\[Rule]", "542"}], ",", 
       RowBox[{"823", "\[Rule]", "1200"}], ",", 
       RowBox[{"823", "\[Rule]", "1200"}], ",", 
       RowBox[{"823", "\[Rule]", "448"}], ",", 
       RowBox[{"823", "\[Rule]", "1106"}], ",", 
       RowBox[{"823", "\[Rule]", "1106"}], ",", 
       RowBox[{"823", "\[Rule]", "824"}], ",", 
       RowBox[{"71", "\[Rule]", "448"}], ",", 
       RowBox[{"71", "\[Rule]", "448"}], ",", 
       RowBox[{"71", "\[Rule]", "72"}], ",", 
       RowBox[{"729", "\[Rule]", "448"}], ",", 
       RowBox[{"729", "\[Rule]", "448"}], ",", 
       RowBox[{"729", "\[Rule]", "1106"}], ",", 
       RowBox[{"729", "\[Rule]", "730"}], ",", 
       RowBox[{"1905", "\[Rule]", "1624"}], ",", 
       RowBox[{"1905", "\[Rule]", "1624"}], ",", 
       RowBox[{"1905", "\[Rule]", "2282"}], ",", 
       RowBox[{"1905", "\[Rule]", "2282"}], ",", 
       RowBox[{"1905", "\[Rule]", "1530"}], ",", 
       RowBox[{"1905", "\[Rule]", "1530"}], ",", 
       RowBox[{"1905", "\[Rule]", "2188"}], ",", 
       RowBox[{"1905", "\[Rule]", "2188"}], ",", 
       RowBox[{"1905", "\[Rule]", "1906"}], ",", 
       RowBox[{"1931", "\[Rule]", "1650"}], ",", 
       RowBox[{"1931", "\[Rule]", "1650"}], ",", 
       RowBox[{"1931", "\[Rule]", "2308"}], ",", 
       RowBox[{"1931", "\[Rule]", "2308"}], ",", 
       RowBox[{"1931", "\[Rule]", "1556"}], ",", 
       RowBox[{"1931", "\[Rule]", "1556"}], ",", 
       RowBox[{"1931", "\[Rule]", "2214"}], ",", 
       RowBox[{"1931", "\[Rule]", "2214"}], ",", 
       RowBox[{"1931", "\[Rule]", "1932"}], ",", 
       RowBox[{"1917", "\[Rule]", "1636"}], ",", 
       RowBox[{"1917", "\[Rule]", "1636"}], ",", 
       RowBox[{"1917", "\[Rule]", "2294"}], ",", 
       RowBox[{"1917", "\[Rule]", "2294"}], ",", 
       RowBox[{"1917", "\[Rule]", "1542"}], ",", 
       RowBox[{"1917", "\[Rule]", "1542"}], ",", 
       RowBox[{"1917", "\[Rule]", "2200"}], ",", 
       RowBox[{"1917", "\[Rule]", "2200"}], ",", 
       RowBox[{"1917", "\[Rule]", "1918"}], ",", 
       RowBox[{"1811", "\[Rule]", "1530"}], ",", 
       RowBox[{"1811", "\[Rule]", "1530"}], ",", 
       RowBox[{"1811", "\[Rule]", "2188"}], ",", 
       RowBox[{"1811", "\[Rule]", "2188"}], ",", 
       RowBox[{"1811", "\[Rule]", "1436"}], ",", 
       RowBox[{"1811", "\[Rule]", "1436"}], ",", 
       RowBox[{"1811", "\[Rule]", "2094"}], ",", 
       RowBox[{"1811", "\[Rule]", "2094"}], ",", 
       RowBox[{"1811", "\[Rule]", "1812"}], ",", 
       RowBox[{"1837", "\[Rule]", "1556"}], ",", 
       RowBox[{"1837", "\[Rule]", "1556"}], ",", 
       RowBox[{"1837", "\[Rule]", "2214"}], ",", 
       RowBox[{"1837", "\[Rule]", "2214"}], ",", 
       RowBox[{"1837", "\[Rule]", "1462"}], ",", 
       RowBox[{"1837", "\[Rule]", "1462"}], ",", 
       RowBox[{"1837", "\[Rule]", "2120"}], ",", 
       RowBox[{"1837", "\[Rule]", "2120"}], ",", 
       RowBox[{"1837", "\[Rule]", "1838"}], ",", 
       RowBox[{"1823", "\[Rule]", "1542"}], ",", 
       RowBox[{"1823", "\[Rule]", "1542"}], ",", 
       RowBox[{"1823", "\[Rule]", "2200"}], ",", 
       RowBox[{"1823", "\[Rule]", "2200"}], ",", 
       RowBox[{"1823", "\[Rule]", "1448"}], ",", 
       RowBox[{"1823", "\[Rule]", "1448"}], ",", 
       RowBox[{"1823", "\[Rule]", "2106"}], ",", 
       RowBox[{"1823", "\[Rule]", "2106"}], ",", 
       RowBox[{"1823", "\[Rule]", "1824"}], ",", 
       RowBox[{"1529", "\[Rule]", "1248"}], ",", 
       RowBox[{"1529", "\[Rule]", "1248"}], ",", 
       RowBox[{"1529", "\[Rule]", "1906"}], ",", 
       RowBox[{"1529", "\[Rule]", "1906"}], ",", 
       RowBox[{"1529", "\[Rule]", "1154"}], ",", 
       RowBox[{"1529", "\[Rule]", "1154"}], ",", 
       RowBox[{"1529", "\[Rule]", "1812"}], ",", 
       RowBox[{"1529", "\[Rule]", "1812"}], ",", 
       RowBox[{"1529", "\[Rule]", "1530"}], ",", 
       RowBox[{"1555", "\[Rule]", "1274"}], ",", 
       RowBox[{"1555", "\[Rule]", "1274"}], ",", 
       RowBox[{"1555", "\[Rule]", "1932"}], ",", 
       RowBox[{"1555", "\[Rule]", "1932"}], ",", 
       RowBox[{"1555", "\[Rule]", "1180"}], ",", 
       RowBox[{"1555", "\[Rule]", "1180"}], ",", 
       RowBox[{"1555", "\[Rule]", "1838"}], ",", 
       RowBox[{"1555", "\[Rule]", "1838"}], ",", 
       RowBox[{"1555", "\[Rule]", "1556"}], ",", 
       RowBox[{"1541", "\[Rule]", "1260"}], ",", 
       RowBox[{"1541", "\[Rule]", "1260"}], ",", 
       RowBox[{"1541", "\[Rule]", "1918"}], ",", 
       RowBox[{"1541", "\[Rule]", "1918"}], ",", 
       RowBox[{"1541", "\[Rule]", "1166"}], ",", 
       RowBox[{"1541", "\[Rule]", "1166"}], ",", 
       RowBox[{"1541", "\[Rule]", "1824"}], ",", 
       RowBox[{"1541", "\[Rule]", "1824"}], ",", 
       RowBox[{"1541", "\[Rule]", "1542"}], ",", 
       RowBox[{"1959", "\[Rule]", "1678"}], ",", 
       RowBox[{"1959", "\[Rule]", "2336"}], ",", 
       RowBox[{"1959", "\[Rule]", "1584"}], ",", 
       RowBox[{"1959", "\[Rule]", "1584"}], ",", 
       RowBox[{"1959", "\[Rule]", "2242"}], ",", 
       RowBox[{"1959", "\[Rule]", "2242"}], ",", 
       RowBox[{"1959", "\[Rule]", "1960"}], ",", 
       RowBox[{"1943", "\[Rule]", "1662"}], ",", 
       RowBox[{"1943", "\[Rule]", "2320"}], ",", 
       RowBox[{"1943", "\[Rule]", "2320"}], ",", 
       RowBox[{"1943", "\[Rule]", "1568"}], ",", 
       RowBox[{"1943", "\[Rule]", "2226"}], ",", 
       RowBox[{"1943", "\[Rule]", "2226"}], ",", 
       RowBox[{"1943", "\[Rule]", "1944"}], ",", 
       RowBox[{"1865", "\[Rule]", "1584"}], ",", 
       RowBox[{"1865", "\[Rule]", "1584"}], ",", 
       RowBox[{"1865", "\[Rule]", "2242"}], ",", 
       RowBox[{"1865", "\[Rule]", "2242"}], ",", 
       RowBox[{"1865", "\[Rule]", "1490"}], ",", 
       RowBox[{"1865", "\[Rule]", "1490"}], ",", 
       RowBox[{"1865", "\[Rule]", "2148"}], ",", 
       RowBox[{"1865", "\[Rule]", "2148"}], ",", 
       RowBox[{"1865", "\[Rule]", "1866"}], ",", 
       RowBox[{"1849", "\[Rule]", "1568"}], ",", 
       RowBox[{"1849", "\[Rule]", "1568"}], ",", 
       RowBox[{"1849", "\[Rule]", "2226"}], ",", 
       RowBox[{"1849", "\[Rule]", "2226"}], ",", 
       RowBox[{"1849", "\[Rule]", "1474"}], ",", 
       RowBox[{"1849", "\[Rule]", "1474"}], ",", 
       RowBox[{"1849", "\[Rule]", "2132"}], ",", 
       RowBox[{"1849", "\[Rule]", "2132"}], ",", 
       RowBox[{"1849", "\[Rule]", "1850"}], ",", 
       RowBox[{"1583", "\[Rule]", "1302"}], ",", 
       RowBox[{"1583", "\[Rule]", "1302"}], ",", 
       RowBox[{"1583", "\[Rule]", "1960"}], ",", 
       RowBox[{"1583", "\[Rule]", "1960"}], ",", 
       RowBox[{"1583", "\[Rule]", "1208"}], ",", 
       RowBox[{"1583", "\[Rule]", "1208"}], ",", 
       RowBox[{"1583", "\[Rule]", "1866"}], ",", 
       RowBox[{"1583", "\[Rule]", "1866"}], ",", 
       RowBox[{"1583", "\[Rule]", "1584"}], ",", 
       RowBox[{"1567", "\[Rule]", "1286"}], ",", 
       RowBox[{"1567", "\[Rule]", "1944"}], ",", 
       RowBox[{"1567", "\[Rule]", "1192"}], ",", 
       RowBox[{"1567", "\[Rule]", "1192"}], ",", 
       RowBox[{"1567", "\[Rule]", "1850"}], ",", 
       RowBox[{"1567", "\[Rule]", "1850"}], ",", 
       RowBox[{"1567", "\[Rule]", "1568"}], ",", 
       RowBox[{"1927", "\[Rule]", "1646"}], ",", 
       RowBox[{"1927", "\[Rule]", "1646"}], ",", 
       RowBox[{"1927", "\[Rule]", "2304"}], ",", 
       RowBox[{"1927", "\[Rule]", "2304"}], ",", 
       RowBox[{"1927", "\[Rule]", "1552"}], ",", 
       RowBox[{"1927", "\[Rule]", "1552"}], ",", 
       RowBox[{"1927", "\[Rule]", "2210"}], ",", 
       RowBox[{"1927", "\[Rule]", "2210"}], ",", 
       RowBox[{"1927", "\[Rule]", "1928"}], ",", 
       RowBox[{"1833", "\[Rule]", "1552"}], ",", 
       RowBox[{"1833", "\[Rule]", "1552"}], ",", 
       RowBox[{"1833", "\[Rule]", "2210"}], ",", 
       RowBox[{"1833", "\[Rule]", "2210"}], ",", 
       RowBox[{"1833", "\[Rule]", "1458"}], ",", 
       RowBox[{"1833", "\[Rule]", "1458"}], ",", 
       RowBox[{"1833", "\[Rule]", "2116"}], ",", 
       RowBox[{"1833", "\[Rule]", "2116"}], ",", 
       RowBox[{"1833", "\[Rule]", "1834"}], ",", 
       RowBox[{"1551", "\[Rule]", "1270"}], ",", 
       RowBox[{"1551", "\[Rule]", "1928"}], ",", 
       RowBox[{"1551", "\[Rule]", "1928"}], ",", 
       RowBox[{"1551", "\[Rule]", "1176"}], ",", 
       RowBox[{"1551", "\[Rule]", "1834"}], ",", 
       RowBox[{"1551", "\[Rule]", "1834"}], ",", 
       RowBox[{"1551", "\[Rule]", "1552"}], ",", 
       RowBox[{"1717", "\[Rule]", "1436"}], ",", 
       RowBox[{"1717", "\[Rule]", "1436"}], ",", 
       RowBox[{"1717", "\[Rule]", "2094"}], ",", 
       RowBox[{"1717", "\[Rule]", "2094"}], ",", 
       RowBox[{"1717", "\[Rule]", "1342"}], ",", 
       RowBox[{"1717", "\[Rule]", "1342"}], ",", 
       RowBox[{"1717", "\[Rule]", "2000"}], ",", 
       RowBox[{"1717", "\[Rule]", "2000"}], ",", 
       RowBox[{"1717", "\[Rule]", "1718"}], ",", 
       RowBox[{"1743", "\[Rule]", "1462"}], ",", 
       RowBox[{"1743", "\[Rule]", "1462"}], ",", 
       RowBox[{"1743", "\[Rule]", "2120"}], ",", 
       RowBox[{"1743", "\[Rule]", "2120"}], ",", 
       RowBox[{"1743", "\[Rule]", "1368"}], ",", 
       RowBox[{"1743", "\[Rule]", "1368"}], ",", 
       RowBox[{"1743", "\[Rule]", "2026"}], ",", 
       RowBox[{"1743", "\[Rule]", "2026"}], ",", 
       RowBox[{"1743", "\[Rule]", "1744"}], ",", 
       RowBox[{"1729", "\[Rule]", "1448"}], ",", 
       RowBox[{"1729", "\[Rule]", "1448"}], ",", 
       RowBox[{"1729", "\[Rule]", "2106"}], ",", 
       RowBox[{"1729", "\[Rule]", "2106"}], ",", 
       RowBox[{"1729", "\[Rule]", "1354"}], ",", 
       RowBox[{"1729", "\[Rule]", "1354"}], ",", 
       RowBox[{"1729", "\[Rule]", "2012"}], ",", 
       RowBox[{"1729", "\[Rule]", "2012"}], ",", 
       RowBox[{"1729", "\[Rule]", "1730"}], ",", 
       RowBox[{"1435", "\[Rule]", "1154"}], ",", 
       RowBox[{"1435", "\[Rule]", "1154"}], ",", 
       RowBox[{"1435", "\[Rule]", "1812"}], ",", 
       RowBox[{"1435", "\[Rule]", "1812"}], ",", 
       RowBox[{"1435", "\[Rule]", "1060"}], ",", 
       RowBox[{"1435", "\[Rule]", "1060"}], ",", 
       RowBox[{"1435", "\[Rule]", "1718"}], ",", 
       RowBox[{"1435", "\[Rule]", "1718"}], ",", 
       RowBox[{"1435", "\[Rule]", "1436"}], ",", 
       RowBox[{"1461", "\[Rule]", "1180"}], ",", 
       RowBox[{"1461", "\[Rule]", "1180"}], ",", 
       RowBox[{"1461", "\[Rule]", "1838"}], ",", 
       RowBox[{"1461", "\[Rule]", "1838"}], ",", 
       RowBox[{"1461", "\[Rule]", "1086"}], ",", 
       RowBox[{"1461", "\[Rule]", "1086"}], ",", 
       RowBox[{"1461", "\[Rule]", "1744"}], ",", 
       RowBox[{"1461", "\[Rule]", "1744"}], ",", 
       RowBox[{"1461", "\[Rule]", "1462"}], ",", 
       RowBox[{"1447", "\[Rule]", "1166"}], ",", 
       RowBox[{"1447", "\[Rule]", "1166"}], ",", 
       RowBox[{"1447", "\[Rule]", "1824"}], ",", 
       RowBox[{"1447", "\[Rule]", "1824"}], ",", 
       RowBox[{"1447", "\[Rule]", "1072"}], ",", 
       RowBox[{"1447", "\[Rule]", "1072"}], ",", 
       RowBox[{"1447", "\[Rule]", "1730"}], ",", 
       RowBox[{"1447", "\[Rule]", "1730"}], ",", 
       RowBox[{"1447", "\[Rule]", "1448"}], ",", 
       RowBox[{"1771", "\[Rule]", "1490"}], ",", 
       RowBox[{"1771", "\[Rule]", "1490"}], ",", 
       RowBox[{"1771", "\[Rule]", "2148"}], ",", 
       RowBox[{"1771", "\[Rule]", "2148"}], ",", 
       RowBox[{"1771", "\[Rule]", "1396"}], ",", 
       RowBox[{"1771", "\[Rule]", "1396"}], ",", 
       RowBox[{"1771", "\[Rule]", "2054"}], ",", 
       RowBox[{"1771", "\[Rule]", "2054"}], ",", 
       RowBox[{"1771", "\[Rule]", "1772"}], ",", 
       RowBox[{"1755", "\[Rule]", "1474"}], ",", 
       RowBox[{"1755", "\[Rule]", "1474"}], ",", 
       RowBox[{"1755", "\[Rule]", "2132"}], ",", 
       RowBox[{"1755", "\[Rule]", "2132"}], ",", 
       RowBox[{"1755", "\[Rule]", "1380"}], ",", 
       RowBox[{"1755", "\[Rule]", "1380"}], ",", 
       RowBox[{"1755", "\[Rule]", "2038"}], ",", 
       RowBox[{"1755", "\[Rule]", "2038"}], ",", 
       RowBox[{"1755", "\[Rule]", "1756"}], ",", 
       RowBox[{"1489", "\[Rule]", "1208"}], ",", 
       RowBox[{"1489", "\[Rule]", "1208"}], ",", 
       RowBox[{"1489", "\[Rule]", "1866"}], ",", 
       RowBox[{"1489", "\[Rule]", "1866"}], ",", 
       RowBox[{"1489", "\[Rule]", "1114"}], ",", 
       RowBox[{"1489", "\[Rule]", "1114"}], ",", 
       RowBox[{"1489", "\[Rule]", "1772"}], ",", 
       RowBox[{"1489", "\[Rule]", "1772"}], ",", 
       RowBox[{"1489", "\[Rule]", "1490"}], ",", 
       RowBox[{"1473", "\[Rule]", "1192"}], ",", 
       RowBox[{"1473", "\[Rule]", "1192"}], ",", 
       RowBox[{"1473", "\[Rule]", "1850"}], ",", 
       RowBox[{"1473", "\[Rule]", "1850"}], ",", 
       RowBox[{"1473", "\[Rule]", "1098"}], ",", 
       RowBox[{"1473", "\[Rule]", "1098"}], ",", 
       RowBox[{"1473", "\[Rule]", "1756"}], ",", 
       RowBox[{"1473", "\[Rule]", "1756"}], ",", 
       RowBox[{"1473", "\[Rule]", "1474"}], ",", 
       RowBox[{"1739", "\[Rule]", "1458"}], ",", 
       RowBox[{"1739", "\[Rule]", "1458"}], ",", 
       RowBox[{"1739", "\[Rule]", "2116"}], ",", 
       RowBox[{"1739", "\[Rule]", "2116"}], ",", 
       RowBox[{"1739", "\[Rule]", "1364"}], ",", 
       RowBox[{"1739", "\[Rule]", "1364"}], ",", 
       RowBox[{"1739", "\[Rule]", "2022"}], ",", 
       RowBox[{"1739", "\[Rule]", "2022"}], ",", 
       RowBox[{"1739", "\[Rule]", "1740"}], ",", 
       RowBox[{"1457", "\[Rule]", "1176"}], ",", 
       RowBox[{"1457", "\[Rule]", "1176"}], ",", 
       RowBox[{"1457", "\[Rule]", "1834"}], ",", 
       RowBox[{"1457", "\[Rule]", "1834"}], ",", 
       RowBox[{"1457", "\[Rule]", "1082"}], ",", 
       RowBox[{"1457", "\[Rule]", "1082"}], ",", 
       RowBox[{"1457", "\[Rule]", "1740"}], ",", 
       RowBox[{"1457", "\[Rule]", "1740"}], ",", 
       RowBox[{"1457", "\[Rule]", "1458"}], ",", 
       RowBox[{"1971", "\[Rule]", "1690"}], ",", 
       RowBox[{"1971", "\[Rule]", "1690"}], ",", 
       RowBox[{"1971", "\[Rule]", "2348"}], ",", 
       RowBox[{"1971", "\[Rule]", "1596"}], ",", 
       RowBox[{"1971", "\[Rule]", "1596"}], ",", 
       RowBox[{"1971", "\[Rule]", "2254"}], ",", 
       RowBox[{"1971", "\[Rule]", "1972"}], ",", 
       RowBox[{"1877", "\[Rule]", "1596"}], ",", 
       RowBox[{"1877", "\[Rule]", "1596"}], ",", 
       RowBox[{"1877", "\[Rule]", "2254"}], ",", 
       RowBox[{"1877", "\[Rule]", "2254"}], ",", 
       RowBox[{"1877", "\[Rule]", "1502"}], ",", 
       RowBox[{"1877", "\[Rule]", "1502"}], ",", 
       RowBox[{"1877", "\[Rule]", "2160"}], ",", 
       RowBox[{"1877", "\[Rule]", "2160"}], ",", 
       RowBox[{"1877", "\[Rule]", "1878"}], ",", 
       RowBox[{"1595", "\[Rule]", "1314"}], ",", 
       RowBox[{"1595", "\[Rule]", "1314"}], ",", 
       RowBox[{"1595", "\[Rule]", "1972"}], ",", 
       RowBox[{"1595", "\[Rule]", "1972"}], ",", 
       RowBox[{"1595", "\[Rule]", "1220"}], ",", 
       RowBox[{"1595", "\[Rule]", "1220"}], ",", 
       RowBox[{"1595", "\[Rule]", "1878"}], ",", 
       RowBox[{"1595", "\[Rule]", "1878"}], ",", 
       RowBox[{"1595", "\[Rule]", "1596"}], ",", 
       RowBox[{"1955", "\[Rule]", "1674"}], ",", 
       RowBox[{"1955", "\[Rule]", "1674"}], ",", 
       RowBox[{"1955", "\[Rule]", "2332"}], ",", 
       RowBox[{"1955", "\[Rule]", "2332"}], ",", 
       RowBox[{"1955", "\[Rule]", "1580"}], ",", 
       RowBox[{"1955", "\[Rule]", "2238"}], ",", 
       RowBox[{"1955", "\[Rule]", "1956"}], ",", 
       RowBox[{"1861", "\[Rule]", "1580"}], ",", 
       RowBox[{"1861", "\[Rule]", "2238"}], ",", 
       RowBox[{"1861", "\[Rule]", "1486"}], ",", 
       RowBox[{"1861", "\[Rule]", "1486"}], ",", 
       RowBox[{"1861", "\[Rule]", "2144"}], ",", 
       RowBox[{"1861", "\[Rule]", "2144"}], ",", 
       RowBox[{"1861", "\[Rule]", "1862"}], ",", 
       RowBox[{"1579", "\[Rule]", "1298"}], ",", 
       RowBox[{"1579", "\[Rule]", "1298"}], ",", 
       RowBox[{"1579", "\[Rule]", "1956"}], ",", 
       RowBox[{"1579", "\[Rule]", "1204"}], ",", 
       RowBox[{"1579", "\[Rule]", "1204"}], ",", 
       RowBox[{"1579", "\[Rule]", "1862"}], ",", 
       RowBox[{"1579", "\[Rule]", "1580"}], ",", 
       RowBox[{"1783", "\[Rule]", "1502"}], ",", 
       RowBox[{"1783", "\[Rule]", "1502"}], ",", 
       RowBox[{"1783", "\[Rule]", "2160"}], ",", 
       RowBox[{"1783", "\[Rule]", "2160"}], ",", 
       RowBox[{"1783", "\[Rule]", "1408"}], ",", 
       RowBox[{"1783", "\[Rule]", "1408"}], ",", 
       RowBox[{"1783", "\[Rule]", "2066"}], ",", 
       RowBox[{"1783", "\[Rule]", "2066"}], ",", 
       RowBox[{"1783", "\[Rule]", "1784"}], ",", 
       RowBox[{"1501", "\[Rule]", "1220"}], ",", 
       RowBox[{"1501", "\[Rule]", "1220"}], ",", 
       RowBox[{"1501", "\[Rule]", "1878"}], ",", 
       RowBox[{"1501", "\[Rule]", "1878"}], ",", 
       RowBox[{"1501", "\[Rule]", "1126"}], ",", 
       RowBox[{"1501", "\[Rule]", "1126"}], ",", 
       RowBox[{"1501", "\[Rule]", "1784"}], ",", 
       RowBox[{"1501", "\[Rule]", "1784"}], ",", 
       RowBox[{"1501", "\[Rule]", "1502"}], ",", 
       RowBox[{"1767", "\[Rule]", "1486"}], ",", 
       RowBox[{"1767", "\[Rule]", "1486"}], ",", 
       RowBox[{"1767", "\[Rule]", "2144"}], ",", 
       RowBox[{"1767", "\[Rule]", "2144"}], ",", 
       RowBox[{"1767", "\[Rule]", "1392"}], ",", 
       RowBox[{"1767", "\[Rule]", "1392"}], ",", 
       RowBox[{"1767", "\[Rule]", "2050"}], ",", 
       RowBox[{"1767", "\[Rule]", "2050"}], ",", 
       RowBox[{"1767", "\[Rule]", "1768"}], ",", 
       RowBox[{"1485", "\[Rule]", "1204"}], ",", 
       RowBox[{"1485", "\[Rule]", "1204"}], ",", 
       RowBox[{"1485", "\[Rule]", "1862"}], ",", 
       RowBox[{"1485", "\[Rule]", "1862"}], ",", 
       RowBox[{"1485", "\[Rule]", "1110"}], ",", 
       RowBox[{"1485", "\[Rule]", "1110"}], ",", 
       RowBox[{"1485", "\[Rule]", "1768"}], ",", 
       RowBox[{"1485", "\[Rule]", "1768"}], ",", 
       RowBox[{"1485", "\[Rule]", "1486"}], ",", 
       RowBox[{"1939", "\[Rule]", "1658"}], ",", 
       RowBox[{"1939", "\[Rule]", "1658"}], ",", 
       RowBox[{"1939", "\[Rule]", "2316"}], ",", 
       RowBox[{"1939", "\[Rule]", "2316"}], ",", 
       RowBox[{"1939", "\[Rule]", "1564"}], ",", 
       RowBox[{"1939", "\[Rule]", "1564"}], ",", 
       RowBox[{"1939", "\[Rule]", "2222"}], ",", 
       RowBox[{"1939", "\[Rule]", "2222"}], ",", 
       RowBox[{"1939", "\[Rule]", "1940"}], ",", 
       RowBox[{"1845", "\[Rule]", "1564"}], ",", 
       RowBox[{"1845", "\[Rule]", "2222"}], ",", 
       RowBox[{"1845", "\[Rule]", "2222"}], ",", 
       RowBox[{"1845", "\[Rule]", "1470"}], ",", 
       RowBox[{"1845", "\[Rule]", "2128"}], ",", 
       RowBox[{"1845", "\[Rule]", "2128"}], ",", 
       RowBox[{"1845", "\[Rule]", "1846"}], ",", 
       RowBox[{"1563", "\[Rule]", "1282"}], ",", 
       RowBox[{"1563", "\[Rule]", "1282"}], ",", 
       RowBox[{"1563", "\[Rule]", "1940"}], ",", 
       RowBox[{"1563", "\[Rule]", "1940"}], ",", 
       RowBox[{"1563", "\[Rule]", "1188"}], ",", 
       RowBox[{"1563", "\[Rule]", "1846"}], ",", 
       RowBox[{"1563", "\[Rule]", "1564"}], ",", 
       RowBox[{"1751", "\[Rule]", "1470"}], ",", 
       RowBox[{"1751", "\[Rule]", "1470"}], ",", 
       RowBox[{"1751", "\[Rule]", "2128"}], ",", 
       RowBox[{"1751", "\[Rule]", "2128"}], ",", 
       RowBox[{"1751", "\[Rule]", "1376"}], ",", 
       RowBox[{"1751", "\[Rule]", "1376"}], ",", 
       RowBox[{"1751", "\[Rule]", "2034"}], ",", 
       RowBox[{"1751", "\[Rule]", "2034"}], ",", 
       RowBox[{"1751", "\[Rule]", "1752"}], ",", 
       RowBox[{"1469", "\[Rule]", "1188"}], ",", 
       RowBox[{"1469", "\[Rule]", "1846"}], ",", 
       RowBox[{"1469", "\[Rule]", "1094"}], ",", 
       RowBox[{"1469", "\[Rule]", "1094"}], ",", 
       RowBox[{"1469", "\[Rule]", "1752"}], ",", 
       RowBox[{"1469", "\[Rule]", "1752"}], ",", 
       RowBox[{"1469", "\[Rule]", "1470"}], ",", 
       RowBox[{"1341", "\[Rule]", "1060"}], ",", 
       RowBox[{"1341", "\[Rule]", "1718"}], ",", 
       RowBox[{"1341", "\[Rule]", "1718"}], ",", 
       RowBox[{"1341", "\[Rule]", "1342"}], ",", 
       RowBox[{"1367", "\[Rule]", "1086"}], ",", 
       RowBox[{"1367", "\[Rule]", "1744"}], ",", 
       RowBox[{"1367", "\[Rule]", "1744"}], ",", 
       RowBox[{"1367", "\[Rule]", "1368"}], ",", 
       RowBox[{"1353", "\[Rule]", "1072"}], ",", 
       RowBox[{"1353", "\[Rule]", "1730"}], ",", 
       RowBox[{"1353", "\[Rule]", "1730"}], ",", 
       RowBox[{"1353", "\[Rule]", "1354"}], ",", 
       RowBox[{"1395", "\[Rule]", "1114"}], ",", 
       RowBox[{"1395", "\[Rule]", "1772"}], ",", 
       RowBox[{"1395", "\[Rule]", "1772"}], ",", 
       RowBox[{"1395", "\[Rule]", "1396"}], ",", 
       RowBox[{"1379", "\[Rule]", "1098"}], ",", 
       RowBox[{"1379", "\[Rule]", "1756"}], ",", 
       RowBox[{"1379", "\[Rule]", "1756"}], ",", 
       RowBox[{"1379", "\[Rule]", "1380"}], ",", 
       RowBox[{"1363", "\[Rule]", "1082"}], ",", 
       RowBox[{"1363", "\[Rule]", "1740"}], ",", 
       RowBox[{"1363", "\[Rule]", "1740"}], ",", 
       RowBox[{"1363", "\[Rule]", "1364"}], ",", 
       RowBox[{"1407", "\[Rule]", "1126"}], ",", 
       RowBox[{"1407", "\[Rule]", "1784"}], ",", 
       RowBox[{"1407", "\[Rule]", "1784"}], ",", 
       RowBox[{"1407", "\[Rule]", "1408"}], ",", 
       RowBox[{"1391", "\[Rule]", "1110"}], ",", 
       RowBox[{"1391", "\[Rule]", "1768"}], ",", 
       RowBox[{"1391", "\[Rule]", "1768"}], ",", 
       RowBox[{"1391", "\[Rule]", "1392"}], ",", 
       RowBox[{"1375", "\[Rule]", "1094"}], ",", 
       RowBox[{"1375", "\[Rule]", "1752"}], ",", 
       RowBox[{"1375", "\[Rule]", "1752"}], ",", 
       RowBox[{"1375", "\[Rule]", "1376"}], ",", 
       RowBox[{"1967", "\[Rule]", "1686"}], ",", 
       RowBox[{"1967", "\[Rule]", "1686"}], ",", 
       RowBox[{"1967", "\[Rule]", "2344"}], ",", 
       RowBox[{"1967", "\[Rule]", "2344"}], ",", 
       RowBox[{"1967", "\[Rule]", "1592"}], ",", 
       RowBox[{"1967", "\[Rule]", "1592"}], ",", 
       RowBox[{"1967", "\[Rule]", "2250"}], ",", 
       RowBox[{"1967", "\[Rule]", "2250"}], ",", 
       RowBox[{"1967", "\[Rule]", "1968"}], ",", 
       RowBox[{"1873", "\[Rule]", "1592"}], ",", 
       RowBox[{"1873", "\[Rule]", "1592"}], ",", 
       RowBox[{"1873", "\[Rule]", "2250"}], ",", 
       RowBox[{"1873", "\[Rule]", "1498"}], ",", 
       RowBox[{"1873", "\[Rule]", "1498"}], ",", 
       RowBox[{"1873", "\[Rule]", "2156"}], ",", 
       RowBox[{"1873", "\[Rule]", "1874"}], ",", 
       RowBox[{"1591", "\[Rule]", "1310"}], ",", 
       RowBox[{"1591", "\[Rule]", "1310"}], ",", 
       RowBox[{"1591", "\[Rule]", "1968"}], ",", 
       RowBox[{"1591", "\[Rule]", "1968"}], ",", 
       RowBox[{"1591", "\[Rule]", "1216"}], ",", 
       RowBox[{"1591", "\[Rule]", "1216"}], ",", 
       RowBox[{"1591", "\[Rule]", "1874"}], ",", 
       RowBox[{"1591", "\[Rule]", "1874"}], ",", 
       RowBox[{"1591", "\[Rule]", "1592"}], ",", 
       RowBox[{"1779", "\[Rule]", "1498"}], ",", 
       RowBox[{"1779", "\[Rule]", "1498"}], ",", 
       RowBox[{"1779", "\[Rule]", "2156"}], ",", 
       RowBox[{"1779", "\[Rule]", "2156"}], ",", 
       RowBox[{"1779", "\[Rule]", "1404"}], ",", 
       RowBox[{"1779", "\[Rule]", "1404"}], ",", 
       RowBox[{"1779", "\[Rule]", "2062"}], ",", 
       RowBox[{"1779", "\[Rule]", "2062"}], ",", 
       RowBox[{"1779", "\[Rule]", "1780"}], ",", 
       RowBox[{"1497", "\[Rule]", "1216"}], ",", 
       RowBox[{"1497", "\[Rule]", "1216"}], ",", 
       RowBox[{"1497", "\[Rule]", "1874"}], ",", 
       RowBox[{"1497", "\[Rule]", "1874"}], ",", 
       RowBox[{"1497", "\[Rule]", "1122"}], ",", 
       RowBox[{"1497", "\[Rule]", "1122"}], ",", 
       RowBox[{"1497", "\[Rule]", "1780"}], ",", 
       RowBox[{"1497", "\[Rule]", "1780"}], ",", 
       RowBox[{"1497", "\[Rule]", "1498"}], ",", 
       RowBox[{"1403", "\[Rule]", "1122"}], ",", 
       RowBox[{"1403", "\[Rule]", "1780"}], ",", 
       RowBox[{"1403", "\[Rule]", "1780"}], ",", 
       RowBox[{"1403", "\[Rule]", "1404"}], ",", 
       RowBox[{"1951", "\[Rule]", "1670"}], ",", 
       RowBox[{"1951", "\[Rule]", "1670"}], ",", 
       RowBox[{"1951", "\[Rule]", "2328"}], ",", 
       RowBox[{"1951", "\[Rule]", "2328"}], ",", 
       RowBox[{"1951", "\[Rule]", "1576"}], ",", 
       RowBox[{"1951", "\[Rule]", "1576"}], ",", 
       RowBox[{"1951", "\[Rule]", "2234"}], ",", 
       RowBox[{"1951", "\[Rule]", "2234"}], ",", 
       RowBox[{"1951", "\[Rule]", "1952"}], ",", 
       RowBox[{"1857", "\[Rule]", "1576"}], ",", 
       RowBox[{"1857", "\[Rule]", "1576"}], ",", 
       RowBox[{"1857", "\[Rule]", "2234"}], ",", 
       RowBox[{"1857", "\[Rule]", "2234"}], ",", 
       RowBox[{"1857", "\[Rule]", "1482"}], ",", 
       RowBox[{"1857", "\[Rule]", "2140"}], ",", 
       RowBox[{"1857", "\[Rule]", "1858"}], ",", 
       RowBox[{"1575", "\[Rule]", "1294"}], ",", 
       RowBox[{"1575", "\[Rule]", "1294"}], ",", 
       RowBox[{"1575", "\[Rule]", "1952"}], ",", 
       RowBox[{"1575", "\[Rule]", "1952"}], ",", 
       RowBox[{"1575", "\[Rule]", "1200"}], ",", 
       RowBox[{"1575", "\[Rule]", "1200"}], ",", 
       RowBox[{"1575", "\[Rule]", "1858"}], ",", 
       RowBox[{"1575", "\[Rule]", "1858"}], ",", 
       RowBox[{"1575", "\[Rule]", "1576"}], ",", 
       RowBox[{"1763", "\[Rule]", "1482"}], ",", 
       RowBox[{"1763", "\[Rule]", "2140"}], ",", 
       RowBox[{"1763", "\[Rule]", "1388"}], ",", 
       RowBox[{"1763", "\[Rule]", "1388"}], ",", 
       RowBox[{"1763", "\[Rule]", "2046"}], ",", 
       RowBox[{"1763", "\[Rule]", "2046"}], ",", 
       RowBox[{"1763", "\[Rule]", "1764"}], ",", 
       RowBox[{"1481", "\[Rule]", "1200"}], ",", 
       RowBox[{"1481", "\[Rule]", "1200"}], ",", 
       RowBox[{"1481", "\[Rule]", "1858"}], ",", 
       RowBox[{"1481", "\[Rule]", "1106"}], ",", 
       RowBox[{"1481", "\[Rule]", "1106"}], ",", 
       RowBox[{"1481", "\[Rule]", "1764"}], ",", 
       RowBox[{"1481", "\[Rule]", "1482"}], ",", 
       RowBox[{"1387", "\[Rule]", "1106"}], ",", 
       RowBox[{"1387", "\[Rule]", "1764"}], ",", 
       RowBox[{"1387", "\[Rule]", "1764"}], ",", 
       RowBox[{"1387", "\[Rule]", "1388"}], ",", 
       RowBox[{"647", "\[Rule]", "366"}], ",", 
       RowBox[{"647", "\[Rule]", "366"}], ",", 
       RowBox[{"647", "\[Rule]", "1024"}], ",", 
       RowBox[{"647", "\[Rule]", "1024"}], ",", 
       RowBox[{"647", "\[Rule]", "272"}], ",", 
       RowBox[{"647", "\[Rule]", "272"}], ",", 
       RowBox[{"647", "\[Rule]", "930"}], ",", 
       RowBox[{"647", "\[Rule]", "930"}], ",", 
       RowBox[{"647", "\[Rule]", "648"}], ",", 
       RowBox[{"553", "\[Rule]", "272"}], ",", 
       RowBox[{"553", "\[Rule]", "272"}], ",", 
       RowBox[{"553", "\[Rule]", "930"}], ",", 
       RowBox[{"553", "\[Rule]", "930"}], ",", 
       RowBox[{"553", "\[Rule]", "178"}], ",", 
       RowBox[{"553", "\[Rule]", "836"}], ",", 
       RowBox[{"553", "\[Rule]", "554"}], ",", 
       RowBox[{"271", "\[Rule]", "648"}], ",", 
       RowBox[{"271", "\[Rule]", "648"}], ",", 
       RowBox[{"271", "\[Rule]", "554"}], ",", 
       RowBox[{"271", "\[Rule]", "554"}], ",", 
       RowBox[{"271", "\[Rule]", "272"}], ",", 
       RowBox[{"1305", "\[Rule]", "1024"}], ",", 
       RowBox[{"1305", "\[Rule]", "1024"}], ",", 
       RowBox[{"1305", "\[Rule]", "1682"}], ",", 
       RowBox[{"1305", "\[Rule]", "1682"}], ",", 
       RowBox[{"1305", "\[Rule]", "930"}], ",", 
       RowBox[{"1305", "\[Rule]", "930"}], ",", 
       RowBox[{"1305", "\[Rule]", "1588"}], ",", 
       RowBox[{"1305", "\[Rule]", "1588"}], ",", 
       RowBox[{"1305", "\[Rule]", "1306"}], ",", 
       RowBox[{"1211", "\[Rule]", "930"}], ",", 
       RowBox[{"1211", "\[Rule]", "930"}], ",", 
       RowBox[{"1211", "\[Rule]", "1588"}], ",", 
       RowBox[{"1211", "\[Rule]", "1588"}], ",", 
       RowBox[{"1211", "\[Rule]", "836"}], ",", 
       RowBox[{"1211", "\[Rule]", "836"}], ",", 
       RowBox[{"1211", "\[Rule]", "1494"}], ",", 
       RowBox[{"1211", "\[Rule]", "1494"}], ",", 
       RowBox[{"1211", "\[Rule]", "1212"}], ",", 
       RowBox[{"929", "\[Rule]", "648"}], ",", 
       RowBox[{"929", "\[Rule]", "648"}], ",", 
       RowBox[{"929", "\[Rule]", "1306"}], ",", 
       RowBox[{"929", "\[Rule]", "1306"}], ",", 
       RowBox[{"929", "\[Rule]", "554"}], ",", 
       RowBox[{"929", "\[Rule]", "554"}], ",", 
       RowBox[{"929", "\[Rule]", "1212"}], ",", 
       RowBox[{"929", "\[Rule]", "1212"}], ",", 
       RowBox[{"929", "\[Rule]", "930"}], ",", 
       RowBox[{"459", "\[Rule]", "178"}], ",", 
       RowBox[{"459", "\[Rule]", "836"}], ",", 
       RowBox[{"459", "\[Rule]", "84"}], ",", 
       RowBox[{"459", "\[Rule]", "84"}], ",", 
       RowBox[{"459", "\[Rule]", "742"}], ",", 
       RowBox[{"459", "\[Rule]", "742"}], ",", 
       RowBox[{"459", "\[Rule]", "460"}], ",", 
       RowBox[{"177", "\[Rule]", "554"}], ",", 
       RowBox[{"177", "\[Rule]", "460"}], ",", 
       RowBox[{"177", "\[Rule]", "178"}], ",", 
       RowBox[{"1117", "\[Rule]", "836"}], ",", 
       RowBox[{"1117", "\[Rule]", "836"}], ",", 
       RowBox[{"1117", "\[Rule]", "1494"}], ",", 
       RowBox[{"1117", "\[Rule]", "1494"}], ",", 
       RowBox[{"1117", "\[Rule]", "742"}], ",", 
       RowBox[{"1117", "\[Rule]", "1400"}], ",", 
       RowBox[{"1117", "\[Rule]", "1118"}], ",", 
       RowBox[{"835", "\[Rule]", "554"}], ",", 
       RowBox[{"835", "\[Rule]", "1212"}], ",", 
       RowBox[{"835", "\[Rule]", "1212"}], ",", 
       RowBox[{"835", "\[Rule]", "460"}], ",", 
       RowBox[{"835", "\[Rule]", "1118"}], ",", 
       RowBox[{"835", "\[Rule]", "1118"}], ",", 
       RowBox[{"835", "\[Rule]", "836"}], ",", 
       RowBox[{"83", "\[Rule]", "460"}], ",", 
       RowBox[{"83", "\[Rule]", "460"}], ",", 
       RowBox[{"83", "\[Rule]", "84"}], ",", 
       RowBox[{"741", "\[Rule]", "460"}], ",", 
       RowBox[{"741", "\[Rule]", "460"}], ",", 
       RowBox[{"741", "\[Rule]", "1118"}], ",", 
       RowBox[{"741", "\[Rule]", "742"}], ",", 
       RowBox[{"1963", "\[Rule]", "1682"}], ",", 
       RowBox[{"1963", "\[Rule]", "1682"}], ",", 
       RowBox[{"1963", "\[Rule]", "2340"}], ",", 
       RowBox[{"1963", "\[Rule]", "2340"}], ",", 
       RowBox[{"1963", "\[Rule]", "1588"}], ",", 
       RowBox[{"1963", "\[Rule]", "1588"}], ",", 
       RowBox[{"1963", "\[Rule]", "2246"}], ",", 
       RowBox[{"1963", "\[Rule]", "2246"}], ",", 
       RowBox[{"1963", "\[Rule]", "1964"}], ",", 
       RowBox[{"1869", "\[Rule]", "1588"}], ",", 
       RowBox[{"1869", "\[Rule]", "1588"}], ",", 
       RowBox[{"1869", "\[Rule]", "2246"}], ",", 
       RowBox[{"1869", "\[Rule]", "2246"}], ",", 
       RowBox[{"1869", "\[Rule]", "1494"}], ",", 
       RowBox[{"1869", "\[Rule]", "1494"}], ",", 
       RowBox[{"1869", "\[Rule]", "2152"}], ",", 
       RowBox[{"1869", "\[Rule]", "2152"}], ",", 
       RowBox[{"1869", "\[Rule]", "1870"}], ",", 
       RowBox[{"1587", "\[Rule]", "1306"}], ",", 
       RowBox[{"1587", "\[Rule]", "1306"}], ",", 
       RowBox[{"1587", "\[Rule]", "1964"}], ",", 
       RowBox[{"1587", "\[Rule]", "1964"}], ",", 
       RowBox[{"1587", "\[Rule]", "1212"}], ",", 
       RowBox[{"1587", "\[Rule]", "1212"}], ",", 
       RowBox[{"1587", "\[Rule]", "1870"}], ",", 
       RowBox[{"1587", "\[Rule]", "1870"}], ",", 
       RowBox[{"1587", "\[Rule]", "1588"}], ",", 
       RowBox[{"1775", "\[Rule]", "1494"}], ",", 
       RowBox[{"1775", "\[Rule]", "1494"}], ",", 
       RowBox[{"1775", "\[Rule]", "2152"}], ",", 
       RowBox[{"1775", "\[Rule]", "1400"}], ",", 
       RowBox[{"1775", "\[Rule]", "1400"}], ",", 
       RowBox[{"1775", "\[Rule]", "2058"}], ",", 
       RowBox[{"1775", "\[Rule]", "1776"}], ",", 
       RowBox[{"1493", "\[Rule]", "1212"}], ",", 
       RowBox[{"1493", "\[Rule]", "1212"}], ",", 
       RowBox[{"1493", "\[Rule]", "1870"}], ",", 
       RowBox[{"1493", "\[Rule]", "1870"}], ",", 
       RowBox[{"1493", "\[Rule]", "1118"}], ",", 
       RowBox[{"1493", "\[Rule]", "1118"}], ",", 
       RowBox[{"1493", "\[Rule]", "1776"}], ",", 
       RowBox[{"1493", "\[Rule]", "1776"}], ",", 
       RowBox[{"1493", "\[Rule]", "1494"}], ",", 
       RowBox[{"1399", "\[Rule]", "1118"}], ",", 
       RowBox[{"1399", "\[Rule]", "1776"}], ",", 
       RowBox[{"1399", "\[Rule]", "1776"}], ",", 
       RowBox[{"1399", "\[Rule]", "1400"}], ",", 
       RowBox[{"308", "\[Rule]", "295"}], ",", 
       RowBox[{"308", "\[Rule]", "321"}], ",", 
       RowBox[{"308", "\[Rule]", "305"}], ",", 
       RowBox[{"966", "\[Rule]", "953"}], ",", 
       RowBox[{"966", "\[Rule]", "979"}], ",", 
       RowBox[{"966", "\[Rule]", "963"}], ",", 
       RowBox[{"214", "\[Rule]", "201"}], ",", 
       RowBox[{"214", "\[Rule]", "227"}], ",", 
       RowBox[{"214", "\[Rule]", "211"}], ",", 
       RowBox[{"872", "\[Rule]", "859"}], ",", 
       RowBox[{"872", "\[Rule]", "885"}], ",", 
       RowBox[{"872", "\[Rule]", "869"}], ",", 
       RowBox[{"590", "\[Rule]", "577"}], ",", 
       RowBox[{"590", "\[Rule]", "603"}], ",", 
       RowBox[{"590", "\[Rule]", "587"}], ",", 
       RowBox[{"334", "\[Rule]", "321"}], ",", 
       RowBox[{"334", "\[Rule]", "347"}], ",", 
       RowBox[{"334", "\[Rule]", "331"}], ",", 
       RowBox[{"992", "\[Rule]", "979"}], ",", 
       RowBox[{"992", "\[Rule]", "1005"}], ",", 
       RowBox[{"992", "\[Rule]", "989"}], ",", 
       RowBox[{"616", "\[Rule]", "603"}], ",", 
       RowBox[{"616", "\[Rule]", "629"}], ",", 
       RowBox[{"616", "\[Rule]", "613"}], ",", 
       RowBox[{"320", "\[Rule]", "305"}], ",", 
       RowBox[{"320", "\[Rule]", "331"}], ",", 
       RowBox[{"320", "\[Rule]", "321"}], ",", 
       RowBox[{"320", "\[Rule]", "317"}], ",", 
       RowBox[{"978", "\[Rule]", "963"}], ",", 
       RowBox[{"978", "\[Rule]", "989"}], ",", 
       RowBox[{"978", "\[Rule]", "979"}], ",", 
       RowBox[{"978", "\[Rule]", "975"}], ",", 
       RowBox[{"226", "\[Rule]", "211"}], ",", 
       RowBox[{"226", "\[Rule]", "237"}], ",", 
       RowBox[{"226", "\[Rule]", "227"}], ",", 
       RowBox[{"226", "\[Rule]", "223"}], ",", 
       RowBox[{"884", "\[Rule]", "869"}], ",", 
       RowBox[{"884", "\[Rule]", "895"}], ",", 
       RowBox[{"884", "\[Rule]", "885"}], ",", 
       RowBox[{"884", "\[Rule]", "881"}], ",", 
       RowBox[{"602", "\[Rule]", "587"}], ",", 
       RowBox[{"602", "\[Rule]", "613"}], ",", 
       RowBox[{"602", "\[Rule]", "603"}], ",", 
       RowBox[{"602", "\[Rule]", "599"}], ",", 
       RowBox[{"120", "\[Rule]", "107"}], ",", 
       RowBox[{"120", "\[Rule]", "133"}], ",", 
       RowBox[{"120", "\[Rule]", "117"}], ",", 
       RowBox[{"778", "\[Rule]", "765"}], ",", 
       RowBox[{"778", "\[Rule]", "791"}], ",", 
       RowBox[{"778", "\[Rule]", "775"}], ",", 
       RowBox[{"496", "\[Rule]", "483"}], ",", 
       RowBox[{"496", "\[Rule]", "509"}], ",", 
       RowBox[{"496", "\[Rule]", "493"}], ",", 
       RowBox[{"132", "\[Rule]", "117"}], ",", 
       RowBox[{"132", "\[Rule]", "143"}], ",", 
       RowBox[{"132", "\[Rule]", "133"}], ",", 
       RowBox[{"132", "\[Rule]", "129"}], ",", 
       RowBox[{"790", "\[Rule]", "775"}], ",", 
       RowBox[{"790", "\[Rule]", "801"}], ",", 
       RowBox[{"790", "\[Rule]", "791"}], ",", 
       RowBox[{"790", "\[Rule]", "787"}], ",", 
       RowBox[{"508", "\[Rule]", "493"}], ",", 
       RowBox[{"508", "\[Rule]", "519"}], ",", 
       RowBox[{"508", "\[Rule]", "509"}], ",", 
       RowBox[{"508", "\[Rule]", "505"}], ",", 
       RowBox[{"362", "\[Rule]", "347"}], ",", 
       RowBox[{"362", "\[Rule]", "375"}], ",", 
       RowBox[{"362", "\[Rule]", "359"}], ",", 
       RowBox[{"1020", "\[Rule]", "1005"}], ",", 
       RowBox[{"1020", "\[Rule]", "1033"}], ",", 
       RowBox[{"1020", "\[Rule]", "1017"}], ",", 
       RowBox[{"644", "\[Rule]", "629"}], ",", 
       RowBox[{"644", "\[Rule]", "657"}], ",", 
       RowBox[{"644", "\[Rule]", "641"}], ",", 
       RowBox[{"346", "\[Rule]", "331"}], ",", 
       RowBox[{"346", "\[Rule]", "359"}], ",", 
       RowBox[{"346", "\[Rule]", "347"}], ",", 
       RowBox[{"346", "\[Rule]", "343"}], ",", 
       RowBox[{"1004", "\[Rule]", "989"}], ",", 
       RowBox[{"1004", "\[Rule]", "1017"}], ",", 
       RowBox[{"1004", "\[Rule]", "1005"}], ",", 
       RowBox[{"1004", "\[Rule]", "1001"}], ",", 
       RowBox[{"628", "\[Rule]", "613"}], ",", 
       RowBox[{"628", "\[Rule]", "641"}], ",", 
       RowBox[{"628", "\[Rule]", "629"}], ",", 
       RowBox[{"628", "\[Rule]", "625"}], ",", 
       RowBox[{"330", "\[Rule]", "317"}], ",", 
       RowBox[{"330", "\[Rule]", "343"}], ",", 
       RowBox[{"330", "\[Rule]", "331"}], ",", 
       RowBox[{"330", "\[Rule]", "327"}], ",", 
       RowBox[{"988", "\[Rule]", "975"}], ",", 
       RowBox[{"988", "\[Rule]", "1001"}], ",", 
       RowBox[{"988", "\[Rule]", "989"}], ",", 
       RowBox[{"988", "\[Rule]", "985"}], ",", 
       RowBox[{"236", "\[Rule]", "223"}], ",", 
       RowBox[{"236", "\[Rule]", "249"}], ",", 
       RowBox[{"236", "\[Rule]", "237"}], ",", 
       RowBox[{"236", "\[Rule]", "233"}], ",", 
       RowBox[{"894", "\[Rule]", "881"}], ",", 
       RowBox[{"894", "\[Rule]", "907"}], ",", 
       RowBox[{"894", "\[Rule]", "895"}], ",", 
       RowBox[{"894", "\[Rule]", "891"}], ",", 
       RowBox[{"612", "\[Rule]", "599"}], ",", 
       RowBox[{"612", "\[Rule]", "625"}], ",", 
       RowBox[{"612", "\[Rule]", "613"}], ",", 
       RowBox[{"612", "\[Rule]", "609"}], ",", 
       RowBox[{"142", "\[Rule]", "129"}], ",", 
       RowBox[{"142", "\[Rule]", "155"}], ",", 
       RowBox[{"142", "\[Rule]", "143"}], ",", 
       RowBox[{"142", "\[Rule]", "139"}], ",", 
       RowBox[{"800", "\[Rule]", "787"}], ",", 
       RowBox[{"800", "\[Rule]", "813"}], ",", 
       RowBox[{"800", "\[Rule]", "801"}], ",", 
       RowBox[{"800", "\[Rule]", "797"}], ",", 
       RowBox[{"518", "\[Rule]", "505"}], ",", 
       RowBox[{"518", "\[Rule]", "531"}], ",", 
       RowBox[{"518", "\[Rule]", "519"}], ",", 
       RowBox[{"518", "\[Rule]", "515"}], ",", 
       RowBox[{"1624", "\[Rule]", "1611"}], ",", 
       RowBox[{"1624", "\[Rule]", "1637"}], ",", 
       RowBox[{"1624", "\[Rule]", "1621"}], ",", 
       RowBox[{"1530", "\[Rule]", "1517"}], ",", 
       RowBox[{"1530", "\[Rule]", "1543"}], ",", 
       RowBox[{"1530", "\[Rule]", "1527"}], ",", 
       RowBox[{"1248", "\[Rule]", "1235"}], ",", 
       RowBox[{"1248", "\[Rule]", "1261"}], ",", 
       RowBox[{"1248", "\[Rule]", "1245"}], ",", 
       RowBox[{"1650", "\[Rule]", "1637"}], ",", 
       RowBox[{"1650", "\[Rule]", "1663"}], ",", 
       RowBox[{"1650", "\[Rule]", "1647"}], ",", 
       RowBox[{"1274", "\[Rule]", "1261"}], ",", 
       RowBox[{"1274", "\[Rule]", "1287"}], ",", 
       RowBox[{"1274", "\[Rule]", "1271"}], ",", 
       RowBox[{"1636", "\[Rule]", "1621"}], ",", 
       RowBox[{"1636", "\[Rule]", "1647"}], ",", 
       RowBox[{"1636", "\[Rule]", "1637"}], ",", 
       RowBox[{"1636", "\[Rule]", "1633"}], ",", 
       RowBox[{"1542", "\[Rule]", "1527"}], ",", 
       RowBox[{"1542", "\[Rule]", "1553"}], ",", 
       RowBox[{"1542", "\[Rule]", "1543"}], ",", 
       RowBox[{"1542", "\[Rule]", "1539"}], ",", 
       RowBox[{"1260", "\[Rule]", "1245"}], ",", 
       RowBox[{"1260", "\[Rule]", "1271"}], ",", 
       RowBox[{"1260", "\[Rule]", "1261"}], ",", 
       RowBox[{"1260", "\[Rule]", "1257"}], ",", 
       RowBox[{"1436", "\[Rule]", "1423"}], ",", 
       RowBox[{"1436", "\[Rule]", "1449"}], ",", 
       RowBox[{"1436", "\[Rule]", "1433"}], ",", 
       RowBox[{"1154", "\[Rule]", "1141"}], ",", 
       RowBox[{"1154", "\[Rule]", "1167"}], ",", 
       RowBox[{"1154", "\[Rule]", "1151"}], ",", 
       RowBox[{"1448", "\[Rule]", "1433"}], ",", 
       RowBox[{"1448", "\[Rule]", "1459"}], ",", 
       RowBox[{"1448", "\[Rule]", "1449"}], ",", 
       RowBox[{"1448", "\[Rule]", "1445"}], ",", 
       RowBox[{"1166", "\[Rule]", "1151"}], ",", 
       RowBox[{"1166", "\[Rule]", "1177"}], ",", 
       RowBox[{"1166", "\[Rule]", "1167"}], ",", 
       RowBox[{"1166", "\[Rule]", "1163"}], ",", 
       RowBox[{"1678", "\[Rule]", "1663"}], ",", 
       RowBox[{"1678", "\[Rule]", "1691"}], ",", 
       RowBox[{"1678", "\[Rule]", "1675"}], ",", 
       RowBox[{"1302", "\[Rule]", "1287"}], ",", 
       RowBox[{"1302", "\[Rule]", "1315"}], ",", 
       RowBox[{"1302", "\[Rule]", "1299"}], ",", 
       RowBox[{"1662", "\[Rule]", "1647"}], ",", 
       RowBox[{"1662", "\[Rule]", "1675"}], ",", 
       RowBox[{"1662", "\[Rule]", "1663"}], ",", 
       RowBox[{"1662", "\[Rule]", "1659"}], ",", 
       RowBox[{"1286", "\[Rule]", "1271"}], ",", 
       RowBox[{"1286", "\[Rule]", "1299"}], ",", 
       RowBox[{"1286", "\[Rule]", "1287"}], ",", 
       RowBox[{"1286", "\[Rule]", "1283"}], ",", 
       RowBox[{"1646", "\[Rule]", "1633"}], ",", 
       RowBox[{"1646", "\[Rule]", "1659"}], ",", 
       RowBox[{"1646", "\[Rule]", "1647"}], ",", 
       RowBox[{"1646", "\[Rule]", "1643"}], ",", 
       RowBox[{"1552", "\[Rule]", "1539"}], ",", 
       RowBox[{"1552", "\[Rule]", "1565"}], ",", 
       RowBox[{"1552", "\[Rule]", "1553"}], ",", 
       RowBox[{"1552", "\[Rule]", "1549"}], ",", 
       RowBox[{"1270", "\[Rule]", "1257"}], ",", 
       RowBox[{"1270", "\[Rule]", "1283"}], ",", 
       RowBox[{"1270", "\[Rule]", "1271"}], ",", 
       RowBox[{"1270", "\[Rule]", "1267"}], ",", 
       RowBox[{"1458", "\[Rule]", "1445"}], ",", 
       RowBox[{"1458", "\[Rule]", "1471"}], ",", 
       RowBox[{"1458", "\[Rule]", "1459"}], ",", 
       RowBox[{"1458", "\[Rule]", "1455"}], ",", 
       RowBox[{"1176", "\[Rule]", "1163"}], ",", 
       RowBox[{"1176", "\[Rule]", "1189"}], ",", 
       RowBox[{"1176", "\[Rule]", "1177"}], ",", 
       RowBox[{"1176", "\[Rule]", "1173"}], ",", 
       RowBox[{"26", "\[Rule]", "13"}], ",", 
       RowBox[{"26", "\[Rule]", "39"}], ",", 
       RowBox[{"26", "\[Rule]", "23"}], ",", 
       RowBox[{"684", "\[Rule]", "671"}], ",", 
       RowBox[{"684", "\[Rule]", "697"}], ",", 
       RowBox[{"684", "\[Rule]", "681"}], ",", 
       RowBox[{"402", "\[Rule]", "389"}], ",", 
       RowBox[{"402", "\[Rule]", "415"}], ",", 
       RowBox[{"402", "\[Rule]", "399"}], ",", 
       RowBox[{"38", "\[Rule]", "23"}], ",", 
       RowBox[{"38", "\[Rule]", "49"}], ",", 
       RowBox[{"38", "\[Rule]", "39"}], ",", 
       RowBox[{"38", "\[Rule]", "35"}], ",", 
       RowBox[{"696", "\[Rule]", "681"}], ",", 
       RowBox[{"696", "\[Rule]", "707"}], ",", 
       RowBox[{"696", "\[Rule]", "697"}], ",", 
       RowBox[{"696", "\[Rule]", "693"}], ",", 
       RowBox[{"414", "\[Rule]", "399"}], ",", 
       RowBox[{"414", "\[Rule]", "425"}], ",", 
       RowBox[{"414", "\[Rule]", "415"}], ",", 
       RowBox[{"414", "\[Rule]", "411"}], ",", 
       RowBox[{"48", "\[Rule]", "35"}], ",", 
       RowBox[{"48", "\[Rule]", "61"}], ",", 
       RowBox[{"48", "\[Rule]", "49"}], ",", 
       RowBox[{"48", "\[Rule]", "45"}], ",", 
       RowBox[{"706", "\[Rule]", "693"}], ",", 
       RowBox[{"706", "\[Rule]", "719"}], ",", 
       RowBox[{"706", "\[Rule]", "707"}], ",", 
       RowBox[{"706", "\[Rule]", "703"}], ",", 
       RowBox[{"424", "\[Rule]", "411"}], ",", 
       RowBox[{"424", "\[Rule]", "437"}], ",", 
       RowBox[{"424", "\[Rule]", "425"}], ",", 
       RowBox[{"424", "\[Rule]", "421"}], ",", 
       RowBox[{"1342", "\[Rule]", "1329"}], ",", 
       RowBox[{"1342", "\[Rule]", "1355"}], ",", 
       RowBox[{"1342", "\[Rule]", "1339"}], ",", 
       RowBox[{"1060", "\[Rule]", "1047"}], ",", 
       RowBox[{"1060", "\[Rule]", "1073"}], ",", 
       RowBox[{"1060", "\[Rule]", "1057"}], ",", 
       RowBox[{"1354", "\[Rule]", "1339"}], ",", 
       RowBox[{"1354", "\[Rule]", "1365"}], ",", 
       RowBox[{"1354", "\[Rule]", "1355"}], ",", 
       RowBox[{"1354", "\[Rule]", "1351"}], ",", 
       RowBox[{"1072", "\[Rule]", "1057"}], ",", 
       RowBox[{"1072", "\[Rule]", "1083"}], ",", 
       RowBox[{"1072", "\[Rule]", "1073"}], ",", 
       RowBox[{"1072", "\[Rule]", "1069"}], ",", 
       RowBox[{"1364", "\[Rule]", "1351"}], ",", 
       RowBox[{"1364", "\[Rule]", "1377"}], ",", 
       RowBox[{"1364", "\[Rule]", "1365"}], ",", 
       RowBox[{"1364", "\[Rule]", "1361"}], ",", 
       RowBox[{"1082", "\[Rule]", "1069"}], ",", 
       RowBox[{"1082", "\[Rule]", "1095"}], ",", 
       RowBox[{"1082", "\[Rule]", "1083"}], ",", 
       RowBox[{"1082", "\[Rule]", "1079"}], ",", 
       RowBox[{"374", "\[Rule]", "359"}], ",", 
       RowBox[{"374", "\[Rule]", "375"}], ",", 
       RowBox[{"374", "\[Rule]", "371"}], ",", 
       RowBox[{"1032", "\[Rule]", "1017"}], ",", 
       RowBox[{"1032", "\[Rule]", "1033"}], ",", 
       RowBox[{"1032", "\[Rule]", "1029"}], ",", 
       RowBox[{"656", "\[Rule]", "641"}], ",", 
       RowBox[{"656", "\[Rule]", "657"}], ",", 
       RowBox[{"656", "\[Rule]", "653"}], ",", 
       RowBox[{"358", "\[Rule]", "343"}], ",", 
       RowBox[{"358", "\[Rule]", "371"}], ",", 
       RowBox[{"358", "\[Rule]", "359"}], ",", 
       RowBox[{"358", "\[Rule]", "355"}], ",", 
       RowBox[{"1016", "\[Rule]", "1001"}], ",", 
       RowBox[{"1016", "\[Rule]", "1029"}], ",", 
       RowBox[{"1016", "\[Rule]", "1017"}], ",", 
       RowBox[{"1016", "\[Rule]", "1013"}], ",", 
       RowBox[{"640", "\[Rule]", "625"}], ",", 
       RowBox[{"640", "\[Rule]", "653"}], ",", 
       RowBox[{"640", "\[Rule]", "641"}], ",", 
       RowBox[{"640", "\[Rule]", "637"}], ",", 
       RowBox[{"1690", "\[Rule]", "1675"}], ",", 
       RowBox[{"1690", "\[Rule]", "1691"}], ",", 
       RowBox[{"1690", "\[Rule]", "1687"}], ",", 
       RowBox[{"1314", "\[Rule]", "1299"}], ",", 
       RowBox[{"1314", "\[Rule]", "1315"}], ",", 
       RowBox[{"1314", "\[Rule]", "1311"}], ",", 
       RowBox[{"1674", "\[Rule]", "1659"}], ",", 
       RowBox[{"1674", "\[Rule]", "1687"}], ",", 
       RowBox[{"1674", "\[Rule]", "1675"}], ",", 
       RowBox[{"1674", "\[Rule]", "1671"}], ",", 
       RowBox[{"1298", "\[Rule]", "1283"}], ",", 
       RowBox[{"1298", "\[Rule]", "1311"}], ",", 
       RowBox[{"1298", "\[Rule]", "1299"}], ",", 
       RowBox[{"1298", "\[Rule]", "1295"}], ",", 
       RowBox[{"342", "\[Rule]", "327"}], ",", 
       RowBox[{"342", "\[Rule]", "355"}], ",", 
       RowBox[{"342", "\[Rule]", "343"}], ",", 
       RowBox[{"342", "\[Rule]", "339"}], ",", 
       RowBox[{"1000", "\[Rule]", "985"}], ",", 
       RowBox[{"1000", "\[Rule]", "1013"}], ",", 
       RowBox[{"1000", "\[Rule]", "1001"}], ",", 
       RowBox[{"1000", "\[Rule]", "997"}], ",", 
       RowBox[{"248", "\[Rule]", "233"}], ",", 
       RowBox[{"248", "\[Rule]", "261"}], ",", 
       RowBox[{"248", "\[Rule]", "249"}], ",", 
       RowBox[{"248", "\[Rule]", "245"}], ",", 
       RowBox[{"906", "\[Rule]", "891"}], ",", 
       RowBox[{"906", "\[Rule]", "919"}], ",", 
       RowBox[{"906", "\[Rule]", "907"}], ",", 
       RowBox[{"906", "\[Rule]", "903"}], ",", 
       RowBox[{"624", "\[Rule]", "609"}], ",", 
       RowBox[{"624", "\[Rule]", "637"}], ",", 
       RowBox[{"624", "\[Rule]", "625"}], ",", 
       RowBox[{"624", "\[Rule]", "621"}], ",", 
       RowBox[{"154", "\[Rule]", "139"}], ",", 
       RowBox[{"154", "\[Rule]", "167"}], ",", 
       RowBox[{"154", "\[Rule]", "155"}], ",", 
       RowBox[{"154", "\[Rule]", "151"}], ",", 
       RowBox[{"812", "\[Rule]", "797"}], ",", 
       RowBox[{"812", "\[Rule]", "825"}], ",", 
       RowBox[{"812", "\[Rule]", "813"}], ",", 
       RowBox[{"812", "\[Rule]", "809"}], ",", 
       RowBox[{"530", "\[Rule]", "515"}], ",", 
       RowBox[{"530", "\[Rule]", "543"}], ",", 
       RowBox[{"530", "\[Rule]", "531"}], ",", 
       RowBox[{"530", "\[Rule]", "527"}], ",", 
       RowBox[{"1658", "\[Rule]", "1643"}], ",", 
       RowBox[{"1658", "\[Rule]", "1671"}], ",", 
       RowBox[{"1658", "\[Rule]", "1659"}], ",", 
       RowBox[{"1658", "\[Rule]", "1655"}], ",", 
       RowBox[{"1564", "\[Rule]", "1549"}], ",", 
       RowBox[{"1564", "\[Rule]", "1577"}], ",", 
       RowBox[{"1564", "\[Rule]", "1565"}], ",", 
       RowBox[{"1564", "\[Rule]", "1561"}], ",", 
       RowBox[{"1282", "\[Rule]", "1267"}], ",", 
       RowBox[{"1282", "\[Rule]", "1295"}], ",", 
       RowBox[{"1282", "\[Rule]", "1283"}], ",", 
       RowBox[{"1282", "\[Rule]", "1279"}], ",", 
       RowBox[{"1470", "\[Rule]", "1455"}], ",", 
       RowBox[{"1470", "\[Rule]", "1483"}], ",", 
       RowBox[{"1470", "\[Rule]", "1471"}], ",", 
       RowBox[{"1470", "\[Rule]", "1467"}], ",", 
       RowBox[{"1188", "\[Rule]", "1173"}], ",", 
       RowBox[{"1188", "\[Rule]", "1201"}], ",", 
       RowBox[{"1188", "\[Rule]", "1189"}], ",", 
       RowBox[{"1188", "\[Rule]", "1185"}], ",", 
       RowBox[{"60", "\[Rule]", "45"}], ",", 
       RowBox[{"60", "\[Rule]", "73"}], ",", 
       RowBox[{"60", "\[Rule]", "61"}], ",", 
       RowBox[{"60", "\[Rule]", "57"}], ",", 
       RowBox[{"718", "\[Rule]", "703"}], ",", 
       RowBox[{"718", "\[Rule]", "731"}], ",", 
       RowBox[{"718", "\[Rule]", "719"}], ",", 
       RowBox[{"718", "\[Rule]", "715"}], ",", 
       RowBox[{"436", "\[Rule]", "421"}], ",", 
       RowBox[{"436", "\[Rule]", "449"}], ",", 
       RowBox[{"436", "\[Rule]", "437"}], ",", 
       RowBox[{"436", "\[Rule]", "433"}], ",", 
       RowBox[{"1376", "\[Rule]", "1361"}], ",", 
       RowBox[{"1376", "\[Rule]", "1389"}], ",", 
       RowBox[{"1376", "\[Rule]", "1377"}], ",", 
       RowBox[{"1376", "\[Rule]", "1373"}], ",", 
       RowBox[{"1094", "\[Rule]", "1079"}], ",", 
       RowBox[{"1094", "\[Rule]", "1107"}], ",", 
       RowBox[{"1094", "\[Rule]", "1095"}], ",", 
       RowBox[{"1094", "\[Rule]", "1091"}], ",", 
       RowBox[{"370", "\[Rule]", "355"}], ",", 
       RowBox[{"370", "\[Rule]", "371"}], ",", 
       RowBox[{"370", "\[Rule]", "367"}], ",", 
       RowBox[{"1028", "\[Rule]", "1013"}], ",", 
       RowBox[{"1028", "\[Rule]", "1029"}], ",", 
       RowBox[{"1028", "\[Rule]", "1025"}], ",", 
       RowBox[{"652", "\[Rule]", "637"}], ",", 
       RowBox[{"652", "\[Rule]", "653"}], ",", 
       RowBox[{"652", "\[Rule]", "649"}], ",", 
       RowBox[{"1686", "\[Rule]", "1671"}], ",", 
       RowBox[{"1686", "\[Rule]", "1687"}], ",", 
       RowBox[{"1686", "\[Rule]", "1683"}], ",", 
       RowBox[{"1310", "\[Rule]", "1295"}], ",", 
       RowBox[{"1310", "\[Rule]", "1311"}], ",", 
       RowBox[{"1310", "\[Rule]", "1307"}], ",", 
       RowBox[{"354", "\[Rule]", "339"}], ",", 
       RowBox[{"354", "\[Rule]", "367"}], ",", 
       RowBox[{"354", "\[Rule]", "355"}], ",", 
       RowBox[{"354", "\[Rule]", "351"}], ",", 
       RowBox[{"1012", "\[Rule]", "997"}], ",", 
       RowBox[{"1012", "\[Rule]", "1025"}], ",", 
       RowBox[{"1012", "\[Rule]", "1013"}], ",", 
       RowBox[{"1012", "\[Rule]", "1009"}], ",", 
       RowBox[{"260", "\[Rule]", "245"}], ",", 
       RowBox[{"260", "\[Rule]", "273"}], ",", 
       RowBox[{"260", "\[Rule]", "261"}], ",", 
       RowBox[{"260", "\[Rule]", "257"}], ",", 
       RowBox[{"918", "\[Rule]", "903"}], ",", 
       RowBox[{"918", "\[Rule]", "931"}], ",", 
       RowBox[{"918", "\[Rule]", "919"}], ",", 
       RowBox[{"918", "\[Rule]", "915"}], ",", 
       RowBox[{"636", "\[Rule]", "621"}], ",", 
       RowBox[{"636", "\[Rule]", "649"}], ",", 
       RowBox[{"636", "\[Rule]", "637"}], ",", 
       RowBox[{"636", "\[Rule]", "633"}], ",", 
       RowBox[{"166", "\[Rule]", "151"}], ",", 
       RowBox[{"166", "\[Rule]", "179"}], ",", 
       RowBox[{"166", "\[Rule]", "167"}], ",", 
       RowBox[{"166", "\[Rule]", "163"}], ",", 
       RowBox[{"824", "\[Rule]", "809"}], ",", 
       RowBox[{"824", "\[Rule]", "837"}], ",", 
       RowBox[{"824", "\[Rule]", "825"}], ",", 
       RowBox[{"824", "\[Rule]", "821"}], ",", 
       RowBox[{"542", "\[Rule]", "527"}], ",", 
       RowBox[{"542", "\[Rule]", "555"}], ",", 
       RowBox[{"542", "\[Rule]", "543"}], ",", 
       RowBox[{"542", "\[Rule]", "539"}], ",", 
       RowBox[{"1670", "\[Rule]", "1655"}], ",", 
       RowBox[{"1670", "\[Rule]", "1683"}], ",", 
       RowBox[{"1670", "\[Rule]", "1671"}], ",", 
       RowBox[{"1670", "\[Rule]", "1667"}], ",", 
       RowBox[{"1576", "\[Rule]", "1561"}], ",", 
       RowBox[{"1576", "\[Rule]", "1589"}], ",", 
       RowBox[{"1576", "\[Rule]", "1577"}], ",", 
       RowBox[{"1576", "\[Rule]", "1573"}], ",", 
       RowBox[{"1294", "\[Rule]", "1279"}], ",", 
       RowBox[{"1294", "\[Rule]", "1307"}], ",", 
       RowBox[{"1294", "\[Rule]", "1295"}], ",", 
       RowBox[{"1294", "\[Rule]", "1291"}], ",", 
       RowBox[{"1482", "\[Rule]", "1467"}], ",", 
       RowBox[{"1482", "\[Rule]", "1495"}], ",", 
       RowBox[{"1482", "\[Rule]", "1483"}], ",", 
       RowBox[{"1482", "\[Rule]", "1479"}], ",", 
       RowBox[{"1200", "\[Rule]", "1185"}], ",", 
       RowBox[{"1200", "\[Rule]", "1213"}], ",", 
       RowBox[{"1200", "\[Rule]", "1201"}], ",", 
       RowBox[{"1200", "\[Rule]", "1197"}], ",", 
       RowBox[{"72", "\[Rule]", "57"}], ",", 
       RowBox[{"72", "\[Rule]", "85"}], ",", 
       RowBox[{"72", "\[Rule]", "73"}], ",", 
       RowBox[{"72", "\[Rule]", "69"}], ",", 
       RowBox[{"730", "\[Rule]", "715"}], ",", 
       RowBox[{"730", "\[Rule]", "743"}], ",", 
       RowBox[{"730", "\[Rule]", "731"}], ",", 
       RowBox[{"730", "\[Rule]", "727"}], ",", 
       RowBox[{"448", "\[Rule]", "433"}], ",", 
       RowBox[{"448", "\[Rule]", "461"}], ",", 
       RowBox[{"448", "\[Rule]", "449"}], ",", 
       RowBox[{"448", "\[Rule]", "445"}], ",", 
       RowBox[{"1388", "\[Rule]", "1373"}], ",", 
       RowBox[{"1388", "\[Rule]", "1401"}], ",", 
       RowBox[{"1388", "\[Rule]", "1389"}], ",", 
       RowBox[{"1388", "\[Rule]", "1385"}], ",", 
       RowBox[{"1106", "\[Rule]", "1091"}], ",", 
       RowBox[{"1106", "\[Rule]", "1119"}], ",", 
       RowBox[{"1106", "\[Rule]", "1107"}], ",", 
       RowBox[{"1106", "\[Rule]", "1103"}], ",", 
       RowBox[{"2282", "\[Rule]", "2269"}], ",", 
       RowBox[{"2282", "\[Rule]", "2295"}], ",", 
       RowBox[{"2282", "\[Rule]", "2279"}], ",", 
       RowBox[{"2188", "\[Rule]", "2175"}], ",", 
       RowBox[{"2188", "\[Rule]", "2201"}], ",", 
       RowBox[{"2188", "\[Rule]", "2185"}], ",", 
       RowBox[{"1906", "\[Rule]", "1893"}], ",", 
       RowBox[{"1906", "\[Rule]", "1919"}], ",", 
       RowBox[{"1906", "\[Rule]", "1903"}], ",", 
       RowBox[{"2308", "\[Rule]", "2295"}], ",", 
       RowBox[{"2308", "\[Rule]", "2321"}], ",", 
       RowBox[{"2308", "\[Rule]", "2305"}], ",", 
       RowBox[{"2214", "\[Rule]", "2201"}], ",", 
       RowBox[{"2214", "\[Rule]", "2227"}], ",", 
       RowBox[{"2214", "\[Rule]", "2211"}], ",", 
       RowBox[{"1932", "\[Rule]", "1919"}], ",", 
       RowBox[{"1932", "\[Rule]", "1945"}], ",", 
       RowBox[{"1932", "\[Rule]", "1929"}], ",", 
       RowBox[{"2294", "\[Rule]", "2279"}], ",", 
       RowBox[{"2294", "\[Rule]", "2305"}], ",", 
       RowBox[{"2294", "\[Rule]", "2295"}], ",", 
       RowBox[{"2294", "\[Rule]", "2291"}], ",", 
       RowBox[{"2200", "\[Rule]", "2185"}], ",", 
       RowBox[{"2200", "\[Rule]", "2211"}], ",", 
       RowBox[{"2200", "\[Rule]", "2201"}], ",", 
       RowBox[{"2200", "\[Rule]", "2197"}], ",", 
       RowBox[{"1918", "\[Rule]", "1903"}], ",", 
       RowBox[{"1918", "\[Rule]", "1929"}], ",", 
       RowBox[{"1918", "\[Rule]", "1919"}], ",", 
       RowBox[{"1918", "\[Rule]", "1915"}], ",", 
       RowBox[{"2094", "\[Rule]", "2081"}], ",", 
       RowBox[{"2094", "\[Rule]", "2107"}], ",", 
       RowBox[{"2094", "\[Rule]", "2091"}], ",", 
       RowBox[{"1812", "\[Rule]", "1799"}], ",", 
       RowBox[{"1812", "\[Rule]", "1825"}], ",", 
       RowBox[{"1812", "\[Rule]", "1809"}], ",", 
       RowBox[{"2120", "\[Rule]", "2107"}], ",", 
       RowBox[{"2120", "\[Rule]", "2133"}], ",", 
       RowBox[{"2120", "\[Rule]", "2117"}], ",", 
       RowBox[{"1838", "\[Rule]", "1825"}], ",", 
       RowBox[{"1838", "\[Rule]", "1851"}], ",", 
       RowBox[{"1838", "\[Rule]", "1835"}], ",", 
       RowBox[{"2106", "\[Rule]", "2091"}], ",", 
       RowBox[{"2106", "\[Rule]", "2117"}], ",", 
       RowBox[{"2106", "\[Rule]", "2107"}], ",", 
       RowBox[{"2106", "\[Rule]", "2103"}], ",", 
       RowBox[{"1824", "\[Rule]", "1809"}], ",", 
       RowBox[{"1824", "\[Rule]", "1835"}], ",", 
       RowBox[{"1824", "\[Rule]", "1825"}], ",", 
       RowBox[{"1824", "\[Rule]", "1821"}], ",", 
       RowBox[{"2336", "\[Rule]", "2321"}], ",", 
       RowBox[{"2336", "\[Rule]", "2349"}], ",", 
       RowBox[{"2336", "\[Rule]", "2333"}], ",", 
       RowBox[{"2242", "\[Rule]", "2227"}], ",", 
       RowBox[{"2242", "\[Rule]", "2255"}], ",", 
       RowBox[{"2242", "\[Rule]", "2239"}], ",", 
       RowBox[{"1960", "\[Rule]", "1945"}], ",", 
       RowBox[{"1960", "\[Rule]", "1973"}], ",", 
       RowBox[{"1960", "\[Rule]", "1957"}], ",", 
       RowBox[{"2320", "\[Rule]", "2305"}], ",", 
       RowBox[{"2320", "\[Rule]", "2333"}], ",", 
       RowBox[{"2320", "\[Rule]", "2321"}], ",", 
       RowBox[{"2320", "\[Rule]", "2317"}], ",", 
       RowBox[{"2226", "\[Rule]", "2211"}], ",", 
       RowBox[{"2226", "\[Rule]", "2239"}], ",", 
       RowBox[{"2226", "\[Rule]", "2227"}], ",", 
       RowBox[{"2226", "\[Rule]", "2223"}], ",", 
       RowBox[{"1944", "\[Rule]", "1929"}], ",", 
       RowBox[{"1944", "\[Rule]", "1957"}], ",", 
       RowBox[{"1944", "\[Rule]", "1945"}], ",", 
       RowBox[{"1944", "\[Rule]", "1941"}], ",", 
       RowBox[{"2148", "\[Rule]", "2133"}], ",", 
       RowBox[{"2148", "\[Rule]", "2161"}], ",", 
       RowBox[{"2148", "\[Rule]", "2145"}], ",", 
       RowBox[{"1866", "\[Rule]", "1851"}], ",", 
       RowBox[{"1866", "\[Rule]", "1879"}], ",", 
       RowBox[{"1866", "\[Rule]", "1863"}], ",", 
       RowBox[{"2132", "\[Rule]", "2117"}], ",", 
       RowBox[{"2132", "\[Rule]", "2145"}], ",", 
       RowBox[{"2132", "\[Rule]", "2133"}], ",", 
       RowBox[{"2132", "\[Rule]", "2129"}], ",", 
       RowBox[{"1850", "\[Rule]", "1835"}], ",", 
       RowBox[{"1850", "\[Rule]", "1863"}], ",", 
       RowBox[{"1850", "\[Rule]", "1851"}], ",", 
       RowBox[{"1850", "\[Rule]", "1847"}], ",", 
       RowBox[{"2304", "\[Rule]", "2291"}], ",", 
       RowBox[{"2304", "\[Rule]", "2317"}], ",", 
       RowBox[{"2304", "\[Rule]", "2305"}], ",", 
       RowBox[{"2304", "\[Rule]", "2301"}], ",", 
       RowBox[{"2210", "\[Rule]", "2197"}], ",", 
       RowBox[{"2210", "\[Rule]", "2223"}], ",", 
       RowBox[{"2210", "\[Rule]", "2211"}], ",", 
       RowBox[{"2210", "\[Rule]", "2207"}], ",", 
       RowBox[{"1928", "\[Rule]", "1915"}], ",", 
       RowBox[{"1928", "\[Rule]", "1941"}], ",", 
       RowBox[{"1928", "\[Rule]", "1929"}], ",", 
       RowBox[{"1928", "\[Rule]", "1925"}], ",", 
       RowBox[{"2116", "\[Rule]", "2103"}], ",", 
       RowBox[{"2116", "\[Rule]", "2129"}], ",", 
       RowBox[{"2116", "\[Rule]", "2117"}], ",", 
       RowBox[{"2116", "\[Rule]", "2113"}], ",", 
       RowBox[{"1834", "\[Rule]", "1821"}], ",", 
       RowBox[{"1834", "\[Rule]", "1847"}], ",", 
       RowBox[{"1834", "\[Rule]", "1835"}], ",", 
       RowBox[{"1834", "\[Rule]", "1831"}], ",", 
       RowBox[{"2000", "\[Rule]", "1987"}], ",", 
       RowBox[{"2000", "\[Rule]", "2013"}], ",", 
       RowBox[{"2000", "\[Rule]", "1997"}], ",", 
       RowBox[{"1718", "\[Rule]", "1705"}], ",", 
       RowBox[{"1718", "\[Rule]", "1731"}], ",", 
       RowBox[{"1718", "\[Rule]", "1715"}], ",", 
       RowBox[{"2026", "\[Rule]", "2013"}], ",", 
       RowBox[{"2026", "\[Rule]", "2039"}], ",", 
       RowBox[{"2026", "\[Rule]", "2023"}], ",", 
       RowBox[{"1744", "\[Rule]", "1731"}], ",", 
       RowBox[{"1744", "\[Rule]", "1757"}], ",", 
       RowBox[{"1744", "\[Rule]", "1741"}], ",", 
       RowBox[{"2012", "\[Rule]", "1997"}], ",", 
       RowBox[{"2012", "\[Rule]", "2023"}], ",", 
       RowBox[{"2012", "\[Rule]", "2013"}], ",", 
       RowBox[{"2012", "\[Rule]", "2009"}], ",", 
       RowBox[{"1730", "\[Rule]", "1715"}], ",", 
       RowBox[{"1730", "\[Rule]", "1741"}], ",", 
       RowBox[{"1730", "\[Rule]", "1731"}], ",", 
       RowBox[{"1730", "\[Rule]", "1727"}], ",", 
       RowBox[{"2054", "\[Rule]", "2039"}], ",", 
       RowBox[{"2054", "\[Rule]", "2067"}], ",", 
       RowBox[{"2054", "\[Rule]", "2051"}], ",", 
       RowBox[{"1772", "\[Rule]", "1757"}], ",", 
       RowBox[{"1772", "\[Rule]", "1785"}], ",", 
       RowBox[{"1772", "\[Rule]", "1769"}], ",", 
       RowBox[{"2038", "\[Rule]", "2023"}], ",", 
       RowBox[{"2038", "\[Rule]", "2051"}], ",", 
       RowBox[{"2038", "\[Rule]", "2039"}], ",", 
       RowBox[{"2038", "\[Rule]", "2035"}], ",", 
       RowBox[{"1756", "\[Rule]", "1741"}], ",", 
       RowBox[{"1756", "\[Rule]", "1769"}], ",", 
       RowBox[{"1756", "\[Rule]", "1757"}], ",", 
       RowBox[{"1756", "\[Rule]", "1753"}], ",", 
       RowBox[{"2022", "\[Rule]", "2009"}], ",", 
       RowBox[{"2022", "\[Rule]", "2035"}], ",", 
       RowBox[{"2022", "\[Rule]", "2023"}], ",", 
       RowBox[{"2022", "\[Rule]", "2019"}], ",", 
       RowBox[{"1740", "\[Rule]", "1727"}], ",", 
       RowBox[{"1740", "\[Rule]", "1753"}], ",", 
       RowBox[{"1740", "\[Rule]", "1741"}], ",", 
       RowBox[{"1740", "\[Rule]", "1737"}], ",", 
       RowBox[{"2348", "\[Rule]", "2333"}], ",", 
       RowBox[{"2348", "\[Rule]", "2349"}], ",", 
       RowBox[{"2348", "\[Rule]", "2345"}], ",", 
       RowBox[{"2254", "\[Rule]", "2239"}], ",", 
       RowBox[{"2254", "\[Rule]", "2255"}], ",", 
       RowBox[{"2254", "\[Rule]", "2251"}], ",", 
       RowBox[{"1972", "\[Rule]", "1957"}], ",", 
       RowBox[{"1972", "\[Rule]", "1973"}], ",", 
       RowBox[{"1972", "\[Rule]", "1969"}], ",", 
       RowBox[{"2160", "\[Rule]", "2145"}], ",", 
       RowBox[{"2160", "\[Rule]", "2161"}], ",", 
       RowBox[{"2160", "\[Rule]", "2157"}], ",", 
       RowBox[{"1878", "\[Rule]", "1863"}], ",", 
       RowBox[{"1878", "\[Rule]", "1879"}], ",", 
       RowBox[{"1878", "\[Rule]", "1875"}], ",", 
       RowBox[{"2332", "\[Rule]", "2317"}], ",", 
       RowBox[{"2332", "\[Rule]", "2345"}], ",", 
       RowBox[{"2332", "\[Rule]", "2333"}], ",", 
       RowBox[{"2332", "\[Rule]", "2329"}], ",", 
       RowBox[{"2238", "\[Rule]", "2223"}], ",", 
       RowBox[{"2238", "\[Rule]", "2251"}], ",", 
       RowBox[{"2238", "\[Rule]", "2239"}], ",", 
       RowBox[{"2238", "\[Rule]", "2235"}], ",", 
       RowBox[{"1956", "\[Rule]", "1941"}], ",", 
       RowBox[{"1956", "\[Rule]", "1969"}], ",", 
       RowBox[{"1956", "\[Rule]", "1957"}], ",", 
       RowBox[{"1956", "\[Rule]", "1953"}], ",", 
       RowBox[{"2144", "\[Rule]", "2129"}], ",", 
       RowBox[{"2144", "\[Rule]", "2157"}], ",", 
       RowBox[{"2144", "\[Rule]", "2145"}], ",", 
       RowBox[{"2144", "\[Rule]", "2141"}], ",", 
       RowBox[{"1862", "\[Rule]", "1847"}], ",", 
       RowBox[{"1862", "\[Rule]", "1875"}], ",", 
       RowBox[{"1862", "\[Rule]", "1863"}], ",", 
       RowBox[{"1862", "\[Rule]", "1859"}], ",", 
       RowBox[{"2066", "\[Rule]", "2051"}], ",", 
       RowBox[{"2066", "\[Rule]", "2067"}], ",", 
       RowBox[{"2066", "\[Rule]", "2063"}], ",", 
       RowBox[{"1784", "\[Rule]", "1769"}], ",", 
       RowBox[{"1784", "\[Rule]", "1785"}], ",", 
       RowBox[{"1784", "\[Rule]", "1781"}], ",", 
       RowBox[{"2050", "\[Rule]", "2035"}], ",", 
       RowBox[{"2050", "\[Rule]", "2063"}], ",", 
       RowBox[{"2050", "\[Rule]", "2051"}], ",", 
       RowBox[{"2050", "\[Rule]", "2047"}], ",", 
       RowBox[{"1768", "\[Rule]", "1753"}], ",", 
       RowBox[{"1768", "\[Rule]", "1781"}], ",", 
       RowBox[{"1768", "\[Rule]", "1769"}], ",", 
       RowBox[{"1768", "\[Rule]", "1765"}], ",", 
       RowBox[{"2316", "\[Rule]", "2301"}], ",", 
       RowBox[{"2316", "\[Rule]", "2329"}], ",", 
       RowBox[{"2316", "\[Rule]", "2317"}], ",", 
       RowBox[{"2316", "\[Rule]", "2313"}], ",", 
       RowBox[{"2222", "\[Rule]", "2207"}], ",", 
       RowBox[{"2222", "\[Rule]", "2235"}], ",", 
       RowBox[{"2222", "\[Rule]", "2223"}], ",", 
       RowBox[{"2222", "\[Rule]", "2219"}], ",", 
       RowBox[{"1940", "\[Rule]", "1925"}], ",", 
       RowBox[{"1940", "\[Rule]", "1953"}], ",", 
       RowBox[{"1940", "\[Rule]", "1941"}], ",", 
       RowBox[{"1940", "\[Rule]", "1937"}], ",", 
       RowBox[{"2128", "\[Rule]", "2113"}], ",", 
       RowBox[{"2128", "\[Rule]", "2141"}], ",", 
       RowBox[{"2128", "\[Rule]", "2129"}], ",", 
       RowBox[{"2128", "\[Rule]", "2125"}], ",", 
       RowBox[{"1846", "\[Rule]", "1831"}], ",", 
       RowBox[{"1846", "\[Rule]", "1859"}], ",", 
       RowBox[{"1846", "\[Rule]", "1847"}], ",", 
       RowBox[{"1846", "\[Rule]", "1843"}], ",", 
       RowBox[{"2034", "\[Rule]", "2019"}], ",", 
       RowBox[{"2034", "\[Rule]", "2047"}], ",", 
       RowBox[{"2034", "\[Rule]", "2035"}], ",", 
       RowBox[{"2034", "\[Rule]", "2031"}], ",", 
       RowBox[{"1752", "\[Rule]", "1737"}], ",", 
       RowBox[{"1752", "\[Rule]", "1765"}], ",", 
       RowBox[{"1752", "\[Rule]", "1753"}], ",", 
       RowBox[{"1752", "\[Rule]", "1749"}], ",", 
       RowBox[{"2344", "\[Rule]", "2329"}], ",", 
       RowBox[{"2344", "\[Rule]", "2345"}], ",", 
       RowBox[{"2344", "\[Rule]", "2341"}], ",", 
       RowBox[{"2250", "\[Rule]", "2235"}], ",", 
       RowBox[{"2250", "\[Rule]", "2251"}], ",", 
       RowBox[{"2250", "\[Rule]", "2247"}], ",", 
       RowBox[{"1968", "\[Rule]", "1953"}], ",", 
       RowBox[{"1968", "\[Rule]", "1969"}], ",", 
       RowBox[{"1968", "\[Rule]", "1965"}], ",", 
       RowBox[{"2156", "\[Rule]", "2141"}], ",", 
       RowBox[{"2156", "\[Rule]", "2157"}], ",", 
       RowBox[{"2156", "\[Rule]", "2153"}], ",", 
       RowBox[{"1874", "\[Rule]", "1859"}], ",", 
       RowBox[{"1874", "\[Rule]", "1875"}], ",", 
       RowBox[{"1874", "\[Rule]", "1871"}], ",", 
       RowBox[{"2062", "\[Rule]", "2047"}], ",", 
       RowBox[{"2062", "\[Rule]", "2063"}], ",", 
       RowBox[{"2062", "\[Rule]", "2059"}], ",", 
       RowBox[{"1780", "\[Rule]", "1765"}], ",", 
       RowBox[{"1780", "\[Rule]", "1781"}], ",", 
       RowBox[{"1780", "\[Rule]", "1777"}], ",", 
       RowBox[{"2328", "\[Rule]", "2313"}], ",", 
       RowBox[{"2328", "\[Rule]", "2341"}], ",", 
       RowBox[{"2328", "\[Rule]", "2329"}], ",", 
       RowBox[{"2328", "\[Rule]", "2325"}], ",", 
       RowBox[{"2234", "\[Rule]", "2219"}], ",", 
       RowBox[{"2234", "\[Rule]", "2247"}], ",", 
       RowBox[{"2234", "\[Rule]", "2235"}], ",", 
       RowBox[{"2234", "\[Rule]", "2231"}], ",", 
       RowBox[{"1952", "\[Rule]", "1937"}], ",", 
       RowBox[{"1952", "\[Rule]", "1965"}], ",", 
       RowBox[{"1952", "\[Rule]", "1953"}], ",", 
       RowBox[{"1952", "\[Rule]", "1949"}], ",", 
       RowBox[{"2140", "\[Rule]", "2125"}], ",", 
       RowBox[{"2140", "\[Rule]", "2153"}], ",", 
       RowBox[{"2140", "\[Rule]", "2141"}], ",", 
       RowBox[{"2140", "\[Rule]", "2137"}], ",", 
       RowBox[{"1858", "\[Rule]", "1843"}], ",", 
       RowBox[{"1858", "\[Rule]", "1871"}], ",", 
       RowBox[{"1858", "\[Rule]", "1859"}], ",", 
       RowBox[{"1858", "\[Rule]", "1855"}], ",", 
       RowBox[{"2046", "\[Rule]", "2031"}], ",", 
       RowBox[{"2046", "\[Rule]", "2059"}], ",", 
       RowBox[{"2046", "\[Rule]", "2047"}], ",", 
       RowBox[{"2046", "\[Rule]", "2043"}], ",", 
       RowBox[{"1764", "\[Rule]", "1749"}], ",", 
       RowBox[{"1764", "\[Rule]", "1777"}], ",", 
       RowBox[{"1764", "\[Rule]", "1765"}], ",", 
       RowBox[{"1764", "\[Rule]", "1761"}], ",", 
       RowBox[{"366", "\[Rule]", "351"}], ",", 
       RowBox[{"366", "\[Rule]", "367"}], ",", 
       RowBox[{"366", "\[Rule]", "363"}], ",", 
       RowBox[{"1024", "\[Rule]", "1009"}], ",", 
       RowBox[{"1024", "\[Rule]", "1025"}], ",", 
       RowBox[{"1024", "\[Rule]", "1021"}], ",", 
       RowBox[{"272", "\[Rule]", "257"}], ",", 
       RowBox[{"272", "\[Rule]", "273"}], ",", 
       RowBox[{"272", "\[Rule]", "269"}], ",", 
       RowBox[{"930", "\[Rule]", "915"}], ",", 
       RowBox[{"930", "\[Rule]", "931"}], ",", 
       RowBox[{"930", "\[Rule]", "927"}], ",", 
       RowBox[{"648", "\[Rule]", "633"}], ",", 
       RowBox[{"648", "\[Rule]", "649"}], ",", 
       RowBox[{"648", "\[Rule]", "645"}], ",", 
       RowBox[{"178", "\[Rule]", "163"}], ",", 
       RowBox[{"178", "\[Rule]", "179"}], ",", 
       RowBox[{"178", "\[Rule]", "175"}], ",", 
       RowBox[{"836", "\[Rule]", "821"}], ",", 
       RowBox[{"836", "\[Rule]", "837"}], ",", 
       RowBox[{"836", "\[Rule]", "833"}], ",", 
       RowBox[{"554", "\[Rule]", "539"}], ",", 
       RowBox[{"554", "\[Rule]", "555"}], ",", 
       RowBox[{"554", "\[Rule]", "551"}], ",", 
       RowBox[{"1682", "\[Rule]", "1667"}], ",", 
       RowBox[{"1682", "\[Rule]", "1683"}], ",", 
       RowBox[{"1682", "\[Rule]", "1679"}], ",", 
       RowBox[{"1588", "\[Rule]", "1573"}], ",", 
       RowBox[{"1588", "\[Rule]", "1589"}], ",", 
       RowBox[{"1588", "\[Rule]", "1585"}], ",", 
       RowBox[{"1306", "\[Rule]", "1291"}], ",", 
       RowBox[{"1306", "\[Rule]", "1307"}], ",", 
       RowBox[{"1306", "\[Rule]", "1303"}], ",", 
       RowBox[{"1494", "\[Rule]", "1479"}], ",", 
       RowBox[{"1494", "\[Rule]", "1495"}], ",", 
       RowBox[{"1494", "\[Rule]", "1491"}], ",", 
       RowBox[{"1212", "\[Rule]", "1197"}], ",", 
       RowBox[{"1212", "\[Rule]", "1213"}], ",", 
       RowBox[{"1212", "\[Rule]", "1209"}], ",", 
       RowBox[{"84", "\[Rule]", "69"}], ",", 
       RowBox[{"84", "\[Rule]", "85"}], ",", 
       RowBox[{"84", "\[Rule]", "81"}], ",", 
       RowBox[{"742", "\[Rule]", "727"}], ",", 
       RowBox[{"742", "\[Rule]", "743"}], ",", 
       RowBox[{"742", "\[Rule]", "739"}], ",", 
       RowBox[{"460", "\[Rule]", "445"}], ",", 
       RowBox[{"460", "\[Rule]", "461"}], ",", 
       RowBox[{"460", "\[Rule]", "457"}], ",", 
       RowBox[{"1400", "\[Rule]", "1385"}], ",", 
       RowBox[{"1400", "\[Rule]", "1401"}], ",", 
       RowBox[{"1400", "\[Rule]", "1397"}], ",", 
       RowBox[{"1118", "\[Rule]", "1103"}], ",", 
       RowBox[{"1118", "\[Rule]", "1119"}], ",", 
       RowBox[{"1118", "\[Rule]", "1115"}], ",", 
       RowBox[{"2340", "\[Rule]", "2325"}], ",", 
       RowBox[{"2340", "\[Rule]", "2341"}], ",", 
       RowBox[{"2340", "\[Rule]", "2337"}], ",", 
       RowBox[{"2246", "\[Rule]", "2231"}], ",", 
       RowBox[{"2246", "\[Rule]", "2247"}], ",", 
       RowBox[{"2246", "\[Rule]", "2243"}], ",", 
       RowBox[{"1964", "\[Rule]", "1949"}], ",", 
       RowBox[{"1964", "\[Rule]", "1965"}], ",", 
       RowBox[{"1964", "\[Rule]", "1961"}], ",", 
       RowBox[{"2152", "\[Rule]", "2137"}], ",", 
       RowBox[{"2152", "\[Rule]", "2153"}], ",", 
       RowBox[{"2152", "\[Rule]", "2149"}], ",", 
       RowBox[{"1870", "\[Rule]", "1855"}], ",", 
       RowBox[{"1870", "\[Rule]", "1871"}], ",", 
       RowBox[{"1870", "\[Rule]", "1867"}], ",", 
       RowBox[{"2058", "\[Rule]", "2043"}], ",", 
       RowBox[{"2058", "\[Rule]", "2059"}], ",", 
       RowBox[{"2058", "\[Rule]", "2055"}], ",", 
       RowBox[{"1776", "\[Rule]", "1761"}], ",", 
       RowBox[{"1776", "\[Rule]", "1777"}], ",", 
       RowBox[{"1776", "\[Rule]", "1773"}], ",", 
       RowBox[{"295", "\[Rule]", "578"}], ",", 
       RowBox[{"295", "\[Rule]", "578"}], ",", 
       RowBox[{"295", "\[Rule]", "296"}], ",", 
       RowBox[{"321", "\[Rule]", "604"}], ",", 
       RowBox[{"321", "\[Rule]", "604"}], ",", 
       RowBox[{"321", "\[Rule]", "322"}], ",", 
       RowBox[{"305", "\[Rule]", "588"}], ",", 
       RowBox[{"305", "\[Rule]", "588"}], ",", 
       RowBox[{"305", "\[Rule]", "306"}], ",", 
       RowBox[{"953", "\[Rule]", "578"}], ",", 
       RowBox[{"953", "\[Rule]", "578"}], ",", 
       RowBox[{"953", "\[Rule]", "1236"}], ",", 
       RowBox[{"953", "\[Rule]", "1236"}], ",", 
       RowBox[{"953", "\[Rule]", "954"}], ",", 
       RowBox[{"979", "\[Rule]", "604"}], ",", 
       RowBox[{"979", "\[Rule]", "604"}], ",", 
       RowBox[{"979", "\[Rule]", "1262"}], ",", 
       RowBox[{"979", "\[Rule]", "1262"}], ",", 
       RowBox[{"979", "\[Rule]", "980"}], ",", 
       RowBox[{"963", "\[Rule]", "588"}], ",", 
       RowBox[{"963", "\[Rule]", "588"}], ",", 
       RowBox[{"963", "\[Rule]", "1246"}], ",", 
       RowBox[{"963", "\[Rule]", "1246"}], ",", 
       RowBox[{"963", "\[Rule]", "964"}], ",", 
       RowBox[{"201", "\[Rule]", "578"}], ",", 
       RowBox[{"201", "\[Rule]", "578"}], ",", 
       RowBox[{"201", "\[Rule]", "484"}], ",", 
       RowBox[{"201", "\[Rule]", "484"}], ",", 
       RowBox[{"201", "\[Rule]", "202"}], ",", 
       RowBox[{"211", "\[Rule]", "588"}], ",", 
       RowBox[{"211", "\[Rule]", "588"}], ",", 
       RowBox[{"211", "\[Rule]", "494"}], ",", 
       RowBox[{"211", "\[Rule]", "494"}], ",", 
       RowBox[{"211", "\[Rule]", "212"}], ",", 
       RowBox[{"859", "\[Rule]", "578"}], ",", 
       RowBox[{"859", "\[Rule]", "578"}], ",", 
       RowBox[{"859", "\[Rule]", "1236"}], ",", 
       RowBox[{"859", "\[Rule]", "1236"}], ",", 
       RowBox[{"859", "\[Rule]", "484"}], ",", 
       RowBox[{"859", "\[Rule]", "484"}], ",", 
       RowBox[{"859", "\[Rule]", "1142"}], ",", 
       RowBox[{"859", "\[Rule]", "1142"}], ",", 
       RowBox[{"859", "\[Rule]", "860"}], ",", 
       RowBox[{"869", "\[Rule]", "588"}], ",", 
       RowBox[{"869", "\[Rule]", "588"}], ",", 
       RowBox[{"869", "\[Rule]", "1246"}], ",", 
       RowBox[{"869", "\[Rule]", "1246"}], ",", 
       RowBox[{"869", "\[Rule]", "494"}], ",", 
       RowBox[{"869", "\[Rule]", "494"}], ",", 
       RowBox[{"869", "\[Rule]", "1152"}], ",", 
       RowBox[{"869", "\[Rule]", "1152"}], ",", 
       RowBox[{"869", "\[Rule]", "870"}], ",", 
       RowBox[{"577", "\[Rule]", "296"}], ",", 
       RowBox[{"577", "\[Rule]", "296"}], ",", 
       RowBox[{"577", "\[Rule]", "954"}], ",", 
       RowBox[{"577", "\[Rule]", "954"}], ",", 
       RowBox[{"577", "\[Rule]", "202"}], ",", 
       RowBox[{"577", "\[Rule]", "202"}], ",", 
       RowBox[{"577", "\[Rule]", "860"}], ",", 
       RowBox[{"577", "\[Rule]", "860"}], ",", 
       RowBox[{"577", "\[Rule]", "578"}], ",", 
       RowBox[{"603", "\[Rule]", "322"}], ",", 
       RowBox[{"603", "\[Rule]", "322"}], ",", 
       RowBox[{"603", "\[Rule]", "980"}], ",", 
       RowBox[{"603", "\[Rule]", "980"}], ",", 
       RowBox[{"603", "\[Rule]", "228"}], ",", 
       RowBox[{"603", "\[Rule]", "228"}], ",", 
       RowBox[{"603", "\[Rule]", "886"}], ",", 
       RowBox[{"603", "\[Rule]", "886"}], ",", 
       RowBox[{"603", "\[Rule]", "604"}], ",", 
       RowBox[{"587", "\[Rule]", "306"}], ",", 
       RowBox[{"587", "\[Rule]", "306"}], ",", 
       RowBox[{"587", "\[Rule]", "964"}], ",", 
       RowBox[{"587", "\[Rule]", "964"}], ",", 
       RowBox[{"587", "\[Rule]", "212"}], ",", 
       RowBox[{"587", "\[Rule]", "212"}], ",", 
       RowBox[{"587", "\[Rule]", "870"}], ",", 
       RowBox[{"587", "\[Rule]", "870"}], ",", 
       RowBox[{"587", "\[Rule]", "588"}], ",", 
       RowBox[{"347", "\[Rule]", "630"}], ",", 
       RowBox[{"347", "\[Rule]", "630"}], ",", 
       RowBox[{"347", "\[Rule]", "348"}], ",", 
       RowBox[{"331", "\[Rule]", "614"}], ",", 
       RowBox[{"331", "\[Rule]", "614"}], ",", 
       RowBox[{"331", "\[Rule]", "332"}], ",", 
       RowBox[{"1005", "\[Rule]", "630"}], ",", 
       RowBox[{"1005", "\[Rule]", "630"}], ",", 
       RowBox[{"1005", "\[Rule]", "1288"}], ",", 
       RowBox[{"1005", "\[Rule]", "1288"}], ",", 
       RowBox[{"1005", "\[Rule]", "1006"}], ",", 
       RowBox[{"989", "\[Rule]", "614"}], ",", 
       RowBox[{"989", "\[Rule]", "614"}], ",", 
       RowBox[{"989", "\[Rule]", "1272"}], ",", 
       RowBox[{"989", "\[Rule]", "1272"}], ",", 
       RowBox[{"989", "\[Rule]", "990"}], ",", 
       RowBox[{"629", "\[Rule]", "348"}], ",", 
       RowBox[{"629", "\[Rule]", "348"}], ",", 
       RowBox[{"629", "\[Rule]", "1006"}], ",", 
       RowBox[{"629", "\[Rule]", "1006"}], ",", 
       RowBox[{"629", "\[Rule]", "254"}], ",", 
       RowBox[{"629", "\[Rule]", "254"}], ",", 
       RowBox[{"629", "\[Rule]", "912"}], ",", 
       RowBox[{"629", "\[Rule]", "912"}], ",", 
       RowBox[{"629", "\[Rule]", "630"}], ",", 
       RowBox[{"613", "\[Rule]", "332"}], ",", 
       RowBox[{"613", "\[Rule]", "332"}], ",", 
       RowBox[{"613", "\[Rule]", "990"}], ",", 
       RowBox[{"613", "\[Rule]", "990"}], ",", 
       RowBox[{"613", "\[Rule]", "238"}], ",", 
       RowBox[{"613", "\[Rule]", "238"}], ",", 
       RowBox[{"613", "\[Rule]", "896"}], ",", 
       RowBox[{"613", "\[Rule]", "896"}], ",", 
       RowBox[{"613", "\[Rule]", "614"}], ",", 
       RowBox[{"317", "\[Rule]", "600"}], ",", 
       RowBox[{"317", "\[Rule]", "600"}], ",", 
       RowBox[{"317", "\[Rule]", "318"}], ",", 
       RowBox[{"975", "\[Rule]", "600"}], ",", 
       RowBox[{"975", "\[Rule]", "600"}], ",", 
       RowBox[{"975", "\[Rule]", "1258"}], ",", 
       RowBox[{"975", "\[Rule]", "1258"}], ",", 
       RowBox[{"975", "\[Rule]", "976"}], ",", 
       RowBox[{"223", "\[Rule]", "600"}], ",", 
       RowBox[{"223", "\[Rule]", "600"}], ",", 
       RowBox[{"223", "\[Rule]", "506"}], ",", 
       RowBox[{"223", "\[Rule]", "506"}], ",", 
       RowBox[{"223", "\[Rule]", "224"}], ",", 
       RowBox[{"881", "\[Rule]", "600"}], ",", 
       RowBox[{"881", "\[Rule]", "600"}], ",", 
       RowBox[{"881", "\[Rule]", "1258"}], ",", 
       RowBox[{"881", "\[Rule]", "1258"}], ",", 
       RowBox[{"881", "\[Rule]", "506"}], ",", 
       RowBox[{"881", "\[Rule]", "506"}], ",", 
       RowBox[{"881", "\[Rule]", "1164"}], ",", 
       RowBox[{"881", "\[Rule]", "1164"}], ",", 
       RowBox[{"881", "\[Rule]", "882"}], ",", 
       RowBox[{"599", "\[Rule]", "318"}], ",", 
       RowBox[{"599", "\[Rule]", "318"}], ",", 
       RowBox[{"599", "\[Rule]", "976"}], ",", 
       RowBox[{"599", "\[Rule]", "976"}], ",", 
       RowBox[{"599", "\[Rule]", "224"}], ",", 
       RowBox[{"599", "\[Rule]", "224"}], ",", 
       RowBox[{"599", "\[Rule]", "882"}], ",", 
       RowBox[{"599", "\[Rule]", "882"}], ",", 
       RowBox[{"599", "\[Rule]", "600"}], ",", 
       RowBox[{"107", "\[Rule]", "484"}], ",", 
       RowBox[{"107", "\[Rule]", "390"}], ",", 
       RowBox[{"107", "\[Rule]", "108"}], ",", 
       RowBox[{"117", "\[Rule]", "494"}], ",", 
       RowBox[{"117", "\[Rule]", "400"}], ",", 
       RowBox[{"117", "\[Rule]", "118"}], ",", 
       RowBox[{"765", "\[Rule]", "484"}], ",", 
       RowBox[{"765", "\[Rule]", "1142"}], ",", 
       RowBox[{"765", "\[Rule]", "1142"}], ",", 
       RowBox[{"765", "\[Rule]", "390"}], ",", 
       RowBox[{"765", "\[Rule]", "1048"}], ",", 
       RowBox[{"765", "\[Rule]", "1048"}], ",", 
       RowBox[{"765", "\[Rule]", "766"}], ",", 
       RowBox[{"775", "\[Rule]", "494"}], ",", 
       RowBox[{"775", "\[Rule]", "1152"}], ",", 
       RowBox[{"775", "\[Rule]", "1152"}], ",", 
       RowBox[{"775", "\[Rule]", "400"}], ",", 
       RowBox[{"775", "\[Rule]", "1058"}], ",", 
       RowBox[{"775", "\[Rule]", "1058"}], ",", 
       RowBox[{"775", "\[Rule]", "776"}], ",", 
       RowBox[{"483", "\[Rule]", "202"}], ",", 
       RowBox[{"483", "\[Rule]", "202"}], ",", 
       RowBox[{"483", "\[Rule]", "860"}], ",", 
       RowBox[{"483", "\[Rule]", "860"}], ",", 
       RowBox[{"483", "\[Rule]", "108"}], ",", 
       RowBox[{"483", "\[Rule]", "766"}], ",", 
       RowBox[{"483", "\[Rule]", "484"}], ",", 
       RowBox[{"493", "\[Rule]", "212"}], ",", 
       RowBox[{"493", "\[Rule]", "212"}], ",", 
       RowBox[{"493", "\[Rule]", "870"}], ",", 
       RowBox[{"493", "\[Rule]", "870"}], ",", 
       RowBox[{"493", "\[Rule]", "118"}], ",", 
       RowBox[{"493", "\[Rule]", "776"}], ",", 
       RowBox[{"493", "\[Rule]", "494"}], ",", 
       RowBox[{"129", "\[Rule]", "506"}], ",", 
       RowBox[{"129", "\[Rule]", "412"}], ",", 
       RowBox[{"129", "\[Rule]", "130"}], ",", 
       RowBox[{"787", "\[Rule]", "506"}], ",", 
       RowBox[{"787", "\[Rule]", "1164"}], ",", 
       RowBox[{"787", "\[Rule]", "1164"}], ",", 
       RowBox[{"787", "\[Rule]", "412"}], ",", 
       RowBox[{"787", "\[Rule]", "1070"}], ",", 
       RowBox[{"787", "\[Rule]", "1070"}], ",", 
       RowBox[{"787", "\[Rule]", "788"}], ",", 
       RowBox[{"505", "\[Rule]", "224"}], ",", 
       RowBox[{"505", "\[Rule]", "224"}], ",", 
       RowBox[{"505", "\[Rule]", "882"}], ",", 
       RowBox[{"505", "\[Rule]", "882"}], ",", 
       RowBox[{"505", "\[Rule]", "130"}], ",", 
       RowBox[{"505", "\[Rule]", "788"}], ",", 
       RowBox[{"505", "\[Rule]", "506"}], ",", 
       RowBox[{"375", "\[Rule]", "658"}], ",", 
       RowBox[{"375", "\[Rule]", "658"}], ",", 
       RowBox[{"375", "\[Rule]", "376"}], ",", 
       RowBox[{"359", "\[Rule]", "642"}], ",", 
       RowBox[{"359", "\[Rule]", "642"}], ",", 
       RowBox[{"359", "\[Rule]", "360"}], ",", 
       RowBox[{"1033", "\[Rule]", "658"}], ",", 
       RowBox[{"1033", "\[Rule]", "658"}], ",", 
       RowBox[{"1033", "\[Rule]", "1316"}], ",", 
       RowBox[{"1033", "\[Rule]", "1316"}], ",", 
       RowBox[{"1033", "\[Rule]", "1034"}], ",", 
       RowBox[{"1017", "\[Rule]", "642"}], ",", 
       RowBox[{"1017", "\[Rule]", "642"}], ",", 
       RowBox[{"1017", "\[Rule]", "1300"}], ",", 
       RowBox[{"1017", "\[Rule]", "1300"}], ",", 
       RowBox[{"1017", "\[Rule]", "1018"}], ",", 
       RowBox[{"657", "\[Rule]", "376"}], ",", 
       RowBox[{"657", "\[Rule]", "376"}], ",", 
       RowBox[{"657", "\[Rule]", "1034"}], ",", 
       RowBox[{"657", "\[Rule]", "1034"}], ",", 
       RowBox[{"657", "\[Rule]", "282"}], ",", 
       RowBox[{"657", "\[Rule]", "282"}], ",", 
       RowBox[{"657", "\[Rule]", "940"}], ",", 
       RowBox[{"657", "\[Rule]", "940"}], ",", 
       RowBox[{"657", "\[Rule]", "658"}], ",", 
       RowBox[{"641", "\[Rule]", "360"}], ",", 
       RowBox[{"641", "\[Rule]", "360"}], ",", 
       RowBox[{"641", "\[Rule]", "1018"}], ",", 
       RowBox[{"641", "\[Rule]", "1018"}], ",", 
       RowBox[{"641", "\[Rule]", "266"}], ",", 
       RowBox[{"641", "\[Rule]", "266"}], ",", 
       RowBox[{"641", "\[Rule]", "924"}], ",", 
       RowBox[{"641", "\[Rule]", "924"}], ",", 
       RowBox[{"641", "\[Rule]", "642"}], ",", 
       RowBox[{"343", "\[Rule]", "626"}], ",", 
       RowBox[{"343", "\[Rule]", "626"}], ",", 
       RowBox[{"343", "\[Rule]", "344"}], ",", 
       RowBox[{"1001", "\[Rule]", "626"}], ",", 
       RowBox[{"1001", "\[Rule]", "626"}], ",", 
       RowBox[{"1001", "\[Rule]", "1284"}], ",", 
       RowBox[{"1001", "\[Rule]", "1284"}], ",", 
       RowBox[{"1001", "\[Rule]", "1002"}], ",", 
       RowBox[{"625", "\[Rule]", "344"}], ",", 
       RowBox[{"625", "\[Rule]", "344"}], ",", 
       RowBox[{"625", "\[Rule]", "1002"}], ",", 
       RowBox[{"625", "\[Rule]", "1002"}], ",", 
       RowBox[{"625", "\[Rule]", "250"}], ",", 
       RowBox[{"625", "\[Rule]", "250"}], ",", 
       RowBox[{"625", "\[Rule]", "908"}], ",", 
       RowBox[{"625", "\[Rule]", "908"}], ",", 
       RowBox[{"625", "\[Rule]", "626"}], ",", 
       RowBox[{"327", "\[Rule]", "610"}], ",", 
       RowBox[{"327", "\[Rule]", "610"}], ",", 
       RowBox[{"327", "\[Rule]", "328"}], ",", 
       RowBox[{"985", "\[Rule]", "610"}], ",", 
       RowBox[{"985", "\[Rule]", "610"}], ",", 
       RowBox[{"985", "\[Rule]", "1268"}], ",", 
       RowBox[{"985", "\[Rule]", "1268"}], ",", 
       RowBox[{"985", "\[Rule]", "986"}], ",", 
       RowBox[{"233", "\[Rule]", "610"}], ",", 
       RowBox[{"233", "\[Rule]", "610"}], ",", 
       RowBox[{"233", "\[Rule]", "516"}], ",", 
       RowBox[{"233", "\[Rule]", "516"}], ",", 
       RowBox[{"233", "\[Rule]", "234"}], ",", 
       RowBox[{"891", "\[Rule]", "610"}], ",", 
       RowBox[{"891", "\[Rule]", "610"}], ",", 
       RowBox[{"891", "\[Rule]", "1268"}], ",", 
       RowBox[{"891", "\[Rule]", "1268"}], ",", 
       RowBox[{"891", "\[Rule]", "516"}], ",", 
       RowBox[{"891", "\[Rule]", "516"}], ",", 
       RowBox[{"891", "\[Rule]", "1174"}], ",", 
       RowBox[{"891", "\[Rule]", "1174"}], ",", 
       RowBox[{"891", "\[Rule]", "892"}], ",", 
       RowBox[{"609", "\[Rule]", "328"}], ",", 
       RowBox[{"609", "\[Rule]", "328"}], ",", 
       RowBox[{"609", "\[Rule]", "986"}], ",", 
       RowBox[{"609", "\[Rule]", "986"}], ",", 
       RowBox[{"609", "\[Rule]", "234"}], ",", 
       RowBox[{"609", "\[Rule]", "234"}], ",", 
       RowBox[{"609", "\[Rule]", "892"}], ",", 
       RowBox[{"609", "\[Rule]", "892"}], ",", 
       RowBox[{"609", "\[Rule]", "610"}], ",", 
       RowBox[{"139", "\[Rule]", "516"}], ",", 
       RowBox[{"139", "\[Rule]", "422"}], ",", 
       RowBox[{"139", "\[Rule]", "140"}], ",", 
       RowBox[{"797", "\[Rule]", "516"}], ",", 
       RowBox[{"797", "\[Rule]", "1174"}], ",", 
       RowBox[{"797", "\[Rule]", "1174"}], ",", 
       RowBox[{"797", "\[Rule]", "422"}], ",", 
       RowBox[{"797", "\[Rule]", "1080"}], ",", 
       RowBox[{"797", "\[Rule]", "1080"}], ",", 
       RowBox[{"797", "\[Rule]", "798"}], ",", 
       RowBox[{"515", "\[Rule]", "234"}], ",", 
       RowBox[{"515", "\[Rule]", "234"}], ",", 
       RowBox[{"515", "\[Rule]", "892"}], ",", 
       RowBox[{"515", "\[Rule]", "892"}], ",", 
       RowBox[{"515", "\[Rule]", "140"}], ",", 
       RowBox[{"515", "\[Rule]", "798"}], ",", 
       RowBox[{"515", "\[Rule]", "516"}], ",", 
       RowBox[{"1611", "\[Rule]", "1236"}], ",", 
       RowBox[{"1611", "\[Rule]", "1236"}], ",", 
       RowBox[{"1611", "\[Rule]", "1894"}], ",", 
       RowBox[{"1611", "\[Rule]", "1894"}], ",", 
       RowBox[{"1611", "\[Rule]", "1612"}], ",", 
       RowBox[{"1637", "\[Rule]", "1262"}], ",", 
       RowBox[{"1637", "\[Rule]", "1262"}], ",", 
       RowBox[{"1637", "\[Rule]", "1920"}], ",", 
       RowBox[{"1637", "\[Rule]", "1920"}], ",", 
       RowBox[{"1637", "\[Rule]", "1638"}], ",", 
       RowBox[{"1621", "\[Rule]", "1246"}], ",", 
       RowBox[{"1621", "\[Rule]", "1246"}], ",", 
       RowBox[{"1621", "\[Rule]", "1904"}], ",", 
       RowBox[{"1621", "\[Rule]", "1904"}], ",", 
       RowBox[{"1621", "\[Rule]", "1622"}], ",", 
       RowBox[{"1517", "\[Rule]", "1236"}], ",", 
       RowBox[{"1517", "\[Rule]", "1236"}], ",", 
       RowBox[{"1517", "\[Rule]", "1894"}], ",", 
       RowBox[{"1517", "\[Rule]", "1894"}], ",", 
       RowBox[{"1517", "\[Rule]", "1142"}], ",", 
       RowBox[{"1517", "\[Rule]", "1142"}], ",", 
       RowBox[{"1517", "\[Rule]", "1800"}], ",", 
       RowBox[{"1517", "\[Rule]", "1800"}], ",", 
       RowBox[{"1517", "\[Rule]", "1518"}], ",", 
       RowBox[{"1527", "\[Rule]", "1246"}], ",", 
       RowBox[{"1527", "\[Rule]", "1246"}], ",", 
       RowBox[{"1527", "\[Rule]", "1904"}], ",", 
       RowBox[{"1527", "\[Rule]", "1904"}], ",", 
       RowBox[{"1527", "\[Rule]", "1152"}], ",", 
       RowBox[{"1527", "\[Rule]", "1152"}], ",", 
       RowBox[{"1527", "\[Rule]", "1810"}], ",", 
       RowBox[{"1527", "\[Rule]", "1810"}], ",", 
       RowBox[{"1527", "\[Rule]", "1528"}], ",", 
       RowBox[{"1235", "\[Rule]", "954"}], ",", 
       RowBox[{"1235", "\[Rule]", "954"}], ",", 
       RowBox[{"1235", "\[Rule]", "1612"}], ",", 
       RowBox[{"1235", "\[Rule]", "1612"}], ",", 
       RowBox[{"1235", "\[Rule]", "860"}], ",", 
       RowBox[{"1235", "\[Rule]", "860"}], ",", 
       RowBox[{"1235", "\[Rule]", "1518"}], ",", 
       RowBox[{"1235", "\[Rule]", "1518"}], ",", 
       RowBox[{"1235", "\[Rule]", "1236"}], ",", 
       RowBox[{"1261", "\[Rule]", "980"}], ",", 
       RowBox[{"1261", "\[Rule]", "980"}], ",", 
       RowBox[{"1261", "\[Rule]", "1638"}], ",", 
       RowBox[{"1261", "\[Rule]", "1638"}], ",", 
       RowBox[{"1261", "\[Rule]", "886"}], ",", 
       RowBox[{"1261", "\[Rule]", "886"}], ",", 
       RowBox[{"1261", "\[Rule]", "1544"}], ",", 
       RowBox[{"1261", "\[Rule]", "1544"}], ",", 
       RowBox[{"1261", "\[Rule]", "1262"}], ",", 
       RowBox[{"1245", "\[Rule]", "964"}], ",", 
       RowBox[{"1245", "\[Rule]", "964"}], ",", 
       RowBox[{"1245", "\[Rule]", "1622"}], ",", 
       RowBox[{"1245", "\[Rule]", "1622"}], ",", 
       RowBox[{"1245", "\[Rule]", "870"}], ",", 
       RowBox[{"1245", "\[Rule]", "870"}], ",", 
       RowBox[{"1245", "\[Rule]", "1528"}], ",", 
       RowBox[{"1245", "\[Rule]", "1528"}], ",", 
       RowBox[{"1245", "\[Rule]", "1246"}], ",", 
       RowBox[{"1663", "\[Rule]", "1288"}], ",", 
       RowBox[{"1663", "\[Rule]", "1288"}], ",", 
       RowBox[{"1663", "\[Rule]", "1946"}], ",", 
       RowBox[{"1663", "\[Rule]", "1946"}], ",", 
       RowBox[{"1663", "\[Rule]", "1664"}], ",", 
       RowBox[{"1647", "\[Rule]", "1272"}], ",", 
       RowBox[{"1647", "\[Rule]", "1272"}], ",", 
       RowBox[{"1647", "\[Rule]", "1930"}], ",", 
       RowBox[{"1647", "\[Rule]", "1930"}], ",", 
       RowBox[{"1647", "\[Rule]", "1648"}], ",", 
       RowBox[{"1287", "\[Rule]", "1006"}], ",", 
       RowBox[{"1287", "\[Rule]", "1006"}], ",", 
       RowBox[{"1287", "\[Rule]", "1664"}], ",", 
       RowBox[{"1287", "\[Rule]", "1664"}], ",", 
       RowBox[{"1287", "\[Rule]", "912"}], ",", 
       RowBox[{"1287", "\[Rule]", "912"}], ",", 
       RowBox[{"1287", "\[Rule]", "1570"}], ",", 
       RowBox[{"1287", "\[Rule]", "1570"}], ",", 
       RowBox[{"1287", "\[Rule]", "1288"}], ",", 
       RowBox[{"1271", "\[Rule]", "990"}], ",", 
       RowBox[{"1271", "\[Rule]", "990"}], ",", 
       RowBox[{"1271", "\[Rule]", "1648"}], ",", 
       RowBox[{"1271", "\[Rule]", "1648"}], ",", 
       RowBox[{"1271", "\[Rule]", "896"}], ",", 
       RowBox[{"1271", "\[Rule]", "896"}], ",", 
       RowBox[{"1271", "\[Rule]", "1554"}], ",", 
       RowBox[{"1271", "\[Rule]", "1554"}], ",", 
       RowBox[{"1271", "\[Rule]", "1272"}], ",", 
       RowBox[{"1633", "\[Rule]", "1258"}], ",", 
       RowBox[{"1633", "\[Rule]", "1258"}], ",", 
       RowBox[{"1633", "\[Rule]", "1916"}], ",", 
       RowBox[{"1633", "\[Rule]", "1916"}], ",", 
       RowBox[{"1633", "\[Rule]", "1634"}], ",", 
       RowBox[{"1539", "\[Rule]", "1258"}], ",", 
       RowBox[{"1539", "\[Rule]", "1258"}], ",", 
       RowBox[{"1539", "\[Rule]", "1916"}], ",", 
       RowBox[{"1539", "\[Rule]", "1916"}], ",", 
       RowBox[{"1539", "\[Rule]", "1164"}], ",", 
       RowBox[{"1539", "\[Rule]", "1164"}], ",", 
       RowBox[{"1539", "\[Rule]", "1822"}], ",", 
       RowBox[{"1539", "\[Rule]", "1822"}], ",", 
       RowBox[{"1539", "\[Rule]", "1540"}], ",", 
       RowBox[{"1257", "\[Rule]", "976"}], ",", 
       RowBox[{"1257", "\[Rule]", "976"}], ",", 
       RowBox[{"1257", "\[Rule]", "1634"}], ",", 
       RowBox[{"1257", "\[Rule]", "1634"}], ",", 
       RowBox[{"1257", "\[Rule]", "882"}], ",", 
       RowBox[{"1257", "\[Rule]", "882"}], ",", 
       RowBox[{"1257", "\[Rule]", "1540"}], ",", 
       RowBox[{"1257", "\[Rule]", "1540"}], ",", 
       RowBox[{"1257", "\[Rule]", "1258"}], ",", 
       RowBox[{"1423", "\[Rule]", "1142"}], ",", 
       RowBox[{"1423", "\[Rule]", "1142"}], ",", 
       RowBox[{"1423", "\[Rule]", "1800"}], ",", 
       RowBox[{"1423", "\[Rule]", "1800"}], ",", 
       RowBox[{"1423", "\[Rule]", "1048"}], ",", 
       RowBox[{"1423", "\[Rule]", "1048"}], ",", 
       RowBox[{"1423", "\[Rule]", "1706"}], ",", 
       RowBox[{"1423", "\[Rule]", "1706"}], ",", 
       RowBox[{"1423", "\[Rule]", "1424"}], ",", 
       RowBox[{"1433", "\[Rule]", "1152"}], ",", 
       RowBox[{"1433", "\[Rule]", "1152"}], ",", 
       RowBox[{"1433", "\[Rule]", "1810"}], ",", 
       RowBox[{"1433", "\[Rule]", "1810"}], ",", 
       RowBox[{"1433", "\[Rule]", "1058"}], ",", 
       RowBox[{"1433", "\[Rule]", "1058"}], ",", 
       RowBox[{"1433", "\[Rule]", "1716"}], ",", 
       RowBox[{"1433", "\[Rule]", "1716"}], ",", 
       RowBox[{"1433", "\[Rule]", "1434"}], ",", 
       RowBox[{"1141", "\[Rule]", "860"}], ",", 
       RowBox[{"1141", "\[Rule]", "860"}], ",", 
       RowBox[{"1141", "\[Rule]", "1518"}], ",", 
       RowBox[{"1141", "\[Rule]", "1518"}], ",", 
       RowBox[{"1141", "\[Rule]", "766"}], ",", 
       RowBox[{"1141", "\[Rule]", "766"}], ",", 
       RowBox[{"1141", "\[Rule]", "1424"}], ",", 
       RowBox[{"1141", "\[Rule]", "1424"}], ",", 
       RowBox[{"1141", "\[Rule]", "1142"}], ",", 
       RowBox[{"1151", "\[Rule]", "870"}], ",", 
       RowBox[{"1151", "\[Rule]", "870"}], ",", 
       RowBox[{"1151", "\[Rule]", "1528"}], ",", 
       RowBox[{"1151", "\[Rule]", "1528"}], ",", 
       RowBox[{"1151", "\[Rule]", "776"}], ",", 
       RowBox[{"1151", "\[Rule]", "776"}], ",", 
       RowBox[{"1151", "\[Rule]", "1434"}], ",", 
       RowBox[{"1151", "\[Rule]", "1434"}], ",", 
       RowBox[{"1151", "\[Rule]", "1152"}], ",", 
       RowBox[{"1445", "\[Rule]", "1164"}], ",", 
       RowBox[{"1445", "\[Rule]", "1164"}], ",", 
       RowBox[{"1445", "\[Rule]", "1822"}], ",", 
       RowBox[{"1445", "\[Rule]", "1822"}], ",", 
       RowBox[{"1445", "\[Rule]", "1070"}], ",", 
       RowBox[{"1445", "\[Rule]", "1070"}], ",", 
       RowBox[{"1445", "\[Rule]", "1728"}], ",", 
       RowBox[{"1445", "\[Rule]", "1728"}], ",", 
       RowBox[{"1445", "\[Rule]", "1446"}], ",", 
       RowBox[{"1163", "\[Rule]", "882"}], ",", 
       RowBox[{"1163", "\[Rule]", "882"}], ",", 
       RowBox[{"1163", "\[Rule]", "1540"}], ",", 
       RowBox[{"1163", "\[Rule]", "1540"}], ",", 
       RowBox[{"1163", "\[Rule]", "788"}], ",", 
       RowBox[{"1163", "\[Rule]", "788"}], ",", 
       RowBox[{"1163", "\[Rule]", "1446"}], ",", 
       RowBox[{"1163", "\[Rule]", "1446"}], ",", 
       RowBox[{"1163", "\[Rule]", "1164"}], ",", 
       RowBox[{"1691", "\[Rule]", "1316"}], ",", 
       RowBox[{"1691", "\[Rule]", "1316"}], ",", 
       RowBox[{"1691", "\[Rule]", "1974"}], ",", 
       RowBox[{"1691", "\[Rule]", "1974"}], ",", 
       RowBox[{"1691", "\[Rule]", "1692"}], ",", 
       RowBox[{"1675", "\[Rule]", "1300"}], ",", 
       RowBox[{"1675", "\[Rule]", "1300"}], ",", 
       RowBox[{"1675", "\[Rule]", "1958"}], ",", 
       RowBox[{"1675", "\[Rule]", "1958"}], ",", 
       RowBox[{"1675", "\[Rule]", "1676"}], ",", 
       RowBox[{"1315", "\[Rule]", "1034"}], ",", 
       RowBox[{"1315", "\[Rule]", "1034"}], ",", 
       RowBox[{"1315", "\[Rule]", "1692"}], ",", 
       RowBox[{"1315", "\[Rule]", "1692"}], ",", 
       RowBox[{"1315", "\[Rule]", "940"}], ",", 
       RowBox[{"1315", "\[Rule]", "940"}], ",", 
       RowBox[{"1315", "\[Rule]", "1598"}], ",", 
       RowBox[{"1315", "\[Rule]", "1598"}], ",", 
       RowBox[{"1315", "\[Rule]", "1316"}], ",", 
       RowBox[{"1299", "\[Rule]", "1018"}], ",", 
       RowBox[{"1299", "\[Rule]", "1018"}], ",", 
       RowBox[{"1299", "\[Rule]", "1676"}], ",", 
       RowBox[{"1299", "\[Rule]", "1676"}], ",", 
       RowBox[{"1299", "\[Rule]", "924"}], ",", 
       RowBox[{"1299", "\[Rule]", "924"}], ",", 
       RowBox[{"1299", "\[Rule]", "1582"}], ",", 
       RowBox[{"1299", "\[Rule]", "1582"}], ",", 
       RowBox[{"1299", "\[Rule]", "1300"}], ",", 
       RowBox[{"1659", "\[Rule]", "1284"}], ",", 
       RowBox[{"1659", "\[Rule]", "1284"}], ",", 
       RowBox[{"1659", "\[Rule]", "1942"}], ",", 
       RowBox[{"1659", "\[Rule]", "1942"}], ",", 
       RowBox[{"1659", "\[Rule]", "1660"}], ",", 
       RowBox[{"1283", "\[Rule]", "1002"}], ",", 
       RowBox[{"1283", "\[Rule]", "1002"}], ",", 
       RowBox[{"1283", "\[Rule]", "1660"}], ",", 
       RowBox[{"1283", "\[Rule]", "1660"}], ",", 
       RowBox[{"1283", "\[Rule]", "908"}], ",", 
       RowBox[{"1283", "\[Rule]", "908"}], ",", 
       RowBox[{"1283", "\[Rule]", "1566"}], ",", 
       RowBox[{"1283", "\[Rule]", "1566"}], ",", 
       RowBox[{"1283", "\[Rule]", "1284"}], ",", 
       RowBox[{"1643", "\[Rule]", "1268"}], ",", 
       RowBox[{"1643", "\[Rule]", "1268"}], ",", 
       RowBox[{"1643", "\[Rule]", "1926"}], ",", 
       RowBox[{"1643", "\[Rule]", "1926"}], ",", 
       RowBox[{"1643", "\[Rule]", "1644"}], ",", 
       RowBox[{"1549", "\[Rule]", "1268"}], ",", 
       RowBox[{"1549", "\[Rule]", "1268"}], ",", 
       RowBox[{"1549", "\[Rule]", "1926"}], ",", 
       RowBox[{"1549", "\[Rule]", "1926"}], ",", 
       RowBox[{"1549", "\[Rule]", "1174"}], ",", 
       RowBox[{"1549", "\[Rule]", "1174"}], ",", 
       RowBox[{"1549", "\[Rule]", "1832"}], ",", 
       RowBox[{"1549", "\[Rule]", "1832"}], ",", 
       RowBox[{"1549", "\[Rule]", "1550"}], ",", 
       RowBox[{"1267", "\[Rule]", "986"}], ",", 
       RowBox[{"1267", "\[Rule]", "986"}], ",", 
       RowBox[{"1267", "\[Rule]", "1644"}], ",", 
       RowBox[{"1267", "\[Rule]", "1644"}], ",", 
       RowBox[{"1267", "\[Rule]", "892"}], ",", 
       RowBox[{"1267", "\[Rule]", "892"}], ",", 
       RowBox[{"1267", "\[Rule]", "1550"}], ",", 
       RowBox[{"1267", "\[Rule]", "1550"}], ",", 
       RowBox[{"1267", "\[Rule]", "1268"}], ",", 
       RowBox[{"1455", "\[Rule]", "1174"}], ",", 
       RowBox[{"1455", "\[Rule]", "1174"}], ",", 
       RowBox[{"1455", "\[Rule]", "1832"}], ",", 
       RowBox[{"1455", "\[Rule]", "1832"}], ",", 
       RowBox[{"1455", "\[Rule]", "1080"}], ",", 
       RowBox[{"1455", "\[Rule]", "1080"}], ",", 
       RowBox[{"1455", "\[Rule]", "1738"}], ",", 
       RowBox[{"1455", "\[Rule]", "1738"}], ",", 
       RowBox[{"1455", "\[Rule]", "1456"}], ",", 
       RowBox[{"1173", "\[Rule]", "892"}], ",", 
       RowBox[{"1173", "\[Rule]", "892"}], ",", 
       RowBox[{"1173", "\[Rule]", "1550"}], ",", 
       RowBox[{"1173", "\[Rule]", "1550"}], ",", 
       RowBox[{"1173", "\[Rule]", "798"}], ",", 
       RowBox[{"1173", "\[Rule]", "798"}], ",", 
       RowBox[{"1173", "\[Rule]", "1456"}], ",", 
       RowBox[{"1173", "\[Rule]", "1456"}], ",", 
       RowBox[{"1173", "\[Rule]", "1174"}], ",", 
       RowBox[{"13", "\[Rule]", "390"}], ",", 
       RowBox[{"13", "\[Rule]", "390"}], ",", 
       RowBox[{"13", "\[Rule]", "14"}], ",", 
       RowBox[{"23", "\[Rule]", "400"}], ",", 
       RowBox[{"23", "\[Rule]", "400"}], ",", 
       RowBox[{"23", "\[Rule]", "24"}], ",", 
       RowBox[{"671", "\[Rule]", "390"}], ",", 
       RowBox[{"671", "\[Rule]", "390"}], ",", 
       RowBox[{"671", "\[Rule]", "1048"}], ",", 
       RowBox[{"671", "\[Rule]", "672"}], ",", 
       RowBox[{"681", "\[Rule]", "400"}], ",", 
       RowBox[{"681", "\[Rule]", "400"}], ",", 
       RowBox[{"681", "\[Rule]", "1058"}], ",", 
       RowBox[{"681", "\[Rule]", "682"}], ",", 
       RowBox[{"389", "\[Rule]", "108"}], ",", 
       RowBox[{"389", "\[Rule]", "766"}], ",", 
       RowBox[{"389", "\[Rule]", "14"}], ",", 
       RowBox[{"389", "\[Rule]", "14"}], ",", 
       RowBox[{"389", "\[Rule]", "672"}], ",", 
       RowBox[{"389", "\[Rule]", "672"}], ",", 
       RowBox[{"389", "\[Rule]", "390"}], ",", 
       RowBox[{"399", "\[Rule]", "118"}], ",", 
       RowBox[{"399", "\[Rule]", "776"}], ",", 
       RowBox[{"399", "\[Rule]", "24"}], ",", 
       RowBox[{"399", "\[Rule]", "24"}], ",", 
       RowBox[{"399", "\[Rule]", "682"}], ",", 
       RowBox[{"399", "\[Rule]", "682"}], ",", 
       RowBox[{"399", "\[Rule]", "400"}], ",", 
       RowBox[{"35", "\[Rule]", "412"}], ",", 
       RowBox[{"35", "\[Rule]", "412"}], ",", 
       RowBox[{"35", "\[Rule]", "36"}], ",", 
       RowBox[{"693", "\[Rule]", "412"}], ",", 
       RowBox[{"693", "\[Rule]", "412"}], ",", 
       RowBox[{"693", "\[Rule]", "1070"}], ",", 
       RowBox[{"693", "\[Rule]", "694"}], ",", 
       RowBox[{"411", "\[Rule]", "130"}], ",", 
       RowBox[{"411", "\[Rule]", "788"}], ",", 
       RowBox[{"411", "\[Rule]", "36"}], ",", 
       RowBox[{"411", "\[Rule]", "36"}], ",", 
       RowBox[{"411", "\[Rule]", "694"}], ",", 
       RowBox[{"411", "\[Rule]", "694"}], ",", 
       RowBox[{"411", "\[Rule]", "412"}], ",", 
       RowBox[{"45", "\[Rule]", "422"}], ",", 
       RowBox[{"45", "\[Rule]", "422"}], ",", 
       RowBox[{"45", "\[Rule]", "46"}], ",", 
       RowBox[{"703", "\[Rule]", "422"}], ",", 
       RowBox[{"703", "\[Rule]", "422"}], ",", 
       RowBox[{"703", "\[Rule]", "1080"}], ",", 
       RowBox[{"703", "\[Rule]", "704"}], ",", 
       RowBox[{"421", "\[Rule]", "140"}], ",", 
       RowBox[{"421", "\[Rule]", "798"}], ",", 
       RowBox[{"421", "\[Rule]", "46"}], ",", 
       RowBox[{"421", "\[Rule]", "46"}], ",", 
       RowBox[{"421", "\[Rule]", "704"}], ",", 
       RowBox[{"421", "\[Rule]", "704"}], ",", 
       RowBox[{"421", "\[Rule]", "422"}], ",", 
       RowBox[{"1329", "\[Rule]", "1048"}], ",", 
       RowBox[{"1329", "\[Rule]", "1706"}], ",", 
       RowBox[{"1329", "\[Rule]", "1706"}], ",", 
       RowBox[{"1329", "\[Rule]", "1330"}], ",", 
       RowBox[{"1339", "\[Rule]", "1058"}], ",", 
       RowBox[{"1339", "\[Rule]", "1716"}], ",", 
       RowBox[{"1339", "\[Rule]", "1716"}], ",", 
       RowBox[{"1339", "\[Rule]", "1340"}], ",", 
       RowBox[{"1047", "\[Rule]", "766"}], ",", 
       RowBox[{"1047", "\[Rule]", "766"}], ",", 
       RowBox[{"1047", "\[Rule]", "1424"}], ",", 
       RowBox[{"1047", "\[Rule]", "1424"}], ",", 
       RowBox[{"1047", "\[Rule]", "672"}], ",", 
       RowBox[{"1047", "\[Rule]", "1330"}], ",", 
       RowBox[{"1047", "\[Rule]", "1048"}], ",", 
       RowBox[{"1057", "\[Rule]", "776"}], ",", 
       RowBox[{"1057", "\[Rule]", "776"}], ",", 
       RowBox[{"1057", "\[Rule]", "1434"}], ",", 
       RowBox[{"1057", "\[Rule]", "1434"}], ",", 
       RowBox[{"1057", "\[Rule]", "682"}], ",", 
       RowBox[{"1057", "\[Rule]", "1340"}], ",", 
       RowBox[{"1057", "\[Rule]", "1058"}], ",", 
       RowBox[{"1351", "\[Rule]", "1070"}], ",", 
       RowBox[{"1351", "\[Rule]", "1728"}], ",", 
       RowBox[{"1351", "\[Rule]", "1728"}], ",", 
       RowBox[{"1351", "\[Rule]", "1352"}], ",", 
       RowBox[{"1069", "\[Rule]", "788"}], ",", 
       RowBox[{"1069", "\[Rule]", "788"}], ",", 
       RowBox[{"1069", "\[Rule]", "1446"}], ",", 
       RowBox[{"1069", "\[Rule]", "1446"}], ",", 
       RowBox[{"1069", "\[Rule]", "694"}], ",", 
       RowBox[{"1069", "\[Rule]", "1352"}], ",", 
       RowBox[{"1069", "\[Rule]", "1070"}], ",", 
       RowBox[{"1361", "\[Rule]", "1080"}], ",", 
       RowBox[{"1361", "\[Rule]", "1738"}], ",", 
       RowBox[{"1361", "\[Rule]", "1738"}], ",", 
       RowBox[{"1361", "\[Rule]", "1362"}], ",", 
       RowBox[{"1079", "\[Rule]", "798"}], ",", 
       RowBox[{"1079", "\[Rule]", "798"}], ",", 
       RowBox[{"1079", "\[Rule]", "1456"}], ",", 
       RowBox[{"1079", "\[Rule]", "1456"}], ",", 
       RowBox[{"1079", "\[Rule]", "704"}], ",", 
       RowBox[{"1079", "\[Rule]", "1362"}], ",", 
       RowBox[{"1079", "\[Rule]", "1080"}], ",", 
       RowBox[{"371", "\[Rule]", "654"}], ",", 
       RowBox[{"371", "\[Rule]", "654"}], ",", 
       RowBox[{"371", "\[Rule]", "372"}], ",", 
       RowBox[{"1029", "\[Rule]", "654"}], ",", 
       RowBox[{"1029", "\[Rule]", "654"}], ",", 
       RowBox[{"1029", "\[Rule]", "1312"}], ",", 
       RowBox[{"1029", "\[Rule]", "1312"}], ",", 
       RowBox[{"1029", "\[Rule]", "1030"}], ",", 
       RowBox[{"653", "\[Rule]", "372"}], ",", 
       RowBox[{"653", "\[Rule]", "372"}], ",", 
       RowBox[{"653", "\[Rule]", "1030"}], ",", 
       RowBox[{"653", "\[Rule]", "1030"}], ",", 
       RowBox[{"653", "\[Rule]", "278"}], ",", 
       RowBox[{"653", "\[Rule]", "278"}], ",", 
       RowBox[{"653", "\[Rule]", "936"}], ",", 
       RowBox[{"653", "\[Rule]", "936"}], ",", 
       RowBox[{"653", "\[Rule]", "654"}], ",", 
       RowBox[{"355", "\[Rule]", "638"}], ",", 
       RowBox[{"355", "\[Rule]", "638"}], ",", 
       RowBox[{"355", "\[Rule]", "356"}], ",", 
       RowBox[{"1013", "\[Rule]", "638"}], ",", 
       RowBox[{"1013", "\[Rule]", "638"}], ",", 
       RowBox[{"1013", "\[Rule]", "1296"}], ",", 
       RowBox[{"1013", "\[Rule]", "1296"}], ",", 
       RowBox[{"1013", "\[Rule]", "1014"}], ",", 
       RowBox[{"637", "\[Rule]", "356"}], ",", 
       RowBox[{"637", "\[Rule]", "356"}], ",", 
       RowBox[{"637", "\[Rule]", "1014"}], ",", 
       RowBox[{"637", "\[Rule]", "1014"}], ",", 
       RowBox[{"637", "\[Rule]", "262"}], ",", 
       RowBox[{"637", "\[Rule]", "262"}], ",", 
       RowBox[{"637", "\[Rule]", "920"}], ",", 
       RowBox[{"637", "\[Rule]", "920"}], ",", 
       RowBox[{"637", "\[Rule]", "638"}], ",", 
       RowBox[{"1687", "\[Rule]", "1312"}], ",", 
       RowBox[{"1687", "\[Rule]", "1312"}], ",", 
       RowBox[{"1687", "\[Rule]", "1970"}], ",", 
       RowBox[{"1687", "\[Rule]", "1970"}], ",", 
       RowBox[{"1687", "\[Rule]", "1688"}], ",", 
       RowBox[{"1311", "\[Rule]", "1030"}], ",", 
       RowBox[{"1311", "\[Rule]", "1030"}], ",", 
       RowBox[{"1311", "\[Rule]", "1688"}], ",", 
       RowBox[{"1311", "\[Rule]", "1688"}], ",", 
       RowBox[{"1311", "\[Rule]", "936"}], ",", 
       RowBox[{"1311", "\[Rule]", "936"}], ",", 
       RowBox[{"1311", "\[Rule]", "1594"}], ",", 
       RowBox[{"1311", "\[Rule]", "1594"}], ",", 
       RowBox[{"1311", "\[Rule]", "1312"}], ",", 
       RowBox[{"1671", "\[Rule]", "1296"}], ",", 
       RowBox[{"1671", "\[Rule]", "1296"}], ",", 
       RowBox[{"1671", "\[Rule]", "1954"}], ",", 
       RowBox[{"1671", "\[Rule]", "1954"}], ",", 
       RowBox[{"1671", "\[Rule]", "1672"}], ",", 
       RowBox[{"1295", "\[Rule]", "1014"}], ",", 
       RowBox[{"1295", "\[Rule]", "1014"}], ",", 
       RowBox[{"1295", "\[Rule]", "1672"}], ",", 
       RowBox[{"1295", "\[Rule]", "1672"}], ",", 
       RowBox[{"1295", "\[Rule]", "920"}], ",", 
       RowBox[{"1295", "\[Rule]", "920"}], ",", 
       RowBox[{"1295", "\[Rule]", "1578"}], ",", 
       RowBox[{"1295", "\[Rule]", "1578"}], ",", 
       RowBox[{"1295", "\[Rule]", "1296"}], ",", 
       RowBox[{"339", "\[Rule]", "622"}], ",", 
       RowBox[{"339", "\[Rule]", "622"}], ",", 
       RowBox[{"339", "\[Rule]", "340"}], ",", 
       RowBox[{"997", "\[Rule]", "622"}], ",", 
       RowBox[{"997", "\[Rule]", "622"}], ",", 
       RowBox[{"997", "\[Rule]", "1280"}], ",", 
       RowBox[{"997", "\[Rule]", "1280"}], ",", 
       RowBox[{"997", "\[Rule]", "998"}], ",", 
       RowBox[{"245", "\[Rule]", "622"}], ",", 
       RowBox[{"245", "\[Rule]", "622"}], ",", 
       RowBox[{"245", "\[Rule]", "528"}], ",", 
       RowBox[{"245", "\[Rule]", "528"}], ",", 
       RowBox[{"245", "\[Rule]", "246"}], ",", 
       RowBox[{"903", "\[Rule]", "622"}], ",", 
       RowBox[{"903", "\[Rule]", "622"}], ",", 
       RowBox[{"903", "\[Rule]", "1280"}], ",", 
       RowBox[{"903", "\[Rule]", "1280"}], ",", 
       RowBox[{"903", "\[Rule]", "528"}], ",", 
       RowBox[{"903", "\[Rule]", "528"}], ",", 
       RowBox[{"903", "\[Rule]", "1186"}], ",", 
       RowBox[{"903", "\[Rule]", "1186"}], ",", 
       RowBox[{"903", "\[Rule]", "904"}], ",", 
       RowBox[{"621", "\[Rule]", "340"}], ",", 
       RowBox[{"621", "\[Rule]", "340"}], ",", 
       RowBox[{"621", "\[Rule]", "998"}], ",", 
       RowBox[{"621", "\[Rule]", "998"}], ",", 
       RowBox[{"621", "\[Rule]", "246"}], ",", 
       RowBox[{"621", "\[Rule]", "246"}], ",", 
       RowBox[{"621", "\[Rule]", "904"}], ",", 
       RowBox[{"621", "\[Rule]", "904"}], ",", 
       RowBox[{"621", "\[Rule]", "622"}], ",", 
       RowBox[{"151", "\[Rule]", "528"}], ",", 
       RowBox[{"151", "\[Rule]", "434"}], ",", 
       RowBox[{"151", "\[Rule]", "152"}], ",", 
       RowBox[{"809", "\[Rule]", "528"}], ",", 
       RowBox[{"809", "\[Rule]", "1186"}], ",", 
       RowBox[{"809", "\[Rule]", "1186"}], ",", 
       RowBox[{"809", "\[Rule]", "434"}], ",", 
       RowBox[{"809", "\[Rule]", "1092"}], ",", 
       RowBox[{"809", "\[Rule]", "1092"}], ",", 
       RowBox[{"809", "\[Rule]", "810"}], ",", 
       RowBox[{"527", "\[Rule]", "246"}], ",", 
       RowBox[{"527", "\[Rule]", "246"}], ",", 
       RowBox[{"527", "\[Rule]", "904"}], ",", 
       RowBox[{"527", "\[Rule]", "904"}], ",", 
       RowBox[{"527", "\[Rule]", "152"}], ",", 
       RowBox[{"527", "\[Rule]", "810"}], ",", 
       RowBox[{"527", "\[Rule]", "528"}], ",", 
       RowBox[{"1655", "\[Rule]", "1280"}], ",", 
       RowBox[{"1655", "\[Rule]", "1280"}], ",", 
       RowBox[{"1655", "\[Rule]", "1938"}], ",", 
       RowBox[{"1655", "\[Rule]", "1938"}], ",", 
       RowBox[{"1655", "\[Rule]", "1656"}], ",", 
       RowBox[{"1561", "\[Rule]", "1280"}], ",", 
       RowBox[{"1561", "\[Rule]", "1280"}], ",", 
       RowBox[{"1561", "\[Rule]", "1938"}], ",", 
       RowBox[{"1561", "\[Rule]", "1938"}], ",", 
       RowBox[{"1561", "\[Rule]", "1186"}], ",", 
       RowBox[{"1561", "\[Rule]", "1186"}], ",", 
       RowBox[{"1561", "\[Rule]", "1844"}], ",", 
       RowBox[{"1561", "\[Rule]", "1844"}], ",", 
       RowBox[{"1561", "\[Rule]", "1562"}], ",", 
       RowBox[{"1279", "\[Rule]", "998"}], ",", 
       RowBox[{"1279", "\[Rule]", "998"}], ",", 
       RowBox[{"1279", "\[Rule]", "1656"}], ",", 
       RowBox[{"1279", "\[Rule]", "1656"}], ",", 
       RowBox[{"1279", "\[Rule]", "904"}], ",", 
       RowBox[{"1279", "\[Rule]", "904"}], ",", 
       RowBox[{"1279", "\[Rule]", "1562"}], ",", 
       RowBox[{"1279", "\[Rule]", "1562"}], ",", 
       RowBox[{"1279", "\[Rule]", "1280"}], ",", 
       RowBox[{"1467", "\[Rule]", "1186"}], ",", 
       RowBox[{"1467", "\[Rule]", "1186"}], ",", 
       RowBox[{"1467", "\[Rule]", "1844"}], ",", 
       RowBox[{"1467", "\[Rule]", "1844"}], ",", 
       RowBox[{"1467", "\[Rule]", "1092"}], ",", 
       RowBox[{"1467", "\[Rule]", "1092"}], ",", 
       RowBox[{"1467", "\[Rule]", "1750"}], ",", 
       RowBox[{"1467", "\[Rule]", "1750"}], ",", 
       RowBox[{"1467", "\[Rule]", "1468"}], ",", 
       RowBox[{"1185", "\[Rule]", "904"}], ",", 
       RowBox[{"1185", "\[Rule]", "904"}], ",", 
       RowBox[{"1185", "\[Rule]", "1562"}], ",", 
       RowBox[{"1185", "\[Rule]", "1562"}], ",", 
       RowBox[{"1185", "\[Rule]", "810"}], ",", 
       RowBox[{"1185", "\[Rule]", "810"}], ",", 
       RowBox[{"1185", "\[Rule]", "1468"}], ",", 
       RowBox[{"1185", "\[Rule]", "1468"}], ",", 
       RowBox[{"1185", "\[Rule]", "1186"}], ",", 
       RowBox[{"57", "\[Rule]", "434"}], ",", 
       RowBox[{"57", "\[Rule]", "434"}], ",", 
       RowBox[{"57", "\[Rule]", "58"}], ",", 
       RowBox[{"715", "\[Rule]", "434"}], ",", 
       RowBox[{"715", "\[Rule]", "434"}], ",", 
       RowBox[{"715", "\[Rule]", "1092"}], ",", 
       RowBox[{"715", "\[Rule]", "716"}], ",", 
       RowBox[{"433", "\[Rule]", "152"}], ",", 
       RowBox[{"433", "\[Rule]", "810"}], ",", 
       RowBox[{"433", "\[Rule]", "58"}], ",", 
       RowBox[{"433", "\[Rule]", "58"}], ",", 
       RowBox[{"433", "\[Rule]", "716"}], ",", 
       RowBox[{"433", "\[Rule]", "716"}], ",", 
       RowBox[{"433", "\[Rule]", "434"}], ",", 
       RowBox[{"1373", "\[Rule]", "1092"}], ",", 
       RowBox[{"1373", "\[Rule]", "1750"}], ",", 
       RowBox[{"1373", "\[Rule]", "1750"}], ",", 
       RowBox[{"1373", "\[Rule]", "1374"}], ",", 
       RowBox[{"1091", "\[Rule]", "810"}], ",", 
       RowBox[{"1091", "\[Rule]", "810"}], ",", 
       RowBox[{"1091", "\[Rule]", "1468"}], ",", 
       RowBox[{"1091", "\[Rule]", "1468"}], ",", 
       RowBox[{"1091", "\[Rule]", "716"}], ",", 
       RowBox[{"1091", "\[Rule]", "1374"}], ",", 
       RowBox[{"1091", "\[Rule]", "1092"}], ",", 
       RowBox[{"367", "\[Rule]", "650"}], ",", 
       RowBox[{"367", "\[Rule]", "650"}], ",", 
       RowBox[{"367", "\[Rule]", "368"}], ",", 
       RowBox[{"1025", "\[Rule]", "650"}], ",", 
       RowBox[{"1025", "\[Rule]", "650"}], ",", 
       RowBox[{"1025", "\[Rule]", "1308"}], ",", 
       RowBox[{"1025", "\[Rule]", "1308"}], ",", 
       RowBox[{"1025", "\[Rule]", "1026"}], ",", 
       RowBox[{"649", "\[Rule]", "368"}], ",", 
       RowBox[{"649", "\[Rule]", "368"}], ",", 
       RowBox[{"649", "\[Rule]", "1026"}], ",", 
       RowBox[{"649", "\[Rule]", "1026"}], ",", 
       RowBox[{"649", "\[Rule]", "274"}], ",", 
       RowBox[{"649", "\[Rule]", "274"}], ",", 
       RowBox[{"649", "\[Rule]", "932"}], ",", 
       RowBox[{"649", "\[Rule]", "932"}], ",", 
       RowBox[{"649", "\[Rule]", "650"}], ",", 
       RowBox[{"1683", "\[Rule]", "1308"}], ",", 
       RowBox[{"1683", "\[Rule]", "1308"}], ",", 
       RowBox[{"1683", "\[Rule]", "1966"}], ",", 
       RowBox[{"1683", "\[Rule]", "1966"}], ",", 
       RowBox[{"1683", "\[Rule]", "1684"}], ",", 
       RowBox[{"1307", "\[Rule]", "1026"}], ",", 
       RowBox[{"1307", "\[Rule]", "1026"}], ",", 
       RowBox[{"1307", "\[Rule]", "1684"}], ",", 
       RowBox[{"1307", "\[Rule]", "1684"}], ",", 
       RowBox[{"1307", "\[Rule]", "932"}], ",", 
       RowBox[{"1307", "\[Rule]", "932"}], ",", 
       RowBox[{"1307", "\[Rule]", "1590"}], ",", 
       RowBox[{"1307", "\[Rule]", "1590"}], ",", 
       RowBox[{"1307", "\[Rule]", "1308"}], ",", 
       RowBox[{"351", "\[Rule]", "634"}], ",", 
       RowBox[{"351", "\[Rule]", "634"}], ",", 
       RowBox[{"351", "\[Rule]", "352"}], ",", 
       RowBox[{"1009", "\[Rule]", "634"}], ",", 
       RowBox[{"1009", "\[Rule]", "634"}], ",", 
       RowBox[{"1009", "\[Rule]", "1292"}], ",", 
       RowBox[{"1009", "\[Rule]", "1292"}], ",", 
       RowBox[{"1009", "\[Rule]", "1010"}], ",", 
       RowBox[{"257", "\[Rule]", "634"}], ",", 
       RowBox[{"257", "\[Rule]", "634"}], ",", 
       RowBox[{"257", "\[Rule]", "540"}], ",", 
       RowBox[{"257", "\[Rule]", "540"}], ",", 
       RowBox[{"257", "\[Rule]", "258"}], ",", 
       RowBox[{"915", "\[Rule]", "634"}], ",", 
       RowBox[{"915", "\[Rule]", "634"}], ",", 
       RowBox[{"915", "\[Rule]", "1292"}], ",", 
       RowBox[{"915", "\[Rule]", "1292"}], ",", 
       RowBox[{"915", "\[Rule]", "540"}], ",", 
       RowBox[{"915", "\[Rule]", "540"}], ",", 
       RowBox[{"915", "\[Rule]", "1198"}], ",", 
       RowBox[{"915", "\[Rule]", "1198"}], ",", 
       RowBox[{"915", "\[Rule]", "916"}], ",", 
       RowBox[{"633", "\[Rule]", "352"}], ",", 
       RowBox[{"633", "\[Rule]", "352"}], ",", 
       RowBox[{"633", "\[Rule]", "1010"}], ",", 
       RowBox[{"633", "\[Rule]", "1010"}], ",", 
       RowBox[{"633", "\[Rule]", "258"}], ",", 
       RowBox[{"633", "\[Rule]", "258"}], ",", 
       RowBox[{"633", "\[Rule]", "916"}], ",", 
       RowBox[{"633", "\[Rule]", "916"}], ",", 
       RowBox[{"633", "\[Rule]", "634"}], ",", 
       RowBox[{"163", "\[Rule]", "540"}], ",", 
       RowBox[{"163", "\[Rule]", "446"}], ",", 
       RowBox[{"163", "\[Rule]", "164"}], ",", 
       RowBox[{"821", "\[Rule]", "540"}], ",", 
       RowBox[{"821", "\[Rule]", "1198"}], ",", 
       RowBox[{"821", "\[Rule]", "1198"}], ",", 
       RowBox[{"821", "\[Rule]", "446"}], ",", 
       RowBox[{"821", "\[Rule]", "1104"}], ",", 
       RowBox[{"821", "\[Rule]", "1104"}], ",", 
       RowBox[{"821", "\[Rule]", "822"}], ",", 
       RowBox[{"539", "\[Rule]", "258"}], ",", 
       RowBox[{"539", "\[Rule]", "258"}], ",", 
       RowBox[{"539", "\[Rule]", "916"}], ",", 
       RowBox[{"539", "\[Rule]", "916"}], ",", 
       RowBox[{"539", "\[Rule]", "164"}], ",", 
       RowBox[{"539", "\[Rule]", "822"}], ",", 
       RowBox[{"539", "\[Rule]", "540"}], ",", 
       RowBox[{"1667", "\[Rule]", "1292"}], ",", 
       RowBox[{"1667", "\[Rule]", "1292"}], ",", 
       RowBox[{"1667", "\[Rule]", "1950"}], ",", 
       RowBox[{"1667", "\[Rule]", "1950"}], ",", 
       RowBox[{"1667", "\[Rule]", "1668"}], ",", 
       RowBox[{"1573", "\[Rule]", "1292"}], ",", 
       RowBox[{"1573", "\[Rule]", "1292"}], ",", 
       RowBox[{"1573", "\[Rule]", "1950"}], ",", 
       RowBox[{"1573", "\[Rule]", "1950"}], ",", 
       RowBox[{"1573", "\[Rule]", "1198"}], ",", 
       RowBox[{"1573", "\[Rule]", "1198"}], ",", 
       RowBox[{"1573", "\[Rule]", "1856"}], ",", 
       RowBox[{"1573", "\[Rule]", "1856"}], ",", 
       RowBox[{"1573", "\[Rule]", "1574"}], ",", 
       RowBox[{"1291", "\[Rule]", "1010"}], ",", 
       RowBox[{"1291", "\[Rule]", "1010"}], ",", 
       RowBox[{"1291", "\[Rule]", "1668"}], ",", 
       RowBox[{"1291", "\[Rule]", "1668"}], ",", 
       RowBox[{"1291", "\[Rule]", "916"}], ",", 
       RowBox[{"1291", "\[Rule]", "916"}], ",", 
       RowBox[{"1291", "\[Rule]", "1574"}], ",", 
       RowBox[{"1291", "\[Rule]", "1574"}], ",", 
       RowBox[{"1291", "\[Rule]", "1292"}], ",", 
       RowBox[{"1479", "\[Rule]", "1198"}], ",", 
       RowBox[{"1479", "\[Rule]", "1198"}], ",", 
       RowBox[{"1479", "\[Rule]", "1856"}], ",", 
       RowBox[{"1479", "\[Rule]", "1856"}], ",", 
       RowBox[{"1479", "\[Rule]", "1104"}], ",", 
       RowBox[{"1479", "\[Rule]", "1104"}], ",", 
       RowBox[{"1479", "\[Rule]", "1762"}], ",", 
       RowBox[{"1479", "\[Rule]", "1762"}], ",", 
       RowBox[{"1479", "\[Rule]", "1480"}], ",", 
       RowBox[{"1197", "\[Rule]", "916"}], ",", 
       RowBox[{"1197", "\[Rule]", "916"}], ",", 
       RowBox[{"1197", "\[Rule]", "1574"}], ",", 
       RowBox[{"1197", "\[Rule]", "1574"}], ",", 
       RowBox[{"1197", "\[Rule]", "822"}], ",", 
       RowBox[{"1197", "\[Rule]", "822"}], ",", 
       RowBox[{"1197", "\[Rule]", "1480"}], ",", 
       RowBox[{"1197", "\[Rule]", "1480"}], ",", 
       RowBox[{"1197", "\[Rule]", "1198"}], ",", 
       RowBox[{"69", "\[Rule]", "446"}], ",", 
       RowBox[{"69", "\[Rule]", "446"}], ",", 
       RowBox[{"69", "\[Rule]", "70"}], ",", 
       RowBox[{"727", "\[Rule]", "446"}], ",", 
       RowBox[{"727", "\[Rule]", "446"}], ",", 
       RowBox[{"727", "\[Rule]", "1104"}], ",", 
       RowBox[{"727", "\[Rule]", "728"}], ",", 
       RowBox[{"445", "\[Rule]", "164"}], ",", 
       RowBox[{"445", "\[Rule]", "822"}], ",", 
       RowBox[{"445", "\[Rule]", "70"}], ",", 
       RowBox[{"445", "\[Rule]", "70"}], ",", 
       RowBox[{"445", "\[Rule]", "728"}], ",", 
       RowBox[{"445", "\[Rule]", "728"}], ",", 
       RowBox[{"445", "\[Rule]", "446"}], ",", 
       RowBox[{"1385", "\[Rule]", "1104"}], ",", 
       RowBox[{"1385", "\[Rule]", "1762"}], ",", 
       RowBox[{"1385", "\[Rule]", "1762"}], ",", 
       RowBox[{"1385", "\[Rule]", "1386"}], ",", 
       RowBox[{"1103", "\[Rule]", "822"}], ",", 
       RowBox[{"1103", "\[Rule]", "822"}], ",", 
       RowBox[{"1103", "\[Rule]", "1480"}], ",", 
       RowBox[{"1103", "\[Rule]", "1480"}], ",", 
       RowBox[{"1103", "\[Rule]", "728"}], ",", 
       RowBox[{"1103", "\[Rule]", "1386"}], ",", 
       RowBox[{"1103", "\[Rule]", "1104"}], ",", 
       RowBox[{"2269", "\[Rule]", "1894"}], ",", 
       RowBox[{"2269", "\[Rule]", "1894"}], ",", 
       RowBox[{"2269", "\[Rule]", "2270"}], ",", 
       RowBox[{"2295", "\[Rule]", "1920"}], ",", 
       RowBox[{"2295", "\[Rule]", "1920"}], ",", 
       RowBox[{"2295", "\[Rule]", "2296"}], ",", 
       RowBox[{"2279", "\[Rule]", "1904"}], ",", 
       RowBox[{"2279", "\[Rule]", "1904"}], ",", 
       RowBox[{"2279", "\[Rule]", "2280"}], ",", 
       RowBox[{"2175", "\[Rule]", "1894"}], ",", 
       RowBox[{"2175", "\[Rule]", "1894"}], ",", 
       RowBox[{"2175", "\[Rule]", "1800"}], ",", 
       RowBox[{"2175", "\[Rule]", "1800"}], ",", 
       RowBox[{"2175", "\[Rule]", "2176"}], ",", 
       RowBox[{"2201", "\[Rule]", "1920"}], ",", 
       RowBox[{"2201", "\[Rule]", "1920"}], ",", 
       RowBox[{"2201", "\[Rule]", "1826"}], ",", 
       RowBox[{"2201", "\[Rule]", "1826"}], ",", 
       RowBox[{"2201", "\[Rule]", "2202"}], ",", 
       RowBox[{"2185", "\[Rule]", "1904"}], ",", 
       RowBox[{"2185", "\[Rule]", "1904"}], ",", 
       RowBox[{"2185", "\[Rule]", "1810"}], ",", 
       RowBox[{"2185", "\[Rule]", "1810"}], ",", 
       RowBox[{"2185", "\[Rule]", "2186"}], ",", 
       RowBox[{"1893", "\[Rule]", "1612"}], ",", 
       RowBox[{"1893", "\[Rule]", "1612"}], ",", 
       RowBox[{"1893", "\[Rule]", "2270"}], ",", 
       RowBox[{"1893", "\[Rule]", "2270"}], ",", 
       RowBox[{"1893", "\[Rule]", "1518"}], ",", 
       RowBox[{"1893", "\[Rule]", "1518"}], ",", 
       RowBox[{"1893", "\[Rule]", "2176"}], ",", 
       RowBox[{"1893", "\[Rule]", "2176"}], ",", 
       RowBox[{"1893", "\[Rule]", "1894"}], ",", 
       RowBox[{"1919", "\[Rule]", "1638"}], ",", 
       RowBox[{"1919", "\[Rule]", "1638"}], ",", 
       RowBox[{"1919", "\[Rule]", "2296"}], ",", 
       RowBox[{"1919", "\[Rule]", "2296"}], ",", 
       RowBox[{"1919", "\[Rule]", "1544"}], ",", 
       RowBox[{"1919", "\[Rule]", "1544"}], ",", 
       RowBox[{"1919", "\[Rule]", "2202"}], ",", 
       RowBox[{"1919", "\[Rule]", "2202"}], ",", 
       RowBox[{"1919", "\[Rule]", "1920"}], ",", 
       RowBox[{"1903", "\[Rule]", "1622"}], ",", 
       RowBox[{"1903", "\[Rule]", "1622"}], ",", 
       RowBox[{"1903", "\[Rule]", "2280"}], ",", 
       RowBox[{"1903", "\[Rule]", "2280"}], ",", 
       RowBox[{"1903", "\[Rule]", "1528"}], ",", 
       RowBox[{"1903", "\[Rule]", "1528"}], ",", 
       RowBox[{"1903", "\[Rule]", "2186"}], ",", 
       RowBox[{"1903", "\[Rule]", "2186"}], ",", 
       RowBox[{"1903", "\[Rule]", "1904"}], ",", 
       RowBox[{"2321", "\[Rule]", "1946"}], ",", 
       RowBox[{"2321", "\[Rule]", "1946"}], ",", 
       RowBox[{"2321", "\[Rule]", "2322"}], ",", 
       RowBox[{"2305", "\[Rule]", "1930"}], ",", 
       RowBox[{"2305", "\[Rule]", "1930"}], ",", 
       RowBox[{"2305", "\[Rule]", "2306"}], ",", 
       RowBox[{"2227", "\[Rule]", "1946"}], ",", 
       RowBox[{"2227", "\[Rule]", "1946"}], ",", 
       RowBox[{"2227", "\[Rule]", "1852"}], ",", 
       RowBox[{"2227", "\[Rule]", "1852"}], ",", 
       RowBox[{"2227", "\[Rule]", "2228"}], ",", 
       RowBox[{"2211", "\[Rule]", "1930"}], ",", 
       RowBox[{"2211", "\[Rule]", "1930"}], ",", 
       RowBox[{"2211", "\[Rule]", "1836"}], ",", 
       RowBox[{"2211", "\[Rule]", "1836"}], ",", 
       RowBox[{"2211", "\[Rule]", "2212"}], ",", 
       RowBox[{"1945", "\[Rule]", "1664"}], ",", 
       RowBox[{"1945", "\[Rule]", "1664"}], ",", 
       RowBox[{"1945", "\[Rule]", "2322"}], ",", 
       RowBox[{"1945", "\[Rule]", "2322"}], ",", 
       RowBox[{"1945", "\[Rule]", "1570"}], ",", 
       RowBox[{"1945", "\[Rule]", "1570"}], ",", 
       RowBox[{"1945", "\[Rule]", "2228"}], ",", 
       RowBox[{"1945", "\[Rule]", "2228"}], ",", 
       RowBox[{"1945", "\[Rule]", "1946"}], ",", 
       RowBox[{"1929", "\[Rule]", "1648"}], ",", 
       RowBox[{"1929", "\[Rule]", "1648"}], ",", 
       RowBox[{"1929", "\[Rule]", "2306"}], ",", 
       RowBox[{"1929", "\[Rule]", "2306"}], ",", 
       RowBox[{"1929", "\[Rule]", "1554"}], ",", 
       RowBox[{"1929", "\[Rule]", "1554"}], ",", 
       RowBox[{"1929", "\[Rule]", "2212"}], ",", 
       RowBox[{"1929", "\[Rule]", "2212"}], ",", 
       RowBox[{"1929", "\[Rule]", "1930"}], ",", 
       RowBox[{"2291", "\[Rule]", "1916"}], ",", 
       RowBox[{"2291", "\[Rule]", "1916"}], ",", 
       RowBox[{"2291", "\[Rule]", "2292"}], ",", 
       RowBox[{"2197", "\[Rule]", "1916"}], ",", 
       RowBox[{"2197", "\[Rule]", "1916"}], ",", 
       RowBox[{"2197", "\[Rule]", "1822"}], ",", 
       RowBox[{"2197", "\[Rule]", "1822"}], ",", 
       RowBox[{"2197", "\[Rule]", "2198"}], ",", 
       RowBox[{"1915", "\[Rule]", "1634"}], ",", 
       RowBox[{"1915", "\[Rule]", "1634"}], ",", 
       RowBox[{"1915", "\[Rule]", "2292"}], ",", 
       RowBox[{"1915", "\[Rule]", "2292"}], ",", 
       RowBox[{"1915", "\[Rule]", "1540"}], ",", 
       RowBox[{"1915", "\[Rule]", "1540"}], ",", 
       RowBox[{"1915", "\[Rule]", "2198"}], ",", 
       RowBox[{"1915", "\[Rule]", "2198"}], ",", 
       RowBox[{"1915", "\[Rule]", "1916"}], ",", 
       RowBox[{"2081", "\[Rule]", "1800"}], ",", 
       RowBox[{"2081", "\[Rule]", "1800"}], ",", 
       RowBox[{"2081", "\[Rule]", "1706"}], ",", 
       RowBox[{"2081", "\[Rule]", "1706"}], ",", 
       RowBox[{"2081", "\[Rule]", "2082"}], ",", 
       RowBox[{"2107", "\[Rule]", "1826"}], ",", 
       RowBox[{"2107", "\[Rule]", "1826"}], ",", 
       RowBox[{"2107", "\[Rule]", "1732"}], ",", 
       RowBox[{"2107", "\[Rule]", "1732"}], ",", 
       RowBox[{"2107", "\[Rule]", "2108"}], ",", 
       RowBox[{"2091", "\[Rule]", "1810"}], ",", 
       RowBox[{"2091", "\[Rule]", "1810"}], ",", 
       RowBox[{"2091", "\[Rule]", "1716"}], ",", 
       RowBox[{"2091", "\[Rule]", "1716"}], ",", 
       RowBox[{"2091", "\[Rule]", "2092"}], ",", 
       RowBox[{"1799", "\[Rule]", "1518"}], ",", 
       RowBox[{"1799", "\[Rule]", "1518"}], ",", 
       RowBox[{"1799", "\[Rule]", "2176"}], ",", 
       RowBox[{"1799", "\[Rule]", "2176"}], ",", 
       RowBox[{"1799", "\[Rule]", "1424"}], ",", 
       RowBox[{"1799", "\[Rule]", "1424"}], ",", 
       RowBox[{"1799", "\[Rule]", "2082"}], ",", 
       RowBox[{"1799", "\[Rule]", "2082"}], ",", 
       RowBox[{"1799", "\[Rule]", "1800"}], ",", 
       RowBox[{"1825", "\[Rule]", "1544"}], ",", 
       RowBox[{"1825", "\[Rule]", "1544"}], ",", 
       RowBox[{"1825", "\[Rule]", "2202"}], ",", 
       RowBox[{"1825", "\[Rule]", "2202"}], ",", 
       RowBox[{"1825", "\[Rule]", "1450"}], ",", 
       RowBox[{"1825", "\[Rule]", "1450"}], ",", 
       RowBox[{"1825", "\[Rule]", "2108"}], ",", 
       RowBox[{"1825", "\[Rule]", "2108"}], ",", 
       RowBox[{"1825", "\[Rule]", "1826"}], ",", 
       RowBox[{"1809", "\[Rule]", "1528"}], ",", 
       RowBox[{"1809", "\[Rule]", "1528"}], ",", 
       RowBox[{"1809", "\[Rule]", "2186"}], ",", 
       RowBox[{"1809", "\[Rule]", "2186"}], ",", 
       RowBox[{"1809", "\[Rule]", "1434"}], ",", 
       RowBox[{"1809", "\[Rule]", "1434"}], ",", 
       RowBox[{"1809", "\[Rule]", "2092"}], ",", 
       RowBox[{"1809", "\[Rule]", "2092"}], ",", 
       RowBox[{"1809", "\[Rule]", "1810"}], ",", 
       RowBox[{"2133", "\[Rule]", "1852"}], ",", 
       RowBox[{"2133", "\[Rule]", "1852"}], ",", 
       RowBox[{"2133", "\[Rule]", "1758"}], ",", 
       RowBox[{"2133", "\[Rule]", "1758"}], ",", 
       RowBox[{"2133", "\[Rule]", "2134"}], ",", 
       RowBox[{"2117", "\[Rule]", "1836"}], ",", 
       RowBox[{"2117", "\[Rule]", "1836"}], ",", 
       RowBox[{"2117", "\[Rule]", "1742"}], ",", 
       RowBox[{"2117", "\[Rule]", "1742"}], ",", 
       RowBox[{"2117", "\[Rule]", "2118"}], ",", 
       RowBox[{"1851", "\[Rule]", "1570"}], ",", 
       RowBox[{"1851", "\[Rule]", "1570"}], ",", 
       RowBox[{"1851", "\[Rule]", "2228"}], ",", 
       RowBox[{"1851", "\[Rule]", "2228"}], ",", 
       RowBox[{"1851", "\[Rule]", "1476"}], ",", 
       RowBox[{"1851", "\[Rule]", "1476"}], ",", 
       RowBox[{"1851", "\[Rule]", "2134"}], ",", 
       RowBox[{"1851", "\[Rule]", "2134"}], ",", 
       RowBox[{"1851", "\[Rule]", "1852"}], ",", 
       RowBox[{"1835", "\[Rule]", "1554"}], ",", 
       RowBox[{"1835", "\[Rule]", "1554"}], ",", 
       RowBox[{"1835", "\[Rule]", "2212"}], ",", 
       RowBox[{"1835", "\[Rule]", "2212"}], ",", 
       RowBox[{"1835", "\[Rule]", "1460"}], ",", 
       RowBox[{"1835", "\[Rule]", "1460"}], ",", 
       RowBox[{"1835", "\[Rule]", "2118"}], ",", 
       RowBox[{"1835", "\[Rule]", "2118"}], ",", 
       RowBox[{"1835", "\[Rule]", "1836"}], ",", 
       RowBox[{"2103", "\[Rule]", "1822"}], ",", 
       RowBox[{"2103", "\[Rule]", "1822"}], ",", 
       RowBox[{"2103", "\[Rule]", "1728"}], ",", 
       RowBox[{"2103", "\[Rule]", "1728"}], ",", 
       RowBox[{"2103", "\[Rule]", "2104"}], ",", 
       RowBox[{"1821", "\[Rule]", "1540"}], ",", 
       RowBox[{"1821", "\[Rule]", "1540"}], ",", 
       RowBox[{"1821", "\[Rule]", "2198"}], ",", 
       RowBox[{"1821", "\[Rule]", "2198"}], ",", 
       RowBox[{"1821", "\[Rule]", "1446"}], ",", 
       RowBox[{"1821", "\[Rule]", "1446"}], ",", 
       RowBox[{"1821", "\[Rule]", "2104"}], ",", 
       RowBox[{"1821", "\[Rule]", "2104"}], ",", 
       RowBox[{"1821", "\[Rule]", "1822"}], ",", 
       RowBox[{"2349", "\[Rule]", "1974"}], ",", 
       RowBox[{"2349", "\[Rule]", "1974"}], ",", 
       RowBox[{"2349", "\[Rule]", "2350"}], ",", 
       RowBox[{"2333", "\[Rule]", "1958"}], ",", 
       RowBox[{"2333", "\[Rule]", "1958"}], ",", 
       RowBox[{"2333", "\[Rule]", "2334"}], ",", 
       RowBox[{"2255", "\[Rule]", "1974"}], ",", 
       RowBox[{"2255", "\[Rule]", "1974"}], ",", 
       RowBox[{"2255", "\[Rule]", "1880"}], ",", 
       RowBox[{"2255", "\[Rule]", "1880"}], ",", 
       RowBox[{"2255", "\[Rule]", "2256"}], ",", 
       RowBox[{"2239", "\[Rule]", "1958"}], ",", 
       RowBox[{"2239", "\[Rule]", "1958"}], ",", 
       RowBox[{"2239", "\[Rule]", "1864"}], ",", 
       RowBox[{"2239", "\[Rule]", "1864"}], ",", 
       RowBox[{"2239", "\[Rule]", "2240"}], ",", 
       RowBox[{"1973", "\[Rule]", "1692"}], ",", 
       RowBox[{"1973", "\[Rule]", "1692"}], ",", 
       RowBox[{"1973", "\[Rule]", "2350"}], ",", 
       RowBox[{"1973", "\[Rule]", "2350"}], ",", 
       RowBox[{"1973", "\[Rule]", "1598"}], ",", 
       RowBox[{"1973", "\[Rule]", "1598"}], ",", 
       RowBox[{"1973", "\[Rule]", "2256"}], ",", 
       RowBox[{"1973", "\[Rule]", "2256"}], ",", 
       RowBox[{"1973", "\[Rule]", "1974"}], ",", 
       RowBox[{"1957", "\[Rule]", "1676"}], ",", 
       RowBox[{"1957", "\[Rule]", "1676"}], ",", 
       RowBox[{"1957", "\[Rule]", "2334"}], ",", 
       RowBox[{"1957", "\[Rule]", "2334"}], ",", 
       RowBox[{"1957", "\[Rule]", "1582"}], ",", 
       RowBox[{"1957", "\[Rule]", "1582"}], ",", 
       RowBox[{"1957", "\[Rule]", "2240"}], ",", 
       RowBox[{"1957", "\[Rule]", "2240"}], ",", 
       RowBox[{"1957", "\[Rule]", "1958"}], ",", 
       RowBox[{"2317", "\[Rule]", "1942"}], ",", 
       RowBox[{"2317", "\[Rule]", "1942"}], ",", 
       RowBox[{"2317", "\[Rule]", "2318"}], ",", 
       RowBox[{"2223", "\[Rule]", "1942"}], ",", 
       RowBox[{"2223", "\[Rule]", "1942"}], ",", 
       RowBox[{"2223", "\[Rule]", "1848"}], ",", 
       RowBox[{"2223", "\[Rule]", "1848"}], ",", 
       RowBox[{"2223", "\[Rule]", "2224"}], ",", 
       RowBox[{"1941", "\[Rule]", "1660"}], ",", 
       RowBox[{"1941", "\[Rule]", "1660"}], ",", 
       RowBox[{"1941", "\[Rule]", "2318"}], ",", 
       RowBox[{"1941", "\[Rule]", "2318"}], ",", 
       RowBox[{"1941", "\[Rule]", "1566"}], ",", 
       RowBox[{"1941", "\[Rule]", "1566"}], ",", 
       RowBox[{"1941", "\[Rule]", "2224"}], ",", 
       RowBox[{"1941", "\[Rule]", "2224"}], ",", 
       RowBox[{"1941", "\[Rule]", "1942"}], ",", 
       RowBox[{"2161", "\[Rule]", "1880"}], ",", 
       RowBox[{"2161", "\[Rule]", "1880"}], ",", 
       RowBox[{"2161", "\[Rule]", "1786"}], ",", 
       RowBox[{"2161", "\[Rule]", "1786"}], ",", 
       RowBox[{"2161", "\[Rule]", "2162"}], ",", 
       RowBox[{"2145", "\[Rule]", "1864"}], ",", 
       RowBox[{"2145", "\[Rule]", "1864"}], ",", 
       RowBox[{"2145", "\[Rule]", "1770"}], ",", 
       RowBox[{"2145", "\[Rule]", "1770"}], ",", 
       RowBox[{"2145", "\[Rule]", "2146"}], ",", 
       RowBox[{"1879", "\[Rule]", "1598"}], ",", 
       RowBox[{"1879", "\[Rule]", "1598"}], ",", 
       RowBox[{"1879", "\[Rule]", "2256"}], ",", 
       RowBox[{"1879", "\[Rule]", "2256"}], ",", 
       RowBox[{"1879", "\[Rule]", "1504"}], ",", 
       RowBox[{"1879", "\[Rule]", "1504"}], ",", 
       RowBox[{"1879", "\[Rule]", "2162"}], ",", 
       RowBox[{"1879", "\[Rule]", "2162"}], ",", 
       RowBox[{"1879", "\[Rule]", "1880"}], ",", 
       RowBox[{"1863", "\[Rule]", "1582"}], ",", 
       RowBox[{"1863", "\[Rule]", "1582"}], ",", 
       RowBox[{"1863", "\[Rule]", "2240"}], ",", 
       RowBox[{"1863", "\[Rule]", "2240"}], ",", 
       RowBox[{"1863", "\[Rule]", "1488"}], ",", 
       RowBox[{"1863", "\[Rule]", "1488"}], ",", 
       RowBox[{"1863", "\[Rule]", "2146"}], ",", 
       RowBox[{"1863", "\[Rule]", "2146"}], ",", 
       RowBox[{"1863", "\[Rule]", "1864"}], ",", 
       RowBox[{"2129", "\[Rule]", "1848"}], ",", 
       RowBox[{"2129", "\[Rule]", "1848"}], ",", 
       RowBox[{"2129", "\[Rule]", "1754"}], ",", 
       RowBox[{"2129", "\[Rule]", "1754"}], ",", 
       RowBox[{"2129", "\[Rule]", "2130"}], ",", 
       RowBox[{"1847", "\[Rule]", "1566"}], ",", 
       RowBox[{"1847", "\[Rule]", "1566"}], ",", 
       RowBox[{"1847", "\[Rule]", "2224"}], ",", 
       RowBox[{"1847", "\[Rule]", "2224"}], ",", 
       RowBox[{"1847", "\[Rule]", "1472"}], ",", 
       RowBox[{"1847", "\[Rule]", "1472"}], ",", 
       RowBox[{"1847", "\[Rule]", "2130"}], ",", 
       RowBox[{"1847", "\[Rule]", "2130"}], ",", 
       RowBox[{"1847", "\[Rule]", "1848"}], ",", 
       RowBox[{"2301", "\[Rule]", "1926"}], ",", 
       RowBox[{"2301", "\[Rule]", "1926"}], ",", 
       RowBox[{"2301", "\[Rule]", "2302"}], ",", 
       RowBox[{"2207", "\[Rule]", "1926"}], ",", 
       RowBox[{"2207", "\[Rule]", "1926"}], ",", 
       RowBox[{"2207", "\[Rule]", "1832"}], ",", 
       RowBox[{"2207", "\[Rule]", "1832"}], ",", 
       RowBox[{"2207", "\[Rule]", "2208"}], ",", 
       RowBox[{"1925", "\[Rule]", "1644"}], ",", 
       RowBox[{"1925", "\[Rule]", "1644"}], ",", 
       RowBox[{"1925", "\[Rule]", "2302"}], ",", 
       RowBox[{"1925", "\[Rule]", "2302"}], ",", 
       RowBox[{"1925", "\[Rule]", "1550"}], ",", 
       RowBox[{"1925", "\[Rule]", "1550"}], ",", 
       RowBox[{"1925", "\[Rule]", "2208"}], ",", 
       RowBox[{"1925", "\[Rule]", "2208"}], ",", 
       RowBox[{"1925", "\[Rule]", "1926"}], ",", 
       RowBox[{"2113", "\[Rule]", "1832"}], ",", 
       RowBox[{"2113", "\[Rule]", "1832"}], ",", 
       RowBox[{"2113", "\[Rule]", "1738"}], ",", 
       RowBox[{"2113", "\[Rule]", "1738"}], ",", 
       RowBox[{"2113", "\[Rule]", "2114"}], ",", 
       RowBox[{"1831", "\[Rule]", "1550"}], ",", 
       RowBox[{"1831", "\[Rule]", "1550"}], ",", 
       RowBox[{"1831", "\[Rule]", "2208"}], ",", 
       RowBox[{"1831", "\[Rule]", "2208"}], ",", 
       RowBox[{"1831", "\[Rule]", "1456"}], ",", 
       RowBox[{"1831", "\[Rule]", "1456"}], ",", 
       RowBox[{"1831", "\[Rule]", "2114"}], ",", 
       RowBox[{"1831", "\[Rule]", "2114"}], ",", 
       RowBox[{"1831", "\[Rule]", "1832"}], ",", 
       RowBox[{"1987", "\[Rule]", "1706"}], ",", 
       RowBox[{"1987", "\[Rule]", "1706"}], ",", 
       RowBox[{"1987", "\[Rule]", "1988"}], ",", 
       RowBox[{"2013", "\[Rule]", "1732"}], ",", 
       RowBox[{"2013", "\[Rule]", "1732"}], ",", 
       RowBox[{"2013", "\[Rule]", "2014"}], ",", 
       RowBox[{"1997", "\[Rule]", "1716"}], ",", 
       RowBox[{"1997", "\[Rule]", "1716"}], ",", 
       RowBox[{"1997", "\[Rule]", "1998"}], ",", 
       RowBox[{"1705", "\[Rule]", "1424"}], ",", 
       RowBox[{"1705", "\[Rule]", "1424"}], ",", 
       RowBox[{"1705", "\[Rule]", "2082"}], ",", 
       RowBox[{"1705", "\[Rule]", "2082"}], ",", 
       RowBox[{"1705", "\[Rule]", "1330"}], ",", 
       RowBox[{"1705", "\[Rule]", "1330"}], ",", 
       RowBox[{"1705", "\[Rule]", "1988"}], ",", 
       RowBox[{"1705", "\[Rule]", "1988"}], ",", 
       RowBox[{"1705", "\[Rule]", "1706"}], ",", 
       RowBox[{"1731", "\[Rule]", "1450"}], ",", 
       RowBox[{"1731", "\[Rule]", "1450"}], ",", 
       RowBox[{"1731", "\[Rule]", "2108"}], ",", 
       RowBox[{"1731", "\[Rule]", "2108"}], ",", 
       RowBox[{"1731", "\[Rule]", "1356"}], ",", 
       RowBox[{"1731", "\[Rule]", "1356"}], ",", 
       RowBox[{"1731", "\[Rule]", "2014"}], ",", 
       RowBox[{"1731", "\[Rule]", "2014"}], ",", 
       RowBox[{"1731", "\[Rule]", "1732"}], ",", 
       RowBox[{"1715", "\[Rule]", "1434"}], ",", 
       RowBox[{"1715", "\[Rule]", "1434"}], ",", 
       RowBox[{"1715", "\[Rule]", "2092"}], ",", 
       RowBox[{"1715", "\[Rule]", "2092"}], ",", 
       RowBox[{"1715", "\[Rule]", "1340"}], ",", 
       RowBox[{"1715", "\[Rule]", "1340"}], ",", 
       RowBox[{"1715", "\[Rule]", "1998"}], ",", 
       RowBox[{"1715", "\[Rule]", "1998"}], ",", 
       RowBox[{"1715", "\[Rule]", "1716"}], ",", 
       RowBox[{"2039", "\[Rule]", "1758"}], ",", 
       RowBox[{"2039", "\[Rule]", "1758"}], ",", 
       RowBox[{"2039", "\[Rule]", "2040"}], ",", 
       RowBox[{"2023", "\[Rule]", "1742"}], ",", 
       RowBox[{"2023", "\[Rule]", "1742"}], ",", 
       RowBox[{"2023", "\[Rule]", "2024"}], ",", 
       RowBox[{"1757", "\[Rule]", "1476"}], ",", 
       RowBox[{"1757", "\[Rule]", "1476"}], ",", 
       RowBox[{"1757", "\[Rule]", "2134"}], ",", 
       RowBox[{"1757", "\[Rule]", "2134"}], ",", 
       RowBox[{"1757", "\[Rule]", "1382"}], ",", 
       RowBox[{"1757", "\[Rule]", "1382"}], ",", 
       RowBox[{"1757", "\[Rule]", "2040"}], ",", 
       RowBox[{"1757", "\[Rule]", "2040"}], ",", 
       RowBox[{"1757", "\[Rule]", "1758"}], ",", 
       RowBox[{"1741", "\[Rule]", "1460"}], ",", 
       RowBox[{"1741", "\[Rule]", "1460"}], ",", 
       RowBox[{"1741", "\[Rule]", "2118"}], ",", 
       RowBox[{"1741", "\[Rule]", "2118"}], ",", 
       RowBox[{"1741", "\[Rule]", "1366"}], ",", 
       RowBox[{"1741", "\[Rule]", "1366"}], ",", 
       RowBox[{"1741", "\[Rule]", "2024"}], ",", 
       RowBox[{"1741", "\[Rule]", "2024"}], ",", 
       RowBox[{"1741", "\[Rule]", "1742"}], ",", 
       RowBox[{"2009", "\[Rule]", "1728"}], ",", 
       RowBox[{"2009", "\[Rule]", "1728"}], ",", 
       RowBox[{"2009", "\[Rule]", "2010"}], ",", 
       RowBox[{"1727", "\[Rule]", "1446"}], ",", 
       RowBox[{"1727", "\[Rule]", "1446"}], ",", 
       RowBox[{"1727", "\[Rule]", "2104"}], ",", 
       RowBox[{"1727", "\[Rule]", "2104"}], ",", 
       RowBox[{"1727", "\[Rule]", "1352"}], ",", 
       RowBox[{"1727", "\[Rule]", "1352"}], ",", 
       RowBox[{"1727", "\[Rule]", "2010"}], ",", 
       RowBox[{"1727", "\[Rule]", "2010"}], ",", 
       RowBox[{"1727", "\[Rule]", "1728"}], ",", 
       RowBox[{"2067", "\[Rule]", "1786"}], ",", 
       RowBox[{"2067", "\[Rule]", "1786"}], ",", 
       RowBox[{"2067", "\[Rule]", "2068"}], ",", 
       RowBox[{"2051", "\[Rule]", "1770"}], ",", 
       RowBox[{"2051", "\[Rule]", "1770"}], ",", 
       RowBox[{"2051", "\[Rule]", "2052"}], ",", 
       RowBox[{"1785", "\[Rule]", "1504"}], ",", 
       RowBox[{"1785", "\[Rule]", "1504"}], ",", 
       RowBox[{"1785", "\[Rule]", "2162"}], ",", 
       RowBox[{"1785", "\[Rule]", "2162"}], ",", 
       RowBox[{"1785", "\[Rule]", "1410"}], ",", 
       RowBox[{"1785", "\[Rule]", "1410"}], ",", 
       RowBox[{"1785", "\[Rule]", "2068"}], ",", 
       RowBox[{"1785", "\[Rule]", "2068"}], ",", 
       RowBox[{"1785", "\[Rule]", "1786"}], ",", 
       RowBox[{"1769", "\[Rule]", "1488"}], ",", 
       RowBox[{"1769", "\[Rule]", "1488"}], ",", 
       RowBox[{"1769", "\[Rule]", "2146"}], ",", 
       RowBox[{"1769", "\[Rule]", "2146"}], ",", 
       RowBox[{"1769", "\[Rule]", "1394"}], ",", 
       RowBox[{"1769", "\[Rule]", "1394"}], ",", 
       RowBox[{"1769", "\[Rule]", "2052"}], ",", 
       RowBox[{"1769", "\[Rule]", "2052"}], ",", 
       RowBox[{"1769", "\[Rule]", "1770"}], ",", 
       RowBox[{"2035", "\[Rule]", "1754"}], ",", 
       RowBox[{"2035", "\[Rule]", "1754"}], ",", 
       RowBox[{"2035", "\[Rule]", "2036"}], ",", 
       RowBox[{"1753", "\[Rule]", "1472"}], ",", 
       RowBox[{"1753", "\[Rule]", "1472"}], ",", 
       RowBox[{"1753", "\[Rule]", "2130"}], ",", 
       RowBox[{"1753", "\[Rule]", "2130"}], ",", 
       RowBox[{"1753", "\[Rule]", "1378"}], ",", 
       RowBox[{"1753", "\[Rule]", "1378"}], ",", 
       RowBox[{"1753", "\[Rule]", "2036"}], ",", 
       RowBox[{"1753", "\[Rule]", "2036"}], ",", 
       RowBox[{"1753", "\[Rule]", "1754"}], ",", 
       RowBox[{"2019", "\[Rule]", "1738"}], ",", 
       RowBox[{"2019", "\[Rule]", "1738"}], ",", 
       RowBox[{"2019", "\[Rule]", "2020"}], ",", 
       RowBox[{"1737", "\[Rule]", "1456"}], ",", 
       RowBox[{"1737", "\[Rule]", "1456"}], ",", 
       RowBox[{"1737", "\[Rule]", "2114"}], ",", 
       RowBox[{"1737", "\[Rule]", "2114"}], ",", 
       RowBox[{"1737", "\[Rule]", "1362"}], ",", 
       RowBox[{"1737", "\[Rule]", "1362"}], ",", 
       RowBox[{"1737", "\[Rule]", "2020"}], ",", 
       RowBox[{"1737", "\[Rule]", "2020"}], ",", 
       RowBox[{"1737", "\[Rule]", "1738"}], ",", 
       RowBox[{"2345", "\[Rule]", "1970"}], ",", 
       RowBox[{"2345", "\[Rule]", "1970"}], ",", 
       RowBox[{"2345", "\[Rule]", "2346"}], ",", 
       RowBox[{"2251", "\[Rule]", "1970"}], ",", 
       RowBox[{"2251", "\[Rule]", "1970"}], ",", 
       RowBox[{"2251", "\[Rule]", "1876"}], ",", 
       RowBox[{"2251", "\[Rule]", "1876"}], ",", 
       RowBox[{"2251", "\[Rule]", "2252"}], ",", 
       RowBox[{"1969", "\[Rule]", "1688"}], ",", 
       RowBox[{"1969", "\[Rule]", "1688"}], ",", 
       RowBox[{"1969", "\[Rule]", "2346"}], ",", 
       RowBox[{"1969", "\[Rule]", "2346"}], ",", 
       RowBox[{"1969", "\[Rule]", "1594"}], ",", 
       RowBox[{"1969", "\[Rule]", "1594"}], ",", 
       RowBox[{"1969", "\[Rule]", "2252"}], ",", 
       RowBox[{"1969", "\[Rule]", "2252"}], ",", 
       RowBox[{"1969", "\[Rule]", "1970"}], ",", 
       RowBox[{"2157", "\[Rule]", "1876"}], ",", 
       RowBox[{"2157", "\[Rule]", "1876"}], ",", 
       RowBox[{"2157", "\[Rule]", "1782"}], ",", 
       RowBox[{"2157", "\[Rule]", "1782"}], ",", 
       RowBox[{"2157", "\[Rule]", "2158"}], ",", 
       RowBox[{"1875", "\[Rule]", "1594"}], ",", 
       RowBox[{"1875", "\[Rule]", "1594"}], ",", 
       RowBox[{"1875", "\[Rule]", "2252"}], ",", 
       RowBox[{"1875", "\[Rule]", "2252"}], ",", 
       RowBox[{"1875", "\[Rule]", "1500"}], ",", 
       RowBox[{"1875", "\[Rule]", "1500"}], ",", 
       RowBox[{"1875", "\[Rule]", "2158"}], ",", 
       RowBox[{"1875", "\[Rule]", "2158"}], ",", 
       RowBox[{"1875", "\[Rule]", "1876"}], ",", 
       RowBox[{"2329", "\[Rule]", "1954"}], ",", 
       RowBox[{"2329", "\[Rule]", "1954"}], ",", 
       RowBox[{"2329", "\[Rule]", "2330"}], ",", 
       RowBox[{"2235", "\[Rule]", "1954"}], ",", 
       RowBox[{"2235", "\[Rule]", "1954"}], ",", 
       RowBox[{"2235", "\[Rule]", "1860"}], ",", 
       RowBox[{"2235", "\[Rule]", "1860"}], ",", 
       RowBox[{"2235", "\[Rule]", "2236"}], ",", 
       RowBox[{"1953", "\[Rule]", "1672"}], ",", 
       RowBox[{"1953", "\[Rule]", "1672"}], ",", 
       RowBox[{"1953", "\[Rule]", "2330"}], ",", 
       RowBox[{"1953", "\[Rule]", "2330"}], ",", 
       RowBox[{"1953", "\[Rule]", "1578"}], ",", 
       RowBox[{"1953", "\[Rule]", "1578"}], ",", 
       RowBox[{"1953", "\[Rule]", "2236"}], ",", 
       RowBox[{"1953", "\[Rule]", "2236"}], ",", 
       RowBox[{"1953", "\[Rule]", "1954"}], ",", 
       RowBox[{"2141", "\[Rule]", "1860"}], ",", 
       RowBox[{"2141", "\[Rule]", "1860"}], ",", 
       RowBox[{"2141", "\[Rule]", "1766"}], ",", 
       RowBox[{"2141", "\[Rule]", "1766"}], ",", 
       RowBox[{"2141", "\[Rule]", "2142"}], ",", 
       RowBox[{"1859", "\[Rule]", "1578"}], ",", 
       RowBox[{"1859", "\[Rule]", "1578"}], ",", 
       RowBox[{"1859", "\[Rule]", "2236"}], ",", 
       RowBox[{"1859", "\[Rule]", "2236"}], ",", 
       RowBox[{"1859", "\[Rule]", "1484"}], ",", 
       RowBox[{"1859", "\[Rule]", "1484"}], ",", 
       RowBox[{"1859", "\[Rule]", "2142"}], ",", 
       RowBox[{"1859", "\[Rule]", "2142"}], ",", 
       RowBox[{"1859", "\[Rule]", "1860"}], ",", 
       RowBox[{"2063", "\[Rule]", "1782"}], ",", 
       RowBox[{"2063", "\[Rule]", "1782"}], ",", 
       RowBox[{"2063", "\[Rule]", "2064"}], ",", 
       RowBox[{"1781", "\[Rule]", "1500"}], ",", 
       RowBox[{"1781", "\[Rule]", "1500"}], ",", 
       RowBox[{"1781", "\[Rule]", "2158"}], ",", 
       RowBox[{"1781", "\[Rule]", "2158"}], ",", 
       RowBox[{"1781", "\[Rule]", "1406"}], ",", 
       RowBox[{"1781", "\[Rule]", "1406"}], ",", 
       RowBox[{"1781", "\[Rule]", "2064"}], ",", 
       RowBox[{"1781", "\[Rule]", "2064"}], ",", 
       RowBox[{"1781", "\[Rule]", "1782"}], ",", 
       RowBox[{"2047", "\[Rule]", "1766"}], ",", 
       RowBox[{"2047", "\[Rule]", "1766"}], ",", 
       RowBox[{"2047", "\[Rule]", "2048"}], ",", 
       RowBox[{"1765", "\[Rule]", "1484"}], ",", 
       RowBox[{"1765", "\[Rule]", "1484"}], ",", 
       RowBox[{"1765", "\[Rule]", "2142"}], ",", 
       RowBox[{"1765", "\[Rule]", "2142"}], ",", 
       RowBox[{"1765", "\[Rule]", "1390"}], ",", 
       RowBox[{"1765", "\[Rule]", "1390"}], ",", 
       RowBox[{"1765", "\[Rule]", "2048"}], ",", 
       RowBox[{"1765", "\[Rule]", "2048"}], ",", 
       RowBox[{"1765", "\[Rule]", "1766"}], ",", 
       RowBox[{"2313", "\[Rule]", "1938"}], ",", 
       RowBox[{"2313", "\[Rule]", "1938"}], ",", 
       RowBox[{"2313", "\[Rule]", "2314"}], ",", 
       RowBox[{"2219", "\[Rule]", "1938"}], ",", 
       RowBox[{"2219", "\[Rule]", "1938"}], ",", 
       RowBox[{"2219", "\[Rule]", "1844"}], ",", 
       RowBox[{"2219", "\[Rule]", "1844"}], ",", 
       RowBox[{"2219", "\[Rule]", "2220"}], ",", 
       RowBox[{"1937", "\[Rule]", "1656"}], ",", 
       RowBox[{"1937", "\[Rule]", "1656"}], ",", 
       RowBox[{"1937", "\[Rule]", "2314"}], ",", 
       RowBox[{"1937", "\[Rule]", "2314"}], ",", 
       RowBox[{"1937", "\[Rule]", "1562"}], ",", 
       RowBox[{"1937", "\[Rule]", "1562"}], ",", 
       RowBox[{"1937", "\[Rule]", "2220"}], ",", 
       RowBox[{"1937", "\[Rule]", "2220"}], ",", 
       RowBox[{"1937", "\[Rule]", "1938"}], ",", 
       RowBox[{"2125", "\[Rule]", "1844"}], ",", 
       RowBox[{"2125", "\[Rule]", "1844"}], ",", 
       RowBox[{"2125", "\[Rule]", "1750"}], ",", 
       RowBox[{"2125", "\[Rule]", "1750"}], ",", 
       RowBox[{"2125", "\[Rule]", "2126"}], ",", 
       RowBox[{"1843", "\[Rule]", "1562"}], ",", 
       RowBox[{"1843", "\[Rule]", "1562"}], ",", 
       RowBox[{"1843", "\[Rule]", "2220"}], ",", 
       RowBox[{"1843", "\[Rule]", "2220"}], ",", 
       RowBox[{"1843", "\[Rule]", "1468"}], ",", 
       RowBox[{"1843", "\[Rule]", "1468"}], ",", 
       RowBox[{"1843", "\[Rule]", "2126"}], ",", 
       RowBox[{"1843", "\[Rule]", "2126"}], ",", 
       RowBox[{"1843", "\[Rule]", "1844"}], ",", 
       RowBox[{"2031", "\[Rule]", "1750"}], ",", 
       RowBox[{"2031", "\[Rule]", "1750"}], ",", 
       RowBox[{"2031", "\[Rule]", "2032"}], ",", 
       RowBox[{"1749", "\[Rule]", "1468"}], ",", 
       RowBox[{"1749", "\[Rule]", "1468"}], ",", 
       RowBox[{"1749", "\[Rule]", "2126"}], ",", 
       RowBox[{"1749", "\[Rule]", "2126"}], ",", 
       RowBox[{"1749", "\[Rule]", "1374"}], ",", 
       RowBox[{"1749", "\[Rule]", "1374"}], ",", 
       RowBox[{"1749", "\[Rule]", "2032"}], ",", 
       RowBox[{"1749", "\[Rule]", "2032"}], ",", 
       RowBox[{"1749", "\[Rule]", "1750"}], ",", 
       RowBox[{"2341", "\[Rule]", "1966"}], ",", 
       RowBox[{"2341", "\[Rule]", "1966"}], ",", 
       RowBox[{"2341", "\[Rule]", "2342"}], ",", 
       RowBox[{"2247", "\[Rule]", "1966"}], ",", 
       RowBox[{"2247", "\[Rule]", "1966"}], ",", 
       RowBox[{"2247", "\[Rule]", "1872"}], ",", 
       RowBox[{"2247", "\[Rule]", "1872"}], ",", 
       RowBox[{"2247", "\[Rule]", "2248"}], ",", 
       RowBox[{"1965", "\[Rule]", "1684"}], ",", 
       RowBox[{"1965", "\[Rule]", "1684"}], ",", 
       RowBox[{"1965", "\[Rule]", "2342"}], ",", 
       RowBox[{"1965", "\[Rule]", "2342"}], ",", 
       RowBox[{"1965", "\[Rule]", "1590"}], ",", 
       RowBox[{"1965", "\[Rule]", "1590"}], ",", 
       RowBox[{"1965", "\[Rule]", "2248"}], ",", 
       RowBox[{"1965", "\[Rule]", "2248"}], ",", 
       RowBox[{"1965", "\[Rule]", "1966"}], ",", 
       RowBox[{"2153", "\[Rule]", "1872"}], ",", 
       RowBox[{"2153", "\[Rule]", "1872"}], ",", 
       RowBox[{"2153", "\[Rule]", "1778"}], ",", 
       RowBox[{"2153", "\[Rule]", "1778"}], ",", 
       RowBox[{"2153", "\[Rule]", "2154"}], ",", 
       RowBox[{"1871", "\[Rule]", "1590"}], ",", 
       RowBox[{"1871", "\[Rule]", "1590"}], ",", 
       RowBox[{"1871", "\[Rule]", "2248"}], ",", 
       RowBox[{"1871", "\[Rule]", "2248"}], ",", 
       RowBox[{"1871", "\[Rule]", "1496"}], ",", 
       RowBox[{"1871", "\[Rule]", "1496"}], ",", 
       RowBox[{"1871", "\[Rule]", "2154"}], ",", 
       RowBox[{"1871", "\[Rule]", "2154"}], ",", 
       RowBox[{"1871", "\[Rule]", "1872"}], ",", 
       RowBox[{"2059", "\[Rule]", "1778"}], ",", 
       RowBox[{"2059", "\[Rule]", "1778"}], ",", 
       RowBox[{"2059", "\[Rule]", "2060"}], ",", 
       RowBox[{"1777", "\[Rule]", "1496"}], ",", 
       RowBox[{"1777", "\[Rule]", "1496"}], ",", 
       RowBox[{"1777", "\[Rule]", "2154"}], ",", 
       RowBox[{"1777", "\[Rule]", "2154"}], ",", 
       RowBox[{"1777", "\[Rule]", "1402"}], ",", 
       RowBox[{"1777", "\[Rule]", "1402"}], ",", 
       RowBox[{"1777", "\[Rule]", "2060"}], ",", 
       RowBox[{"1777", "\[Rule]", "2060"}], ",", 
       RowBox[{"1777", "\[Rule]", "1778"}], ",", 
       RowBox[{"2325", "\[Rule]", "1950"}], ",", 
       RowBox[{"2325", "\[Rule]", "1950"}], ",", 
       RowBox[{"2325", "\[Rule]", "2326"}], ",", 
       RowBox[{"2231", "\[Rule]", "1950"}], ",", 
       RowBox[{"2231", "\[Rule]", "1950"}], ",", 
       RowBox[{"2231", "\[Rule]", "1856"}], ",", 
       RowBox[{"2231", "\[Rule]", "1856"}], ",", 
       RowBox[{"2231", "\[Rule]", "2232"}], ",", 
       RowBox[{"1949", "\[Rule]", "1668"}], ",", 
       RowBox[{"1949", "\[Rule]", "1668"}], ",", 
       RowBox[{"1949", "\[Rule]", "2326"}], ",", 
       RowBox[{"1949", "\[Rule]", "2326"}], ",", 
       RowBox[{"1949", "\[Rule]", "1574"}], ",", 
       RowBox[{"1949", "\[Rule]", "1574"}], ",", 
       RowBox[{"1949", "\[Rule]", "2232"}], ",", 
       RowBox[{"1949", "\[Rule]", "2232"}], ",", 
       RowBox[{"1949", "\[Rule]", "1950"}], ",", 
       RowBox[{"2137", "\[Rule]", "1856"}], ",", 
       RowBox[{"2137", "\[Rule]", "1856"}], ",", 
       RowBox[{"2137", "\[Rule]", "1762"}], ",", 
       RowBox[{"2137", "\[Rule]", "1762"}], ",", 
       RowBox[{"2137", "\[Rule]", "2138"}], ",", 
       RowBox[{"1855", "\[Rule]", "1574"}], ",", 
       RowBox[{"1855", "\[Rule]", "1574"}], ",", 
       RowBox[{"1855", "\[Rule]", "2232"}], ",", 
       RowBox[{"1855", "\[Rule]", "2232"}], ",", 
       RowBox[{"1855", "\[Rule]", "1480"}], ",", 
       RowBox[{"1855", "\[Rule]", "1480"}], ",", 
       RowBox[{"1855", "\[Rule]", "2138"}], ",", 
       RowBox[{"1855", "\[Rule]", "2138"}], ",", 
       RowBox[{"1855", "\[Rule]", "1856"}], ",", 
       RowBox[{"2043", "\[Rule]", "1762"}], ",", 
       RowBox[{"2043", "\[Rule]", "1762"}], ",", 
       RowBox[{"2043", "\[Rule]", "2044"}], ",", 
       RowBox[{"1761", "\[Rule]", "1480"}], ",", 
       RowBox[{"1761", "\[Rule]", "1480"}], ",", 
       RowBox[{"1761", "\[Rule]", "2138"}], ",", 
       RowBox[{"1761", "\[Rule]", "2138"}], ",", 
       RowBox[{"1761", "\[Rule]", "1386"}], ",", 
       RowBox[{"1761", "\[Rule]", "1386"}], ",", 
       RowBox[{"1761", "\[Rule]", "2044"}], ",", 
       RowBox[{"1761", "\[Rule]", "2044"}], ",", 
       RowBox[{"1761", "\[Rule]", "1762"}], ",", 
       RowBox[{"363", "\[Rule]", "646"}], ",", 
       RowBox[{"363", "\[Rule]", "646"}], ",", 
       RowBox[{"363", "\[Rule]", "364"}], ",", 
       RowBox[{"1021", "\[Rule]", "646"}], ",", 
       RowBox[{"1021", "\[Rule]", "646"}], ",", 
       RowBox[{"1021", "\[Rule]", "1304"}], ",", 
       RowBox[{"1021", "\[Rule]", "1304"}], ",", 
       RowBox[{"1021", "\[Rule]", "1022"}], ",", 
       RowBox[{"269", "\[Rule]", "646"}], ",", 
       RowBox[{"269", "\[Rule]", "646"}], ",", 
       RowBox[{"269", "\[Rule]", "552"}], ",", 
       RowBox[{"269", "\[Rule]", "552"}], ",", 
       RowBox[{"269", "\[Rule]", "270"}], ",", 
       RowBox[{"927", "\[Rule]", "646"}], ",", 
       RowBox[{"927", "\[Rule]", "646"}], ",", 
       RowBox[{"927", "\[Rule]", "1304"}], ",", 
       RowBox[{"927", "\[Rule]", "1304"}], ",", 
       RowBox[{"927", "\[Rule]", "552"}], ",", 
       RowBox[{"927", "\[Rule]", "552"}], ",", 
       RowBox[{"927", "\[Rule]", "1210"}], ",", 
       RowBox[{"927", "\[Rule]", "1210"}], ",", 
       RowBox[{"927", "\[Rule]", "928"}], ",", 
       RowBox[{"645", "\[Rule]", "364"}], ",", 
       RowBox[{"645", "\[Rule]", "364"}], ",", 
       RowBox[{"645", "\[Rule]", "1022"}], ",", 
       RowBox[{"645", "\[Rule]", "1022"}], ",", 
       RowBox[{"645", "\[Rule]", "270"}], ",", 
       RowBox[{"645", "\[Rule]", "270"}], ",", 
       RowBox[{"645", "\[Rule]", "928"}], ",", 
       RowBox[{"645", "\[Rule]", "928"}], ",", 
       RowBox[{"645", "\[Rule]", "646"}], ",", 
       RowBox[{"175", "\[Rule]", "552"}], ",", 
       RowBox[{"175", "\[Rule]", "458"}], ",", 
       RowBox[{"175", "\[Rule]", "176"}], ",", 
       RowBox[{"833", "\[Rule]", "552"}], ",", 
       RowBox[{"833", "\[Rule]", "1210"}], ",", 
       RowBox[{"833", "\[Rule]", "1210"}], ",", 
       RowBox[{"833", "\[Rule]", "458"}], ",", 
       RowBox[{"833", "\[Rule]", "1116"}], ",", 
       RowBox[{"833", "\[Rule]", "1116"}], ",", 
       RowBox[{"833", "\[Rule]", "834"}], ",", 
       RowBox[{"551", "\[Rule]", "270"}], ",", 
       RowBox[{"551", "\[Rule]", "270"}], ",", 
       RowBox[{"551", "\[Rule]", "928"}], ",", 
       RowBox[{"551", "\[Rule]", "928"}], ",", 
       RowBox[{"551", "\[Rule]", "176"}], ",", 
       RowBox[{"551", "\[Rule]", "834"}], ",", 
       RowBox[{"551", "\[Rule]", "552"}], ",", 
       RowBox[{"1679", "\[Rule]", "1304"}], ",", 
       RowBox[{"1679", "\[Rule]", "1304"}], ",", 
       RowBox[{"1679", "\[Rule]", "1962"}], ",", 
       RowBox[{"1679", "\[Rule]", "1962"}], ",", 
       RowBox[{"1679", "\[Rule]", "1680"}], ",", 
       RowBox[{"1585", "\[Rule]", "1304"}], ",", 
       RowBox[{"1585", "\[Rule]", "1304"}], ",", 
       RowBox[{"1585", "\[Rule]", "1962"}], ",", 
       RowBox[{"1585", "\[Rule]", "1962"}], ",", 
       RowBox[{"1585", "\[Rule]", "1210"}], ",", 
       RowBox[{"1585", "\[Rule]", "1210"}], ",", 
       RowBox[{"1585", "\[Rule]", "1868"}], ",", 
       RowBox[{"1585", "\[Rule]", "1868"}], ",", 
       RowBox[{"1585", "\[Rule]", "1586"}], ",", 
       RowBox[{"1303", "\[Rule]", "1022"}], ",", 
       RowBox[{"1303", "\[Rule]", "1022"}], ",", 
       RowBox[{"1303", "\[Rule]", "1680"}], ",", 
       RowBox[{"1303", "\[Rule]", "1680"}], ",", 
       RowBox[{"1303", "\[Rule]", "928"}], ",", 
       RowBox[{"1303", "\[Rule]", "928"}], ",", 
       RowBox[{"1303", "\[Rule]", "1586"}], ",", 
       RowBox[{"1303", "\[Rule]", "1586"}], ",", 
       RowBox[{"1303", "\[Rule]", "1304"}], ",", 
       RowBox[{"1491", "\[Rule]", "1210"}], ",", 
       RowBox[{"1491", "\[Rule]", "1210"}], ",", 
       RowBox[{"1491", "\[Rule]", "1868"}], ",", 
       RowBox[{"1491", "\[Rule]", "1868"}], ",", 
       RowBox[{"1491", "\[Rule]", "1116"}], ",", 
       RowBox[{"1491", "\[Rule]", "1116"}], ",", 
       RowBox[{"1491", "\[Rule]", "1774"}], ",", 
       RowBox[{"1491", "\[Rule]", "1774"}], ",", 
       RowBox[{"1491", "\[Rule]", "1492"}], ",", 
       RowBox[{"1209", "\[Rule]", "928"}], ",", 
       RowBox[{"1209", "\[Rule]", "928"}], ",", 
       RowBox[{"1209", "\[Rule]", "1586"}], ",", 
       RowBox[{"1209", "\[Rule]", "1586"}], ",", 
       RowBox[{"1209", "\[Rule]", "834"}], ",", 
       RowBox[{"1209", "\[Rule]", "834"}], ",", 
       RowBox[{"1209", "\[Rule]", "1492"}], ",", 
       RowBox[{"1209", "\[Rule]", "1492"}], ",", 
       RowBox[{"1209", "\[Rule]", "1210"}], ",", 
       RowBox[{"81", "\[Rule]", "458"}], ",", 
       RowBox[{"81", "\[Rule]", "458"}], ",", 
       RowBox[{"81", "\[Rule]", "82"}], ",", 
       RowBox[{"739", "\[Rule]", "458"}], ",", 
       RowBox[{"739", "\[Rule]", "458"}], ",", 
       RowBox[{"739", "\[Rule]", "1116"}], ",", 
       RowBox[{"739", "\[Rule]", "740"}], ",", 
       RowBox[{"457", "\[Rule]", "176"}], ",", 
       RowBox[{"457", "\[Rule]", "834"}], ",", 
       RowBox[{"457", "\[Rule]", "82"}], ",", 
       RowBox[{"457", "\[Rule]", "82"}], ",", 
       RowBox[{"457", "\[Rule]", "740"}], ",", 
       RowBox[{"457", "\[Rule]", "740"}], ",", 
       RowBox[{"457", "\[Rule]", "458"}], ",", 
       RowBox[{"1397", "\[Rule]", "1116"}], ",", 
       RowBox[{"1397", "\[Rule]", "1774"}], ",", 
       RowBox[{"1397", "\[Rule]", "1774"}], ",", 
       RowBox[{"1397", "\[Rule]", "1398"}], ",", 
       RowBox[{"1115", "\[Rule]", "834"}], ",", 
       RowBox[{"1115", "\[Rule]", "834"}], ",", 
       RowBox[{"1115", "\[Rule]", "1492"}], ",", 
       RowBox[{"1115", "\[Rule]", "1492"}], ",", 
       RowBox[{"1115", "\[Rule]", "740"}], ",", 
       RowBox[{"1115", "\[Rule]", "1398"}], ",", 
       RowBox[{"1115", "\[Rule]", "1116"}], ",", 
       RowBox[{"2337", "\[Rule]", "1962"}], ",", 
       RowBox[{"2337", "\[Rule]", "1962"}], ",", 
       RowBox[{"2337", "\[Rule]", "2338"}], ",", 
       RowBox[{"2243", "\[Rule]", "1962"}], ",", 
       RowBox[{"2243", "\[Rule]", "1962"}], ",", 
       RowBox[{"2243", "\[Rule]", "1868"}], ",", 
       RowBox[{"2243", "\[Rule]", "1868"}], ",", 
       RowBox[{"2243", "\[Rule]", "2244"}], ",", 
       RowBox[{"1961", "\[Rule]", "1680"}], ",", 
       RowBox[{"1961", "\[Rule]", "1680"}], ",", 
       RowBox[{"1961", "\[Rule]", "2338"}], ",", 
       RowBox[{"1961", "\[Rule]", "2338"}], ",", 
       RowBox[{"1961", "\[Rule]", "1586"}], ",", 
       RowBox[{"1961", "\[Rule]", "1586"}], ",", 
       RowBox[{"1961", "\[Rule]", "2244"}], ",", 
       RowBox[{"1961", "\[Rule]", "2244"}], ",", 
       RowBox[{"1961", "\[Rule]", "1962"}], ",", 
       RowBox[{"2149", "\[Rule]", "1868"}], ",", 
       RowBox[{"2149", "\[Rule]", "1868"}], ",", 
       RowBox[{"2149", "\[Rule]", "1774"}], ",", 
       RowBox[{"2149", "\[Rule]", "1774"}], ",", 
       RowBox[{"2149", "\[Rule]", "2150"}], ",", 
       RowBox[{"1867", "\[Rule]", "1586"}], ",", 
       RowBox[{"1867", "\[Rule]", "1586"}], ",", 
       RowBox[{"1867", "\[Rule]", "2244"}], ",", 
       RowBox[{"1867", "\[Rule]", "2244"}], ",", 
       RowBox[{"1867", "\[Rule]", "1492"}], ",", 
       RowBox[{"1867", "\[Rule]", "1492"}], ",", 
       RowBox[{"1867", "\[Rule]", "2150"}], ",", 
       RowBox[{"1867", "\[Rule]", "2150"}], ",", 
       RowBox[{"1867", "\[Rule]", "1868"}], ",", 
       RowBox[{"2055", "\[Rule]", "1774"}], ",", 
       RowBox[{"2055", "\[Rule]", "1774"}], ",", 
       RowBox[{"2055", "\[Rule]", "2056"}], ",", 
       RowBox[{"1773", "\[Rule]", "1492"}], ",", 
       RowBox[{"1773", "\[Rule]", "1492"}], ",", 
       RowBox[{"1773", "\[Rule]", "2150"}], ",", 
       RowBox[{"1773", "\[Rule]", "2150"}], ",", 
       RowBox[{"1773", "\[Rule]", "1398"}], ",", 
       RowBox[{"1773", "\[Rule]", "1398"}], ",", 
       RowBox[{"1773", "\[Rule]", "2056"}], ",", 
       RowBox[{"1773", "\[Rule]", "2056"}], ",", 
       RowBox[{"1773", "\[Rule]", "1774"}], ",", 
       RowBox[{"578", "\[Rule]", "589"}], ",", 
       RowBox[{"578", "\[Rule]", "575"}], ",", 
       RowBox[{"296", "\[Rule]", "307"}], ",", 
       RowBox[{"296", "\[Rule]", "293"}], ",", 
       RowBox[{"322", "\[Rule]", "307"}], ",", 
       RowBox[{"322", "\[Rule]", "333"}], ",", 
       RowBox[{"322", "\[Rule]", "319"}], ",", 
       RowBox[{"588", "\[Rule]", "575"}], ",", 
       RowBox[{"588", "\[Rule]", "601"}], ",", 
       RowBox[{"588", "\[Rule]", "589"}], ",", 
       RowBox[{"588", "\[Rule]", "585"}], ",", 
       RowBox[{"306", "\[Rule]", "293"}], ",", 
       RowBox[{"306", "\[Rule]", "319"}], ",", 
       RowBox[{"306", "\[Rule]", "307"}], ",", 
       RowBox[{"306", "\[Rule]", "303"}], ",", 
       RowBox[{"1236", "\[Rule]", "1247"}], ",", 
       RowBox[{"1236", "\[Rule]", "1233"}], ",", 
       RowBox[{"954", "\[Rule]", "965"}], ",", 
       RowBox[{"954", "\[Rule]", "951"}], ",", 
       RowBox[{"980", "\[Rule]", "965"}], ",", 
       RowBox[{"980", "\[Rule]", "991"}], ",", 
       RowBox[{"980", "\[Rule]", "977"}], ",", 
       RowBox[{"1246", "\[Rule]", "1233"}], ",", 
       RowBox[{"1246", "\[Rule]", "1259"}], ",", 
       RowBox[{"1246", "\[Rule]", "1247"}], ",", 
       RowBox[{"1246", "\[Rule]", "1243"}], ",", 
       RowBox[{"964", "\[Rule]", "951"}], ",", 
       RowBox[{"964", "\[Rule]", "977"}], ",", 
       RowBox[{"964", "\[Rule]", "965"}], ",", 
       RowBox[{"964", "\[Rule]", "961"}], ",", 
       RowBox[{"484", "\[Rule]", "495"}], ",", 
       RowBox[{"484", "\[Rule]", "481"}], ",", 
       RowBox[{"202", "\[Rule]", "213"}], ",", 
       RowBox[{"202", "\[Rule]", "199"}], ",", 
       RowBox[{"494", "\[Rule]", "481"}], ",", 
       RowBox[{"494", "\[Rule]", "507"}], ",", 
       RowBox[{"494", "\[Rule]", "495"}], ",", 
       RowBox[{"494", "\[Rule]", "491"}], ",", 
       RowBox[{"212", "\[Rule]", "199"}], ",", 
       RowBox[{"212", "\[Rule]", "225"}], ",", 
       RowBox[{"212", "\[Rule]", "213"}], ",", 
       RowBox[{"212", "\[Rule]", "209"}], ",", 
       RowBox[{"1142", "\[Rule]", "1153"}], ",", 
       RowBox[{"1142", "\[Rule]", "1139"}], ",", 
       RowBox[{"860", "\[Rule]", "871"}], ",", 
       RowBox[{"860", "\[Rule]", "857"}], ",", 
       RowBox[{"1152", "\[Rule]", "1139"}], ",", 
       RowBox[{"1152", "\[Rule]", "1165"}], ",", 
       RowBox[{"1152", "\[Rule]", "1153"}], ",", 
       RowBox[{"1152", "\[Rule]", "1149"}], ",", 
       RowBox[{"870", "\[Rule]", "857"}], ",", 
       RowBox[{"870", "\[Rule]", "883"}], ",", 
       RowBox[{"870", "\[Rule]", "871"}], ",", 
       RowBox[{"870", "\[Rule]", "867"}], ",", 
       RowBox[{"348", "\[Rule]", "333"}], ",", 
       RowBox[{"348", "\[Rule]", "361"}], ",", 
       RowBox[{"348", "\[Rule]", "345"}], ",", 
       RowBox[{"332", "\[Rule]", "319"}], ",", 
       RowBox[{"332", "\[Rule]", "345"}], ",", 
       RowBox[{"332", "\[Rule]", "333"}], ",", 
       RowBox[{"332", "\[Rule]", "329"}], ",", 
       RowBox[{"1006", "\[Rule]", "991"}], ",", 
       RowBox[{"1006", "\[Rule]", "1019"}], ",", 
       RowBox[{"1006", "\[Rule]", "1003"}], ",", 
       RowBox[{"990", "\[Rule]", "977"}], ",", 
       RowBox[{"990", "\[Rule]", "1003"}], ",", 
       RowBox[{"990", "\[Rule]", "991"}], ",", 
       RowBox[{"990", "\[Rule]", "987"}], ",", 
       RowBox[{"600", "\[Rule]", "585"}], ",", 
       RowBox[{"600", "\[Rule]", "611"}], ",", 
       RowBox[{"600", "\[Rule]", "601"}], ",", 
       RowBox[{"600", "\[Rule]", "597"}], ",", 
       RowBox[{"318", "\[Rule]", "303"}], ",", 
       RowBox[{"318", "\[Rule]", "329"}], ",", 
       RowBox[{"318", "\[Rule]", "319"}], ",", 
       RowBox[{"318", "\[Rule]", "315"}], ",", 
       RowBox[{"1258", "\[Rule]", "1243"}], ",", 
       RowBox[{"1258", "\[Rule]", "1269"}], ",", 
       RowBox[{"1258", "\[Rule]", "1259"}], ",", 
       RowBox[{"1258", "\[Rule]", "1255"}], ",", 
       RowBox[{"976", "\[Rule]", "961"}], ",", 
       RowBox[{"976", "\[Rule]", "987"}], ",", 
       RowBox[{"976", "\[Rule]", "977"}], ",", 
       RowBox[{"976", "\[Rule]", "973"}], ",", 
       RowBox[{"506", "\[Rule]", "491"}], ",", 
       RowBox[{"506", "\[Rule]", "517"}], ",", 
       RowBox[{"506", "\[Rule]", "507"}], ",", 
       RowBox[{"506", "\[Rule]", "503"}], ",", 
       RowBox[{"224", "\[Rule]", "209"}], ",", 
       RowBox[{"224", "\[Rule]", "235"}], ",", 
       RowBox[{"224", "\[Rule]", "225"}], ",", 
       RowBox[{"224", "\[Rule]", "221"}], ",", 
       RowBox[{"1164", "\[Rule]", "1149"}], ",", 
       RowBox[{"1164", "\[Rule]", "1175"}], ",", 
       RowBox[{"1164", "\[Rule]", "1165"}], ",", 
       RowBox[{"1164", "\[Rule]", "1161"}], ",", 
       RowBox[{"882", "\[Rule]", "867"}], ",", 
       RowBox[{"882", "\[Rule]", "893"}], ",", 
       RowBox[{"882", "\[Rule]", "883"}], ",", 
       RowBox[{"882", "\[Rule]", "879"}], ",", 
       RowBox[{"390", "\[Rule]", "401"}], ",", 
       RowBox[{"390", "\[Rule]", "387"}], ",", 
       RowBox[{"108", "\[Rule]", "119"}], ",", 
       RowBox[{"108", "\[Rule]", "105"}], ",", 
       RowBox[{"400", "\[Rule]", "387"}], ",", 
       RowBox[{"400", "\[Rule]", "413"}], ",", 
       RowBox[{"400", "\[Rule]", "401"}], ",", 
       RowBox[{"400", "\[Rule]", "397"}], ",", 
       RowBox[{"118", "\[Rule]", "105"}], ",", 
       RowBox[{"118", "\[Rule]", "131"}], ",", 
       RowBox[{"118", "\[Rule]", "119"}], ",", 
       RowBox[{"118", "\[Rule]", "115"}], ",", 
       RowBox[{"1048", "\[Rule]", "1059"}], ",", 
       RowBox[{"1048", "\[Rule]", "1045"}], ",", 
       RowBox[{"766", "\[Rule]", "777"}], ",", 
       RowBox[{"766", "\[Rule]", "763"}], ",", 
       RowBox[{"1058", "\[Rule]", "1045"}], ",", 
       RowBox[{"1058", "\[Rule]", "1071"}], ",", 
       RowBox[{"1058", "\[Rule]", "1059"}], ",", 
       RowBox[{"1058", "\[Rule]", "1055"}], ",", 
       RowBox[{"776", "\[Rule]", "763"}], ",", 
       RowBox[{"776", "\[Rule]", "789"}], ",", 
       RowBox[{"776", "\[Rule]", "777"}], ",", 
       RowBox[{"776", "\[Rule]", "773"}], ",", 
       RowBox[{"412", "\[Rule]", "397"}], ",", 
       RowBox[{"412", "\[Rule]", "423"}], ",", 
       RowBox[{"412", "\[Rule]", "413"}], ",", 
       RowBox[{"412", "\[Rule]", "409"}], ",", 
       RowBox[{"130", "\[Rule]", "115"}], ",", 
       RowBox[{"130", "\[Rule]", "141"}], ",", 
       RowBox[{"130", "\[Rule]", "131"}], ",", 
       RowBox[{"130", "\[Rule]", "127"}], ",", 
       RowBox[{"1070", "\[Rule]", "1055"}], ",", 
       RowBox[{"1070", "\[Rule]", "1081"}], ",", 
       RowBox[{"1070", "\[Rule]", "1071"}], ",", 
       RowBox[{"1070", "\[Rule]", "1067"}], ",", 
       RowBox[{"788", "\[Rule]", "773"}], ",", 
       RowBox[{"788", "\[Rule]", "799"}], ",", 
       RowBox[{"788", "\[Rule]", "789"}], ",", 
       RowBox[{"788", "\[Rule]", "785"}], ",", 
       RowBox[{"376", "\[Rule]", "361"}], ",", 
       RowBox[{"376", "\[Rule]", "373"}], ",", 
       RowBox[{"360", "\[Rule]", "345"}], ",", 
       RowBox[{"360", "\[Rule]", "373"}], ",", 
       RowBox[{"360", "\[Rule]", "361"}], ",", 
       RowBox[{"360", "\[Rule]", "357"}], ",", 
       RowBox[{"1034", "\[Rule]", "1019"}], ",", 
       RowBox[{"1034", "\[Rule]", "1031"}], ",", 
       RowBox[{"1018", "\[Rule]", "1003"}], ",", 
       RowBox[{"1018", "\[Rule]", "1031"}], ",", 
       RowBox[{"1018", "\[Rule]", "1019"}], ",", 
       RowBox[{"1018", "\[Rule]", "1015"}], ",", 
       RowBox[{"344", "\[Rule]", "329"}], ",", 
       RowBox[{"344", "\[Rule]", "357"}], ",", 
       RowBox[{"344", "\[Rule]", "345"}], ",", 
       RowBox[{"344", "\[Rule]", "341"}], ",", 
       RowBox[{"1002", "\[Rule]", "987"}], ",", 
       RowBox[{"1002", "\[Rule]", "1015"}], ",", 
       RowBox[{"1002", "\[Rule]", "1003"}], ",", 
       RowBox[{"1002", "\[Rule]", "999"}], ",", 
       RowBox[{"610", "\[Rule]", "597"}], ",", 
       RowBox[{"610", "\[Rule]", "623"}], ",", 
       RowBox[{"610", "\[Rule]", "611"}], ",", 
       RowBox[{"610", "\[Rule]", "607"}], ",", 
       RowBox[{"328", "\[Rule]", "315"}], ",", 
       RowBox[{"328", "\[Rule]", "341"}], ",", 
       RowBox[{"328", "\[Rule]", "329"}], ",", 
       RowBox[{"328", "\[Rule]", "325"}], ",", 
       RowBox[{"1268", "\[Rule]", "1255"}], ",", 
       RowBox[{"1268", "\[Rule]", "1281"}], ",", 
       RowBox[{"1268", "\[Rule]", "1269"}], ",", 
       RowBox[{"1268", "\[Rule]", "1265"}], ",", 
       RowBox[{"986", "\[Rule]", "973"}], ",", 
       RowBox[{"986", "\[Rule]", "999"}], ",", 
       RowBox[{"986", "\[Rule]", "987"}], ",", 
       RowBox[{"986", "\[Rule]", "983"}], ",", 
       RowBox[{"516", "\[Rule]", "503"}], ",", 
       RowBox[{"516", "\[Rule]", "529"}], ",", 
       RowBox[{"516", "\[Rule]", "517"}], ",", 
       RowBox[{"516", "\[Rule]", "513"}], ",", 
       RowBox[{"234", "\[Rule]", "221"}], ",", 
       RowBox[{"234", "\[Rule]", "247"}], ",", 
       RowBox[{"234", "\[Rule]", "235"}], ",", 
       RowBox[{"234", "\[Rule]", "231"}], ",", 
       RowBox[{"1174", "\[Rule]", "1161"}], ",", 
       RowBox[{"1174", "\[Rule]", "1187"}], ",", 
       RowBox[{"1174", "\[Rule]", "1175"}], ",", 
       RowBox[{"1174", "\[Rule]", "1171"}], ",", 
       RowBox[{"892", "\[Rule]", "879"}], ",", 
       RowBox[{"892", "\[Rule]", "905"}], ",", 
       RowBox[{"892", "\[Rule]", "893"}], ",", 
       RowBox[{"892", "\[Rule]", "889"}], ",", 
       RowBox[{"422", "\[Rule]", "409"}], ",", 
       RowBox[{"422", "\[Rule]", "435"}], ",", 
       RowBox[{"422", "\[Rule]", "423"}], ",", 
       RowBox[{"422", "\[Rule]", "419"}], ",", 
       RowBox[{"140", "\[Rule]", "127"}], ",", 
       RowBox[{"140", "\[Rule]", "153"}], ",", 
       RowBox[{"140", "\[Rule]", "141"}], ",", 
       RowBox[{"140", "\[Rule]", "137"}], ",", 
       RowBox[{"1080", "\[Rule]", "1067"}], ",", 
       RowBox[{"1080", "\[Rule]", "1093"}], ",", 
       RowBox[{"1080", "\[Rule]", "1081"}], ",", 
       RowBox[{"1080", "\[Rule]", "1077"}], ",", 
       RowBox[{"798", "\[Rule]", "785"}], ",", 
       RowBox[{"798", "\[Rule]", "811"}], ",", 
       RowBox[{"798", "\[Rule]", "799"}], ",", 
       RowBox[{"798", "\[Rule]", "795"}], ",", 
       RowBox[{"1894", "\[Rule]", "1905"}], ",", 
       RowBox[{"1894", "\[Rule]", "1891"}], ",", 
       RowBox[{"1612", "\[Rule]", "1623"}], ",", 
       RowBox[{"1612", "\[Rule]", "1609"}], ",", 
       RowBox[{"1638", "\[Rule]", "1623"}], ",", 
       RowBox[{"1638", "\[Rule]", "1649"}], ",", 
       RowBox[{"1638", "\[Rule]", "1635"}], ",", 
       RowBox[{"1904", "\[Rule]", "1891"}], ",", 
       RowBox[{"1904", "\[Rule]", "1917"}], ",", 
       RowBox[{"1904", "\[Rule]", "1905"}], ",", 
       RowBox[{"1904", "\[Rule]", "1901"}], ",", 
       RowBox[{"1622", "\[Rule]", "1609"}], ",", 
       RowBox[{"1622", "\[Rule]", "1635"}], ",", 
       RowBox[{"1622", "\[Rule]", "1623"}], ",", 
       RowBox[{"1622", "\[Rule]", "1619"}], ",", 
       RowBox[{"1800", "\[Rule]", "1811"}], ",", 
       RowBox[{"1800", "\[Rule]", "1797"}], ",", 
       RowBox[{"1518", "\[Rule]", "1529"}], ",", 
       RowBox[{"1518", "\[Rule]", "1515"}], ",", 
       RowBox[{"1810", "\[Rule]", "1797"}], ",", 
       RowBox[{"1810", "\[Rule]", "1823"}], ",", 
       RowBox[{"1810", "\[Rule]", "1811"}], ",", 
       RowBox[{"1810", "\[Rule]", "1807"}], ",", 
       RowBox[{"1528", "\[Rule]", "1515"}], ",", 
       RowBox[{"1528", "\[Rule]", "1541"}], ",", 
       RowBox[{"1528", "\[Rule]", "1529"}], ",", 
       RowBox[{"1528", "\[Rule]", "1525"}], ",", 
       RowBox[{"1664", "\[Rule]", "1649"}], ",", 
       RowBox[{"1664", "\[Rule]", "1677"}], ",", 
       RowBox[{"1664", "\[Rule]", "1661"}], ",", 
       RowBox[{"1648", "\[Rule]", "1635"}], ",", 
       RowBox[{"1648", "\[Rule]", "1661"}], ",", 
       RowBox[{"1648", "\[Rule]", "1649"}], ",", 
       RowBox[{"1648", "\[Rule]", "1645"}], ",", 
       RowBox[{"1916", "\[Rule]", "1901"}], ",", 
       RowBox[{"1916", "\[Rule]", "1927"}], ",", 
       RowBox[{"1916", "\[Rule]", "1917"}], ",", 
       RowBox[{"1916", "\[Rule]", "1913"}], ",", 
       RowBox[{"1634", "\[Rule]", "1619"}], ",", 
       RowBox[{"1634", "\[Rule]", "1645"}], ",", 
       RowBox[{"1634", "\[Rule]", "1635"}], ",", 
       RowBox[{"1634", "\[Rule]", "1631"}], ",", 
       RowBox[{"1822", "\[Rule]", "1807"}], ",", 
       RowBox[{"1822", "\[Rule]", "1833"}], ",", 
       RowBox[{"1822", "\[Rule]", "1823"}], ",", 
       RowBox[{"1822", "\[Rule]", "1819"}], ",", 
       RowBox[{"1540", "\[Rule]", "1525"}], ",", 
       RowBox[{"1540", "\[Rule]", "1551"}], ",", 
       RowBox[{"1540", "\[Rule]", "1541"}], ",", 
       RowBox[{"1540", "\[Rule]", "1537"}], ",", 
       RowBox[{"1706", "\[Rule]", "1717"}], ",", 
       RowBox[{"1706", "\[Rule]", "1703"}], ",", 
       RowBox[{"1424", "\[Rule]", "1435"}], ",", 
       RowBox[{"1424", "\[Rule]", "1421"}], ",", 
       RowBox[{"1716", "\[Rule]", "1703"}], ",", 
       RowBox[{"1716", "\[Rule]", "1729"}], ",", 
       RowBox[{"1716", "\[Rule]", "1717"}], ",", 
       RowBox[{"1716", "\[Rule]", "1713"}], ",", 
       RowBox[{"1434", "\[Rule]", "1421"}], ",", 
       RowBox[{"1434", "\[Rule]", "1447"}], ",", 
       RowBox[{"1434", "\[Rule]", "1435"}], ",", 
       RowBox[{"1434", "\[Rule]", "1431"}], ",", 
       RowBox[{"1728", "\[Rule]", "1713"}], ",", 
       RowBox[{"1728", "\[Rule]", "1739"}], ",", 
       RowBox[{"1728", "\[Rule]", "1729"}], ",", 
       RowBox[{"1728", "\[Rule]", "1725"}], ",", 
       RowBox[{"1446", "\[Rule]", "1431"}], ",", 
       RowBox[{"1446", "\[Rule]", "1457"}], ",", 
       RowBox[{"1446", "\[Rule]", "1447"}], ",", 
       RowBox[{"1446", "\[Rule]", "1443"}], ",", 
       RowBox[{"1692", "\[Rule]", "1677"}], ",", 
       RowBox[{"1692", "\[Rule]", "1689"}], ",", 
       RowBox[{"1676", "\[Rule]", "1661"}], ",", 
       RowBox[{"1676", "\[Rule]", "1689"}], ",", 
       RowBox[{"1676", "\[Rule]", "1677"}], ",", 
       RowBox[{"1676", "\[Rule]", "1673"}], ",", 
       RowBox[{"1660", "\[Rule]", "1645"}], ",", 
       RowBox[{"1660", "\[Rule]", "1673"}], ",", 
       RowBox[{"1660", "\[Rule]", "1661"}], ",", 
       RowBox[{"1660", "\[Rule]", "1657"}], ",", 
       RowBox[{"1926", "\[Rule]", "1913"}], ",", 
       RowBox[{"1926", "\[Rule]", "1939"}], ",", 
       RowBox[{"1926", "\[Rule]", "1927"}], ",", 
       RowBox[{"1926", "\[Rule]", "1923"}], ",", 
       RowBox[{"1644", "\[Rule]", "1631"}], ",", 
       RowBox[{"1644", "\[Rule]", "1657"}], ",", 
       RowBox[{"1644", "\[Rule]", "1645"}], ",", 
       RowBox[{"1644", "\[Rule]", "1641"}], ",", 
       RowBox[{"1832", "\[Rule]", "1819"}], ",", 
       RowBox[{"1832", "\[Rule]", "1845"}], ",", 
       RowBox[{"1832", "\[Rule]", "1833"}], ",", 
       RowBox[{"1832", "\[Rule]", "1829"}], ",", 
       RowBox[{"1550", "\[Rule]", "1537"}], ",", 
       RowBox[{"1550", "\[Rule]", "1563"}], ",", 
       RowBox[{"1550", "\[Rule]", "1551"}], ",", 
       RowBox[{"1550", "\[Rule]", "1547"}], ",", 
       RowBox[{"1738", "\[Rule]", "1725"}], ",", 
       RowBox[{"1738", "\[Rule]", "1751"}], ",", 
       RowBox[{"1738", "\[Rule]", "1739"}], ",", 
       RowBox[{"1738", "\[Rule]", "1735"}], ",", 
       RowBox[{"1456", "\[Rule]", "1443"}], ",", 
       RowBox[{"1456", "\[Rule]", "1469"}], ",", 
       RowBox[{"1456", "\[Rule]", "1457"}], ",", 
       RowBox[{"1456", "\[Rule]", "1453"}], ",", 
       RowBox[{"14", "\[Rule]", "25"}], ",", 
       RowBox[{"14", "\[Rule]", "11"}], ",", 
       RowBox[{"24", "\[Rule]", "11"}], ",", 
       RowBox[{"24", "\[Rule]", "37"}], ",", 
       RowBox[{"24", "\[Rule]", "25"}], ",", 
       RowBox[{"24", "\[Rule]", "21"}], ",", 
       RowBox[{"672", "\[Rule]", "683"}], ",", 
       RowBox[{"672", "\[Rule]", "669"}], ",", 
       RowBox[{"682", "\[Rule]", "669"}], ",", 
       RowBox[{"682", "\[Rule]", "695"}], ",", 
       RowBox[{"682", "\[Rule]", "683"}], ",", 
       RowBox[{"682", "\[Rule]", "679"}], ",", 
       RowBox[{"36", "\[Rule]", "21"}], ",", 
       RowBox[{"36", "\[Rule]", "47"}], ",", 
       RowBox[{"36", "\[Rule]", "37"}], ",", 
       RowBox[{"36", "\[Rule]", "33"}], ",", 
       RowBox[{"694", "\[Rule]", "679"}], ",", 
       RowBox[{"694", "\[Rule]", "705"}], ",", 
       RowBox[{"694", "\[Rule]", "695"}], ",", 
       RowBox[{"694", "\[Rule]", "691"}], ",", 
       RowBox[{"46", "\[Rule]", "33"}], ",", 
       RowBox[{"46", "\[Rule]", "59"}], ",", 
       RowBox[{"46", "\[Rule]", "47"}], ",", 
       RowBox[{"46", "\[Rule]", "43"}], ",", 
       RowBox[{"704", "\[Rule]", "691"}], ",", 
       RowBox[{"704", "\[Rule]", "717"}], ",", 
       RowBox[{"704", "\[Rule]", "705"}], ",", 
       RowBox[{"704", "\[Rule]", "701"}], ",", 
       RowBox[{"1330", "\[Rule]", "1341"}], ",", 
       RowBox[{"1330", "\[Rule]", "1327"}], ",", 
       RowBox[{"1340", "\[Rule]", "1327"}], ",", 
       RowBox[{"1340", "\[Rule]", "1353"}], ",", 
       RowBox[{"1340", "\[Rule]", "1341"}], ",", 
       RowBox[{"1340", "\[Rule]", "1337"}], ",", 
       RowBox[{"1352", "\[Rule]", "1337"}], ",", 
       RowBox[{"1352", "\[Rule]", "1363"}], ",", 
       RowBox[{"1352", "\[Rule]", "1353"}], ",", 
       RowBox[{"1352", "\[Rule]", "1349"}], ",", 
       RowBox[{"1362", "\[Rule]", "1349"}], ",", 
       RowBox[{"1362", "\[Rule]", "1375"}], ",", 
       RowBox[{"1362", "\[Rule]", "1363"}], ",", 
       RowBox[{"1362", "\[Rule]", "1359"}], ",", 
       RowBox[{"372", "\[Rule]", "357"}], ",", 
       RowBox[{"372", "\[Rule]", "373"}], ",", 
       RowBox[{"372", "\[Rule]", "369"}], ",", 
       RowBox[{"1030", "\[Rule]", "1015"}], ",", 
       RowBox[{"1030", "\[Rule]", "1031"}], ",", 
       RowBox[{"1030", "\[Rule]", "1027"}], ",", 
       RowBox[{"356", "\[Rule]", "341"}], ",", 
       RowBox[{"356", "\[Rule]", "369"}], ",", 
       RowBox[{"356", "\[Rule]", "357"}], ",", 
       RowBox[{"356", "\[Rule]", "353"}], ",", 
       RowBox[{"1014", "\[Rule]", "999"}], ",", 
       RowBox[{"1014", "\[Rule]", "1027"}], ",", 
       RowBox[{"1014", "\[Rule]", "1015"}], ",", 
       RowBox[{"1014", "\[Rule]", "1011"}], ",", 
       RowBox[{"1688", "\[Rule]", "1673"}], ",", 
       RowBox[{"1688", "\[Rule]", "1689"}], ",", 
       RowBox[{"1688", "\[Rule]", "1685"}], ",", 
       RowBox[{"1672", "\[Rule]", "1657"}], ",", 
       RowBox[{"1672", "\[Rule]", "1685"}], ",", 
       RowBox[{"1672", "\[Rule]", "1673"}], ",", 
       RowBox[{"1672", "\[Rule]", "1669"}], ",", 
       RowBox[{"622", "\[Rule]", "607"}], ",", 
       RowBox[{"622", "\[Rule]", "635"}], ",", 
       RowBox[{"622", "\[Rule]", "623"}], ",", 
       RowBox[{"622", "\[Rule]", "619"}], ",", 
       RowBox[{"340", "\[Rule]", "325"}], ",", 
       RowBox[{"340", "\[Rule]", "353"}], ",", 
       RowBox[{"340", "\[Rule]", "341"}], ",", 
       RowBox[{"340", "\[Rule]", "337"}], ",", 
       RowBox[{"1280", "\[Rule]", "1265"}], ",", 
       RowBox[{"1280", "\[Rule]", "1293"}], ",", 
       RowBox[{"1280", "\[Rule]", "1281"}], ",", 
       RowBox[{"1280", "\[Rule]", "1277"}], ",", 
       RowBox[{"998", "\[Rule]", "983"}], ",", 
       RowBox[{"998", "\[Rule]", "1011"}], ",", 
       RowBox[{"998", "\[Rule]", "999"}], ",", 
       RowBox[{"998", "\[Rule]", "995"}], ",", 
       RowBox[{"528", "\[Rule]", "513"}], ",", 
       RowBox[{"528", "\[Rule]", "541"}], ",", 
       RowBox[{"528", "\[Rule]", "529"}], ",", 
       RowBox[{"528", "\[Rule]", "525"}], ",", 
       RowBox[{"246", "\[Rule]", "231"}], ",", 
       RowBox[{"246", "\[Rule]", "259"}], ",", 
       RowBox[{"246", "\[Rule]", "247"}], ",", 
       RowBox[{"246", "\[Rule]", "243"}], ",", 
       RowBox[{"1186", "\[Rule]", "1171"}], ",", 
       RowBox[{"1186", "\[Rule]", "1199"}], ",", 
       RowBox[{"1186", "\[Rule]", "1187"}], ",", 
       RowBox[{"1186", "\[Rule]", "1183"}], ",", 
       RowBox[{"904", "\[Rule]", "889"}], ",", 
       RowBox[{"904", "\[Rule]", "917"}], ",", 
       RowBox[{"904", "\[Rule]", "905"}], ",", 
       RowBox[{"904", "\[Rule]", "901"}], ",", 
       RowBox[{"434", "\[Rule]", "419"}], ",", 
       RowBox[{"434", "\[Rule]", "447"}], ",", 
       RowBox[{"434", "\[Rule]", "435"}], ",", 
       RowBox[{"434", "\[Rule]", "431"}], ",", 
       RowBox[{"152", "\[Rule]", "137"}], ",", 
       RowBox[{"152", "\[Rule]", "165"}], ",", 
       RowBox[{"152", "\[Rule]", "153"}], ",", 
       RowBox[{"152", "\[Rule]", "149"}], ",", 
       RowBox[{"1092", "\[Rule]", "1077"}], ",", 
       RowBox[{"1092", "\[Rule]", "1105"}], ",", 
       RowBox[{"1092", "\[Rule]", "1093"}], ",", 
       RowBox[{"1092", "\[Rule]", "1089"}], ",", 
       RowBox[{"810", "\[Rule]", "795"}], ",", 
       RowBox[{"810", "\[Rule]", "823"}], ",", 
       RowBox[{"810", "\[Rule]", "811"}], ",", 
       RowBox[{"810", "\[Rule]", "807"}], ",", 
       RowBox[{"1938", "\[Rule]", "1923"}], ",", 
       RowBox[{"1938", "\[Rule]", "1951"}], ",", 
       RowBox[{"1938", "\[Rule]", "1939"}], ",", 
       RowBox[{"1938", "\[Rule]", "1935"}], ",", 
       RowBox[{"1656", "\[Rule]", "1641"}], ",", 
       RowBox[{"1656", "\[Rule]", "1669"}], ",", 
       RowBox[{"1656", "\[Rule]", "1657"}], ",", 
       RowBox[{"1656", "\[Rule]", "1653"}], ",", 
       RowBox[{"1844", "\[Rule]", "1829"}], ",", 
       RowBox[{"1844", "\[Rule]", "1857"}], ",", 
       RowBox[{"1844", "\[Rule]", "1845"}], ",", 
       RowBox[{"1844", "\[Rule]", "1841"}], ",", 
       RowBox[{"1562", "\[Rule]", "1547"}], ",", 
       RowBox[{"1562", "\[Rule]", "1575"}], ",", 
       RowBox[{"1562", "\[Rule]", "1563"}], ",", 
       RowBox[{"1562", "\[Rule]", "1559"}], ",", 
       RowBox[{"1750", "\[Rule]", "1735"}], ",", 
       RowBox[{"1750", "\[Rule]", "1763"}], ",", 
       RowBox[{"1750", "\[Rule]", "1751"}], ",", 
       RowBox[{"1750", "\[Rule]", "1747"}], ",", 
       RowBox[{"1468", "\[Rule]", "1453"}], ",", 
       RowBox[{"1468", "\[Rule]", "1481"}], ",", 
       RowBox[{"1468", "\[Rule]", "1469"}], ",", 
       RowBox[{"1468", "\[Rule]", "1465"}], ",", 
       RowBox[{"58", "\[Rule]", "43"}], ",", 
       RowBox[{"58", "\[Rule]", "71"}], ",", 
       RowBox[{"58", "\[Rule]", "59"}], ",", 
       RowBox[{"58", "\[Rule]", "55"}], ",", 
       RowBox[{"716", "\[Rule]", "701"}], ",", 
       RowBox[{"716", "\[Rule]", "729"}], ",", 
       RowBox[{"716", "\[Rule]", "717"}], ",", 
       RowBox[{"716", "\[Rule]", "713"}], ",", 
       RowBox[{"1374", "\[Rule]", "1359"}], ",", 
       RowBox[{"1374", "\[Rule]", "1387"}], ",", 
       RowBox[{"1374", "\[Rule]", "1375"}], ",", 
       RowBox[{"1374", "\[Rule]", "1371"}], ",", 
       RowBox[{"368", "\[Rule]", "353"}], ",", 
       RowBox[{"368", "\[Rule]", "369"}], ",", 
       RowBox[{"368", "\[Rule]", "365"}], ",", 
       RowBox[{"1026", "\[Rule]", "1011"}], ",", 
       RowBox[{"1026", "\[Rule]", "1027"}], ",", 
       RowBox[{"1026", "\[Rule]", "1023"}], ",", 
       RowBox[{"1684", "\[Rule]", "1669"}], ",", 
       RowBox[{"1684", "\[Rule]", "1685"}], ",", 
       RowBox[{"1684", "\[Rule]", "1681"}], ",", 
       RowBox[{"634", "\[Rule]", "619"}], ",", 
       RowBox[{"634", "\[Rule]", "647"}], ",", 
       RowBox[{"634", "\[Rule]", "635"}], ",", 
       RowBox[{"634", "\[Rule]", "631"}], ",", 
       RowBox[{"352", "\[Rule]", "337"}], ",", 
       RowBox[{"352", "\[Rule]", "365"}], ",", 
       RowBox[{"352", "\[Rule]", "353"}], ",", 
       RowBox[{"352", "\[Rule]", "349"}], ",", 
       RowBox[{"1292", "\[Rule]", "1277"}], ",", 
       RowBox[{"1292", "\[Rule]", "1305"}], ",", 
       RowBox[{"1292", "\[Rule]", "1293"}], ",", 
       RowBox[{"1292", "\[Rule]", "1289"}], ",", 
       RowBox[{"1010", "\[Rule]", "995"}], ",", 
       RowBox[{"1010", "\[Rule]", "1023"}], ",", 
       RowBox[{"1010", "\[Rule]", "1011"}], ",", 
       RowBox[{"1010", "\[Rule]", "1007"}], ",", 
       RowBox[{"540", "\[Rule]", "525"}], ",", 
       RowBox[{"540", "\[Rule]", "553"}], ",", 
       RowBox[{"540", "\[Rule]", "541"}], ",", 
       RowBox[{"540", "\[Rule]", "537"}], ",", 
       RowBox[{"258", "\[Rule]", "243"}], ",", 
       RowBox[{"258", "\[Rule]", "271"}], ",", 
       RowBox[{"258", "\[Rule]", "259"}], ",", 
       RowBox[{"258", "\[Rule]", "255"}], ",", 
       RowBox[{"1198", "\[Rule]", "1183"}], ",", 
       RowBox[{"1198", "\[Rule]", "1211"}], ",", 
       RowBox[{"1198", "\[Rule]", "1199"}], ",", 
       RowBox[{"1198", "\[Rule]", "1195"}], ",", 
       RowBox[{"916", "\[Rule]", "901"}], ",", 
       RowBox[{"916", "\[Rule]", "929"}], ",", 
       RowBox[{"916", "\[Rule]", "917"}], ",", 
       RowBox[{"916", "\[Rule]", "913"}], ",", 
       RowBox[{"446", "\[Rule]", "431"}], ",", 
       RowBox[{"446", "\[Rule]", "459"}], ",", 
       RowBox[{"446", "\[Rule]", "447"}], ",", 
       RowBox[{"446", "\[Rule]", "443"}], ",", 
       RowBox[{"164", "\[Rule]", "149"}], ",", 
       RowBox[{"164", "\[Rule]", "177"}], ",", 
       RowBox[{"164", "\[Rule]", "165"}], ",", 
       RowBox[{"164", "\[Rule]", "161"}], ",", 
       RowBox[{"1104", "\[Rule]", "1089"}], ",", 
       RowBox[{"1104", "\[Rule]", "1117"}], ",", 
       RowBox[{"1104", "\[Rule]", "1105"}], ",", 
       RowBox[{"1104", "\[Rule]", "1101"}], ",", 
       RowBox[{"822", "\[Rule]", "807"}], ",", 
       RowBox[{"822", "\[Rule]", "835"}], ",", 
       RowBox[{"822", "\[Rule]", "823"}], ",", 
       RowBox[{"822", "\[Rule]", "819"}], ",", 
       RowBox[{"1950", "\[Rule]", "1935"}], ",", 
       RowBox[{"1950", "\[Rule]", "1963"}], ",", 
       RowBox[{"1950", "\[Rule]", "1951"}], ",", 
       RowBox[{"1950", "\[Rule]", "1947"}], ",", 
       RowBox[{"1668", "\[Rule]", "1653"}], ",", 
       RowBox[{"1668", "\[Rule]", "1681"}], ",", 
       RowBox[{"1668", "\[Rule]", "1669"}], ",", 
       RowBox[{"1668", "\[Rule]", "1665"}], ",", 
       RowBox[{"1856", "\[Rule]", "1841"}], ",", 
       RowBox[{"1856", "\[Rule]", "1869"}], ",", 
       RowBox[{"1856", "\[Rule]", "1857"}], ",", 
       RowBox[{"1856", "\[Rule]", "1853"}], ",", 
       RowBox[{"1574", "\[Rule]", "1559"}], ",", 
       RowBox[{"1574", "\[Rule]", "1587"}], ",", 
       RowBox[{"1574", "\[Rule]", "1575"}], ",", 
       RowBox[{"1574", "\[Rule]", "1571"}], ",", 
       RowBox[{"1762", "\[Rule]", "1747"}], ",", 
       RowBox[{"1762", "\[Rule]", "1775"}], ",", 
       RowBox[{"1762", "\[Rule]", "1763"}], ",", 
       RowBox[{"1762", "\[Rule]", "1759"}], ",", 
       RowBox[{"1480", "\[Rule]", "1465"}], ",", 
       RowBox[{"1480", "\[Rule]", "1493"}], ",", 
       RowBox[{"1480", "\[Rule]", "1481"}], ",", 
       RowBox[{"1480", "\[Rule]", "1477"}], ",", 
       RowBox[{"70", "\[Rule]", "55"}], ",", 
       RowBox[{"70", "\[Rule]", "83"}], ",", 
       RowBox[{"70", "\[Rule]", "71"}], ",", 
       RowBox[{"70", "\[Rule]", "67"}], ",", 
       RowBox[{"728", "\[Rule]", "713"}], ",", 
       RowBox[{"728", "\[Rule]", "741"}], ",", 
       RowBox[{"728", "\[Rule]", "729"}], ",", 
       RowBox[{"728", "\[Rule]", "725"}], ",", 
       RowBox[{"1386", "\[Rule]", "1371"}], ",", 
       RowBox[{"1386", "\[Rule]", "1399"}], ",", 
       RowBox[{"1386", "\[Rule]", "1387"}], ",", 
       RowBox[{"1386", "\[Rule]", "1383"}], ",", 
       RowBox[{"2270", "\[Rule]", "2281"}], ",", 
       RowBox[{"2270", "\[Rule]", "2267"}], ",", 
       RowBox[{"2296", "\[Rule]", "2281"}], ",", 
       RowBox[{"2296", "\[Rule]", "2307"}], ",", 
       RowBox[{"2296", "\[Rule]", "2293"}], ",", 
       RowBox[{"2280", "\[Rule]", "2267"}], ",", 
       RowBox[{"2280", "\[Rule]", "2293"}], ",", 
       RowBox[{"2280", "\[Rule]", "2281"}], ",", 
       RowBox[{"2280", "\[Rule]", "2277"}], ",", 
       RowBox[{"2176", "\[Rule]", "2187"}], ",", 
       RowBox[{"2176", "\[Rule]", "2173"}], ",", 
       RowBox[{"2202", "\[Rule]", "2187"}], ",", 
       RowBox[{"2202", "\[Rule]", "2213"}], ",", 
       RowBox[{"2202", "\[Rule]", "2199"}], ",", 
       RowBox[{"2186", "\[Rule]", "2173"}], ",", 
       RowBox[{"2186", "\[Rule]", "2199"}], ",", 
       RowBox[{"2186", "\[Rule]", "2187"}], ",", 
       RowBox[{"2186", "\[Rule]", "2183"}], ",", 
       RowBox[{"2322", "\[Rule]", "2307"}], ",", 
       RowBox[{"2322", "\[Rule]", "2335"}], ",", 
       RowBox[{"2322", "\[Rule]", "2319"}], ",", 
       RowBox[{"2306", "\[Rule]", "2293"}], ",", 
       RowBox[{"2306", "\[Rule]", "2319"}], ",", 
       RowBox[{"2306", "\[Rule]", "2307"}], ",", 
       RowBox[{"2306", "\[Rule]", "2303"}], ",", 
       RowBox[{"2228", "\[Rule]", "2213"}], ",", 
       RowBox[{"2228", "\[Rule]", "2241"}], ",", 
       RowBox[{"2228", "\[Rule]", "2225"}], ",", 
       RowBox[{"2212", "\[Rule]", "2199"}], ",", 
       RowBox[{"2212", "\[Rule]", "2225"}], ",", 
       RowBox[{"2212", "\[Rule]", "2213"}], ",", 
       RowBox[{"2212", "\[Rule]", "2209"}], ",", 
       RowBox[{"2292", "\[Rule]", "2277"}], ",", 
       RowBox[{"2292", "\[Rule]", "2303"}], ",", 
       RowBox[{"2292", "\[Rule]", "2293"}], ",", 
       RowBox[{"2292", "\[Rule]", "2289"}], ",", 
       RowBox[{"2198", "\[Rule]", "2183"}], ",", 
       RowBox[{"2198", "\[Rule]", "2209"}], ",", 
       RowBox[{"2198", "\[Rule]", "2199"}], ",", 
       RowBox[{"2198", "\[Rule]", "2195"}], ",", 
       RowBox[{"2082", "\[Rule]", "2093"}], ",", 
       RowBox[{"2082", "\[Rule]", "2079"}], ",", 
       RowBox[{"2108", "\[Rule]", "2093"}], ",", 
       RowBox[{"2108", "\[Rule]", "2119"}], ",", 
       RowBox[{"2108", "\[Rule]", "2105"}], ",", 
       RowBox[{"2092", "\[Rule]", "2079"}], ",", 
       RowBox[{"2092", "\[Rule]", "2105"}], ",", 
       RowBox[{"2092", "\[Rule]", "2093"}], ",", 
       RowBox[{"2092", "\[Rule]", "2089"}], ",", 
       RowBox[{"2134", "\[Rule]", "2119"}], ",", 
       RowBox[{"2134", "\[Rule]", "2147"}], ",", 
       RowBox[{"2134", "\[Rule]", "2131"}], ",", 
       RowBox[{"2118", "\[Rule]", "2105"}], ",", 
       RowBox[{"2118", "\[Rule]", "2131"}], ",", 
       RowBox[{"2118", "\[Rule]", "2119"}], ",", 
       RowBox[{"2118", "\[Rule]", "2115"}], ",", 
       RowBox[{"2104", "\[Rule]", "2089"}], ",", 
       RowBox[{"2104", "\[Rule]", "2115"}], ",", 
       RowBox[{"2104", "\[Rule]", "2105"}], ",", 
       RowBox[{"2104", "\[Rule]", "2101"}], ",", 
       RowBox[{"2350", "\[Rule]", "2335"}], ",", 
       RowBox[{"2350", "\[Rule]", "2347"}], ",", 
       RowBox[{"2334", "\[Rule]", "2319"}], ",", 
       RowBox[{"2334", "\[Rule]", "2347"}], ",", 
       RowBox[{"2334", "\[Rule]", "2335"}], ",", 
       RowBox[{"2334", "\[Rule]", "2331"}], ",", 
       RowBox[{"2256", "\[Rule]", "2241"}], ",", 
       RowBox[{"2256", "\[Rule]", "2253"}], ",", 
       RowBox[{"2240", "\[Rule]", "2225"}], ",", 
       RowBox[{"2240", "\[Rule]", "2253"}], ",", 
       RowBox[{"2240", "\[Rule]", "2241"}], ",", 
       RowBox[{"2240", "\[Rule]", "2237"}], ",", 
       RowBox[{"2318", "\[Rule]", "2303"}], ",", 
       RowBox[{"2318", "\[Rule]", "2331"}], ",", 
       RowBox[{"2318", "\[Rule]", "2319"}], ",", 
       RowBox[{"2318", "\[Rule]", "2315"}], ",", 
       RowBox[{"2224", "\[Rule]", "2209"}], ",", 
       RowBox[{"2224", "\[Rule]", "2237"}], ",", 
       RowBox[{"2224", "\[Rule]", "2225"}], ",", 
       RowBox[{"2224", "\[Rule]", "2221"}], ",", 
       RowBox[{"2162", "\[Rule]", "2147"}], ",", 
       RowBox[{"2162", "\[Rule]", "2159"}], ",", 
       RowBox[{"2146", "\[Rule]", "2131"}], ",", 
       RowBox[{"2146", "\[Rule]", "2159"}], ",", 
       RowBox[{"2146", "\[Rule]", "2147"}], ",", 
       RowBox[{"2146", "\[Rule]", "2143"}], ",", 
       RowBox[{"2130", "\[Rule]", "2115"}], ",", 
       RowBox[{"2130", "\[Rule]", "2143"}], ",", 
       RowBox[{"2130", "\[Rule]", "2131"}], ",", 
       RowBox[{"2130", "\[Rule]", "2127"}], ",", 
       RowBox[{"2302", "\[Rule]", "2289"}], ",", 
       RowBox[{"2302", "\[Rule]", "2315"}], ",", 
       RowBox[{"2302", "\[Rule]", "2303"}], ",", 
       RowBox[{"2302", "\[Rule]", "2299"}], ",", 
       RowBox[{"2208", "\[Rule]", "2195"}], ",", 
       RowBox[{"2208", "\[Rule]", "2221"}], ",", 
       RowBox[{"2208", "\[Rule]", "2209"}], ",", 
       RowBox[{"2208", "\[Rule]", "2205"}], ",", 
       RowBox[{"2114", "\[Rule]", "2101"}], ",", 
       RowBox[{"2114", "\[Rule]", "2127"}], ",", 
       RowBox[{"2114", "\[Rule]", "2115"}], ",", 
       RowBox[{"2114", "\[Rule]", "2111"}], ",", 
       RowBox[{"1988", "\[Rule]", "1999"}], ",", 
       RowBox[{"1988", "\[Rule]", "1985"}], ",", 
       RowBox[{"2014", "\[Rule]", "1999"}], ",", 
       RowBox[{"2014", "\[Rule]", "2025"}], ",", 
       RowBox[{"2014", "\[Rule]", "2011"}], ",", 
       RowBox[{"1998", "\[Rule]", "1985"}], ",", 
       RowBox[{"1998", "\[Rule]", "2011"}], ",", 
       RowBox[{"1998", "\[Rule]", "1999"}], ",", 
       RowBox[{"1998", "\[Rule]", "1995"}], ",", 
       RowBox[{"2040", "\[Rule]", "2025"}], ",", 
       RowBox[{"2040", "\[Rule]", "2053"}], ",", 
       RowBox[{"2040", "\[Rule]", "2037"}], ",", 
       RowBox[{"2024", "\[Rule]", "2011"}], ",", 
       RowBox[{"2024", "\[Rule]", "2037"}], ",", 
       RowBox[{"2024", "\[Rule]", "2025"}], ",", 
       RowBox[{"2024", "\[Rule]", "2021"}], ",", 
       RowBox[{"2010", "\[Rule]", "1995"}], ",", 
       RowBox[{"2010", "\[Rule]", "2021"}], ",", 
       RowBox[{"2010", "\[Rule]", "2011"}], ",", 
       RowBox[{"2010", "\[Rule]", "2007"}], ",", 
       RowBox[{"2068", "\[Rule]", "2053"}], ",", 
       RowBox[{"2068", "\[Rule]", "2065"}], ",", 
       RowBox[{"2052", "\[Rule]", "2037"}], ",", 
       RowBox[{"2052", "\[Rule]", "2065"}], ",", 
       RowBox[{"2052", "\[Rule]", "2053"}], ",", 
       RowBox[{"2052", "\[Rule]", "2049"}], ",", 
       RowBox[{"2036", "\[Rule]", "2021"}], ",", 
       RowBox[{"2036", "\[Rule]", "2049"}], ",", 
       RowBox[{"2036", "\[Rule]", "2037"}], ",", 
       RowBox[{"2036", "\[Rule]", "2033"}], ",", 
       RowBox[{"2020", "\[Rule]", "2007"}], ",", 
       RowBox[{"2020", "\[Rule]", "2033"}], ",", 
       RowBox[{"2020", "\[Rule]", "2021"}], ",", 
       RowBox[{"2020", "\[Rule]", "2017"}], ",", 
       RowBox[{"2346", "\[Rule]", "2331"}], ",", 
       RowBox[{"2346", "\[Rule]", "2347"}], ",", 
       RowBox[{"2346", "\[Rule]", "2343"}], ",", 
       RowBox[{"2252", "\[Rule]", "2237"}], ",", 
       RowBox[{"2252", "\[Rule]", "2253"}], ",", 
       RowBox[{"2252", "\[Rule]", "2249"}], ",", 
       RowBox[{"2158", "\[Rule]", "2143"}], ",", 
       RowBox[{"2158", "\[Rule]", "2159"}], ",", 
       RowBox[{"2158", "\[Rule]", "2155"}], ",", 
       RowBox[{"2330", "\[Rule]", "2315"}], ",", 
       RowBox[{"2330", "\[Rule]", "2343"}], ",", 
       RowBox[{"2330", "\[Rule]", "2331"}], ",", 
       RowBox[{"2330", "\[Rule]", "2327"}], ",", 
       RowBox[{"2236", "\[Rule]", "2221"}], ",", 
       RowBox[{"2236", "\[Rule]", "2249"}], ",", 
       RowBox[{"2236", "\[Rule]", "2237"}], ",", 
       RowBox[{"2236", "\[Rule]", "2233"}], ",", 
       RowBox[{"2142", "\[Rule]", "2127"}], ",", 
       RowBox[{"2142", "\[Rule]", "2155"}], ",", 
       RowBox[{"2142", "\[Rule]", "2143"}], ",", 
       RowBox[{"2142", "\[Rule]", "2139"}], ",", 
       RowBox[{"2064", "\[Rule]", "2049"}], ",", 
       RowBox[{"2064", "\[Rule]", "2065"}], ",", 
       RowBox[{"2064", "\[Rule]", "2061"}], ",", 
       RowBox[{"2048", "\[Rule]", "2033"}], ",", 
       RowBox[{"2048", "\[Rule]", "2061"}], ",", 
       RowBox[{"2048", "\[Rule]", "2049"}], ",", 
       RowBox[{"2048", "\[Rule]", "2045"}], ",", 
       RowBox[{"2314", "\[Rule]", "2299"}], ",", 
       RowBox[{"2314", "\[Rule]", "2327"}], ",", 
       RowBox[{"2314", "\[Rule]", "2315"}], ",", 
       RowBox[{"2314", "\[Rule]", "2311"}], ",", 
       RowBox[{"2220", "\[Rule]", "2205"}], ",", 
       RowBox[{"2220", "\[Rule]", "2233"}], ",", 
       RowBox[{"2220", "\[Rule]", "2221"}], ",", 
       RowBox[{"2220", "\[Rule]", "2217"}], ",", 
       RowBox[{"2126", "\[Rule]", "2111"}], ",", 
       RowBox[{"2126", "\[Rule]", "2139"}], ",", 
       RowBox[{"2126", "\[Rule]", "2127"}], ",", 
       RowBox[{"2126", "\[Rule]", "2123"}], ",", 
       RowBox[{"2032", "\[Rule]", "2017"}], ",", 
       RowBox[{"2032", "\[Rule]", "2045"}], ",", 
       RowBox[{"2032", "\[Rule]", "2033"}], ",", 
       RowBox[{"2032", "\[Rule]", "2029"}], ",", 
       RowBox[{"2342", "\[Rule]", "2327"}], ",", 
       RowBox[{"2342", "\[Rule]", "2343"}], ",", 
       RowBox[{"2342", "\[Rule]", "2339"}], ",", 
       RowBox[{"2248", "\[Rule]", "2233"}], ",", 
       RowBox[{"2248", "\[Rule]", "2249"}], ",", 
       RowBox[{"2248", "\[Rule]", "2245"}], ",", 
       RowBox[{"2154", "\[Rule]", "2139"}], ",", 
       RowBox[{"2154", "\[Rule]", "2155"}], ",", 
       RowBox[{"2154", "\[Rule]", "2151"}], ",", 
       RowBox[{"2060", "\[Rule]", "2045"}], ",", 
       RowBox[{"2060", "\[Rule]", "2061"}], ",", 
       RowBox[{"2060", "\[Rule]", "2057"}], ",", 
       RowBox[{"2326", "\[Rule]", "2311"}], ",", 
       RowBox[{"2326", "\[Rule]", "2339"}], ",", 
       RowBox[{"2326", "\[Rule]", "2327"}], ",", 
       RowBox[{"2326", "\[Rule]", "2323"}], ",", 
       RowBox[{"2232", "\[Rule]", "2217"}], ",", 
       RowBox[{"2232", "\[Rule]", "2245"}], ",", 
       RowBox[{"2232", "\[Rule]", "2233"}], ",", 
       RowBox[{"2232", "\[Rule]", "2229"}], ",", 
       RowBox[{"2138", "\[Rule]", "2123"}], ",", 
       RowBox[{"2138", "\[Rule]", "2151"}], ",", 
       RowBox[{"2138", "\[Rule]", "2139"}], ",", 
       RowBox[{"2138", "\[Rule]", "2135"}], ",", 
       RowBox[{"2044", "\[Rule]", "2029"}], ",", 
       RowBox[{"2044", "\[Rule]", "2057"}], ",", 
       RowBox[{"2044", "\[Rule]", "2045"}], ",", 
       RowBox[{"2044", "\[Rule]", "2041"}], ",", 
       RowBox[{"646", "\[Rule]", "631"}], ",", 
       RowBox[{"646", "\[Rule]", "647"}], ",", 
       RowBox[{"364", "\[Rule]", "349"}], ",", 
       RowBox[{"364", "\[Rule]", "365"}], ",", 
       RowBox[{"1304", "\[Rule]", "1289"}], ",", 
       RowBox[{"1304", "\[Rule]", "1305"}], ",", 
       RowBox[{"1022", "\[Rule]", "1007"}], ",", 
       RowBox[{"1022", "\[Rule]", "1023"}], ",", 
       RowBox[{"552", "\[Rule]", "537"}], ",", 
       RowBox[{"552", "\[Rule]", "553"}], ",", 
       RowBox[{"270", "\[Rule]", "255"}], ",", 
       RowBox[{"270", "\[Rule]", "271"}], ",", 
       RowBox[{"1210", "\[Rule]", "1195"}], ",", 
       RowBox[{"1210", "\[Rule]", "1211"}], ",", 
       RowBox[{"928", "\[Rule]", "913"}], ",", 
       RowBox[{"928", "\[Rule]", "929"}], ",", 
       RowBox[{"458", "\[Rule]", "443"}], ",", 
       RowBox[{"458", "\[Rule]", "459"}], ",", 
       RowBox[{"176", "\[Rule]", "161"}], ",", 
       RowBox[{"176", "\[Rule]", "177"}], ",", 
       RowBox[{"1116", "\[Rule]", "1101"}], ",", 
       RowBox[{"1116", "\[Rule]", "1117"}], ",", 
       RowBox[{"834", "\[Rule]", "819"}], ",", 
       RowBox[{"834", "\[Rule]", "835"}], ",", 
       RowBox[{"1962", "\[Rule]", "1947"}], ",", 
       RowBox[{"1962", "\[Rule]", "1963"}], ",", 
       RowBox[{"1680", "\[Rule]", "1665"}], ",", 
       RowBox[{"1680", "\[Rule]", "1681"}], ",", 
       RowBox[{"1868", "\[Rule]", "1853"}], ",", 
       RowBox[{"1868", "\[Rule]", "1869"}], ",", 
       RowBox[{"1586", "\[Rule]", "1571"}], ",", 
       RowBox[{"1586", "\[Rule]", "1587"}], ",", 
       RowBox[{"1774", "\[Rule]", "1759"}], ",", 
       RowBox[{"1774", "\[Rule]", "1775"}], ",", 
       RowBox[{"1492", "\[Rule]", "1477"}], ",", 
       RowBox[{"1492", "\[Rule]", "1493"}], ",", 
       RowBox[{"82", "\[Rule]", "67"}], ",", 
       RowBox[{"82", "\[Rule]", "83"}], ",", 
       RowBox[{"740", "\[Rule]", "725"}], ",", 
       RowBox[{"740", "\[Rule]", "741"}], ",", 
       RowBox[{"1398", "\[Rule]", "1383"}], ",", 
       RowBox[{"1398", "\[Rule]", "1399"}], ",", 
       RowBox[{"2338", "\[Rule]", "2323"}], ",", 
       RowBox[{"2338", "\[Rule]", "2339"}], ",", 
       RowBox[{"2244", "\[Rule]", "2229"}], ",", 
       RowBox[{"2244", "\[Rule]", "2245"}], ",", 
       RowBox[{"2150", "\[Rule]", "2135"}], ",", 
       RowBox[{"2150", "\[Rule]", "2151"}], ",", 
       RowBox[{"2056", "\[Rule]", "2041"}], ",", 
       RowBox[{"2056", "\[Rule]", "2057"}], ",", 
       RowBox[{"575", "\[Rule]", "294"}], ",", 
       RowBox[{"575", "\[Rule]", "952"}], ",", 
       RowBox[{"575", "\[Rule]", "952"}], ",", 
       RowBox[{"575", "\[Rule]", "200"}], ",", 
       RowBox[{"575", "\[Rule]", "858"}], ",", 
       RowBox[{"575", "\[Rule]", "858"}], ",", 
       RowBox[{"575", "\[Rule]", "576"}], ",", 
       RowBox[{"307", "\[Rule]", "590"}], ",", 
       RowBox[{"307", "\[Rule]", "308"}], ",", 
       RowBox[{"293", "\[Rule]", "576"}], ",", 
       RowBox[{"293", "\[Rule]", "294"}], ",", 
       RowBox[{"333", "\[Rule]", "616"}], ",", 
       RowBox[{"333", "\[Rule]", "616"}], ",", 
       RowBox[{"333", "\[Rule]", "334"}], ",", 
       RowBox[{"319", "\[Rule]", "602"}], ",", 
       RowBox[{"319", "\[Rule]", "602"}], ",", 
       RowBox[{"319", "\[Rule]", "320"}], ",", 
       RowBox[{"585", "\[Rule]", "304"}], ",", 
       RowBox[{"585", "\[Rule]", "304"}], ",", 
       RowBox[{"585", "\[Rule]", "962"}], ",", 
       RowBox[{"585", "\[Rule]", "962"}], ",", 
       RowBox[{"585", "\[Rule]", "210"}], ",", 
       RowBox[{"585", "\[Rule]", "868"}], ",", 
       RowBox[{"585", "\[Rule]", "586"}], ",", 
       RowBox[{"303", "\[Rule]", "586"}], ",", 
       RowBox[{"303", "\[Rule]", "586"}], ",", 
       RowBox[{"303", "\[Rule]", "304"}], ",", 
       RowBox[{"1233", "\[Rule]", "952"}], ",", 
       RowBox[{"1233", "\[Rule]", "952"}], ",", 
       RowBox[{"1233", "\[Rule]", "1610"}], ",", 
       RowBox[{"1233", "\[Rule]", "1610"}], ",", 
       RowBox[{"1233", "\[Rule]", "858"}], ",", 
       RowBox[{"1233", "\[Rule]", "858"}], ",", 
       RowBox[{"1233", "\[Rule]", "1516"}], ",", 
       RowBox[{"1233", "\[Rule]", "1516"}], ",", 
       RowBox[{"1233", "\[Rule]", "1234"}], ",", 
       RowBox[{"965", "\[Rule]", "590"}], ",", 
       RowBox[{"965", "\[Rule]", "1248"}], ",", 
       RowBox[{"965", "\[Rule]", "1248"}], ",", 
       RowBox[{"965", "\[Rule]", "966"}], ",", 
       RowBox[{"951", "\[Rule]", "576"}], ",", 
       RowBox[{"951", "\[Rule]", "576"}], ",", 
       RowBox[{"951", "\[Rule]", "1234"}], ",", 
       RowBox[{"951", "\[Rule]", "1234"}], ",", 
       RowBox[{"951", "\[Rule]", "952"}], ",", 
       RowBox[{"991", "\[Rule]", "616"}], ",", 
       RowBox[{"991", "\[Rule]", "616"}], ",", 
       RowBox[{"991", "\[Rule]", "1274"}], ",", 
       RowBox[{"991", "\[Rule]", "992"}], ",", 
       RowBox[{"977", "\[Rule]", "602"}], ",", 
       RowBox[{"977", "\[Rule]", "1260"}], ",", 
       RowBox[{"977", "\[Rule]", "978"}], ",", 
       RowBox[{"1243", "\[Rule]", "962"}], ",", 
       RowBox[{"1243", "\[Rule]", "962"}], ",", 
       RowBox[{"1243", "\[Rule]", "1620"}], ",", 
       RowBox[{"1243", "\[Rule]", "1620"}], ",", 
       RowBox[{"1243", "\[Rule]", "868"}], ",", 
       RowBox[{"1243", "\[Rule]", "868"}], ",", 
       RowBox[{"1243", "\[Rule]", "1526"}], ",", 
       RowBox[{"1243", "\[Rule]", "1526"}], ",", 
       RowBox[{"1243", "\[Rule]", "1244"}], ",", 
       RowBox[{"961", "\[Rule]", "586"}], ",", 
       RowBox[{"961", "\[Rule]", "586"}], ",", 
       RowBox[{"961", "\[Rule]", "1244"}], ",", 
       RowBox[{"961", "\[Rule]", "1244"}], ",", 
       RowBox[{"961", "\[Rule]", "962"}], ",", 
       RowBox[{"481", "\[Rule]", "200"}], ",", 
       RowBox[{"481", "\[Rule]", "200"}], ",", 
       RowBox[{"481", "\[Rule]", "858"}], ",", 
       RowBox[{"481", "\[Rule]", "858"}], ",", 
       RowBox[{"481", "\[Rule]", "106"}], ",", 
       RowBox[{"481", "\[Rule]", "764"}], ",", 
       RowBox[{"481", "\[Rule]", "482"}], ",", 
       RowBox[{"199", "\[Rule]", "576"}], ",", 
       RowBox[{"199", "\[Rule]", "482"}], ",", 
       RowBox[{"199", "\[Rule]", "482"}], ",", 
       RowBox[{"199", "\[Rule]", "200"}], ",", 
       RowBox[{"491", "\[Rule]", "210"}], ",", 
       RowBox[{"491", "\[Rule]", "868"}], ",", 
       RowBox[{"491", "\[Rule]", "116"}], ",", 
       RowBox[{"491", "\[Rule]", "774"}], ",", 
       RowBox[{"491", "\[Rule]", "492"}], ",", 
       RowBox[{"209", "\[Rule]", "586"}], ",", 
       RowBox[{"209", "\[Rule]", "492"}], ",", 
       RowBox[{"209", "\[Rule]", "210"}], ",", 
       RowBox[{"1139", "\[Rule]", "858"}], ",", 
       RowBox[{"1139", "\[Rule]", "858"}], ",", 
       RowBox[{"1139", "\[Rule]", "1516"}], ",", 
       RowBox[{"1139", "\[Rule]", "1516"}], ",", 
       RowBox[{"1139", "\[Rule]", "764"}], ",", 
       RowBox[{"1139", "\[Rule]", "764"}], ",", 
       RowBox[{"1139", "\[Rule]", "1422"}], ",", 
       RowBox[{"1139", "\[Rule]", "1422"}], ",", 
       RowBox[{"1139", "\[Rule]", "1140"}], ",", 
       RowBox[{"857", "\[Rule]", "576"}], ",", 
       RowBox[{"857", "\[Rule]", "576"}], ",", 
       RowBox[{"857", "\[Rule]", "1234"}], ",", 
       RowBox[{"857", "\[Rule]", "1234"}], ",", 
       RowBox[{"857", "\[Rule]", "482"}], ",", 
       RowBox[{"857", "\[Rule]", "482"}], ",", 
       RowBox[{"857", "\[Rule]", "1140"}], ",", 
       RowBox[{"857", "\[Rule]", "1140"}], ",", 
       RowBox[{"857", "\[Rule]", "858"}], ",", 
       RowBox[{"1149", "\[Rule]", "868"}], ",", 
       RowBox[{"1149", "\[Rule]", "868"}], ",", 
       RowBox[{"1149", "\[Rule]", "1526"}], ",", 
       RowBox[{"1149", "\[Rule]", "1526"}], ",", 
       RowBox[{"1149", "\[Rule]", "774"}], ",", 
       RowBox[{"1149", "\[Rule]", "774"}], ",", 
       RowBox[{"1149", "\[Rule]", "1432"}], ",", 
       RowBox[{"1149", "\[Rule]", "1432"}], ",", 
       RowBox[{"1149", "\[Rule]", "1150"}], ",", 
       RowBox[{"867", "\[Rule]", "586"}], ",", 
       RowBox[{"867", "\[Rule]", "1244"}], ",", 
       RowBox[{"867", "\[Rule]", "1244"}], ",", 
       RowBox[{"867", "\[Rule]", "492"}], ",", 
       RowBox[{"867", "\[Rule]", "1150"}], ",", 
       RowBox[{"867", "\[Rule]", "1150"}], ",", 
       RowBox[{"867", "\[Rule]", "868"}], ",", 
       RowBox[{"361", "\[Rule]", "644"}], ",", 
       RowBox[{"361", "\[Rule]", "644"}], ",", 
       RowBox[{"361", "\[Rule]", "362"}], ",", 
       RowBox[{"345", "\[Rule]", "628"}], ",", 
       RowBox[{"345", "\[Rule]", "628"}], ",", 
       RowBox[{"345", "\[Rule]", "346"}], ",", 
       RowBox[{"329", "\[Rule]", "612"}], ",", 
       RowBox[{"329", "\[Rule]", "612"}], ",", 
       RowBox[{"329", "\[Rule]", "330"}], ",", 
       RowBox[{"1019", "\[Rule]", "644"}], ",", 
       RowBox[{"1019", "\[Rule]", "644"}], ",", 
       RowBox[{"1019", "\[Rule]", "1302"}], ",", 
       RowBox[{"1019", "\[Rule]", "1302"}], ",", 
       RowBox[{"1019", "\[Rule]", "1020"}], ",", 
       RowBox[{"1003", "\[Rule]", "628"}], ",", 
       RowBox[{"1003", "\[Rule]", "628"}], ",", 
       RowBox[{"1003", "\[Rule]", "1286"}], ",", 
       RowBox[{"1003", "\[Rule]", "1286"}], ",", 
       RowBox[{"1003", "\[Rule]", "1004"}], ",", 
       RowBox[{"987", "\[Rule]", "612"}], ",", 
       RowBox[{"987", "\[Rule]", "612"}], ",", 
       RowBox[{"987", "\[Rule]", "1270"}], ",", 
       RowBox[{"987", "\[Rule]", "1270"}], ",", 
       RowBox[{"987", "\[Rule]", "988"}], ",", 
       RowBox[{"597", "\[Rule]", "316"}], ",", 
       RowBox[{"597", "\[Rule]", "316"}], ",", 
       RowBox[{"597", "\[Rule]", "974"}], ",", 
       RowBox[{"597", "\[Rule]", "974"}], ",", 
       RowBox[{"597", "\[Rule]", "222"}], ",", 
       RowBox[{"597", "\[Rule]", "222"}], ",", 
       RowBox[{"597", "\[Rule]", "880"}], ",", 
       RowBox[{"597", "\[Rule]", "880"}], ",", 
       RowBox[{"597", "\[Rule]", "598"}], ",", 
       RowBox[{"315", "\[Rule]", "598"}], ",", 
       RowBox[{"315", "\[Rule]", "598"}], ",", 
       RowBox[{"315", "\[Rule]", "316"}], ",", 
       RowBox[{"1255", "\[Rule]", "974"}], ",", 
       RowBox[{"1255", "\[Rule]", "974"}], ",", 
       RowBox[{"1255", "\[Rule]", "1632"}], ",", 
       RowBox[{"1255", "\[Rule]", "1632"}], ",", 
       RowBox[{"1255", "\[Rule]", "880"}], ",", 
       RowBox[{"1255", "\[Rule]", "880"}], ",", 
       RowBox[{"1255", "\[Rule]", "1538"}], ",", 
       RowBox[{"1255", "\[Rule]", "1538"}], ",", 
       RowBox[{"1255", "\[Rule]", "1256"}], ",", 
       RowBox[{"973", "\[Rule]", "598"}], ",", 
       RowBox[{"973", "\[Rule]", "598"}], ",", 
       RowBox[{"973", "\[Rule]", "1256"}], ",", 
       RowBox[{"973", "\[Rule]", "1256"}], ",", 
       RowBox[{"973", "\[Rule]", "974"}], ",", 
       RowBox[{"503", "\[Rule]", "222"}], ",", 
       RowBox[{"503", "\[Rule]", "222"}], ",", 
       RowBox[{"503", "\[Rule]", "880"}], ",", 
       RowBox[{"503", "\[Rule]", "128"}], ",", 
       RowBox[{"503", "\[Rule]", "504"}], ",", 
       RowBox[{"221", "\[Rule]", "598"}], ",", 
       RowBox[{"221", "\[Rule]", "598"}], ",", 
       RowBox[{"221", "\[Rule]", "504"}], ",", 
       RowBox[{"221", "\[Rule]", "504"}], ",", 
       RowBox[{"221", "\[Rule]", "222"}], ",", 
       RowBox[{"1161", "\[Rule]", "880"}], ",", 
       RowBox[{"1161", "\[Rule]", "1538"}], ",", 
       RowBox[{"1161", "\[Rule]", "1538"}], ",", 
       RowBox[{"1161", "\[Rule]", "786"}], ",", 
       RowBox[{"1161", "\[Rule]", "1444"}], ",", 
       RowBox[{"1161", "\[Rule]", "1444"}], ",", 
       RowBox[{"1161", "\[Rule]", "1162"}], ",", 
       RowBox[{"879", "\[Rule]", "598"}], ",", 
       RowBox[{"879", "\[Rule]", "598"}], ",", 
       RowBox[{"879", "\[Rule]", "1256"}], ",", 
       RowBox[{"879", "\[Rule]", "1256"}], ",", 
       RowBox[{"879", "\[Rule]", "504"}], ",", 
       RowBox[{"879", "\[Rule]", "1162"}], ",", 
       RowBox[{"879", "\[Rule]", "880"}], ",", 
       RowBox[{"387", "\[Rule]", "106"}], ",", 
       RowBox[{"387", "\[Rule]", "764"}], ",", 
       RowBox[{"387", "\[Rule]", "12"}], ",", 
       RowBox[{"387", "\[Rule]", "12"}], ",", 
       RowBox[{"387", "\[Rule]", "670"}], ",", 
       RowBox[{"387", "\[Rule]", "670"}], ",", 
       RowBox[{"387", "\[Rule]", "388"}], ",", 
       RowBox[{"105", "\[Rule]", "482"}], ",", 
       RowBox[{"105", "\[Rule]", "388"}], ",", 
       RowBox[{"105", "\[Rule]", "106"}], ",", 
       RowBox[{"397", "\[Rule]", "116"}], ",", 
       RowBox[{"397", "\[Rule]", "774"}], ",", 
       RowBox[{"397", "\[Rule]", "22"}], ",", 
       RowBox[{"397", "\[Rule]", "22"}], ",", 
       RowBox[{"397", "\[Rule]", "680"}], ",", 
       RowBox[{"397", "\[Rule]", "680"}], ",", 
       RowBox[{"397", "\[Rule]", "398"}], ",", 
       RowBox[{"115", "\[Rule]", "492"}], ",", 
       RowBox[{"115", "\[Rule]", "398"}], ",", 
       RowBox[{"115", "\[Rule]", "116"}], ",", 
       RowBox[{"1045", "\[Rule]", "764"}], ",", 
       RowBox[{"1045", "\[Rule]", "764"}], ",", 
       RowBox[{"1045", "\[Rule]", "1422"}], ",", 
       RowBox[{"1045", "\[Rule]", "1422"}], ",", 
       RowBox[{"1045", "\[Rule]", "670"}], ",", 
       RowBox[{"1045", "\[Rule]", "1328"}], ",", 
       RowBox[{"1045", "\[Rule]", "1046"}], ",", 
       RowBox[{"763", "\[Rule]", "482"}], ",", 
       RowBox[{"763", "\[Rule]", "1140"}], ",", 
       RowBox[{"763", "\[Rule]", "1140"}], ",", 
       RowBox[{"763", "\[Rule]", "388"}], ",", 
       RowBox[{"763", "\[Rule]", "1046"}], ",", 
       RowBox[{"763", "\[Rule]", "1046"}], ",", 
       RowBox[{"763", "\[Rule]", "764"}], ",", 
       RowBox[{"1055", "\[Rule]", "774"}], ",", 
       RowBox[{"1055", "\[Rule]", "774"}], ",", 
       RowBox[{"1055", "\[Rule]", "1432"}], ",", 
       RowBox[{"1055", "\[Rule]", "1432"}], ",", 
       RowBox[{"1055", "\[Rule]", "680"}], ",", 
       RowBox[{"1055", "\[Rule]", "1338"}], ",", 
       RowBox[{"1055", "\[Rule]", "1056"}], ",", 
       RowBox[{"773", "\[Rule]", "492"}], ",", 
       RowBox[{"773", "\[Rule]", "1150"}], ",", 
       RowBox[{"773", "\[Rule]", "1150"}], ",", 
       RowBox[{"773", "\[Rule]", "398"}], ",", 
       RowBox[{"773", "\[Rule]", "1056"}], ",", 
       RowBox[{"773", "\[Rule]", "1056"}], ",", 
       RowBox[{"773", "\[Rule]", "774"}], ",", 
       RowBox[{"409", "\[Rule]", "128"}], ",", 
       RowBox[{"409", "\[Rule]", "786"}], ",", 
       RowBox[{"409", "\[Rule]", "34"}], ",", 
       RowBox[{"409", "\[Rule]", "34"}], ",", 
       RowBox[{"409", "\[Rule]", "692"}], ",", 
       RowBox[{"409", "\[Rule]", "692"}], ",", 
       RowBox[{"409", "\[Rule]", "410"}], ",", 
       RowBox[{"127", "\[Rule]", "504"}], ",", 
       RowBox[{"127", "\[Rule]", "410"}], ",", 
       RowBox[{"127", "\[Rule]", "128"}], ",", 
       RowBox[{"1067", "\[Rule]", "786"}], ",", 
       RowBox[{"1067", "\[Rule]", "786"}], ",", 
       RowBox[{"1067", "\[Rule]", "1444"}], ",", 
       RowBox[{"1067", "\[Rule]", "1444"}], ",", 
       RowBox[{"1067", "\[Rule]", "692"}], ",", 
       RowBox[{"1067", "\[Rule]", "1350"}], ",", 
       RowBox[{"1067", "\[Rule]", "1068"}], ",", 
       RowBox[{"785", "\[Rule]", "1162"}], ",", 
       RowBox[{"785", "\[Rule]", "410"}], ",", 
       RowBox[{"785", "\[Rule]", "1068"}], ",", 
       RowBox[{"785", "\[Rule]", "1068"}], ",", 
       RowBox[{"785", "\[Rule]", "786"}], ",", 
       RowBox[{"373", "\[Rule]", "656"}], ",", 
       RowBox[{"373", "\[Rule]", "656"}], ",", 
       RowBox[{"373", "\[Rule]", "374"}], ",", 
       RowBox[{"357", "\[Rule]", "640"}], ",", 
       RowBox[{"357", "\[Rule]", "640"}], ",", 
       RowBox[{"357", "\[Rule]", "358"}], ",", 
       RowBox[{"1031", "\[Rule]", "656"}], ",", 
       RowBox[{"1031", "\[Rule]", "656"}], ",", 
       RowBox[{"1031", "\[Rule]", "1314"}], ",", 
       RowBox[{"1031", "\[Rule]", "1314"}], ",", 
       RowBox[{"1031", "\[Rule]", "1032"}], ",", 
       RowBox[{"1015", "\[Rule]", "640"}], ",", 
       RowBox[{"1015", "\[Rule]", "640"}], ",", 
       RowBox[{"1015", "\[Rule]", "1298"}], ",", 
       RowBox[{"1015", "\[Rule]", "1298"}], ",", 
       RowBox[{"1015", "\[Rule]", "1016"}], ",", 
       RowBox[{"341", "\[Rule]", "624"}], ",", 
       RowBox[{"341", "\[Rule]", "624"}], ",", 
       RowBox[{"341", "\[Rule]", "342"}], ",", 
       RowBox[{"999", "\[Rule]", "624"}], ",", 
       RowBox[{"999", "\[Rule]", "624"}], ",", 
       RowBox[{"999", "\[Rule]", "1282"}], ",", 
       RowBox[{"999", "\[Rule]", "1282"}], ",", 
       RowBox[{"999", "\[Rule]", "1000"}], ",", 
       RowBox[{"607", "\[Rule]", "326"}], ",", 
       RowBox[{"607", "\[Rule]", "326"}], ",", 
       RowBox[{"607", "\[Rule]", "984"}], ",", 
       RowBox[{"607", "\[Rule]", "984"}], ",", 
       RowBox[{"607", "\[Rule]", "232"}], ",", 
       RowBox[{"607", "\[Rule]", "232"}], ",", 
       RowBox[{"607", "\[Rule]", "890"}], ",", 
       RowBox[{"607", "\[Rule]", "890"}], ",", 
       RowBox[{"607", "\[Rule]", "608"}], ",", 
       RowBox[{"325", "\[Rule]", "608"}], ",", 
       RowBox[{"325", "\[Rule]", "608"}], ",", 
       RowBox[{"325", "\[Rule]", "326"}], ",", 
       RowBox[{"1265", "\[Rule]", "984"}], ",", 
       RowBox[{"1265", "\[Rule]", "984"}], ",", 
       RowBox[{"1265", "\[Rule]", "1642"}], ",", 
       RowBox[{"1265", "\[Rule]", "1642"}], ",", 
       RowBox[{"1265", "\[Rule]", "890"}], ",", 
       RowBox[{"1265", "\[Rule]", "890"}], ",", 
       RowBox[{"1265", "\[Rule]", "1548"}], ",", 
       RowBox[{"1265", "\[Rule]", "1548"}], ",", 
       RowBox[{"1265", "\[Rule]", "1266"}], ",", 
       RowBox[{"983", "\[Rule]", "608"}], ",", 
       RowBox[{"983", "\[Rule]", "608"}], ",", 
       RowBox[{"983", "\[Rule]", "1266"}], ",", 
       RowBox[{"983", "\[Rule]", "1266"}], ",", 
       RowBox[{"983", "\[Rule]", "984"}], ",", 
       RowBox[{"513", "\[Rule]", "232"}], ",", 
       RowBox[{"513", "\[Rule]", "232"}], ",", 
       RowBox[{"513", "\[Rule]", "890"}], ",", 
       RowBox[{"513", "\[Rule]", "890"}], ",", 
       RowBox[{"513", "\[Rule]", "138"}], ",", 
       RowBox[{"513", "\[Rule]", "796"}], ",", 
       RowBox[{"513", "\[Rule]", "514"}], ",", 
       RowBox[{"231", "\[Rule]", "608"}], ",", 
       RowBox[{"231", "\[Rule]", "608"}], ",", 
       RowBox[{"231", "\[Rule]", "514"}], ",", 
       RowBox[{"231", "\[Rule]", "514"}], ",", 
       RowBox[{"231", "\[Rule]", "232"}], ",", 
       RowBox[{"1171", "\[Rule]", "890"}], ",", 
       RowBox[{"1171", "\[Rule]", "890"}], ",", 
       RowBox[{"1171", "\[Rule]", "1548"}], ",", 
       RowBox[{"1171", "\[Rule]", "1548"}], ",", 
       RowBox[{"1171", "\[Rule]", "796"}], ",", 
       RowBox[{"1171", "\[Rule]", "1454"}], ",", 
       RowBox[{"1171", "\[Rule]", "1172"}], ",", 
       RowBox[{"889", "\[Rule]", "608"}], ",", 
       RowBox[{"889", "\[Rule]", "608"}], ",", 
       RowBox[{"889", "\[Rule]", "1266"}], ",", 
       RowBox[{"889", "\[Rule]", "1266"}], ",", 
       RowBox[{"889", "\[Rule]", "514"}], ",", 
       RowBox[{"889", "\[Rule]", "514"}], ",", 
       RowBox[{"889", "\[Rule]", "1172"}], ",", 
       RowBox[{"889", "\[Rule]", "1172"}], ",", 
       RowBox[{"889", "\[Rule]", "890"}], ",", 
       RowBox[{"419", "\[Rule]", "138"}], ",", 
       RowBox[{"419", "\[Rule]", "796"}], ",", 
       RowBox[{"419", "\[Rule]", "44"}], ",", 
       RowBox[{"419", "\[Rule]", "44"}], ",", 
       RowBox[{"419", "\[Rule]", "702"}], ",", 
       RowBox[{"419", "\[Rule]", "702"}], ",", 
       RowBox[{"419", "\[Rule]", "420"}], ",", 
       RowBox[{"137", "\[Rule]", "514"}], ",", 
       RowBox[{"137", "\[Rule]", "420"}], ",", 
       RowBox[{"137", "\[Rule]", "138"}], ",", 
       RowBox[{"1077", "\[Rule]", "796"}], ",", 
       RowBox[{"1077", "\[Rule]", "1454"}], ",", 
       RowBox[{"1077", "\[Rule]", "702"}], ",", 
       RowBox[{"1077", "\[Rule]", "1360"}], ",", 
       RowBox[{"1077", "\[Rule]", "1078"}], ",", 
       RowBox[{"795", "\[Rule]", "514"}], ",", 
       RowBox[{"795", "\[Rule]", "1172"}], ",", 
       RowBox[{"795", "\[Rule]", "420"}], ",", 
       RowBox[{"795", "\[Rule]", "1078"}], ",", 
       RowBox[{"795", "\[Rule]", "796"}], ",", 
       RowBox[{"1891", "\[Rule]", "1610"}], ",", 
       RowBox[{"1891", "\[Rule]", "1610"}], ",", 
       RowBox[{"1891", "\[Rule]", "2268"}], ",", 
       RowBox[{"1891", "\[Rule]", "2268"}], ",", 
       RowBox[{"1891", "\[Rule]", "1516"}], ",", 
       RowBox[{"1891", "\[Rule]", "1516"}], ",", 
       RowBox[{"1891", "\[Rule]", "2174"}], ",", 
       RowBox[{"1891", "\[Rule]", "2174"}], ",", 
       RowBox[{"1891", "\[Rule]", "1892"}], ",", 
       RowBox[{"1623", "\[Rule]", "1248"}], ",", 
       RowBox[{"1623", "\[Rule]", "1248"}], ",", 
       RowBox[{"1623", "\[Rule]", "1906"}], ",", 
       RowBox[{"1623", "\[Rule]", "1906"}], ",", 
       RowBox[{"1623", "\[Rule]", "1624"}], ",", 
       RowBox[{"1609", "\[Rule]", "1234"}], ",", 
       RowBox[{"1609", "\[Rule]", "1234"}], ",", 
       RowBox[{"1609", "\[Rule]", "1892"}], ",", 
       RowBox[{"1609", "\[Rule]", "1892"}], ",", 
       RowBox[{"1609", "\[Rule]", "1610"}], ",", 
       RowBox[{"1649", "\[Rule]", "1274"}], ",", 
       RowBox[{"1649", "\[Rule]", "1932"}], ",", 
       RowBox[{"1649", "\[Rule]", "1932"}], ",", 
       RowBox[{"1649", "\[Rule]", "1650"}], ",", 
       RowBox[{"1635", "\[Rule]", "1260"}], ",", 
       RowBox[{"1635", "\[Rule]", "1260"}], ",", 
       RowBox[{"1635", "\[Rule]", "1918"}], ",", 
       RowBox[{"1635", "\[Rule]", "1918"}], ",", 
       RowBox[{"1635", "\[Rule]", "1636"}], ",", 
       RowBox[{"1901", "\[Rule]", "1620"}], ",", 
       RowBox[{"1901", "\[Rule]", "1620"}], ",", 
       RowBox[{"1901", "\[Rule]", "2278"}], ",", 
       RowBox[{"1901", "\[Rule]", "2278"}], ",", 
       RowBox[{"1901", "\[Rule]", "1526"}], ",", 
       RowBox[{"1901", "\[Rule]", "1526"}], ",", 
       RowBox[{"1901", "\[Rule]", "2184"}], ",", 
       RowBox[{"1901", "\[Rule]", "2184"}], ",", 
       RowBox[{"1901", "\[Rule]", "1902"}], ",", 
       RowBox[{"1619", "\[Rule]", "1244"}], ",", 
       RowBox[{"1619", "\[Rule]", "1244"}], ",", 
       RowBox[{"1619", "\[Rule]", "1902"}], ",", 
       RowBox[{"1619", "\[Rule]", "1902"}], ",", 
       RowBox[{"1619", "\[Rule]", "1620"}], ",", 
       RowBox[{"1797", "\[Rule]", "1516"}], ",", 
       RowBox[{"1797", "\[Rule]", "1516"}], ",", 
       RowBox[{"1797", "\[Rule]", "2174"}], ",", 
       RowBox[{"1797", "\[Rule]", "2174"}], ",", 
       RowBox[{"1797", "\[Rule]", "1422"}], ",", 
       RowBox[{"1797", "\[Rule]", "1422"}], ",", 
       RowBox[{"1797", "\[Rule]", "2080"}], ",", 
       RowBox[{"1797", "\[Rule]", "2080"}], ",", 
       RowBox[{"1797", "\[Rule]", "1798"}], ",", 
       RowBox[{"1515", "\[Rule]", "1234"}], ",", 
       RowBox[{"1515", "\[Rule]", "1234"}], ",", 
       RowBox[{"1515", "\[Rule]", "1892"}], ",", 
       RowBox[{"1515", "\[Rule]", "1892"}], ",", 
       RowBox[{"1515", "\[Rule]", "1140"}], ",", 
       RowBox[{"1515", "\[Rule]", "1140"}], ",", 
       RowBox[{"1515", "\[Rule]", "1798"}], ",", 
       RowBox[{"1515", "\[Rule]", "1798"}], ",", 
       RowBox[{"1515", "\[Rule]", "1516"}], ",", 
       RowBox[{"1807", "\[Rule]", "1526"}], ",", 
       RowBox[{"1807", "\[Rule]", "1526"}], ",", 
       RowBox[{"1807", "\[Rule]", "2184"}], ",", 
       RowBox[{"1807", "\[Rule]", "2184"}], ",", 
       RowBox[{"1807", "\[Rule]", "1432"}], ",", 
       RowBox[{"1807", "\[Rule]", "1432"}], ",", 
       RowBox[{"1807", "\[Rule]", "2090"}], ",", 
       RowBox[{"1807", "\[Rule]", "2090"}], ",", 
       RowBox[{"1807", "\[Rule]", "1808"}], ",", 
       RowBox[{"1525", "\[Rule]", "1244"}], ",", 
       RowBox[{"1525", "\[Rule]", "1244"}], ",", 
       RowBox[{"1525", "\[Rule]", "1902"}], ",", 
       RowBox[{"1525", "\[Rule]", "1902"}], ",", 
       RowBox[{"1525", "\[Rule]", "1150"}], ",", 
       RowBox[{"1525", "\[Rule]", "1150"}], ",", 
       RowBox[{"1525", "\[Rule]", "1808"}], ",", 
       RowBox[{"1525", "\[Rule]", "1808"}], ",", 
       RowBox[{"1525", "\[Rule]", "1526"}], ",", 
       RowBox[{"1677", "\[Rule]", "1302"}], ",", 
       RowBox[{"1677", "\[Rule]", "1302"}], ",", 
       RowBox[{"1677", "\[Rule]", "1960"}], ",", 
       RowBox[{"1677", "\[Rule]", "1678"}], ",", 
       RowBox[{"1661", "\[Rule]", "1286"}], ",", 
       RowBox[{"1661", "\[Rule]", "1944"}], ",", 
       RowBox[{"1661", "\[Rule]", "1662"}], ",", 
       RowBox[{"1645", "\[Rule]", "1270"}], ",", 
       RowBox[{"1645", "\[Rule]", "1270"}], ",", 
       RowBox[{"1645", "\[Rule]", "1928"}], ",", 
       RowBox[{"1645", "\[Rule]", "1928"}], ",", 
       RowBox[{"1645", "\[Rule]", "1646"}], ",", 
       RowBox[{"1913", "\[Rule]", "1632"}], ",", 
       RowBox[{"1913", "\[Rule]", "1632"}], ",", 
       RowBox[{"1913", "\[Rule]", "2290"}], ",", 
       RowBox[{"1913", "\[Rule]", "2290"}], ",", 
       RowBox[{"1913", "\[Rule]", "1538"}], ",", 
       RowBox[{"1913", "\[Rule]", "1538"}], ",", 
       RowBox[{"1913", "\[Rule]", "2196"}], ",", 
       RowBox[{"1913", "\[Rule]", "2196"}], ",", 
       RowBox[{"1913", "\[Rule]", "1914"}], ",", 
       RowBox[{"1631", "\[Rule]", "1256"}], ",", 
       RowBox[{"1631", "\[Rule]", "1256"}], ",", 
       RowBox[{"1631", "\[Rule]", "1914"}], ",", 
       RowBox[{"1631", "\[Rule]", "1914"}], ",", 
       RowBox[{"1631", "\[Rule]", "1632"}], ",", 
       RowBox[{"1819", "\[Rule]", "1538"}], ",", 
       RowBox[{"1819", "\[Rule]", "1538"}], ",", 
       RowBox[{"1819", "\[Rule]", "2196"}], ",", 
       RowBox[{"1819", "\[Rule]", "2196"}], ",", 
       RowBox[{"1819", "\[Rule]", "1444"}], ",", 
       RowBox[{"1819", "\[Rule]", "1444"}], ",", 
       RowBox[{"1819", "\[Rule]", "2102"}], ",", 
       RowBox[{"1819", "\[Rule]", "2102"}], ",", 
       RowBox[{"1819", "\[Rule]", "1820"}], ",", 
       RowBox[{"1537", "\[Rule]", "1256"}], ",", 
       RowBox[{"1537", "\[Rule]", "1256"}], ",", 
       RowBox[{"1537", "\[Rule]", "1914"}], ",", 
       RowBox[{"1537", "\[Rule]", "1914"}], ",", 
       RowBox[{"1537", "\[Rule]", "1162"}], ",", 
       RowBox[{"1537", "\[Rule]", "1162"}], ",", 
       RowBox[{"1537", "\[Rule]", "1820"}], ",", 
       RowBox[{"1537", "\[Rule]", "1820"}], ",", 
       RowBox[{"1537", "\[Rule]", "1538"}], ",", 
       RowBox[{"1703", "\[Rule]", "1422"}], ",", 
       RowBox[{"1703", "\[Rule]", "1422"}], ",", 
       RowBox[{"1703", "\[Rule]", "2080"}], ",", 
       RowBox[{"1703", "\[Rule]", "2080"}], ",", 
       RowBox[{"1703", "\[Rule]", "1328"}], ",", 
       RowBox[{"1703", "\[Rule]", "1328"}], ",", 
       RowBox[{"1703", "\[Rule]", "1986"}], ",", 
       RowBox[{"1703", "\[Rule]", "1986"}], ",", 
       RowBox[{"1703", "\[Rule]", "1704"}], ",", 
       RowBox[{"1421", "\[Rule]", "1140"}], ",", 
       RowBox[{"1421", "\[Rule]", "1140"}], ",", 
       RowBox[{"1421", "\[Rule]", "1798"}], ",", 
       RowBox[{"1421", "\[Rule]", "1798"}], ",", 
       RowBox[{"1421", "\[Rule]", "1046"}], ",", 
       RowBox[{"1421", "\[Rule]", "1046"}], ",", 
       RowBox[{"1421", "\[Rule]", "1704"}], ",", 
       RowBox[{"1421", "\[Rule]", "1704"}], ",", 
       RowBox[{"1421", "\[Rule]", "1422"}], ",", 
       RowBox[{"1713", "\[Rule]", "1432"}], ",", 
       RowBox[{"1713", "\[Rule]", "1432"}], ",", 
       RowBox[{"1713", "\[Rule]", "2090"}], ",", 
       RowBox[{"1713", "\[Rule]", "2090"}], ",", 
       RowBox[{"1713", "\[Rule]", "1338"}], ",", 
       RowBox[{"1713", "\[Rule]", "1338"}], ",", 
       RowBox[{"1713", "\[Rule]", "1996"}], ",", 
       RowBox[{"1713", "\[Rule]", "1996"}], ",", 
       RowBox[{"1713", "\[Rule]", "1714"}], ",", 
       RowBox[{"1431", "\[Rule]", "1150"}], ",", 
       RowBox[{"1431", "\[Rule]", "1150"}], ",", 
       RowBox[{"1431", "\[Rule]", "1808"}], ",", 
       RowBox[{"1431", "\[Rule]", "1808"}], ",", 
       RowBox[{"1431", "\[Rule]", "1056"}], ",", 
       RowBox[{"1431", "\[Rule]", "1056"}], ",", 
       RowBox[{"1431", "\[Rule]", "1714"}], ",", 
       RowBox[{"1431", "\[Rule]", "1714"}], ",", 
       RowBox[{"1431", "\[Rule]", "1432"}], ",", 
       RowBox[{"1725", "\[Rule]", "1444"}], ",", 
       RowBox[{"1725", "\[Rule]", "1444"}], ",", 
       RowBox[{"1725", "\[Rule]", "2102"}], ",", 
       RowBox[{"1725", "\[Rule]", "2102"}], ",", 
       RowBox[{"1725", "\[Rule]", "1350"}], ",", 
       RowBox[{"1725", "\[Rule]", "1350"}], ",", 
       RowBox[{"1725", "\[Rule]", "2008"}], ",", 
       RowBox[{"1725", "\[Rule]", "2008"}], ",", 
       RowBox[{"1725", "\[Rule]", "1726"}], ",", 
       RowBox[{"1443", "\[Rule]", "1162"}], ",", 
       RowBox[{"1443", "\[Rule]", "1162"}], ",", 
       RowBox[{"1443", "\[Rule]", "1820"}], ",", 
       RowBox[{"1443", "\[Rule]", "1820"}], ",", 
       RowBox[{"1443", "\[Rule]", "1068"}], ",", 
       RowBox[{"1443", "\[Rule]", "1068"}], ",", 
       RowBox[{"1443", "\[Rule]", "1726"}], ",", 
       RowBox[{"1443", "\[Rule]", "1726"}], ",", 
       RowBox[{"1443", "\[Rule]", "1444"}], ",", 
       RowBox[{"1689", "\[Rule]", "1314"}], ",", 
       RowBox[{"1689", "\[Rule]", "1314"}], ",", 
       RowBox[{"1689", "\[Rule]", "1972"}], ",", 
       RowBox[{"1689", "\[Rule]", "1972"}], ",", 
       RowBox[{"1689", "\[Rule]", "1690"}], ",", 
       RowBox[{"1673", "\[Rule]", "1298"}], ",", 
       RowBox[{"1673", "\[Rule]", "1298"}], ",", 
       RowBox[{"1673", "\[Rule]", "1956"}], ",", 
       RowBox[{"1673", "\[Rule]", "1956"}], ",", 
       RowBox[{"1673", "\[Rule]", "1674"}], ",", 
       RowBox[{"1657", "\[Rule]", "1282"}], ",", 
       RowBox[{"1657", "\[Rule]", "1282"}], ",", 
       RowBox[{"1657", "\[Rule]", "1940"}], ",", 
       RowBox[{"1657", "\[Rule]", "1940"}], ",", 
       RowBox[{"1657", "\[Rule]", "1658"}], ",", 
       RowBox[{"1923", "\[Rule]", "1642"}], ",", 
       RowBox[{"1923", "\[Rule]", "1642"}], ",", 
       RowBox[{"1923", "\[Rule]", "2300"}], ",", 
       RowBox[{"1923", "\[Rule]", "2300"}], ",", 
       RowBox[{"1923", "\[Rule]", "1548"}], ",", 
       RowBox[{"1923", "\[Rule]", "1548"}], ",", 
       RowBox[{"1923", "\[Rule]", "2206"}], ",", 
       RowBox[{"1923", "\[Rule]", "2206"}], ",", 
       RowBox[{"1923", "\[Rule]", "1924"}], ",", 
       RowBox[{"1641", "\[Rule]", "1266"}], ",", 
       RowBox[{"1641", "\[Rule]", "1266"}], ",", 
       RowBox[{"1641", "\[Rule]", "1924"}], ",", 
       RowBox[{"1641", "\[Rule]", "1924"}], ",", 
       RowBox[{"1641", "\[Rule]", "1642"}], ",", 
       RowBox[{"1829", "\[Rule]", "1548"}], ",", 
       RowBox[{"1829", "\[Rule]", "1548"}], ",", 
       RowBox[{"1829", "\[Rule]", "2206"}], ",", 
       RowBox[{"1829", "\[Rule]", "2206"}], ",", 
       RowBox[{"1829", "\[Rule]", "1454"}], ",", 
       RowBox[{"1829", "\[Rule]", "1454"}], ",", 
       RowBox[{"1829", "\[Rule]", "2112"}], ",", 
       RowBox[{"1829", "\[Rule]", "2112"}], ",", 
       RowBox[{"1829", "\[Rule]", "1830"}], ",", 
       RowBox[{"1547", "\[Rule]", "1266"}], ",", 
       RowBox[{"1547", "\[Rule]", "1266"}], ",", 
       RowBox[{"1547", "\[Rule]", "1924"}], ",", 
       RowBox[{"1547", "\[Rule]", "1924"}], ",", 
       RowBox[{"1547", "\[Rule]", "1172"}], ",", 
       RowBox[{"1547", "\[Rule]", "1172"}], ",", 
       RowBox[{"1547", "\[Rule]", "1830"}], ",", 
       RowBox[{"1547", "\[Rule]", "1830"}], ",", 
       RowBox[{"1547", "\[Rule]", "1548"}], ",", 
       RowBox[{"1735", "\[Rule]", "1454"}], ",", 
       RowBox[{"1735", "\[Rule]", "1454"}], ",", 
       RowBox[{"1735", "\[Rule]", "2112"}], ",", 
       RowBox[{"1735", "\[Rule]", "2112"}], ",", 
       RowBox[{"1735", "\[Rule]", "1360"}], ",", 
       RowBox[{"1735", "\[Rule]", "1360"}], ",", 
       RowBox[{"1735", "\[Rule]", "2018"}], ",", 
       RowBox[{"1735", "\[Rule]", "2018"}], ",", 
       RowBox[{"1735", "\[Rule]", "1736"}], ",", 
       RowBox[{"1453", "\[Rule]", "1172"}], ",", 
       RowBox[{"1453", "\[Rule]", "1830"}], ",", 
       RowBox[{"1453", "\[Rule]", "1830"}], ",", 
       RowBox[{"1453", "\[Rule]", "1078"}], ",", 
       RowBox[{"1453", "\[Rule]", "1736"}], ",", 
       RowBox[{"1453", "\[Rule]", "1736"}], ",", 
       RowBox[{"1453", "\[Rule]", "1454"}], ",", 
       RowBox[{"11", "\[Rule]", "388"}], ",", 
       RowBox[{"11", "\[Rule]", "388"}], ",", 
       RowBox[{"11", "\[Rule]", "12"}], ",", 
       RowBox[{"21", "\[Rule]", "398"}], ",", 
       RowBox[{"21", "\[Rule]", "398"}], ",", 
       RowBox[{"21", "\[Rule]", "22"}], ",", 
       RowBox[{"669", "\[Rule]", "388"}], ",", 
       RowBox[{"669", "\[Rule]", "388"}], ",", 
       RowBox[{"669", "\[Rule]", "1046"}], ",", 
       RowBox[{"669", "\[Rule]", "670"}], ",", 
       RowBox[{"679", "\[Rule]", "398"}], ",", 
       RowBox[{"679", "\[Rule]", "398"}], ",", 
       RowBox[{"679", "\[Rule]", "1056"}], ",", 
       RowBox[{"679", "\[Rule]", "680"}], ",", 
       RowBox[{"33", "\[Rule]", "410"}], ",", 
       RowBox[{"33", "\[Rule]", "410"}], ",", 
       RowBox[{"33", "\[Rule]", "34"}], ",", 
       RowBox[{"691", "\[Rule]", "410"}], ",", 
       RowBox[{"691", "\[Rule]", "410"}], ",", 
       RowBox[{"691", "\[Rule]", "1068"}], ",", 
       RowBox[{"691", "\[Rule]", "692"}], ",", 
       RowBox[{"43", "\[Rule]", "420"}], ",", 
       RowBox[{"43", "\[Rule]", "420"}], ",", 
       RowBox[{"43", "\[Rule]", "44"}], ",", 
       RowBox[{"701", "\[Rule]", "420"}], ",", 
       RowBox[{"701", "\[Rule]", "420"}], ",", 
       RowBox[{"701", "\[Rule]", "1078"}], ",", 
       RowBox[{"701", "\[Rule]", "702"}], ",", 
       RowBox[{"1327", "\[Rule]", "1046"}], ",", 
       RowBox[{"1327", "\[Rule]", "1704"}], ",", 
       RowBox[{"1327", "\[Rule]", "1704"}], ",", 
       RowBox[{"1327", "\[Rule]", "1328"}], ",", 
       RowBox[{"1337", "\[Rule]", "1056"}], ",", 
       RowBox[{"1337", "\[Rule]", "1714"}], ",", 
       RowBox[{"1337", "\[Rule]", "1714"}], ",", 
       RowBox[{"1337", "\[Rule]", "1338"}], ",", 
       RowBox[{"1349", "\[Rule]", "1068"}], ",", 
       RowBox[{"1349", "\[Rule]", "1726"}], ",", 
       RowBox[{"1349", "\[Rule]", "1726"}], ",", 
       RowBox[{"1349", "\[Rule]", "1350"}], ",", 
       RowBox[{"1359", "\[Rule]", "1078"}], ",", 
       RowBox[{"1359", "\[Rule]", "1736"}], ",", 
       RowBox[{"1359", "\[Rule]", "1736"}], ",", 
       RowBox[{"1359", "\[Rule]", "1360"}], ",", 
       RowBox[{"369", "\[Rule]", "652"}], ",", 
       RowBox[{"369", "\[Rule]", "652"}], ",", 
       RowBox[{"369", "\[Rule]", "370"}], ",", 
       RowBox[{"1027", "\[Rule]", "652"}], ",", 
       RowBox[{"1027", "\[Rule]", "652"}], ",", 
       RowBox[{"1027", "\[Rule]", "1310"}], ",", 
       RowBox[{"1027", "\[Rule]", "1310"}], ",", 
       RowBox[{"1027", "\[Rule]", "1028"}], ",", 
       RowBox[{"353", "\[Rule]", "636"}], ",", 
       RowBox[{"353", "\[Rule]", "636"}], ",", 
       RowBox[{"353", "\[Rule]", "354"}], ",", 
       RowBox[{"1011", "\[Rule]", "636"}], ",", 
       RowBox[{"1011", "\[Rule]", "636"}], ",", 
       RowBox[{"1011", "\[Rule]", "1294"}], ",", 
       RowBox[{"1011", "\[Rule]", "1294"}], ",", 
       RowBox[{"1011", "\[Rule]", "1012"}], ",", 
       RowBox[{"1685", "\[Rule]", "1310"}], ",", 
       RowBox[{"1685", "\[Rule]", "1310"}], ",", 
       RowBox[{"1685", "\[Rule]", "1968"}], ",", 
       RowBox[{"1685", "\[Rule]", "1968"}], ",", 
       RowBox[{"1685", "\[Rule]", "1686"}], ",", 
       RowBox[{"1669", "\[Rule]", "1294"}], ",", 
       RowBox[{"1669", "\[Rule]", "1294"}], ",", 
       RowBox[{"1669", "\[Rule]", "1952"}], ",", 
       RowBox[{"1669", "\[Rule]", "1952"}], ",", 
       RowBox[{"1669", "\[Rule]", "1670"}], ",", 
       RowBox[{"619", "\[Rule]", "338"}], ",", 
       RowBox[{"619", "\[Rule]", "338"}], ",", 
       RowBox[{"619", "\[Rule]", "996"}], ",", 
       RowBox[{"619", "\[Rule]", "996"}], ",", 
       RowBox[{"619", "\[Rule]", "244"}], ",", 
       RowBox[{"619", "\[Rule]", "244"}], ",", 
       RowBox[{"619", "\[Rule]", "902"}], ",", 
       RowBox[{"619", "\[Rule]", "902"}], ",", 
       RowBox[{"619", "\[Rule]", "620"}], ",", 
       RowBox[{"337", "\[Rule]", "620"}], ",", 
       RowBox[{"337", "\[Rule]", "620"}], ",", 
       RowBox[{"337", "\[Rule]", "338"}], ",", 
       RowBox[{"1277", "\[Rule]", "996"}], ",", 
       RowBox[{"1277", "\[Rule]", "996"}], ",", 
       RowBox[{"1277", "\[Rule]", "1654"}], ",", 
       RowBox[{"1277", "\[Rule]", "1654"}], ",", 
       RowBox[{"1277", "\[Rule]", "902"}], ",", 
       RowBox[{"1277", "\[Rule]", "902"}], ",", 
       RowBox[{"1277", "\[Rule]", "1560"}], ",", 
       RowBox[{"1277", "\[Rule]", "1560"}], ",", 
       RowBox[{"1277", "\[Rule]", "1278"}], ",", 
       RowBox[{"995", "\[Rule]", "620"}], ",", 
       RowBox[{"995", "\[Rule]", "620"}], ",", 
       RowBox[{"995", "\[Rule]", "1278"}], ",", 
       RowBox[{"995", "\[Rule]", "1278"}], ",", 
       RowBox[{"995", "\[Rule]", "996"}], ",", 
       RowBox[{"525", "\[Rule]", "244"}], ",", 
       RowBox[{"525", "\[Rule]", "244"}], ",", 
       RowBox[{"525", "\[Rule]", "902"}], ",", 
       RowBox[{"525", "\[Rule]", "902"}], ",", 
       RowBox[{"525", "\[Rule]", "150"}], ",", 
       RowBox[{"525", "\[Rule]", "808"}], ",", 
       RowBox[{"525", "\[Rule]", "526"}], ",", 
       RowBox[{"243", "\[Rule]", "620"}], ",", 
       RowBox[{"243", "\[Rule]", "620"}], ",", 
       RowBox[{"243", "\[Rule]", "526"}], ",", 
       RowBox[{"243", "\[Rule]", "526"}], ",", 
       RowBox[{"243", "\[Rule]", "244"}], ",", 
       RowBox[{"1183", "\[Rule]", "902"}], ",", 
       RowBox[{"1183", "\[Rule]", "902"}], ",", 
       RowBox[{"1183", "\[Rule]", "1560"}], ",", 
       RowBox[{"1183", "\[Rule]", "1560"}], ",", 
       RowBox[{"1183", "\[Rule]", "808"}], ",", 
       RowBox[{"1183", "\[Rule]", "808"}], ",", 
       RowBox[{"1183", "\[Rule]", "1466"}], ",", 
       RowBox[{"1183", "\[Rule]", "1466"}], ",", 
       RowBox[{"1183", "\[Rule]", "1184"}], ",", 
       RowBox[{"901", "\[Rule]", "620"}], ",", 
       RowBox[{"901", "\[Rule]", "620"}], ",", 
       RowBox[{"901", "\[Rule]", "1278"}], ",", 
       RowBox[{"901", "\[Rule]", "1278"}], ",", 
       RowBox[{"901", "\[Rule]", "526"}], ",", 
       RowBox[{"901", "\[Rule]", "526"}], ",", 
       RowBox[{"901", "\[Rule]", "1184"}], ",", 
       RowBox[{"901", "\[Rule]", "1184"}], ",", 
       RowBox[{"901", "\[Rule]", "902"}], ",", 
       RowBox[{"431", "\[Rule]", "150"}], ",", 
       RowBox[{"431", "\[Rule]", "808"}], ",", 
       RowBox[{"431", "\[Rule]", "56"}], ",", 
       RowBox[{"431", "\[Rule]", "56"}], ",", 
       RowBox[{"431", "\[Rule]", "714"}], ",", 
       RowBox[{"431", "\[Rule]", "714"}], ",", 
       RowBox[{"431", "\[Rule]", "432"}], ",", 
       RowBox[{"149", "\[Rule]", "526"}], ",", 
       RowBox[{"149", "\[Rule]", "432"}], ",", 
       RowBox[{"149", "\[Rule]", "150"}], ",", 
       RowBox[{"1089", "\[Rule]", "808"}], ",", 
       RowBox[{"1089", "\[Rule]", "808"}], ",", 
       RowBox[{"1089", "\[Rule]", "1466"}], ",", 
       RowBox[{"1089", "\[Rule]", "714"}], ",", 
       RowBox[{"1089", "\[Rule]", "1090"}], ",", 
       RowBox[{"807", "\[Rule]", "526"}], ",", 
       RowBox[{"807", "\[Rule]", "1184"}], ",", 
       RowBox[{"807", "\[Rule]", "1184"}], ",", 
       RowBox[{"807", "\[Rule]", "432"}], ",", 
       RowBox[{"807", "\[Rule]", "1090"}], ",", 
       RowBox[{"807", "\[Rule]", "1090"}], ",", 
       RowBox[{"807", "\[Rule]", "808"}], ",", 
       RowBox[{"1935", "\[Rule]", "1654"}], ",", 
       RowBox[{"1935", "\[Rule]", "1654"}], ",", 
       RowBox[{"1935", "\[Rule]", "2312"}], ",", 
       RowBox[{"1935", "\[Rule]", "2312"}], ",", 
       RowBox[{"1935", "\[Rule]", "1560"}], ",", 
       RowBox[{"1935", "\[Rule]", "1560"}], ",", 
       RowBox[{"1935", "\[Rule]", "2218"}], ",", 
       RowBox[{"1935", "\[Rule]", "2218"}], ",", 
       RowBox[{"1935", "\[Rule]", "1936"}], ",", 
       RowBox[{"1653", "\[Rule]", "1278"}], ",", 
       RowBox[{"1653", "\[Rule]", "1278"}], ",", 
       RowBox[{"1653", "\[Rule]", "1936"}], ",", 
       RowBox[{"1653", "\[Rule]", "1936"}], ",", 
       RowBox[{"1653", "\[Rule]", "1654"}], ",", 
       RowBox[{"1841", "\[Rule]", "1560"}], ",", 
       RowBox[{"1841", "\[Rule]", "1560"}], ",", 
       RowBox[{"1841", "\[Rule]", "2218"}], ",", 
       RowBox[{"1841", "\[Rule]", "2218"}], ",", 
       RowBox[{"1841", "\[Rule]", "1466"}], ",", 
       RowBox[{"1841", "\[Rule]", "1466"}], ",", 
       RowBox[{"1841", "\[Rule]", "2124"}], ",", 
       RowBox[{"1841", "\[Rule]", "2124"}], ",", 
       RowBox[{"1841", "\[Rule]", "1842"}], ",", 
       RowBox[{"1559", "\[Rule]", "1278"}], ",", 
       RowBox[{"1559", "\[Rule]", "1278"}], ",", 
       RowBox[{"1559", "\[Rule]", "1936"}], ",", 
       RowBox[{"1559", "\[Rule]", "1936"}], ",", 
       RowBox[{"1559", "\[Rule]", "1184"}], ",", 
       RowBox[{"1559", "\[Rule]", "1184"}], ",", 
       RowBox[{"1559", "\[Rule]", "1842"}], ",", 
       RowBox[{"1559", "\[Rule]", "1842"}], ",", 
       RowBox[{"1559", "\[Rule]", "1560"}], ",", 
       RowBox[{"1747", "\[Rule]", "1466"}], ",", 
       RowBox[{"1747", "\[Rule]", "2124"}], ",", 
       RowBox[{"1747", "\[Rule]", "2124"}], ",", 
       RowBox[{"1747", "\[Rule]", "1372"}], ",", 
       RowBox[{"1747", "\[Rule]", "2030"}], ",", 
       RowBox[{"1747", "\[Rule]", "2030"}], ",", 
       RowBox[{"1747", "\[Rule]", "1748"}], ",", 
       RowBox[{"1465", "\[Rule]", "1184"}], ",", 
       RowBox[{"1465", "\[Rule]", "1184"}], ",", 
       RowBox[{"1465", "\[Rule]", "1842"}], ",", 
       RowBox[{"1465", "\[Rule]", "1842"}], ",", 
       RowBox[{"1465", "\[Rule]", "1090"}], ",", 
       RowBox[{"1465", "\[Rule]", "1748"}], ",", 
       RowBox[{"1465", "\[Rule]", "1466"}], ",", 
       RowBox[{"55", "\[Rule]", "432"}], ",", 
       RowBox[{"55", "\[Rule]", "432"}], ",", 
       RowBox[{"55", "\[Rule]", "56"}], ",", 
       RowBox[{"713", "\[Rule]", "432"}], ",", 
       RowBox[{"713", "\[Rule]", "432"}], ",", 
       RowBox[{"713", "\[Rule]", "1090"}], ",", 
       RowBox[{"713", "\[Rule]", "714"}], ",", 
       RowBox[{"1371", "\[Rule]", "1748"}], ",", 
       RowBox[{"1371", "\[Rule]", "1372"}], ",", 
       RowBox[{"365", "\[Rule]", "648"}], ",", 
       RowBox[{"365", "\[Rule]", "648"}], ",", 
       RowBox[{"365", "\[Rule]", "366"}], ",", 
       RowBox[{"1023", "\[Rule]", "648"}], ",", 
       RowBox[{"1023", "\[Rule]", "648"}], ",", 
       RowBox[{"1023", "\[Rule]", "1306"}], ",", 
       RowBox[{"1023", "\[Rule]", "1306"}], ",", 
       RowBox[{"1023", "\[Rule]", "1024"}], ",", 
       RowBox[{"1681", "\[Rule]", "1306"}], ",", 
       RowBox[{"1681", "\[Rule]", "1306"}], ",", 
       RowBox[{"1681", "\[Rule]", "1964"}], ",", 
       RowBox[{"1681", "\[Rule]", "1964"}], ",", 
       RowBox[{"1681", "\[Rule]", "1682"}], ",", 
       RowBox[{"631", "\[Rule]", "350"}], ",", 
       RowBox[{"631", "\[Rule]", "350"}], ",", 
       RowBox[{"631", "\[Rule]", "1008"}], ",", 
       RowBox[{"631", "\[Rule]", "1008"}], ",", 
       RowBox[{"631", "\[Rule]", "256"}], ",", 
       RowBox[{"631", "\[Rule]", "256"}], ",", 
       RowBox[{"631", "\[Rule]", "914"}], ",", 
       RowBox[{"631", "\[Rule]", "914"}], ",", 
       RowBox[{"631", "\[Rule]", "632"}], ",", 
       RowBox[{"349", "\[Rule]", "632"}], ",", 
       RowBox[{"349", "\[Rule]", "632"}], ",", 
       RowBox[{"349", "\[Rule]", "350"}], ",", 
       RowBox[{"1289", "\[Rule]", "1008"}], ",", 
       RowBox[{"1289", "\[Rule]", "1008"}], ",", 
       RowBox[{"1289", "\[Rule]", "1666"}], ",", 
       RowBox[{"1289", "\[Rule]", "1666"}], ",", 
       RowBox[{"1289", "\[Rule]", "914"}], ",", 
       RowBox[{"1289", "\[Rule]", "914"}], ",", 
       RowBox[{"1289", "\[Rule]", "1572"}], ",", 
       RowBox[{"1289", "\[Rule]", "1572"}], ",", 
       RowBox[{"1289", "\[Rule]", "1290"}], ",", 
       RowBox[{"1007", "\[Rule]", "632"}], ",", 
       RowBox[{"1007", "\[Rule]", "632"}], ",", 
       RowBox[{"1007", "\[Rule]", "1290"}], ",", 
       RowBox[{"1007", "\[Rule]", "1290"}], ",", 
       RowBox[{"1007", "\[Rule]", "1008"}], ",", 
       RowBox[{"537", "\[Rule]", "256"}], ",", 
       RowBox[{"537", "\[Rule]", "256"}], ",", 
       RowBox[{"537", "\[Rule]", "914"}], ",", 
       RowBox[{"537", "\[Rule]", "914"}], ",", 
       RowBox[{"537", "\[Rule]", "162"}], ",", 
       RowBox[{"537", "\[Rule]", "820"}], ",", 
       RowBox[{"537", "\[Rule]", "538"}], ",", 
       RowBox[{"255", "\[Rule]", "632"}], ",", 
       RowBox[{"255", "\[Rule]", "632"}], ",", 
       RowBox[{"255", "\[Rule]", "538"}], ",", 
       RowBox[{"255", "\[Rule]", "538"}], ",", 
       RowBox[{"255", "\[Rule]", "256"}], ",", 
       RowBox[{"1195", "\[Rule]", "914"}], ",", 
       RowBox[{"1195", "\[Rule]", "914"}], ",", 
       RowBox[{"1195", "\[Rule]", "1572"}], ",", 
       RowBox[{"1195", "\[Rule]", "1572"}], ",", 
       RowBox[{"1195", "\[Rule]", "820"}], ",", 
       RowBox[{"1195", "\[Rule]", "820"}], ",", 
       RowBox[{"1195", "\[Rule]", "1478"}], ",", 
       RowBox[{"1195", "\[Rule]", "1478"}], ",", 
       RowBox[{"1195", "\[Rule]", "1196"}], ",", 
       RowBox[{"913", "\[Rule]", "632"}], ",", 
       RowBox[{"913", "\[Rule]", "632"}], ",", 
       RowBox[{"913", "\[Rule]", "1290"}], ",", 
       RowBox[{"913", "\[Rule]", "1290"}], ",", 
       RowBox[{"913", "\[Rule]", "538"}], ",", 
       RowBox[{"913", "\[Rule]", "538"}], ",", 
       RowBox[{"913", "\[Rule]", "1196"}], ",", 
       RowBox[{"913", "\[Rule]", "1196"}], ",", 
       RowBox[{"913", "\[Rule]", "914"}], ",", 
       RowBox[{"443", "\[Rule]", "162"}], ",", 
       RowBox[{"443", "\[Rule]", "820"}], ",", 
       RowBox[{"443", "\[Rule]", "68"}], ",", 
       RowBox[{"443", "\[Rule]", "68"}], ",", 
       RowBox[{"443", "\[Rule]", "726"}], ",", 
       RowBox[{"443", "\[Rule]", "726"}], ",", 
       RowBox[{"443", "\[Rule]", "444"}], ",", 
       RowBox[{"161", "\[Rule]", "538"}], ",", 
       RowBox[{"161", "\[Rule]", "444"}], ",", 
       RowBox[{"161", "\[Rule]", "162"}], ",", 
       RowBox[{"1101", "\[Rule]", "820"}], ",", 
       RowBox[{"1101", "\[Rule]", "820"}], ",", 
       RowBox[{"1101", "\[Rule]", "1478"}], ",", 
       RowBox[{"1101", "\[Rule]", "1478"}], ",", 
       RowBox[{"1101", "\[Rule]", "726"}], ",", 
       RowBox[{"1101", "\[Rule]", "1384"}], ",", 
       RowBox[{"1101", "\[Rule]", "1102"}], ",", 
       RowBox[{"819", "\[Rule]", "538"}], ",", 
       RowBox[{"819", "\[Rule]", "1196"}], ",", 
       RowBox[{"819", "\[Rule]", "1196"}], ",", 
       RowBox[{"819", "\[Rule]", "444"}], ",", 
       RowBox[{"819", "\[Rule]", "1102"}], ",", 
       RowBox[{"819", "\[Rule]", "1102"}], ",", 
       RowBox[{"819", "\[Rule]", "820"}], ",", 
       RowBox[{"1947", "\[Rule]", "1666"}], ",", 
       RowBox[{"1947", "\[Rule]", "1666"}], ",", 
       RowBox[{"1947", "\[Rule]", "2324"}], ",", 
       RowBox[{"1947", "\[Rule]", "2324"}], ",", 
       RowBox[{"1947", "\[Rule]", "1572"}], ",", 
       RowBox[{"1947", "\[Rule]", "1572"}], ",", 
       RowBox[{"1947", "\[Rule]", "2230"}], ",", 
       RowBox[{"1947", "\[Rule]", "2230"}], ",", 
       RowBox[{"1947", "\[Rule]", "1948"}], ",", 
       RowBox[{"1665", "\[Rule]", "1290"}], ",", 
       RowBox[{"1665", "\[Rule]", "1290"}], ",", 
       RowBox[{"1665", "\[Rule]", "1948"}], ",", 
       RowBox[{"1665", "\[Rule]", "1948"}], ",", 
       RowBox[{"1665", "\[Rule]", "1666"}], ",", 
       RowBox[{"1853", "\[Rule]", "1572"}], ",", 
       RowBox[{"1853", "\[Rule]", "1572"}], ",", 
       RowBox[{"1853", "\[Rule]", "2230"}], ",", 
       RowBox[{"1853", "\[Rule]", "2230"}], ",", 
       RowBox[{"1853", "\[Rule]", "1478"}], ",", 
       RowBox[{"1853", "\[Rule]", "1478"}], ",", 
       RowBox[{"1853", "\[Rule]", "2136"}], ",", 
       RowBox[{"1853", "\[Rule]", "2136"}], ",", 
       RowBox[{"1853", "\[Rule]", "1854"}], ",", 
       RowBox[{"1571", "\[Rule]", "1290"}], ",", 
       RowBox[{"1571", "\[Rule]", "1290"}], ",", 
       RowBox[{"1571", "\[Rule]", "1948"}], ",", 
       RowBox[{"1571", "\[Rule]", "1948"}], ",", 
       RowBox[{"1571", "\[Rule]", "1196"}], ",", 
       RowBox[{"1571", "\[Rule]", "1196"}], ",", 
       RowBox[{"1571", "\[Rule]", "1854"}], ",", 
       RowBox[{"1571", "\[Rule]", "1854"}], ",", 
       RowBox[{"1571", "\[Rule]", "1572"}], ",", 
       RowBox[{"1759", "\[Rule]", "1478"}], ",", 
       RowBox[{"1759", "\[Rule]", "1478"}], ",", 
       RowBox[{"1759", "\[Rule]", "2136"}], ",", 
       RowBox[{"1759", "\[Rule]", "2136"}], ",", 
       RowBox[{"1759", "\[Rule]", "1384"}], ",", 
       RowBox[{"1759", "\[Rule]", "2042"}], ",", 
       RowBox[{"1759", "\[Rule]", "1760"}], ",", 
       RowBox[{"1477", "\[Rule]", "1196"}], ",", 
       RowBox[{"1477", "\[Rule]", "1196"}], ",", 
       RowBox[{"1477", "\[Rule]", "1854"}], ",", 
       RowBox[{"1477", "\[Rule]", "1854"}], ",", 
       RowBox[{"1477", "\[Rule]", "1102"}], ",", 
       RowBox[{"1477", "\[Rule]", "1102"}], ",", 
       RowBox[{"1477", "\[Rule]", "1760"}], ",", 
       RowBox[{"1477", "\[Rule]", "1760"}], ",", 
       RowBox[{"1477", "\[Rule]", "1478"}], ",", 
       RowBox[{"67", "\[Rule]", "444"}], ",", 
       RowBox[{"67", "\[Rule]", "444"}], ",", 
       RowBox[{"67", "\[Rule]", "68"}], ",", 
       RowBox[{"725", "\[Rule]", "444"}], ",", 
       RowBox[{"725", "\[Rule]", "444"}], ",", 
       RowBox[{"725", "\[Rule]", "1102"}], ",", 
       RowBox[{"725", "\[Rule]", "726"}], ",", 
       RowBox[{"1383", "\[Rule]", "1102"}], ",", 
       RowBox[{"1383", "\[Rule]", "1760"}], ",", 
       RowBox[{"1383", "\[Rule]", "1384"}], ",", 
       RowBox[{"2281", "\[Rule]", "1906"}], ",", 
       RowBox[{"2281", "\[Rule]", "1906"}], ",", 
       RowBox[{"2281", "\[Rule]", "2282"}], ",", 
       RowBox[{"2267", "\[Rule]", "1892"}], ",", 
       RowBox[{"2267", "\[Rule]", "1892"}], ",", 
       RowBox[{"2267", "\[Rule]", "2268"}], ",", 
       RowBox[{"2307", "\[Rule]", "1932"}], ",", 
       RowBox[{"2307", "\[Rule]", "1932"}], ",", 
       RowBox[{"2307", "\[Rule]", "2308"}], ",", 
       RowBox[{"2293", "\[Rule]", "1918"}], ",", 
       RowBox[{"2293", "\[Rule]", "1918"}], ",", 
       RowBox[{"2293", "\[Rule]", "2294"}], ",", 
       RowBox[{"2277", "\[Rule]", "1902"}], ",", 
       RowBox[{"2277", "\[Rule]", "1902"}], ",", 
       RowBox[{"2277", "\[Rule]", "2278"}], ",", 
       RowBox[{"2187", "\[Rule]", "1906"}], ",", 
       RowBox[{"2187", "\[Rule]", "1906"}], ",", 
       RowBox[{"2187", "\[Rule]", "1812"}], ",", 
       RowBox[{"2187", "\[Rule]", "1812"}], ",", 
       RowBox[{"2187", "\[Rule]", "2188"}], ",", 
       RowBox[{"2173", "\[Rule]", "1892"}], ",", 
       RowBox[{"2173", "\[Rule]", "1892"}], ",", 
       RowBox[{"2173", "\[Rule]", "1798"}], ",", 
       RowBox[{"2173", "\[Rule]", "1798"}], ",", 
       RowBox[{"2173", "\[Rule]", "2174"}], ",", 
       RowBox[{"2213", "\[Rule]", "1932"}], ",", 
       RowBox[{"2213", "\[Rule]", "1932"}], ",", 
       RowBox[{"2213", "\[Rule]", "1838"}], ",", 
       RowBox[{"2213", "\[Rule]", "1838"}], ",", 
       RowBox[{"2213", "\[Rule]", "2214"}], ",", 
       RowBox[{"2199", "\[Rule]", "1918"}], ",", 
       RowBox[{"2199", "\[Rule]", "1918"}], ",", 
       RowBox[{"2199", "\[Rule]", "1824"}], ",", 
       RowBox[{"2199", "\[Rule]", "1824"}], ",", 
       RowBox[{"2199", "\[Rule]", "2200"}], ",", 
       RowBox[{"2183", "\[Rule]", "1902"}], ",", 
       RowBox[{"2183", "\[Rule]", "1902"}], ",", 
       RowBox[{"2183", "\[Rule]", "1808"}], ",", 
       RowBox[{"2183", "\[Rule]", "1808"}], ",", 
       RowBox[{"2183", "\[Rule]", "2184"}], ",", 
       RowBox[{"2335", "\[Rule]", "1960"}], ",", 
       RowBox[{"2335", "\[Rule]", "2336"}], ",", 
       RowBox[{"2319", "\[Rule]", "1944"}], ",", 
       RowBox[{"2319", "\[Rule]", "1944"}], ",", 
       RowBox[{"2319", "\[Rule]", "2320"}], ",", 
       RowBox[{"2303", "\[Rule]", "1928"}], ",", 
       RowBox[{"2303", "\[Rule]", "1928"}], ",", 
       RowBox[{"2303", "\[Rule]", "2304"}], ",", 
       RowBox[{"2241", "\[Rule]", "1960"}], ",", 
       RowBox[{"2241", "\[Rule]", "1960"}], ",", 
       RowBox[{"2241", "\[Rule]", "1866"}], ",", 
       RowBox[{"2241", "\[Rule]", "1866"}], ",", 
       RowBox[{"2241", "\[Rule]", "2242"}], ",", 
       RowBox[{"2225", "\[Rule]", "1944"}], ",", 
       RowBox[{"2225", "\[Rule]", "1944"}], ",", 
       RowBox[{"2225", "\[Rule]", "1850"}], ",", 
       RowBox[{"2225", "\[Rule]", "1850"}], ",", 
       RowBox[{"2225", "\[Rule]", "2226"}], ",", 
       RowBox[{"2209", "\[Rule]", "1928"}], ",", 
       RowBox[{"2209", "\[Rule]", "1928"}], ",", 
       RowBox[{"2209", "\[Rule]", "1834"}], ",", 
       RowBox[{"2209", "\[Rule]", "1834"}], ",", 
       RowBox[{"2209", "\[Rule]", "2210"}], ",", 
       RowBox[{"2289", "\[Rule]", "1914"}], ",", 
       RowBox[{"2289", "\[Rule]", "1914"}], ",", 
       RowBox[{"2289", "\[Rule]", "2290"}], ",", 
       RowBox[{"2195", "\[Rule]", "1914"}], ",", 
       RowBox[{"2195", "\[Rule]", "1914"}], ",", 
       RowBox[{"2195", "\[Rule]", "1820"}], ",", 
       RowBox[{"2195", "\[Rule]", "1820"}], ",", 
       RowBox[{"2195", "\[Rule]", "2196"}], ",", 
       RowBox[{"2093", "\[Rule]", "1812"}], ",", 
       RowBox[{"2093", "\[Rule]", "1812"}], ",", 
       RowBox[{"2093", "\[Rule]", "1718"}], ",", 
       RowBox[{"2093", "\[Rule]", "1718"}], ",", 
       RowBox[{"2093", "\[Rule]", "2094"}], ",", 
       RowBox[{"2079", "\[Rule]", "1798"}], ",", 
       RowBox[{"2079", "\[Rule]", "1798"}], ",", 
       RowBox[{"2079", "\[Rule]", "1704"}], ",", 
       RowBox[{"2079", "\[Rule]", "1704"}], ",", 
       RowBox[{"2079", "\[Rule]", "2080"}], ",", 
       RowBox[{"2119", "\[Rule]", "1838"}], ",", 
       RowBox[{"2119", "\[Rule]", "1838"}], ",", 
       RowBox[{"2119", "\[Rule]", "1744"}], ",", 
       RowBox[{"2119", "\[Rule]", "1744"}], ",", 
       RowBox[{"2119", "\[Rule]", "2120"}], ",", 
       RowBox[{"2105", "\[Rule]", "1824"}], ",", 
       RowBox[{"2105", "\[Rule]", "1824"}], ",", 
       RowBox[{"2105", "\[Rule]", "1730"}], ",", 
       RowBox[{"2105", "\[Rule]", "1730"}], ",", 
       RowBox[{"2105", "\[Rule]", "2106"}], ",", 
       RowBox[{"2089", "\[Rule]", "1808"}], ",", 
       RowBox[{"2089", "\[Rule]", "1808"}], ",", 
       RowBox[{"2089", "\[Rule]", "1714"}], ",", 
       RowBox[{"2089", "\[Rule]", "1714"}], ",", 
       RowBox[{"2089", "\[Rule]", "2090"}], ",", 
       RowBox[{"2147", "\[Rule]", "1866"}], ",", 
       RowBox[{"2147", "\[Rule]", "1866"}], ",", 
       RowBox[{"2147", "\[Rule]", "1772"}], ",", 
       RowBox[{"2147", "\[Rule]", "1772"}], ",", 
       RowBox[{"2147", "\[Rule]", "2148"}], ",", 
       RowBox[{"2131", "\[Rule]", "1850"}], ",", 
       RowBox[{"2131", "\[Rule]", "1850"}], ",", 
       RowBox[{"2131", "\[Rule]", "1756"}], ",", 
       RowBox[{"2131", "\[Rule]", "1756"}], ",", 
       RowBox[{"2131", "\[Rule]", "2132"}], ",", 
       RowBox[{"2115", "\[Rule]", "1834"}], ",", 
       RowBox[{"2115", "\[Rule]", "1834"}], ",", 
       RowBox[{"2115", "\[Rule]", "1740"}], ",", 
       RowBox[{"2115", "\[Rule]", "1740"}], ",", 
       RowBox[{"2115", "\[Rule]", "2116"}], ",", 
       RowBox[{"2101", "\[Rule]", "1820"}], ",", 
       RowBox[{"2101", "\[Rule]", "1820"}], ",", 
       RowBox[{"2101", "\[Rule]", "1726"}], ",", 
       RowBox[{"2101", "\[Rule]", "1726"}], ",", 
       RowBox[{"2101", "\[Rule]", "2102"}], ",", 
       RowBox[{"2347", "\[Rule]", "1972"}], ",", 
       RowBox[{"2347", "\[Rule]", "2348"}], ",", 
       RowBox[{"2331", "\[Rule]", "1956"}], ",", 
       RowBox[{"2331", "\[Rule]", "1956"}], ",", 
       RowBox[{"2331", "\[Rule]", "2332"}], ",", 
       RowBox[{"2253", "\[Rule]", "1972"}], ",", 
       RowBox[{"2253", "\[Rule]", "1878"}], ",", 
       RowBox[{"2253", "\[Rule]", "1878"}], ",", 
       RowBox[{"2253", "\[Rule]", "2254"}], ",", 
       RowBox[{"2237", "\[Rule]", "1956"}], ",", 
       RowBox[{"2237", "\[Rule]", "1862"}], ",", 
       RowBox[{"2237", "\[Rule]", "2238"}], ",", 
       RowBox[{"2315", "\[Rule]", "1940"}], ",", 
       RowBox[{"2315", "\[Rule]", "1940"}], ",", 
       RowBox[{"2315", "\[Rule]", "2316"}], ",", 
       RowBox[{"2221", "\[Rule]", "1940"}], ",", 
       RowBox[{"2221", "\[Rule]", "1940"}], ",", 
       RowBox[{"2221", "\[Rule]", "1846"}], ",", 
       RowBox[{"2221", "\[Rule]", "1846"}], ",", 
       RowBox[{"2221", "\[Rule]", "2222"}], ",", 
       RowBox[{"2159", "\[Rule]", "1878"}], ",", 
       RowBox[{"2159", "\[Rule]", "1878"}], ",", 
       RowBox[{"2159", "\[Rule]", "1784"}], ",", 
       RowBox[{"2159", "\[Rule]", "1784"}], ",", 
       RowBox[{"2159", "\[Rule]", "2160"}], ",", 
       RowBox[{"2143", "\[Rule]", "1862"}], ",", 
       RowBox[{"2143", "\[Rule]", "1862"}], ",", 
       RowBox[{"2143", "\[Rule]", "1768"}], ",", 
       RowBox[{"2143", "\[Rule]", "1768"}], ",", 
       RowBox[{"2143", "\[Rule]", "2144"}], ",", 
       RowBox[{"2127", "\[Rule]", "1846"}], ",", 
       RowBox[{"2127", "\[Rule]", "1846"}], ",", 
       RowBox[{"2127", "\[Rule]", "1752"}], ",", 
       RowBox[{"2127", "\[Rule]", "1752"}], ",", 
       RowBox[{"2127", "\[Rule]", "2128"}], ",", 
       RowBox[{"2299", "\[Rule]", "1924"}], ",", 
       RowBox[{"2299", "\[Rule]", "1924"}], ",", 
       RowBox[{"2299", "\[Rule]", "2300"}], ",", 
       RowBox[{"2205", "\[Rule]", "1924"}], ",", 
       RowBox[{"2205", "\[Rule]", "1924"}], ",", 
       RowBox[{"2205", "\[Rule]", "1830"}], ",", 
       RowBox[{"2205", "\[Rule]", "1830"}], ",", 
       RowBox[{"2205", "\[Rule]", "2206"}], ",", 
       RowBox[{"2111", "\[Rule]", "1830"}], ",", 
       RowBox[{"2111", "\[Rule]", "1830"}], ",", 
       RowBox[{"2111", "\[Rule]", "1736"}], ",", 
       RowBox[{"2111", "\[Rule]", "1736"}], ",", 
       RowBox[{"2111", "\[Rule]", "2112"}], ",", 
       RowBox[{"1999", "\[Rule]", "1718"}], ",", 
       RowBox[{"1999", "\[Rule]", "1718"}], ",", 
       RowBox[{"1999", "\[Rule]", "2000"}], ",", 
       RowBox[{"1985", "\[Rule]", "1704"}], ",", 
       RowBox[{"1985", "\[Rule]", "1704"}], ",", 
       RowBox[{"1985", "\[Rule]", "1986"}], ",", 
       RowBox[{"2025", "\[Rule]", "1744"}], ",", 
       RowBox[{"2025", "\[Rule]", "1744"}], ",", 
       RowBox[{"2025", "\[Rule]", "2026"}], ",", 
       RowBox[{"2011", "\[Rule]", "1730"}], ",", 
       RowBox[{"2011", "\[Rule]", "1730"}], ",", 
       RowBox[{"2011", "\[Rule]", "2012"}], ",", 
       RowBox[{"1995", "\[Rule]", "1714"}], ",", 
       RowBox[{"1995", "\[Rule]", "1714"}], ",", 
       RowBox[{"1995", "\[Rule]", "1996"}], ",", 
       RowBox[{"2053", "\[Rule]", "1772"}], ",", 
       RowBox[{"2053", "\[Rule]", "1772"}], ",", 
       RowBox[{"2053", "\[Rule]", "2054"}], ",", 
       RowBox[{"2037", "\[Rule]", "1756"}], ",", 
       RowBox[{"2037", "\[Rule]", "1756"}], ",", 
       RowBox[{"2037", "\[Rule]", "2038"}], ",", 
       RowBox[{"2021", "\[Rule]", "1740"}], ",", 
       RowBox[{"2021", "\[Rule]", "1740"}], ",", 
       RowBox[{"2021", "\[Rule]", "2022"}], ",", 
       RowBox[{"2007", "\[Rule]", "1726"}], ",", 
       RowBox[{"2007", "\[Rule]", "1726"}], ",", 
       RowBox[{"2007", "\[Rule]", "2008"}], ",", 
       RowBox[{"2065", "\[Rule]", "1784"}], ",", 
       RowBox[{"2065", "\[Rule]", "1784"}], ",", 
       RowBox[{"2065", "\[Rule]", "2066"}], ",", 
       RowBox[{"2049", "\[Rule]", "1768"}], ",", 
       RowBox[{"2049", "\[Rule]", "1768"}], ",", 
       RowBox[{"2049", "\[Rule]", "2050"}], ",", 
       RowBox[{"2033", "\[Rule]", "1752"}], ",", 
       RowBox[{"2033", "\[Rule]", "1752"}], ",", 
       RowBox[{"2033", "\[Rule]", "2034"}], ",", 
       RowBox[{"2017", "\[Rule]", "1736"}], ",", 
       RowBox[{"2017", "\[Rule]", "1736"}], ",", 
       RowBox[{"2017", "\[Rule]", "2018"}], ",", 
       RowBox[{"2343", "\[Rule]", "1968"}], ",", 
       RowBox[{"2343", "\[Rule]", "1968"}], ",", 
       RowBox[{"2343", "\[Rule]", "2344"}], ",", 
       RowBox[{"2249", "\[Rule]", "1968"}], ",", 
       RowBox[{"2249", "\[Rule]", "1968"}], ",", 
       RowBox[{"2249", "\[Rule]", "1874"}], ",", 
       RowBox[{"2249", "\[Rule]", "2250"}], ",", 
       RowBox[{"2155", "\[Rule]", "1874"}], ",", 
       RowBox[{"2155", "\[Rule]", "1780"}], ",", 
       RowBox[{"2155", "\[Rule]", "1780"}], ",", 
       RowBox[{"2155", "\[Rule]", "2156"}], ",", 
       RowBox[{"2327", "\[Rule]", "1952"}], ",", 
       RowBox[{"2327", "\[Rule]", "1952"}], ",", 
       RowBox[{"2327", "\[Rule]", "2328"}], ",", 
       RowBox[{"2233", "\[Rule]", "1952"}], ",", 
       RowBox[{"2233", "\[Rule]", "1952"}], ",", 
       RowBox[{"2233", "\[Rule]", "1858"}], ",", 
       RowBox[{"2233", "\[Rule]", "1858"}], ",", 
       RowBox[{"2233", "\[Rule]", "2234"}], ",", 
       RowBox[{"2139", "\[Rule]", "1858"}], ",", 
       RowBox[{"2139", "\[Rule]", "1764"}], ",", 
       RowBox[{"2139", "\[Rule]", "2140"}], ",", 
       RowBox[{"2061", "\[Rule]", "1780"}], ",", 
       RowBox[{"2061", "\[Rule]", "1780"}], ",", 
       RowBox[{"2061", "\[Rule]", "2062"}], ",", 
       RowBox[{"2045", "\[Rule]", "1764"}], ",", 
       RowBox[{"2045", "\[Rule]", "1764"}], ",", 
       RowBox[{"2045", "\[Rule]", "2046"}], ",", 
       RowBox[{"2311", "\[Rule]", "1936"}], ",", 
       RowBox[{"2311", "\[Rule]", "1936"}], ",", 
       RowBox[{"2311", "\[Rule]", "2312"}], ",", 
       RowBox[{"2217", "\[Rule]", "1936"}], ",", 
       RowBox[{"2217", "\[Rule]", "1936"}], ",", 
       RowBox[{"2217", "\[Rule]", "1842"}], ",", 
       RowBox[{"2217", "\[Rule]", "1842"}], ",", 
       RowBox[{"2217", "\[Rule]", "2218"}], ",", 
       RowBox[{"2123", "\[Rule]", "1842"}], ",", 
       RowBox[{"2123", "\[Rule]", "1842"}], ",", 
       RowBox[{"2123", "\[Rule]", "1748"}], ",", 
       RowBox[{"2123", "\[Rule]", "1748"}], ",", 
       RowBox[{"2123", "\[Rule]", "2124"}], ",", 
       RowBox[{"2029", "\[Rule]", "1748"}], ",", 
       RowBox[{"2029", "\[Rule]", "1748"}], ",", 
       RowBox[{"2029", "\[Rule]", "2030"}], ",", 
       RowBox[{"2339", "\[Rule]", "1964"}], ",", 
       RowBox[{"2339", "\[Rule]", "1964"}], ",", 
       RowBox[{"2339", "\[Rule]", "2340"}], ",", 
       RowBox[{"2245", "\[Rule]", "1964"}], ",", 
       RowBox[{"2245", "\[Rule]", "1964"}], ",", 
       RowBox[{"2245", "\[Rule]", "1870"}], ",", 
       RowBox[{"2245", "\[Rule]", "1870"}], ",", 
       RowBox[{"2245", "\[Rule]", "2246"}], ",", 
       RowBox[{"2151", "\[Rule]", "1870"}], ",", 
       RowBox[{"2151", "\[Rule]", "1870"}], ",", 
       RowBox[{"2151", "\[Rule]", "1776"}], ",", 
       RowBox[{"2151", "\[Rule]", "2152"}], ",", 
       RowBox[{"2057", "\[Rule]", "1776"}], ",", 
       RowBox[{"2057", "\[Rule]", "2058"}], ",", 
       RowBox[{"2323", "\[Rule]", "1948"}], ",", 
       RowBox[{"2323", "\[Rule]", "1948"}], ",", 
       RowBox[{"2323", "\[Rule]", "2324"}], ",", 
       RowBox[{"2229", "\[Rule]", "1948"}], ",", 
       RowBox[{"2229", "\[Rule]", "1948"}], ",", 
       RowBox[{"2229", "\[Rule]", "1854"}], ",", 
       RowBox[{"2229", "\[Rule]", "1854"}], ",", 
       RowBox[{"2229", "\[Rule]", "2230"}], ",", 
       RowBox[{"2135", "\[Rule]", "1854"}], ",", 
       RowBox[{"2135", "\[Rule]", "1854"}], ",", 
       RowBox[{"2135", "\[Rule]", "1760"}], ",", 
       RowBox[{"2135", "\[Rule]", "1760"}], ",", 
       RowBox[{"2135", "\[Rule]", "2136"}], ",", 
       RowBox[{"2041", "\[Rule]", "1760"}], ",", 
       RowBox[{"2041", "\[Rule]", "2042"}], ",", 
       RowBox[{"294", "\[Rule]", "305"}], ",", 
       RowBox[{"294", "\[Rule]", "295"}], ",", 
       RowBox[{"294", "\[Rule]", "291"}], ",", 
       RowBox[{"952", "\[Rule]", "963"}], ",", 
       RowBox[{"952", "\[Rule]", "953"}], ",", 
       RowBox[{"952", "\[Rule]", "949"}], ",", 
       RowBox[{"200", "\[Rule]", "211"}], ",", 
       RowBox[{"200", "\[Rule]", "201"}], ",", 
       RowBox[{"200", "\[Rule]", "197"}], ",", 
       RowBox[{"858", "\[Rule]", "869"}], ",", 
       RowBox[{"858", "\[Rule]", "859"}], ",", 
       RowBox[{"858", "\[Rule]", "855"}], ",", 
       RowBox[{"576", "\[Rule]", "587"}], ",", 
       RowBox[{"576", "\[Rule]", "577"}], ",", 
       RowBox[{"576", "\[Rule]", "573"}], ",", 
       RowBox[{"304", "\[Rule]", "291"}], ",", 
       RowBox[{"304", "\[Rule]", "317"}], ",", 
       RowBox[{"304", "\[Rule]", "305"}], ",", 
       RowBox[{"304", "\[Rule]", "301"}], ",", 
       RowBox[{"962", "\[Rule]", "949"}], ",", 
       RowBox[{"962", "\[Rule]", "975"}], ",", 
       RowBox[{"962", "\[Rule]", "963"}], ",", 
       RowBox[{"962", "\[Rule]", "959"}], ",", 
       RowBox[{"210", "\[Rule]", "197"}], ",", 
       RowBox[{"210", "\[Rule]", "223"}], ",", 
       RowBox[{"210", "\[Rule]", "211"}], ",", 
       RowBox[{"210", "\[Rule]", "207"}], ",", 
       RowBox[{"868", "\[Rule]", "855"}], ",", 
       RowBox[{"868", "\[Rule]", "881"}], ",", 
       RowBox[{"868", "\[Rule]", "869"}], ",", 
       RowBox[{"868", "\[Rule]", "865"}], ",", 
       RowBox[{"586", "\[Rule]", "573"}], ",", 
       RowBox[{"586", "\[Rule]", "599"}], ",", 
       RowBox[{"586", "\[Rule]", "587"}], ",", 
       RowBox[{"586", "\[Rule]", "583"}], ",", 
       RowBox[{"1610", "\[Rule]", "1621"}], ",", 
       RowBox[{"1610", "\[Rule]", "1611"}], ",", 
       RowBox[{"1610", "\[Rule]", "1607"}], ",", 
       RowBox[{"1516", "\[Rule]", "1527"}], ",", 
       RowBox[{"1516", "\[Rule]", "1517"}], ",", 
       RowBox[{"1516", "\[Rule]", "1513"}], ",", 
       RowBox[{"1234", "\[Rule]", "1245"}], ",", 
       RowBox[{"1234", "\[Rule]", "1235"}], ",", 
       RowBox[{"1234", "\[Rule]", "1231"}], ",", 
       RowBox[{"1620", "\[Rule]", "1607"}], ",", 
       RowBox[{"1620", "\[Rule]", "1633"}], ",", 
       RowBox[{"1620", "\[Rule]", "1621"}], ",", 
       RowBox[{"1620", "\[Rule]", "1617"}], ",", 
       RowBox[{"1526", "\[Rule]", "1513"}], ",", 
       RowBox[{"1526", "\[Rule]", "1539"}], ",", 
       RowBox[{"1526", "\[Rule]", "1527"}], ",", 
       RowBox[{"1526", "\[Rule]", "1523"}], ",", 
       RowBox[{"1244", "\[Rule]", "1231"}], ",", 
       RowBox[{"1244", "\[Rule]", "1257"}], ",", 
       RowBox[{"1244", "\[Rule]", "1245"}], ",", 
       RowBox[{"1244", "\[Rule]", "1241"}], ",", 
       RowBox[{"106", "\[Rule]", "117"}], ",", 
       RowBox[{"106", "\[Rule]", "107"}], ",", 
       RowBox[{"106", "\[Rule]", "103"}], ",", 
       RowBox[{"764", "\[Rule]", "775"}], ",", 
       RowBox[{"764", "\[Rule]", "765"}], ",", 
       RowBox[{"764", "\[Rule]", "761"}], ",", 
       RowBox[{"482", "\[Rule]", "493"}], ",", 
       RowBox[{"482", "\[Rule]", "483"}], ",", 
       RowBox[{"482", "\[Rule]", "479"}], ",", 
       RowBox[{"116", "\[Rule]", "103"}], ",", 
       RowBox[{"116", "\[Rule]", "129"}], ",", 
       RowBox[{"116", "\[Rule]", "117"}], ",", 
       RowBox[{"116", "\[Rule]", "113"}], ",", 
       RowBox[{"774", "\[Rule]", "761"}], ",", 
       RowBox[{"774", "\[Rule]", "787"}], ",", 
       RowBox[{"774", "\[Rule]", "775"}], ",", 
       RowBox[{"774", "\[Rule]", "771"}], ",", 
       RowBox[{"492", "\[Rule]", "479"}], ",", 
       RowBox[{"492", "\[Rule]", "505"}], ",", 
       RowBox[{"492", "\[Rule]", "493"}], ",", 
       RowBox[{"492", "\[Rule]", "489"}], ",", 
       RowBox[{"1422", "\[Rule]", "1433"}], ",", 
       RowBox[{"1422", "\[Rule]", "1423"}], ",", 
       RowBox[{"1422", "\[Rule]", "1419"}], ",", 
       RowBox[{"1140", "\[Rule]", "1151"}], ",", 
       RowBox[{"1140", "\[Rule]", "1141"}], ",", 
       RowBox[{"1140", "\[Rule]", "1137"}], ",", 
       RowBox[{"1432", "\[Rule]", "1419"}], ",", 
       RowBox[{"1432", "\[Rule]", "1445"}], ",", 
       RowBox[{"1432", "\[Rule]", "1433"}], ",", 
       RowBox[{"1432", "\[Rule]", "1429"}], ",", 
       RowBox[{"1150", "\[Rule]", "1137"}], ",", 
       RowBox[{"1150", "\[Rule]", "1163"}], ",", 
       RowBox[{"1150", "\[Rule]", "1151"}], ",", 
       RowBox[{"1150", "\[Rule]", "1147"}], ",", 
       RowBox[{"316", "\[Rule]", "301"}], ",", 
       RowBox[{"316", "\[Rule]", "327"}], ",", 
       RowBox[{"316", "\[Rule]", "317"}], ",", 
       RowBox[{"316", "\[Rule]", "313"}], ",", 
       RowBox[{"974", "\[Rule]", "959"}], ",", 
       RowBox[{"974", "\[Rule]", "985"}], ",", 
       RowBox[{"974", "\[Rule]", "975"}], ",", 
       RowBox[{"974", "\[Rule]", "971"}], ",", 
       RowBox[{"222", "\[Rule]", "207"}], ",", 
       RowBox[{"222", "\[Rule]", "233"}], ",", 
       RowBox[{"222", "\[Rule]", "223"}], ",", 
       RowBox[{"222", "\[Rule]", "219"}], ",", 
       RowBox[{"880", "\[Rule]", "865"}], ",", 
       RowBox[{"880", "\[Rule]", "891"}], ",", 
       RowBox[{"880", "\[Rule]", "881"}], ",", 
       RowBox[{"880", "\[Rule]", "877"}], ",", 
       RowBox[{"598", "\[Rule]", "583"}], ",", 
       RowBox[{"598", "\[Rule]", "609"}], ",", 
       RowBox[{"598", "\[Rule]", "599"}], ",", 
       RowBox[{"598", "\[Rule]", "595"}], ",", 
       RowBox[{"1632", "\[Rule]", "1617"}], ",", 
       RowBox[{"1632", "\[Rule]", "1643"}], ",", 
       RowBox[{"1632", "\[Rule]", "1633"}], ",", 
       RowBox[{"1632", "\[Rule]", "1629"}], ",", 
       RowBox[{"1538", "\[Rule]", "1523"}], ",", 
       RowBox[{"1538", "\[Rule]", "1549"}], ",", 
       RowBox[{"1538", "\[Rule]", "1539"}], ",", 
       RowBox[{"1538", "\[Rule]", "1535"}], ",", 
       RowBox[{"1256", "\[Rule]", "1241"}], ",", 
       RowBox[{"1256", "\[Rule]", "1267"}], ",", 
       RowBox[{"1256", "\[Rule]", "1257"}], ",", 
       RowBox[{"1256", "\[Rule]", "1253"}], ",", 
       RowBox[{"128", "\[Rule]", "113"}], ",", 
       RowBox[{"128", "\[Rule]", "139"}], ",", 
       RowBox[{"128", "\[Rule]", "129"}], ",", 
       RowBox[{"128", "\[Rule]", "125"}], ",", 
       RowBox[{"504", "\[Rule]", "489"}], ",", 
       RowBox[{"504", "\[Rule]", "515"}], ",", 
       RowBox[{"504", "\[Rule]", "505"}], ",", 
       RowBox[{"504", "\[Rule]", "501"}], ",", 
       RowBox[{"786", "\[Rule]", "771"}], ",", 
       RowBox[{"786", "\[Rule]", "797"}], ",", 
       RowBox[{"786", "\[Rule]", "787"}], ",", 
       RowBox[{"786", "\[Rule]", "783"}], ",", 
       RowBox[{"1444", "\[Rule]", "1429"}], ",", 
       RowBox[{"1444", "\[Rule]", "1455"}], ",", 
       RowBox[{"1444", "\[Rule]", "1445"}], ",", 
       RowBox[{"1444", "\[Rule]", "1441"}], ",", 
       RowBox[{"1162", "\[Rule]", "1147"}], ",", 
       RowBox[{"1162", "\[Rule]", "1173"}], ",", 
       RowBox[{"1162", "\[Rule]", "1163"}], ",", 
       RowBox[{"1162", "\[Rule]", "1159"}], ",", 
       RowBox[{"12", "\[Rule]", "23"}], ",", 
       RowBox[{"12", "\[Rule]", "13"}], ",", 
       RowBox[{"12", "\[Rule]", "9"}], ",", 
       RowBox[{"670", "\[Rule]", "681"}], ",", 
       RowBox[{"670", "\[Rule]", "671"}], ",", 
       RowBox[{"670", "\[Rule]", "667"}], ",", 
       RowBox[{"388", "\[Rule]", "399"}], ",", 
       RowBox[{"388", "\[Rule]", "389"}], ",", 
       RowBox[{"388", "\[Rule]", "385"}], ",", 
       RowBox[{"22", "\[Rule]", "9"}], ",", 
       RowBox[{"22", "\[Rule]", "35"}], ",", 
       RowBox[{"22", "\[Rule]", "23"}], ",", 
       RowBox[{"22", "\[Rule]", "19"}], ",", 
       RowBox[{"680", "\[Rule]", "667"}], ",", 
       RowBox[{"680", "\[Rule]", "693"}], ",", 
       RowBox[{"680", "\[Rule]", "681"}], ",", 
       RowBox[{"680", "\[Rule]", "677"}], ",", 
       RowBox[{"398", "\[Rule]", "385"}], ",", 
       RowBox[{"398", "\[Rule]", "411"}], ",", 
       RowBox[{"398", "\[Rule]", "399"}], ",", 
       RowBox[{"398", "\[Rule]", "395"}], ",", 
       RowBox[{"1328", "\[Rule]", "1339"}], ",", 
       RowBox[{"1328", "\[Rule]", "1329"}], ",", 
       RowBox[{"1328", "\[Rule]", "1325"}], ",", 
       RowBox[{"1046", "\[Rule]", "1057"}], ",", 
       RowBox[{"1046", "\[Rule]", "1047"}], ",", 
       RowBox[{"1046", "\[Rule]", "1043"}], ",", 
       RowBox[{"1338", "\[Rule]", "1325"}], ",", 
       RowBox[{"1338", "\[Rule]", "1351"}], ",", 
       RowBox[{"1338", "\[Rule]", "1339"}], ",", 
       RowBox[{"1338", "\[Rule]", "1335"}], ",", 
       RowBox[{"1056", "\[Rule]", "1043"}], ",", 
       RowBox[{"1056", "\[Rule]", "1069"}], ",", 
       RowBox[{"1056", "\[Rule]", "1057"}], ",", 
       RowBox[{"1056", "\[Rule]", "1053"}], ",", 
       RowBox[{"34", "\[Rule]", "19"}], ",", 
       RowBox[{"34", "\[Rule]", "45"}], ",", 
       RowBox[{"34", "\[Rule]", "35"}], ",", 
       RowBox[{"34", "\[Rule]", "31"}], ",", 
       RowBox[{"692", "\[Rule]", "677"}], ",", 
       RowBox[{"692", "\[Rule]", "703"}], ",", 
       RowBox[{"692", "\[Rule]", "693"}], ",", 
       RowBox[{"692", "\[Rule]", "689"}], ",", 
       RowBox[{"410", "\[Rule]", "395"}], ",", 
       RowBox[{"410", "\[Rule]", "421"}], ",", 
       RowBox[{"410", "\[Rule]", "411"}], ",", 
       RowBox[{"410", "\[Rule]", "407"}], ",", 
       RowBox[{"1350", "\[Rule]", "1335"}], ",", 
       RowBox[{"1350", "\[Rule]", "1361"}], ",", 
       RowBox[{"1350", "\[Rule]", "1351"}], ",", 
       RowBox[{"1350", "\[Rule]", "1347"}], ",", 
       RowBox[{"1068", "\[Rule]", "1053"}], ",", 
       RowBox[{"1068", "\[Rule]", "1079"}], ",", 
       RowBox[{"1068", "\[Rule]", "1069"}], ",", 
       RowBox[{"1068", "\[Rule]", "1065"}], ",", 
       RowBox[{"326", "\[Rule]", "313"}], ",", 
       RowBox[{"326", "\[Rule]", "339"}], ",", 
       RowBox[{"326", "\[Rule]", "327"}], ",", 
       RowBox[{"326", "\[Rule]", "323"}], ",", 
       RowBox[{"984", "\[Rule]", "971"}], ",", 
       RowBox[{"984", "\[Rule]", "997"}], ",", 
       RowBox[{"984", "\[Rule]", "985"}], ",", 
       RowBox[{"984", "\[Rule]", "981"}], ",", 
       RowBox[{"232", "\[Rule]", "219"}], ",", 
       RowBox[{"232", "\[Rule]", "245"}], ",", 
       RowBox[{"232", "\[Rule]", "233"}], ",", 
       RowBox[{"232", "\[Rule]", "229"}], ",", 
       RowBox[{"890", "\[Rule]", "877"}], ",", 
       RowBox[{"890", "\[Rule]", "903"}], ",", 
       RowBox[{"890", "\[Rule]", "891"}], ",", 
       RowBox[{"890", "\[Rule]", "887"}], ",", 
       RowBox[{"608", "\[Rule]", "595"}], ",", 
       RowBox[{"608", "\[Rule]", "621"}], ",", 
       RowBox[{"608", "\[Rule]", "609"}], ",", 
       RowBox[{"608", "\[Rule]", "605"}], ",", 
       RowBox[{"1642", "\[Rule]", "1629"}], ",", 
       RowBox[{"1642", "\[Rule]", "1655"}], ",", 
       RowBox[{"1642", "\[Rule]", "1643"}], ",", 
       RowBox[{"1642", "\[Rule]", "1639"}], ",", 
       RowBox[{"1548", "\[Rule]", "1535"}], ",", 
       RowBox[{"1548", "\[Rule]", "1561"}], ",", 
       RowBox[{"1548", "\[Rule]", "1549"}], ",", 
       RowBox[{"1548", "\[Rule]", "1545"}], ",", 
       RowBox[{"1266", "\[Rule]", "1253"}], ",", 
       RowBox[{"1266", "\[Rule]", "1279"}], ",", 
       RowBox[{"1266", "\[Rule]", "1267"}], ",", 
       RowBox[{"1266", "\[Rule]", "1263"}], ",", 
       RowBox[{"138", "\[Rule]", "125"}], ",", 
       RowBox[{"138", "\[Rule]", "151"}], ",", 
       RowBox[{"138", "\[Rule]", "139"}], ",", 
       RowBox[{"138", "\[Rule]", "135"}], ",", 
       RowBox[{"796", "\[Rule]", "783"}], ",", 
       RowBox[{"796", "\[Rule]", "809"}], ",", 
       RowBox[{"796", "\[Rule]", "797"}], ",", 
       RowBox[{"796", "\[Rule]", "793"}], ",", 
       RowBox[{"514", "\[Rule]", "501"}], ",", 
       RowBox[{"514", "\[Rule]", "527"}], ",", 
       RowBox[{"514", "\[Rule]", "515"}], ",", 
       RowBox[{"514", "\[Rule]", "511"}], ",", 
       RowBox[{"1454", "\[Rule]", "1441"}], ",", 
       RowBox[{"1454", "\[Rule]", "1467"}], ",", 
       RowBox[{"1454", "\[Rule]", "1455"}], ",", 
       RowBox[{"1454", "\[Rule]", "1451"}], ",", 
       RowBox[{"1172", "\[Rule]", "1159"}], ",", 
       RowBox[{"1172", "\[Rule]", "1185"}], ",", 
       RowBox[{"1172", "\[Rule]", "1173"}], ",", 
       RowBox[{"1172", "\[Rule]", "1169"}], ",", 
       RowBox[{"44", "\[Rule]", "31"}], ",", 
       RowBox[{"44", "\[Rule]", "57"}], ",", 
       RowBox[{"44", "\[Rule]", "45"}], ",", 
       RowBox[{"44", "\[Rule]", "41"}], ",", 
       RowBox[{"702", "\[Rule]", "689"}], ",", 
       RowBox[{"702", "\[Rule]", "715"}], ",", 
       RowBox[{"702", "\[Rule]", "703"}], ",", 
       RowBox[{"702", "\[Rule]", "699"}], ",", 
       RowBox[{"420", "\[Rule]", "407"}], ",", 
       RowBox[{"420", "\[Rule]", "433"}], ",", 
       RowBox[{"420", "\[Rule]", "421"}], ",", 
       RowBox[{"420", "\[Rule]", "417"}], ",", 
       RowBox[{"1360", "\[Rule]", "1347"}], ",", 
       RowBox[{"1360", "\[Rule]", "1373"}], ",", 
       RowBox[{"1360", "\[Rule]", "1361"}], ",", 
       RowBox[{"1360", "\[Rule]", "1357"}], ",", 
       RowBox[{"1078", "\[Rule]", "1065"}], ",", 
       RowBox[{"1078", "\[Rule]", "1091"}], ",", 
       RowBox[{"1078", "\[Rule]", "1079"}], ",", 
       RowBox[{"1078", "\[Rule]", "1075"}], ",", 
       RowBox[{"2268", "\[Rule]", "2279"}], ",", 
       RowBox[{"2268", "\[Rule]", "2269"}], ",", 
       RowBox[{"2268", "\[Rule]", "2265"}], ",", 
       RowBox[{"2174", "\[Rule]", "2185"}], ",", 
       RowBox[{"2174", "\[Rule]", "2175"}], ",", 
       RowBox[{"2174", "\[Rule]", "2171"}], ",", 
       RowBox[{"1892", "\[Rule]", "1903"}], ",", 
       RowBox[{"1892", "\[Rule]", "1893"}], ",", 
       RowBox[{"1892", "\[Rule]", "1889"}], ",", 
       RowBox[{"2278", "\[Rule]", "2265"}], ",", 
       RowBox[{"2278", "\[Rule]", "2291"}], ",", 
       RowBox[{"2278", "\[Rule]", "2279"}], ",", 
       RowBox[{"2278", "\[Rule]", "2275"}], ",", 
       RowBox[{"2184", "\[Rule]", "2171"}], ",", 
       RowBox[{"2184", "\[Rule]", "2197"}], ",", 
       RowBox[{"2184", "\[Rule]", "2185"}], ",", 
       RowBox[{"2184", "\[Rule]", "2181"}], ",", 
       RowBox[{"1902", "\[Rule]", "1889"}], ",", 
       RowBox[{"1902", "\[Rule]", "1915"}], ",", 
       RowBox[{"1902", "\[Rule]", "1903"}], ",", 
       RowBox[{"1902", "\[Rule]", "1899"}], ",", 
       RowBox[{"2080", "\[Rule]", "2091"}], ",", 
       RowBox[{"2080", "\[Rule]", "2081"}], ",", 
       RowBox[{"2080", "\[Rule]", "2077"}], ",", 
       RowBox[{"1798", "\[Rule]", "1809"}], ",", 
       RowBox[{"1798", "\[Rule]", "1799"}], ",", 
       RowBox[{"1798", "\[Rule]", "1795"}], ",", 
       RowBox[{"2090", "\[Rule]", "2077"}], ",", 
       RowBox[{"2090", "\[Rule]", "2103"}], ",", 
       RowBox[{"2090", "\[Rule]", "2091"}], ",", 
       RowBox[{"2090", "\[Rule]", "2087"}], ",", 
       RowBox[{"1808", "\[Rule]", "1795"}], ",", 
       RowBox[{"1808", "\[Rule]", "1821"}], ",", 
       RowBox[{"1808", "\[Rule]", "1809"}], ",", 
       RowBox[{"1808", "\[Rule]", "1805"}], ",", 
       RowBox[{"2290", "\[Rule]", "2275"}], ",", 
       RowBox[{"2290", "\[Rule]", "2301"}], ",", 
       RowBox[{"2290", "\[Rule]", "2291"}], ",", 
       RowBox[{"2290", "\[Rule]", "2287"}], ",", 
       RowBox[{"2196", "\[Rule]", "2181"}], ",", 
       RowBox[{"2196", "\[Rule]", "2207"}], ",", 
       RowBox[{"2196", "\[Rule]", "2197"}], ",", 
       RowBox[{"2196", "\[Rule]", "2193"}], ",", 
       RowBox[{"1914", "\[Rule]", "1899"}], ",", 
       RowBox[{"1914", "\[Rule]", "1925"}], ",", 
       RowBox[{"1914", "\[Rule]", "1915"}], ",", 
       RowBox[{"1914", "\[Rule]", "1911"}], ",", 
       RowBox[{"2102", "\[Rule]", "2087"}], ",", 
       RowBox[{"2102", "\[Rule]", "2113"}], ",", 
       RowBox[{"2102", "\[Rule]", "2103"}], ",", 
       RowBox[{"2102", "\[Rule]", "2099"}], ",", 
       RowBox[{"1820", "\[Rule]", "1805"}], ",", 
       RowBox[{"1820", "\[Rule]", "1831"}], ",", 
       RowBox[{"1820", "\[Rule]", "1821"}], ",", 
       RowBox[{"1820", "\[Rule]", "1817"}], ",", 
       RowBox[{"1986", "\[Rule]", "1997"}], ",", 
       RowBox[{"1986", "\[Rule]", "1987"}], ",", 
       RowBox[{"1986", "\[Rule]", "1983"}], ",", 
       RowBox[{"1704", "\[Rule]", "1715"}], ",", 
       RowBox[{"1704", "\[Rule]", "1705"}], ",", 
       RowBox[{"1704", "\[Rule]", "1701"}], ",", 
       RowBox[{"1996", "\[Rule]", "1983"}], ",", 
       RowBox[{"1996", "\[Rule]", "2009"}], ",", 
       RowBox[{"1996", "\[Rule]", "1997"}], ",", 
       RowBox[{"1996", "\[Rule]", "1993"}], ",", 
       RowBox[{"1714", "\[Rule]", "1701"}], ",", 
       RowBox[{"1714", "\[Rule]", "1727"}], ",", 
       RowBox[{"1714", "\[Rule]", "1715"}], ",", 
       RowBox[{"1714", "\[Rule]", "1711"}], ",", 
       RowBox[{"2008", "\[Rule]", "1993"}], ",", 
       RowBox[{"2008", "\[Rule]", "2019"}], ",", 
       RowBox[{"2008", "\[Rule]", "2009"}], ",", 
       RowBox[{"2008", "\[Rule]", "2005"}], ",", 
       RowBox[{"1726", "\[Rule]", "1711"}], ",", 
       RowBox[{"1726", "\[Rule]", "1737"}], ",", 
       RowBox[{"1726", "\[Rule]", "1727"}], ",", 
       RowBox[{"1726", "\[Rule]", "1723"}], ",", 
       RowBox[{"2300", "\[Rule]", "2287"}], ",", 
       RowBox[{"2300", "\[Rule]", "2313"}], ",", 
       RowBox[{"2300", "\[Rule]", "2301"}], ",", 
       RowBox[{"2300", "\[Rule]", "2297"}], ",", 
       RowBox[{"2206", "\[Rule]", "2193"}], ",", 
       RowBox[{"2206", "\[Rule]", "2219"}], ",", 
       RowBox[{"2206", "\[Rule]", "2207"}], ",", 
       RowBox[{"2206", "\[Rule]", "2203"}], ",", 
       RowBox[{"1924", "\[Rule]", "1911"}], ",", 
       RowBox[{"1924", "\[Rule]", "1937"}], ",", 
       RowBox[{"1924", "\[Rule]", "1925"}], ",", 
       RowBox[{"1924", "\[Rule]", "1921"}], ",", 
       RowBox[{"2112", "\[Rule]", "2099"}], ",", 
       RowBox[{"2112", "\[Rule]", "2125"}], ",", 
       RowBox[{"2112", "\[Rule]", "2113"}], ",", 
       RowBox[{"2112", "\[Rule]", "2109"}], ",", 
       RowBox[{"1830", "\[Rule]", "1817"}], ",", 
       RowBox[{"1830", "\[Rule]", "1843"}], ",", 
       RowBox[{"1830", "\[Rule]", "1831"}], ",", 
       RowBox[{"1830", "\[Rule]", "1827"}], ",", 
       RowBox[{"2018", "\[Rule]", "2005"}], ",", 
       RowBox[{"2018", "\[Rule]", "2031"}], ",", 
       RowBox[{"2018", "\[Rule]", "2019"}], ",", 
       RowBox[{"2018", "\[Rule]", "2015"}], ",", 
       RowBox[{"1736", "\[Rule]", "1723"}], ",", 
       RowBox[{"1736", "\[Rule]", "1749"}], ",", 
       RowBox[{"1736", "\[Rule]", "1737"}], ",", 
       RowBox[{"1736", "\[Rule]", "1733"}], ",", 
       RowBox[{"338", "\[Rule]", "323"}], ",", 
       RowBox[{"338", "\[Rule]", "351"}], ",", 
       RowBox[{"338", "\[Rule]", "339"}], ",", 
       RowBox[{"338", "\[Rule]", "335"}], ",", 
       RowBox[{"996", "\[Rule]", "981"}], ",", 
       RowBox[{"996", "\[Rule]", "1009"}], ",", 
       RowBox[{"996", "\[Rule]", "997"}], ",", 
       RowBox[{"996", "\[Rule]", "993"}], ",", 
       RowBox[{"244", "\[Rule]", "229"}], ",", 
       RowBox[{"244", "\[Rule]", "257"}], ",", 
       RowBox[{"244", "\[Rule]", "245"}], ",", 
       RowBox[{"244", "\[Rule]", "241"}], ",", 
       RowBox[{"902", "\[Rule]", "887"}], ",", 
       RowBox[{"902", "\[Rule]", "915"}], ",", 
       RowBox[{"902", "\[Rule]", "903"}], ",", 
       RowBox[{"902", "\[Rule]", "899"}], ",", 
       RowBox[{"620", "\[Rule]", "605"}], ",", 
       RowBox[{"620", "\[Rule]", "633"}], ",", 
       RowBox[{"620", "\[Rule]", "621"}], ",", 
       RowBox[{"620", "\[Rule]", "617"}], ",", 
       RowBox[{"1654", "\[Rule]", "1639"}], ",", 
       RowBox[{"1654", "\[Rule]", "1667"}], ",", 
       RowBox[{"1654", "\[Rule]", "1655"}], ",", 
       RowBox[{"1654", "\[Rule]", "1651"}], ",", 
       RowBox[{"1560", "\[Rule]", "1545"}], ",", 
       RowBox[{"1560", "\[Rule]", "1573"}], ",", 
       RowBox[{"1560", "\[Rule]", "1561"}], ",", 
       RowBox[{"1560", "\[Rule]", "1557"}], ",", 
       RowBox[{"1278", "\[Rule]", "1263"}], ",", 
       RowBox[{"1278", "\[Rule]", "1291"}], ",", 
       RowBox[{"1278", "\[Rule]", "1279"}], ",", 
       RowBox[{"1278", "\[Rule]", "1275"}], ",", 
       RowBox[{"150", "\[Rule]", "135"}], ",", 
       RowBox[{"150", "\[Rule]", "163"}], ",", 
       RowBox[{"150", "\[Rule]", "151"}], ",", 
       RowBox[{"150", "\[Rule]", "147"}], ",", 
       RowBox[{"808", "\[Rule]", "793"}], ",", 
       RowBox[{"808", "\[Rule]", "821"}], ",", 
       RowBox[{"808", "\[Rule]", "809"}], ",", 
       RowBox[{"808", "\[Rule]", "805"}], ",", 
       RowBox[{"526", "\[Rule]", "511"}], ",", 
       RowBox[{"526", "\[Rule]", "539"}], ",", 
       RowBox[{"526", "\[Rule]", "527"}], ",", 
       RowBox[{"526", "\[Rule]", "523"}], ",", 
       RowBox[{"1466", "\[Rule]", "1451"}], ",", 
       RowBox[{"1466", "\[Rule]", "1479"}], ",", 
       RowBox[{"1466", "\[Rule]", "1467"}], ",", 
       RowBox[{"1466", "\[Rule]", "1463"}], ",", 
       RowBox[{"1184", "\[Rule]", "1169"}], ",", 
       RowBox[{"1184", "\[Rule]", "1197"}], ",", 
       RowBox[{"1184", "\[Rule]", "1185"}], ",", 
       RowBox[{"1184", "\[Rule]", "1181"}], ",", 
       RowBox[{"56", "\[Rule]", "41"}], ",", 
       RowBox[{"56", "\[Rule]", "69"}], ",", 
       RowBox[{"56", "\[Rule]", "57"}], ",", 
       RowBox[{"56", "\[Rule]", "53"}], ",", 
       RowBox[{"714", "\[Rule]", "699"}], ",", 
       RowBox[{"714", "\[Rule]", "727"}], ",", 
       RowBox[{"714", "\[Rule]", "715"}], ",", 
       RowBox[{"714", "\[Rule]", "711"}], ",", 
       RowBox[{"432", "\[Rule]", "417"}], ",", 
       RowBox[{"432", "\[Rule]", "445"}], ",", 
       RowBox[{"432", "\[Rule]", "433"}], ",", 
       RowBox[{"432", "\[Rule]", "429"}], ",", 
       RowBox[{"1090", "\[Rule]", "1075"}], ",", 
       RowBox[{"1090", "\[Rule]", "1103"}], ",", 
       RowBox[{"1090", "\[Rule]", "1091"}], ",", 
       RowBox[{"1090", "\[Rule]", "1087"}], ",", 
       RowBox[{"2312", "\[Rule]", "2297"}], ",", 
       RowBox[{"2312", "\[Rule]", "2325"}], ",", 
       RowBox[{"2312", "\[Rule]", "2313"}], ",", 
       RowBox[{"2312", "\[Rule]", "2309"}], ",", 
       RowBox[{"2218", "\[Rule]", "2203"}], ",", 
       RowBox[{"2218", "\[Rule]", "2231"}], ",", 
       RowBox[{"2218", "\[Rule]", "2219"}], ",", 
       RowBox[{"2218", "\[Rule]", "2215"}], ",", 
       RowBox[{"1936", "\[Rule]", "1921"}], ",", 
       RowBox[{"1936", "\[Rule]", "1949"}], ",", 
       RowBox[{"1936", "\[Rule]", "1937"}], ",", 
       RowBox[{"1936", "\[Rule]", "1933"}], ",", 
       RowBox[{"2124", "\[Rule]", "2109"}], ",", 
       RowBox[{"2124", "\[Rule]", "2137"}], ",", 
       RowBox[{"2124", "\[Rule]", "2125"}], ",", 
       RowBox[{"2124", "\[Rule]", "2121"}], ",", 
       RowBox[{"1842", "\[Rule]", "1827"}], ",", 
       RowBox[{"1842", "\[Rule]", "1855"}], ",", 
       RowBox[{"1842", "\[Rule]", "1843"}], ",", 
       RowBox[{"1842", "\[Rule]", "1839"}], ",", 
       RowBox[{"1372", "\[Rule]", "1357"}], ",", 
       RowBox[{"1372", "\[Rule]", "1385"}], ",", 
       RowBox[{"1372", "\[Rule]", "1373"}], ",", 
       RowBox[{"1372", "\[Rule]", "1369"}], ",", 
       RowBox[{"2030", "\[Rule]", "2015"}], ",", 
       RowBox[{"2030", "\[Rule]", "2043"}], ",", 
       RowBox[{"2030", "\[Rule]", "2031"}], ",", 
       RowBox[{"2030", "\[Rule]", "2027"}], ",", 
       RowBox[{"1748", "\[Rule]", "1733"}], ",", 
       RowBox[{"1748", "\[Rule]", "1761"}], ",", 
       RowBox[{"1748", "\[Rule]", "1749"}], ",", 
       RowBox[{"1748", "\[Rule]", "1745"}], ",", 
       RowBox[{"350", "\[Rule]", "335"}], ",", 
       RowBox[{"350", "\[Rule]", "363"}], ",", 
       RowBox[{"350", "\[Rule]", "351"}], ",", 
       RowBox[{"1008", "\[Rule]", "993"}], ",", 
       RowBox[{"1008", "\[Rule]", "1021"}], ",", 
       RowBox[{"1008", "\[Rule]", "1009"}], ",", 
       RowBox[{"256", "\[Rule]", "241"}], ",", 
       RowBox[{"256", "\[Rule]", "269"}], ",", 
       RowBox[{"256", "\[Rule]", "257"}], ",", 
       RowBox[{"914", "\[Rule]", "899"}], ",", 
       RowBox[{"914", "\[Rule]", "927"}], ",", 
       RowBox[{"914", "\[Rule]", "915"}], ",", 
       RowBox[{"632", "\[Rule]", "617"}], ",", 
       RowBox[{"632", "\[Rule]", "645"}], ",", 
       RowBox[{"632", "\[Rule]", "633"}], ",", 
       RowBox[{"1666", "\[Rule]", "1651"}], ",", 
       RowBox[{"1666", "\[Rule]", "1679"}], ",", 
       RowBox[{"1666", "\[Rule]", "1667"}], ",", 
       RowBox[{"1572", "\[Rule]", "1557"}], ",", 
       RowBox[{"1572", "\[Rule]", "1585"}], ",", 
       RowBox[{"1572", "\[Rule]", "1573"}], ",", 
       RowBox[{"1290", "\[Rule]", "1275"}], ",", 
       RowBox[{"1290", "\[Rule]", "1303"}], ",", 
       RowBox[{"1290", "\[Rule]", "1291"}], ",", 
       RowBox[{"162", "\[Rule]", "147"}], ",", 
       RowBox[{"162", "\[Rule]", "175"}], ",", 
       RowBox[{"162", "\[Rule]", "163"}], ",", 
       RowBox[{"820", "\[Rule]", "805"}], ",", 
       RowBox[{"820", "\[Rule]", "833"}], ",", 
       RowBox[{"820", "\[Rule]", "821"}], ",", 
       RowBox[{"538", "\[Rule]", "523"}], ",", 
       RowBox[{"538", "\[Rule]", "551"}], ",", 
       RowBox[{"538", "\[Rule]", "539"}], ",", 
       RowBox[{"1478", "\[Rule]", "1463"}], ",", 
       RowBox[{"1478", "\[Rule]", "1491"}], ",", 
       RowBox[{"1478", "\[Rule]", "1479"}], ",", 
       RowBox[{"1196", "\[Rule]", "1181"}], ",", 
       RowBox[{"1196", "\[Rule]", "1209"}], ",", 
       RowBox[{"1196", "\[Rule]", "1197"}], ",", 
       RowBox[{"68", "\[Rule]", "53"}], ",", 
       RowBox[{"68", "\[Rule]", "81"}], ",", 
       RowBox[{"68", "\[Rule]", "69"}], ",", 
       RowBox[{"726", "\[Rule]", "711"}], ",", 
       RowBox[{"726", "\[Rule]", "739"}], ",", 
       RowBox[{"726", "\[Rule]", "727"}], ",", 
       RowBox[{"444", "\[Rule]", "429"}], ",", 
       RowBox[{"444", "\[Rule]", "457"}], ",", 
       RowBox[{"444", "\[Rule]", "445"}], ",", 
       RowBox[{"1384", "\[Rule]", "1369"}], ",", 
       RowBox[{"1384", "\[Rule]", "1397"}], ",", 
       RowBox[{"1384", "\[Rule]", "1385"}], ",", 
       RowBox[{"1102", "\[Rule]", "1087"}], ",", 
       RowBox[{"1102", "\[Rule]", "1115"}], ",", 
       RowBox[{"1102", "\[Rule]", "1103"}], ",", 
       RowBox[{"2324", "\[Rule]", "2309"}], ",", 
       RowBox[{"2324", "\[Rule]", "2337"}], ",", 
       RowBox[{"2324", "\[Rule]", "2325"}], ",", 
       RowBox[{"2230", "\[Rule]", "2215"}], ",", 
       RowBox[{"2230", "\[Rule]", "2243"}], ",", 
       RowBox[{"2230", "\[Rule]", "2231"}], ",", 
       RowBox[{"1948", "\[Rule]", "1933"}], ",", 
       RowBox[{"1948", "\[Rule]", "1961"}], ",", 
       RowBox[{"1948", "\[Rule]", "1949"}], ",", 
       RowBox[{"2136", "\[Rule]", "2121"}], ",", 
       RowBox[{"2136", "\[Rule]", "2149"}], ",", 
       RowBox[{"2136", "\[Rule]", "2137"}], ",", 
       RowBox[{"1854", "\[Rule]", "1839"}], ",", 
       RowBox[{"1854", "\[Rule]", "1867"}], ",", 
       RowBox[{"1854", "\[Rule]", "1855"}], ",", 
       RowBox[{"2042", "\[Rule]", "2027"}], ",", 
       RowBox[{"2042", "\[Rule]", "2055"}], ",", 
       RowBox[{"2042", "\[Rule]", "2043"}], ",", 
       RowBox[{"1760", "\[Rule]", "1745"}], ",", 
       RowBox[{"1760", "\[Rule]", "1773"}], ",", 
       RowBox[{"1760", "\[Rule]", "1761"}], ",", 
       RowBox[{"291", "\[Rule]", "574"}], ",", 
       RowBox[{"291", "\[Rule]", "574"}], ",", 
       RowBox[{"291", "\[Rule]", "292"}], ",", 
       RowBox[{"949", "\[Rule]", "574"}], ",", 
       RowBox[{"949", "\[Rule]", "574"}], ",", 
       RowBox[{"949", "\[Rule]", "1232"}], ",", 
       RowBox[{"949", "\[Rule]", "1232"}], ",", 
       RowBox[{"949", "\[Rule]", "950"}], ",", 
       RowBox[{"197", "\[Rule]", "574"}], ",", 
       RowBox[{"197", "\[Rule]", "574"}], ",", 
       RowBox[{"197", "\[Rule]", "480"}], ",", 
       RowBox[{"197", "\[Rule]", "480"}], ",", 
       RowBox[{"197", "\[Rule]", "198"}], ",", 
       RowBox[{"855", "\[Rule]", "574"}], ",", 
       RowBox[{"855", "\[Rule]", "574"}], ",", 
       RowBox[{"855", "\[Rule]", "1232"}], ",", 
       RowBox[{"855", "\[Rule]", "1232"}], ",", 
       RowBox[{"855", "\[Rule]", "480"}], ",", 
       RowBox[{"855", "\[Rule]", "480"}], ",", 
       RowBox[{"855", "\[Rule]", "1138"}], ",", 
       RowBox[{"855", "\[Rule]", "1138"}], ",", 
       RowBox[{"855", "\[Rule]", "856"}], ",", 
       RowBox[{"573", "\[Rule]", "292"}], ",", 
       RowBox[{"573", "\[Rule]", "292"}], ",", 
       RowBox[{"573", "\[Rule]", "950"}], ",", 
       RowBox[{"573", "\[Rule]", "950"}], ",", 
       RowBox[{"573", "\[Rule]", "198"}], ",", 
       RowBox[{"573", "\[Rule]", "198"}], ",", 
       RowBox[{"573", "\[Rule]", "856"}], ",", 
       RowBox[{"573", "\[Rule]", "856"}], ",", 
       RowBox[{"573", "\[Rule]", "574"}], ",", 
       RowBox[{"301", "\[Rule]", "584"}], ",", 
       RowBox[{"301", "\[Rule]", "584"}], ",", 
       RowBox[{"301", "\[Rule]", "302"}], ",", 
       RowBox[{"959", "\[Rule]", "584"}], ",", 
       RowBox[{"959", "\[Rule]", "584"}], ",", 
       RowBox[{"959", "\[Rule]", "1242"}], ",", 
       RowBox[{"959", "\[Rule]", "1242"}], ",", 
       RowBox[{"959", "\[Rule]", "960"}], ",", 
       RowBox[{"207", "\[Rule]", "584"}], ",", 
       RowBox[{"207", "\[Rule]", "584"}], ",", 
       RowBox[{"207", "\[Rule]", "490"}], ",", 
       RowBox[{"207", "\[Rule]", "490"}], ",", 
       RowBox[{"207", "\[Rule]", "208"}], ",", 
       RowBox[{"865", "\[Rule]", "584"}], ",", 
       RowBox[{"865", "\[Rule]", "584"}], ",", 
       RowBox[{"865", "\[Rule]", "1242"}], ",", 
       RowBox[{"865", "\[Rule]", "1242"}], ",", 
       RowBox[{"865", "\[Rule]", "490"}], ",", 
       RowBox[{"865", "\[Rule]", "490"}], ",", 
       RowBox[{"865", "\[Rule]", "1148"}], ",", 
       RowBox[{"865", "\[Rule]", "1148"}], ",", 
       RowBox[{"865", "\[Rule]", "866"}], ",", 
       RowBox[{"583", "\[Rule]", "302"}], ",", 
       RowBox[{"583", "\[Rule]", "302"}], ",", 
       RowBox[{"583", "\[Rule]", "960"}], ",", 
       RowBox[{"583", "\[Rule]", "960"}], ",", 
       RowBox[{"583", "\[Rule]", "208"}], ",", 
       RowBox[{"583", "\[Rule]", "208"}], ",", 
       RowBox[{"583", "\[Rule]", "866"}], ",", 
       RowBox[{"583", "\[Rule]", "866"}], ",", 
       RowBox[{"583", "\[Rule]", "584"}], ",", 
       RowBox[{"1607", "\[Rule]", "1232"}], ",", 
       RowBox[{"1607", "\[Rule]", "1232"}], ",", 
       RowBox[{"1607", "\[Rule]", "1890"}], ",", 
       RowBox[{"1607", "\[Rule]", "1890"}], ",", 
       RowBox[{"1607", "\[Rule]", "1608"}], ",", 
       RowBox[{"1513", "\[Rule]", "1232"}], ",", 
       RowBox[{"1513", "\[Rule]", "1232"}], ",", 
       RowBox[{"1513", "\[Rule]", "1890"}], ",", 
       RowBox[{"1513", "\[Rule]", "1890"}], ",", 
       RowBox[{"1513", "\[Rule]", "1138"}], ",", 
       RowBox[{"1513", "\[Rule]", "1138"}], ",", 
       RowBox[{"1513", "\[Rule]", "1796"}], ",", 
       RowBox[{"1513", "\[Rule]", "1796"}], ",", 
       RowBox[{"1513", "\[Rule]", "1514"}], ",", 
       RowBox[{"1231", "\[Rule]", "950"}], ",", 
       RowBox[{"1231", "\[Rule]", "950"}], ",", 
       RowBox[{"1231", "\[Rule]", "1608"}], ",", 
       RowBox[{"1231", "\[Rule]", "1608"}], ",", 
       RowBox[{"1231", "\[Rule]", "856"}], ",", 
       RowBox[{"1231", "\[Rule]", "856"}], ",", 
       RowBox[{"1231", "\[Rule]", "1514"}], ",", 
       RowBox[{"1231", "\[Rule]", "1514"}], ",", 
       RowBox[{"1231", "\[Rule]", "1232"}], ",", 
       RowBox[{"1617", "\[Rule]", "1242"}], ",", 
       RowBox[{"1617", "\[Rule]", "1242"}], ",", 
       RowBox[{"1617", "\[Rule]", "1900"}], ",", 
       RowBox[{"1617", "\[Rule]", "1900"}], ",", 
       RowBox[{"1617", "\[Rule]", "1618"}], ",", 
       RowBox[{"1523", "\[Rule]", "1242"}], ",", 
       RowBox[{"1523", "\[Rule]", "1242"}], ",", 
       RowBox[{"1523", "\[Rule]", "1900"}], ",", 
       RowBox[{"1523", "\[Rule]", "1900"}], ",", 
       RowBox[{"1523", "\[Rule]", "1148"}], ",", 
       RowBox[{"1523", "\[Rule]", "1148"}], ",", 
       RowBox[{"1523", "\[Rule]", "1806"}], ",", 
       RowBox[{"1523", "\[Rule]", "1806"}], ",", 
       RowBox[{"1523", "\[Rule]", "1524"}], ",", 
       RowBox[{"1241", "\[Rule]", "960"}], ",", 
       RowBox[{"1241", "\[Rule]", "960"}], ",", 
       RowBox[{"1241", "\[Rule]", "1618"}], ",", 
       RowBox[{"1241", "\[Rule]", "1618"}], ",", 
       RowBox[{"1241", "\[Rule]", "866"}], ",", 
       RowBox[{"1241", "\[Rule]", "866"}], ",", 
       RowBox[{"1241", "\[Rule]", "1524"}], ",", 
       RowBox[{"1241", "\[Rule]", "1524"}], ",", 
       RowBox[{"1241", "\[Rule]", "1242"}], ",", 
       RowBox[{"103", "\[Rule]", "480"}], ",", 
       RowBox[{"103", "\[Rule]", "386"}], ",", 
       RowBox[{"103", "\[Rule]", "104"}], ",", 
       RowBox[{"761", "\[Rule]", "480"}], ",", 
       RowBox[{"761", "\[Rule]", "1138"}], ",", 
       RowBox[{"761", "\[Rule]", "1138"}], ",", 
       RowBox[{"761", "\[Rule]", "386"}], ",", 
       RowBox[{"761", "\[Rule]", "1044"}], ",", 
       RowBox[{"761", "\[Rule]", "1044"}], ",", 
       RowBox[{"761", "\[Rule]", "762"}], ",", 
       RowBox[{"479", "\[Rule]", "198"}], ",", 
       RowBox[{"479", "\[Rule]", "198"}], ",", 
       RowBox[{"479", "\[Rule]", "856"}], ",", 
       RowBox[{"479", "\[Rule]", "856"}], ",", 
       RowBox[{"479", "\[Rule]", "104"}], ",", 
       RowBox[{"479", "\[Rule]", "762"}], ",", 
       RowBox[{"479", "\[Rule]", "480"}], ",", 
       RowBox[{"113", "\[Rule]", "490"}], ",", 
       RowBox[{"113", "\[Rule]", "396"}], ",", 
       RowBox[{"113", "\[Rule]", "114"}], ",", 
       RowBox[{"771", "\[Rule]", "490"}], ",", 
       RowBox[{"771", "\[Rule]", "1148"}], ",", 
       RowBox[{"771", "\[Rule]", "1148"}], ",", 
       RowBox[{"771", "\[Rule]", "396"}], ",", 
       RowBox[{"771", "\[Rule]", "1054"}], ",", 
       RowBox[{"771", "\[Rule]", "1054"}], ",", 
       RowBox[{"771", "\[Rule]", "772"}], ",", 
       RowBox[{"489", "\[Rule]", "208"}], ",", 
       RowBox[{"489", "\[Rule]", "208"}], ",", 
       RowBox[{"489", "\[Rule]", "866"}], ",", 
       RowBox[{"489", "\[Rule]", "866"}], ",", 
       RowBox[{"489", "\[Rule]", "114"}], ",", 
       RowBox[{"489", "\[Rule]", "772"}], ",", 
       RowBox[{"489", "\[Rule]", "490"}], ",", 
       RowBox[{"1419", "\[Rule]", "1138"}], ",", 
       RowBox[{"1419", "\[Rule]", "1138"}], ",", 
       RowBox[{"1419", "\[Rule]", "1796"}], ",", 
       RowBox[{"1419", "\[Rule]", "1796"}], ",", 
       RowBox[{"1419", "\[Rule]", "1044"}], ",", 
       RowBox[{"1419", "\[Rule]", "1044"}], ",", 
       RowBox[{"1419", "\[Rule]", "1702"}], ",", 
       RowBox[{"1419", "\[Rule]", "1702"}], ",", 
       RowBox[{"1419", "\[Rule]", "1420"}], ",", 
       RowBox[{"1137", "\[Rule]", "856"}], ",", 
       RowBox[{"1137", "\[Rule]", "856"}], ",", 
       RowBox[{"1137", "\[Rule]", "1514"}], ",", 
       RowBox[{"1137", "\[Rule]", "1514"}], ",", 
       RowBox[{"1137", "\[Rule]", "762"}], ",", 
       RowBox[{"1137", "\[Rule]", "762"}], ",", 
       RowBox[{"1137", "\[Rule]", "1420"}], ",", 
       RowBox[{"1137", "\[Rule]", "1420"}], ",", 
       RowBox[{"1137", "\[Rule]", "1138"}], ",", 
       RowBox[{"1429", "\[Rule]", "1148"}], ",", 
       RowBox[{"1429", "\[Rule]", "1148"}], ",", 
       RowBox[{"1429", "\[Rule]", "1806"}], ",", 
       RowBox[{"1429", "\[Rule]", "1806"}], ",", 
       RowBox[{"1429", "\[Rule]", "1054"}], ",", 
       RowBox[{"1429", "\[Rule]", "1054"}], ",", 
       RowBox[{"1429", "\[Rule]", "1712"}], ",", 
       RowBox[{"1429", "\[Rule]", "1712"}], ",", 
       RowBox[{"1429", "\[Rule]", "1430"}], ",", 
       RowBox[{"1147", "\[Rule]", "866"}], ",", 
       RowBox[{"1147", "\[Rule]", "866"}], ",", 
       RowBox[{"1147", "\[Rule]", "1524"}], ",", 
       RowBox[{"1147", "\[Rule]", "1524"}], ",", 
       RowBox[{"1147", "\[Rule]", "772"}], ",", 
       RowBox[{"1147", "\[Rule]", "772"}], ",", 
       RowBox[{"1147", "\[Rule]", "1430"}], ",", 
       RowBox[{"1147", "\[Rule]", "1430"}], ",", 
       RowBox[{"1147", "\[Rule]", "1148"}], ",", 
       RowBox[{"313", "\[Rule]", "596"}], ",", 
       RowBox[{"313", "\[Rule]", "596"}], ",", 
       RowBox[{"313", "\[Rule]", "314"}], ",", 
       RowBox[{"971", "\[Rule]", "596"}], ",", 
       RowBox[{"971", "\[Rule]", "596"}], ",", 
       RowBox[{"971", "\[Rule]", "1254"}], ",", 
       RowBox[{"971", "\[Rule]", "1254"}], ",", 
       RowBox[{"971", "\[Rule]", "972"}], ",", 
       RowBox[{"219", "\[Rule]", "596"}], ",", 
       RowBox[{"219", "\[Rule]", "596"}], ",", 
       RowBox[{"219", "\[Rule]", "502"}], ",", 
       RowBox[{"219", "\[Rule]", "502"}], ",", 
       RowBox[{"219", "\[Rule]", "220"}], ",", 
       RowBox[{"877", "\[Rule]", "596"}], ",", 
       RowBox[{"877", "\[Rule]", "596"}], ",", 
       RowBox[{"877", "\[Rule]", "1254"}], ",", 
       RowBox[{"877", "\[Rule]", "1254"}], ",", 
       RowBox[{"877", "\[Rule]", "502"}], ",", 
       RowBox[{"877", "\[Rule]", "502"}], ",", 
       RowBox[{"877", "\[Rule]", "1160"}], ",", 
       RowBox[{"877", "\[Rule]", "1160"}], ",", 
       RowBox[{"877", "\[Rule]", "878"}], ",", 
       RowBox[{"595", "\[Rule]", "314"}], ",", 
       RowBox[{"595", "\[Rule]", "314"}], ",", 
       RowBox[{"595", "\[Rule]", "972"}], ",", 
       RowBox[{"595", "\[Rule]", "972"}], ",", 
       RowBox[{"595", "\[Rule]", "220"}], ",", 
       RowBox[{"595", "\[Rule]", "220"}], ",", 
       RowBox[{"595", "\[Rule]", "878"}], ",", 
       RowBox[{"595", "\[Rule]", "878"}], ",", 
       RowBox[{"595", "\[Rule]", "596"}], ",", 
       RowBox[{"1629", "\[Rule]", "1254"}], ",", 
       RowBox[{"1629", "\[Rule]", "1254"}], ",", 
       RowBox[{"1629", "\[Rule]", "1912"}], ",", 
       RowBox[{"1629", "\[Rule]", "1912"}], ",", 
       RowBox[{"1629", "\[Rule]", "1630"}], ",", 
       RowBox[{"1535", "\[Rule]", "1254"}], ",", 
       RowBox[{"1535", "\[Rule]", "1254"}], ",", 
       RowBox[{"1535", "\[Rule]", "1912"}], ",", 
       RowBox[{"1535", "\[Rule]", "1912"}], ",", 
       RowBox[{"1535", "\[Rule]", "1160"}], ",", 
       RowBox[{"1535", "\[Rule]", "1160"}], ",", 
       RowBox[{"1535", "\[Rule]", "1818"}], ",", 
       RowBox[{"1535", "\[Rule]", "1818"}], ",", 
       RowBox[{"1535", "\[Rule]", "1536"}], ",", 
       RowBox[{"1253", "\[Rule]", "972"}], ",", 
       RowBox[{"1253", "\[Rule]", "972"}], ",", 
       RowBox[{"1253", "\[Rule]", "1630"}], ",", 
       RowBox[{"1253", "\[Rule]", "1630"}], ",", 
       RowBox[{"1253", "\[Rule]", "878"}], ",", 
       RowBox[{"1253", "\[Rule]", "878"}], ",", 
       RowBox[{"1253", "\[Rule]", "1536"}], ",", 
       RowBox[{"1253", "\[Rule]", "1536"}], ",", 
       RowBox[{"1253", "\[Rule]", "1254"}], ",", 
       RowBox[{"125", "\[Rule]", "502"}], ",", 
       RowBox[{"125", "\[Rule]", "408"}], ",", 
       RowBox[{"125", "\[Rule]", "126"}], ",", 
       RowBox[{"501", "\[Rule]", "220"}], ",", 
       RowBox[{"501", "\[Rule]", "220"}], ",", 
       RowBox[{"501", "\[Rule]", "878"}], ",", 
       RowBox[{"501", "\[Rule]", "878"}], ",", 
       RowBox[{"501", "\[Rule]", "126"}], ",", 
       RowBox[{"501", "\[Rule]", "784"}], ",", 
       RowBox[{"501", "\[Rule]", "502"}], ",", 
       RowBox[{"783", "\[Rule]", "502"}], ",", 
       RowBox[{"783", "\[Rule]", "1160"}], ",", 
       RowBox[{"783", "\[Rule]", "1160"}], ",", 
       RowBox[{"783", "\[Rule]", "408"}], ",", 
       RowBox[{"783", "\[Rule]", "1066"}], ",", 
       RowBox[{"783", "\[Rule]", "1066"}], ",", 
       RowBox[{"783", "\[Rule]", "784"}], ",", 
       RowBox[{"1441", "\[Rule]", "1160"}], ",", 
       RowBox[{"1441", "\[Rule]", "1160"}], ",", 
       RowBox[{"1441", "\[Rule]", "1818"}], ",", 
       RowBox[{"1441", "\[Rule]", "1818"}], ",", 
       RowBox[{"1441", "\[Rule]", "1066"}], ",", 
       RowBox[{"1441", "\[Rule]", "1066"}], ",", 
       RowBox[{"1441", "\[Rule]", "1724"}], ",", 
       RowBox[{"1441", "\[Rule]", "1724"}], ",", 
       RowBox[{"1441", "\[Rule]", "1442"}], ",", 
       RowBox[{"1159", "\[Rule]", "878"}], ",", 
       RowBox[{"1159", "\[Rule]", "878"}], ",", 
       RowBox[{"1159", "\[Rule]", "1536"}], ",", 
       RowBox[{"1159", "\[Rule]", "1536"}], ",", 
       RowBox[{"1159", "\[Rule]", "784"}], ",", 
       RowBox[{"1159", "\[Rule]", "784"}], ",", 
       RowBox[{"1159", "\[Rule]", "1442"}], ",", 
       RowBox[{"1159", "\[Rule]", "1442"}], ",", 
       RowBox[{"1159", "\[Rule]", "1160"}], ",", 
       RowBox[{"9", "\[Rule]", "386"}], ",", 
       RowBox[{"9", "\[Rule]", "386"}], ",", 
       RowBox[{"9", "\[Rule]", "10"}], ",", 
       RowBox[{"667", "\[Rule]", "386"}], ",", 
       RowBox[{"667", "\[Rule]", "386"}], ",", 
       RowBox[{"667", "\[Rule]", "1044"}], ",", 
       RowBox[{"667", "\[Rule]", "668"}], ",", 
       RowBox[{"385", "\[Rule]", "104"}], ",", 
       RowBox[{"385", "\[Rule]", "762"}], ",", 
       RowBox[{"385", "\[Rule]", "10"}], ",", 
       RowBox[{"385", "\[Rule]", "10"}], ",", 
       RowBox[{"385", "\[Rule]", "668"}], ",", 
       RowBox[{"385", "\[Rule]", "668"}], ",", 
       RowBox[{"385", "\[Rule]", "386"}], ",", 
       RowBox[{"19", "\[Rule]", "396"}], ",", 
       RowBox[{"19", "\[Rule]", "396"}], ",", 
       RowBox[{"19", "\[Rule]", "20"}], ",", 
       RowBox[{"677", "\[Rule]", "396"}], ",", 
       RowBox[{"677", "\[Rule]", "396"}], ",", 
       RowBox[{"677", "\[Rule]", "1054"}], ",", 
       RowBox[{"677", "\[Rule]", "678"}], ",", 
       RowBox[{"395", "\[Rule]", "114"}], ",", 
       RowBox[{"395", "\[Rule]", "772"}], ",", 
       RowBox[{"395", "\[Rule]", "20"}], ",", 
       RowBox[{"395", "\[Rule]", "20"}], ",", 
       RowBox[{"395", "\[Rule]", "678"}], ",", 
       RowBox[{"395", "\[Rule]", "678"}], ",", 
       RowBox[{"395", "\[Rule]", "396"}], ",", 
       RowBox[{"1325", "\[Rule]", "1044"}], ",", 
       RowBox[{"1325", "\[Rule]", "1702"}], ",", 
       RowBox[{"1325", "\[Rule]", "1702"}], ",", 
       RowBox[{"1325", "\[Rule]", "1326"}], ",", 
       RowBox[{"1043", "\[Rule]", "762"}], ",", 
       RowBox[{"1043", "\[Rule]", "762"}], ",", 
       RowBox[{"1043", "\[Rule]", "1420"}], ",", 
       RowBox[{"1043", "\[Rule]", "1420"}], ",", 
       RowBox[{"1043", "\[Rule]", "668"}], ",", 
       RowBox[{"1043", "\[Rule]", "1326"}], ",", 
       RowBox[{"1043", "\[Rule]", "1044"}], ",", 
       RowBox[{"1335", "\[Rule]", "1054"}], ",", 
       RowBox[{"1335", "\[Rule]", "1712"}], ",", 
       RowBox[{"1335", "\[Rule]", "1712"}], ",", 
       RowBox[{"1335", "\[Rule]", "1336"}], ",", 
       RowBox[{"1053", "\[Rule]", "772"}], ",", 
       RowBox[{"1053", "\[Rule]", "772"}], ",", 
       RowBox[{"1053", "\[Rule]", "1430"}], ",", 
       RowBox[{"1053", "\[Rule]", "1430"}], ",", 
       RowBox[{"1053", "\[Rule]", "678"}], ",", 
       RowBox[{"1053", "\[Rule]", "1336"}], ",", 
       RowBox[{"1053", "\[Rule]", "1054"}], ",", 
       RowBox[{"31", "\[Rule]", "408"}], ",", 
       RowBox[{"31", "\[Rule]", "408"}], ",", 
       RowBox[{"31", "\[Rule]", "32"}], ",", 
       RowBox[{"689", "\[Rule]", "408"}], ",", 
       RowBox[{"689", "\[Rule]", "408"}], ",", 
       RowBox[{"689", "\[Rule]", "1066"}], ",", 
       RowBox[{"689", "\[Rule]", "690"}], ",", 
       RowBox[{"407", "\[Rule]", "126"}], ",", 
       RowBox[{"407", "\[Rule]", "784"}], ",", 
       RowBox[{"407", "\[Rule]", "32"}], ",", 
       RowBox[{"407", "\[Rule]", "32"}], ",", 
       RowBox[{"407", "\[Rule]", "690"}], ",", 
       RowBox[{"407", "\[Rule]", "690"}], ",", 
       RowBox[{"407", "\[Rule]", "408"}], ",", 
       RowBox[{"1347", "\[Rule]", "1066"}], ",", 
       RowBox[{"1347", "\[Rule]", "1724"}], ",", 
       RowBox[{"1347", "\[Rule]", "1724"}], ",", 
       RowBox[{"1347", "\[Rule]", "1348"}], ",", 
       RowBox[{"1065", "\[Rule]", "784"}], ",", 
       RowBox[{"1065", "\[Rule]", "784"}], ",", 
       RowBox[{"1065", "\[Rule]", "1442"}], ",", 
       RowBox[{"1065", "\[Rule]", "1442"}], ",", 
       RowBox[{"1065", "\[Rule]", "690"}], ",", 
       RowBox[{"1065", "\[Rule]", "1348"}], ",", 
       RowBox[{"1065", "\[Rule]", "1066"}], ",", 
       RowBox[{"323", "\[Rule]", "606"}], ",", 
       RowBox[{"323", "\[Rule]", "606"}], ",", 
       RowBox[{"323", "\[Rule]", "324"}], ",", 
       RowBox[{"981", "\[Rule]", "606"}], ",", 
       RowBox[{"981", "\[Rule]", "606"}], ",", 
       RowBox[{"981", "\[Rule]", "1264"}], ",", 
       RowBox[{"981", "\[Rule]", "1264"}], ",", 
       RowBox[{"981", "\[Rule]", "982"}], ",", 
       RowBox[{"229", "\[Rule]", "606"}], ",", 
       RowBox[{"229", "\[Rule]", "606"}], ",", 
       RowBox[{"229", "\[Rule]", "512"}], ",", 
       RowBox[{"229", "\[Rule]", "512"}], ",", 
       RowBox[{"229", "\[Rule]", "230"}], ",", 
       RowBox[{"887", "\[Rule]", "606"}], ",", 
       RowBox[{"887", "\[Rule]", "606"}], ",", 
       RowBox[{"887", "\[Rule]", "1264"}], ",", 
       RowBox[{"887", "\[Rule]", "1264"}], ",", 
       RowBox[{"887", "\[Rule]", "512"}], ",", 
       RowBox[{"887", "\[Rule]", "512"}], ",", 
       RowBox[{"887", "\[Rule]", "1170"}], ",", 
       RowBox[{"887", "\[Rule]", "1170"}], ",", 
       RowBox[{"887", "\[Rule]", "888"}], ",", 
       RowBox[{"605", "\[Rule]", "324"}], ",", 
       RowBox[{"605", "\[Rule]", "324"}], ",", 
       RowBox[{"605", "\[Rule]", "982"}], ",", 
       RowBox[{"605", "\[Rule]", "982"}], ",", 
       RowBox[{"605", "\[Rule]", "230"}], ",", 
       RowBox[{"605", "\[Rule]", "230"}], ",", 
       RowBox[{"605", "\[Rule]", "888"}], ",", 
       RowBox[{"605", "\[Rule]", "888"}], ",", 
       RowBox[{"605", "\[Rule]", "606"}], ",", 
       RowBox[{"1639", "\[Rule]", "1264"}], ",", 
       RowBox[{"1639", "\[Rule]", "1264"}], ",", 
       RowBox[{"1639", "\[Rule]", "1922"}], ",", 
       RowBox[{"1639", "\[Rule]", "1922"}], ",", 
       RowBox[{"1639", "\[Rule]", "1640"}], ",", 
       RowBox[{"1545", "\[Rule]", "1264"}], ",", 
       RowBox[{"1545", "\[Rule]", "1264"}], ",", 
       RowBox[{"1545", "\[Rule]", "1922"}], ",", 
       RowBox[{"1545", "\[Rule]", "1922"}], ",", 
       RowBox[{"1545", "\[Rule]", "1170"}], ",", 
       RowBox[{"1545", "\[Rule]", "1170"}], ",", 
       RowBox[{"1545", "\[Rule]", "1828"}], ",", 
       RowBox[{"1545", "\[Rule]", "1828"}], ",", 
       RowBox[{"1545", "\[Rule]", "1546"}], ",", 
       RowBox[{"1263", "\[Rule]", "982"}], ",", 
       RowBox[{"1263", "\[Rule]", "982"}], ",", 
       RowBox[{"1263", "\[Rule]", "1640"}], ",", 
       RowBox[{"1263", "\[Rule]", "1640"}], ",", 
       RowBox[{"1263", "\[Rule]", "888"}], ",", 
       RowBox[{"1263", "\[Rule]", "888"}], ",", 
       RowBox[{"1263", "\[Rule]", "1546"}], ",", 
       RowBox[{"1263", "\[Rule]", "1546"}], ",", 
       RowBox[{"1263", "\[Rule]", "1264"}], ",", 
       RowBox[{"135", "\[Rule]", "512"}], ",", 
       RowBox[{"135", "\[Rule]", "418"}], ",", 
       RowBox[{"135", "\[Rule]", "136"}], ",", 
       RowBox[{"793", "\[Rule]", "512"}], ",", 
       RowBox[{"793", "\[Rule]", "1170"}], ",", 
       RowBox[{"793", "\[Rule]", "1170"}], ",", 
       RowBox[{"793", "\[Rule]", "418"}], ",", 
       RowBox[{"793", "\[Rule]", "1076"}], ",", 
       RowBox[{"793", "\[Rule]", "1076"}], ",", 
       RowBox[{"793", "\[Rule]", "794"}], ",", 
       RowBox[{"511", "\[Rule]", "230"}], ",", 
       RowBox[{"511", "\[Rule]", "230"}], ",", 
       RowBox[{"511", "\[Rule]", "888"}], ",", 
       RowBox[{"511", "\[Rule]", "888"}], ",", 
       RowBox[{"511", "\[Rule]", "136"}], ",", 
       RowBox[{"511", "\[Rule]", "794"}], ",", 
       RowBox[{"511", "\[Rule]", "512"}], ",", 
       RowBox[{"1451", "\[Rule]", "1170"}], ",", 
       RowBox[{"1451", "\[Rule]", "1170"}], ",", 
       RowBox[{"1451", "\[Rule]", "1828"}], ",", 
       RowBox[{"1451", "\[Rule]", "1828"}], ",", 
       RowBox[{"1451", "\[Rule]", "1076"}], ",", 
       RowBox[{"1451", "\[Rule]", "1076"}], ",", 
       RowBox[{"1451", "\[Rule]", "1734"}], ",", 
       RowBox[{"1451", "\[Rule]", "1734"}], ",", 
       RowBox[{"1451", "\[Rule]", "1452"}], ",", 
       RowBox[{"1169", "\[Rule]", "888"}], ",", 
       RowBox[{"1169", "\[Rule]", "888"}], ",", 
       RowBox[{"1169", "\[Rule]", "1546"}], ",", 
       RowBox[{"1169", "\[Rule]", "1546"}], ",", 
       RowBox[{"1169", "\[Rule]", "794"}], ",", 
       RowBox[{"1169", "\[Rule]", "794"}], ",", 
       RowBox[{"1169", "\[Rule]", "1452"}], ",", 
       RowBox[{"1169", "\[Rule]", "1452"}], ",", 
       RowBox[{"1169", "\[Rule]", "1170"}], ",", 
       RowBox[{"41", "\[Rule]", "418"}], ",", 
       RowBox[{"41", "\[Rule]", "418"}], ",", 
       RowBox[{"41", "\[Rule]", "42"}], ",", 
       RowBox[{"699", "\[Rule]", "418"}], ",", 
       RowBox[{"699", "\[Rule]", "418"}], ",", 
       RowBox[{"699", "\[Rule]", "1076"}], ",", 
       RowBox[{"699", "\[Rule]", "700"}], ",", 
       RowBox[{"417", "\[Rule]", "136"}], ",", 
       RowBox[{"417", "\[Rule]", "794"}], ",", 
       RowBox[{"417", "\[Rule]", "42"}], ",", 
       RowBox[{"417", "\[Rule]", "42"}], ",", 
       RowBox[{"417", "\[Rule]", "700"}], ",", 
       RowBox[{"417", "\[Rule]", "700"}], ",", 
       RowBox[{"417", "\[Rule]", "418"}], ",", 
       RowBox[{"1357", "\[Rule]", "1076"}], ",", 
       RowBox[{"1357", "\[Rule]", "1734"}], ",", 
       RowBox[{"1357", "\[Rule]", "1734"}], ",", 
       RowBox[{"1357", "\[Rule]", "1358"}], ",", 
       RowBox[{"1075", "\[Rule]", "794"}], ",", 
       RowBox[{"1075", "\[Rule]", "794"}], ",", 
       RowBox[{"1075", "\[Rule]", "1452"}], ",", 
       RowBox[{"1075", "\[Rule]", "1452"}], ",", 
       RowBox[{"1075", "\[Rule]", "700"}], ",", 
       RowBox[{"1075", "\[Rule]", "1358"}], ",", 
       RowBox[{"1075", "\[Rule]", "1076"}], ",", 
       RowBox[{"2265", "\[Rule]", "1890"}], ",", 
       RowBox[{"2265", "\[Rule]", "1890"}], ",", 
       RowBox[{"2265", "\[Rule]", "2266"}], ",", 
       RowBox[{"2171", "\[Rule]", "1890"}], ",", 
       RowBox[{"2171", "\[Rule]", "1890"}], ",", 
       RowBox[{"2171", "\[Rule]", "1796"}], ",", 
       RowBox[{"2171", "\[Rule]", "1796"}], ",", 
       RowBox[{"2171", "\[Rule]", "2172"}], ",", 
       RowBox[{"1889", "\[Rule]", "1608"}], ",", 
       RowBox[{"1889", "\[Rule]", "1608"}], ",", 
       RowBox[{"1889", "\[Rule]", "2266"}], ",", 
       RowBox[{"1889", "\[Rule]", "2266"}], ",", 
       RowBox[{"1889", "\[Rule]", "1514"}], ",", 
       RowBox[{"1889", "\[Rule]", "1514"}], ",", 
       RowBox[{"1889", "\[Rule]", "2172"}], ",", 
       RowBox[{"1889", "\[Rule]", "2172"}], ",", 
       RowBox[{"1889", "\[Rule]", "1890"}], ",", 
       RowBox[{"2275", "\[Rule]", "1900"}], ",", 
       RowBox[{"2275", "\[Rule]", "1900"}], ",", 
       RowBox[{"2275", "\[Rule]", "2276"}], ",", 
       RowBox[{"2181", "\[Rule]", "1900"}], ",", 
       RowBox[{"2181", "\[Rule]", "1900"}], ",", 
       RowBox[{"2181", "\[Rule]", "1806"}], ",", 
       RowBox[{"2181", "\[Rule]", "1806"}], ",", 
       RowBox[{"2181", "\[Rule]", "2182"}], ",", 
       RowBox[{"1899", "\[Rule]", "1618"}], ",", 
       RowBox[{"1899", "\[Rule]", "1618"}], ",", 
       RowBox[{"1899", "\[Rule]", "2276"}], ",", 
       RowBox[{"1899", "\[Rule]", "2276"}], ",", 
       RowBox[{"1899", "\[Rule]", "1524"}], ",", 
       RowBox[{"1899", "\[Rule]", "1524"}], ",", 
       RowBox[{"1899", "\[Rule]", "2182"}], ",", 
       RowBox[{"1899", "\[Rule]", "2182"}], ",", 
       RowBox[{"1899", "\[Rule]", "1900"}], ",", 
       RowBox[{"2077", "\[Rule]", "1796"}], ",", 
       RowBox[{"2077", "\[Rule]", "1796"}], ",", 
       RowBox[{"2077", "\[Rule]", "1702"}], ",", 
       RowBox[{"2077", "\[Rule]", "1702"}], ",", 
       RowBox[{"2077", "\[Rule]", "2078"}], ",", 
       RowBox[{"1795", "\[Rule]", "1514"}], ",", 
       RowBox[{"1795", "\[Rule]", "1514"}], ",", 
       RowBox[{"1795", "\[Rule]", "2172"}], ",", 
       RowBox[{"1795", "\[Rule]", "2172"}], ",", 
       RowBox[{"1795", "\[Rule]", "1420"}], ",", 
       RowBox[{"1795", "\[Rule]", "1420"}], ",", 
       RowBox[{"1795", "\[Rule]", "2078"}], ",", 
       RowBox[{"1795", "\[Rule]", "2078"}], ",", 
       RowBox[{"1795", "\[Rule]", "1796"}], ",", 
       RowBox[{"2087", "\[Rule]", "1806"}], ",", 
       RowBox[{"2087", "\[Rule]", "1806"}], ",", 
       RowBox[{"2087", "\[Rule]", "1712"}], ",", 
       RowBox[{"2087", "\[Rule]", "1712"}], ",", 
       RowBox[{"2087", "\[Rule]", "2088"}], ",", 
       RowBox[{"1805", "\[Rule]", "1524"}], ",", 
       RowBox[{"1805", "\[Rule]", "1524"}], ",", 
       RowBox[{"1805", "\[Rule]", "2182"}], ",", 
       RowBox[{"1805", "\[Rule]", "2182"}], ",", 
       RowBox[{"1805", "\[Rule]", "1430"}], ",", 
       RowBox[{"1805", "\[Rule]", "1430"}], ",", 
       RowBox[{"1805", "\[Rule]", "2088"}], ",", 
       RowBox[{"1805", "\[Rule]", "2088"}], ",", 
       RowBox[{"1805", "\[Rule]", "1806"}], ",", 
       RowBox[{"2287", "\[Rule]", "1912"}], ",", 
       RowBox[{"2287", "\[Rule]", "1912"}], ",", 
       RowBox[{"2287", "\[Rule]", "2288"}], ",", 
       RowBox[{"2193", "\[Rule]", "1912"}], ",", 
       RowBox[{"2193", "\[Rule]", "1912"}], ",", 
       RowBox[{"2193", "\[Rule]", "1818"}], ",", 
       RowBox[{"2193", "\[Rule]", "1818"}], ",", 
       RowBox[{"2193", "\[Rule]", "2194"}], ",", 
       RowBox[{"1911", "\[Rule]", "1630"}], ",", 
       RowBox[{"1911", "\[Rule]", "1630"}], ",", 
       RowBox[{"1911", "\[Rule]", "2288"}], ",", 
       RowBox[{"1911", "\[Rule]", "2288"}], ",", 
       RowBox[{"1911", "\[Rule]", "1536"}], ",", 
       RowBox[{"1911", "\[Rule]", "1536"}], ",", 
       RowBox[{"1911", "\[Rule]", "2194"}], ",", 
       RowBox[{"1911", "\[Rule]", "2194"}], ",", 
       RowBox[{"1911", "\[Rule]", "1912"}], ",", 
       RowBox[{"2099", "\[Rule]", "1818"}], ",", 
       RowBox[{"2099", "\[Rule]", "1818"}], ",", 
       RowBox[{"2099", "\[Rule]", "1724"}], ",", 
       RowBox[{"2099", "\[Rule]", "1724"}], ",", 
       RowBox[{"2099", "\[Rule]", "2100"}], ",", 
       RowBox[{"1817", "\[Rule]", "1536"}], ",", 
       RowBox[{"1817", "\[Rule]", "1536"}], ",", 
       RowBox[{"1817", "\[Rule]", "2194"}], ",", 
       RowBox[{"1817", "\[Rule]", "2194"}], ",", 
       RowBox[{"1817", "\[Rule]", "1442"}], ",", 
       RowBox[{"1817", "\[Rule]", "1442"}], ",", 
       RowBox[{"1817", "\[Rule]", "2100"}], ",", 
       RowBox[{"1817", "\[Rule]", "2100"}], ",", 
       RowBox[{"1817", "\[Rule]", "1818"}], ",", 
       RowBox[{"1983", "\[Rule]", "1702"}], ",", 
       RowBox[{"1983", "\[Rule]", "1702"}], ",", 
       RowBox[{"1983", "\[Rule]", "1984"}], ",", 
       RowBox[{"1701", "\[Rule]", "1420"}], ",", 
       RowBox[{"1701", "\[Rule]", "1420"}], ",", 
       RowBox[{"1701", "\[Rule]", "2078"}], ",", 
       RowBox[{"1701", "\[Rule]", "2078"}], ",", 
       RowBox[{"1701", "\[Rule]", "1326"}], ",", 
       RowBox[{"1701", "\[Rule]", "1326"}], ",", 
       RowBox[{"1701", "\[Rule]", "1984"}], ",", 
       RowBox[{"1701", "\[Rule]", "1984"}], ",", 
       RowBox[{"1701", "\[Rule]", "1702"}], ",", 
       RowBox[{"1993", "\[Rule]", "1712"}], ",", 
       RowBox[{"1993", "\[Rule]", "1712"}], ",", 
       RowBox[{"1993", "\[Rule]", "1994"}], ",", 
       RowBox[{"1711", "\[Rule]", "1430"}], ",", 
       RowBox[{"1711", "\[Rule]", "1430"}], ",", 
       RowBox[{"1711", "\[Rule]", "2088"}], ",", 
       RowBox[{"1711", "\[Rule]", "2088"}], ",", 
       RowBox[{"1711", "\[Rule]", "1336"}], ",", 
       RowBox[{"1711", "\[Rule]", "1336"}], ",", 
       RowBox[{"1711", "\[Rule]", "1994"}], ",", 
       RowBox[{"1711", "\[Rule]", "1994"}], ",", 
       RowBox[{"1711", "\[Rule]", "1712"}], ",", 
       RowBox[{"2005", "\[Rule]", "1724"}], ",", 
       RowBox[{"2005", "\[Rule]", "1724"}], ",", 
       RowBox[{"2005", "\[Rule]", "2006"}], ",", 
       RowBox[{"1723", "\[Rule]", "1442"}], ",", 
       RowBox[{"1723", "\[Rule]", "1442"}], ",", 
       RowBox[{"1723", "\[Rule]", "2100"}], ",", 
       RowBox[{"1723", "\[Rule]", "2100"}], ",", 
       RowBox[{"1723", "\[Rule]", "1348"}], ",", 
       RowBox[{"1723", "\[Rule]", "1348"}], ",", 
       RowBox[{"1723", "\[Rule]", "2006"}], ",", 
       RowBox[{"1723", "\[Rule]", "2006"}], ",", 
       RowBox[{"1723", "\[Rule]", "1724"}], ",", 
       RowBox[{"2297", "\[Rule]", "1922"}], ",", 
       RowBox[{"2297", "\[Rule]", "1922"}], ",", 
       RowBox[{"2297", "\[Rule]", "2298"}], ",", 
       RowBox[{"2203", "\[Rule]", "1922"}], ",", 
       RowBox[{"2203", "\[Rule]", "1922"}], ",", 
       RowBox[{"2203", "\[Rule]", "1828"}], ",", 
       RowBox[{"2203", "\[Rule]", "1828"}], ",", 
       RowBox[{"2203", "\[Rule]", "2204"}], ",", 
       RowBox[{"1921", "\[Rule]", "1640"}], ",", 
       RowBox[{"1921", "\[Rule]", "1640"}], ",", 
       RowBox[{"1921", "\[Rule]", "2298"}], ",", 
       RowBox[{"1921", "\[Rule]", "2298"}], ",", 
       RowBox[{"1921", "\[Rule]", "1546"}], ",", 
       RowBox[{"1921", "\[Rule]", "1546"}], ",", 
       RowBox[{"1921", "\[Rule]", "2204"}], ",", 
       RowBox[{"1921", "\[Rule]", "2204"}], ",", 
       RowBox[{"1921", "\[Rule]", "1922"}], ",", 
       RowBox[{"2109", "\[Rule]", "1828"}], ",", 
       RowBox[{"2109", "\[Rule]", "1828"}], ",", 
       RowBox[{"2109", "\[Rule]", "1734"}], ",", 
       RowBox[{"2109", "\[Rule]", "1734"}], ",", 
       RowBox[{"2109", "\[Rule]", "2110"}], ",", 
       RowBox[{"1827", "\[Rule]", "1546"}], ",", 
       RowBox[{"1827", "\[Rule]", "1546"}], ",", 
       RowBox[{"1827", "\[Rule]", "2204"}], ",", 
       RowBox[{"1827", "\[Rule]", "2204"}], ",", 
       RowBox[{"1827", "\[Rule]", "1452"}], ",", 
       RowBox[{"1827", "\[Rule]", "1452"}], ",", 
       RowBox[{"1827", "\[Rule]", "2110"}], ",", 
       RowBox[{"1827", "\[Rule]", "2110"}], ",", 
       RowBox[{"1827", "\[Rule]", "1828"}], ",", 
       RowBox[{"2015", "\[Rule]", "1734"}], ",", 
       RowBox[{"2015", "\[Rule]", "1734"}], ",", 
       RowBox[{"2015", "\[Rule]", "2016"}], ",", 
       RowBox[{"1733", "\[Rule]", "1452"}], ",", 
       RowBox[{"1733", "\[Rule]", "1452"}], ",", 
       RowBox[{"1733", "\[Rule]", "2110"}], ",", 
       RowBox[{"1733", "\[Rule]", "2110"}], ",", 
       RowBox[{"1733", "\[Rule]", "1358"}], ",", 
       RowBox[{"1733", "\[Rule]", "1358"}], ",", 
       RowBox[{"1733", "\[Rule]", "2016"}], ",", 
       RowBox[{"1733", "\[Rule]", "2016"}], ",", 
       RowBox[{"1733", "\[Rule]", "1734"}], ",", 
       RowBox[{"335", "\[Rule]", "618"}], ",", 
       RowBox[{"335", "\[Rule]", "618"}], ",", 
       RowBox[{"335", "\[Rule]", "336"}], ",", 
       RowBox[{"993", "\[Rule]", "618"}], ",", 
       RowBox[{"993", "\[Rule]", "618"}], ",", 
       RowBox[{"993", "\[Rule]", "1276"}], ",", 
       RowBox[{"993", "\[Rule]", "1276"}], ",", 
       RowBox[{"993", "\[Rule]", "994"}], ",", 
       RowBox[{"241", "\[Rule]", "618"}], ",", 
       RowBox[{"241", "\[Rule]", "618"}], ",", 
       RowBox[{"241", "\[Rule]", "524"}], ",", 
       RowBox[{"241", "\[Rule]", "524"}], ",", 
       RowBox[{"241", "\[Rule]", "242"}], ",", 
       RowBox[{"899", "\[Rule]", "618"}], ",", 
       RowBox[{"899", "\[Rule]", "618"}], ",", 
       RowBox[{"899", "\[Rule]", "1276"}], ",", 
       RowBox[{"899", "\[Rule]", "1276"}], ",", 
       RowBox[{"899", "\[Rule]", "524"}], ",", 
       RowBox[{"899", "\[Rule]", "524"}], ",", 
       RowBox[{"899", "\[Rule]", "1182"}], ",", 
       RowBox[{"899", "\[Rule]", "1182"}], ",", 
       RowBox[{"899", "\[Rule]", "900"}], ",", 
       RowBox[{"617", "\[Rule]", "336"}], ",", 
       RowBox[{"617", "\[Rule]", "336"}], ",", 
       RowBox[{"617", "\[Rule]", "994"}], ",", 
       RowBox[{"617", "\[Rule]", "994"}], ",", 
       RowBox[{"617", "\[Rule]", "242"}], ",", 
       RowBox[{"617", "\[Rule]", "242"}], ",", 
       RowBox[{"617", "\[Rule]", "900"}], ",", 
       RowBox[{"617", "\[Rule]", "900"}], ",", 
       RowBox[{"617", "\[Rule]", "618"}], ",", 
       RowBox[{"1651", "\[Rule]", "1276"}], ",", 
       RowBox[{"1651", "\[Rule]", "1276"}], ",", 
       RowBox[{"1651", "\[Rule]", "1934"}], ",", 
       RowBox[{"1651", "\[Rule]", "1934"}], ",", 
       RowBox[{"1651", "\[Rule]", "1652"}], ",", 
       RowBox[{"1557", "\[Rule]", "1276"}], ",", 
       RowBox[{"1557", "\[Rule]", "1276"}], ",", 
       RowBox[{"1557", "\[Rule]", "1934"}], ",", 
       RowBox[{"1557", "\[Rule]", "1934"}], ",", 
       RowBox[{"1557", "\[Rule]", "1182"}], ",", 
       RowBox[{"1557", "\[Rule]", "1182"}], ",", 
       RowBox[{"1557", "\[Rule]", "1840"}], ",", 
       RowBox[{"1557", "\[Rule]", "1840"}], ",", 
       RowBox[{"1557", "\[Rule]", "1558"}], ",", 
       RowBox[{"1275", "\[Rule]", "994"}], ",", 
       RowBox[{"1275", "\[Rule]", "994"}], ",", 
       RowBox[{"1275", "\[Rule]", "1652"}], ",", 
       RowBox[{"1275", "\[Rule]", "1652"}], ",", 
       RowBox[{"1275", "\[Rule]", "900"}], ",", 
       RowBox[{"1275", "\[Rule]", "900"}], ",", 
       RowBox[{"1275", "\[Rule]", "1558"}], ",", 
       RowBox[{"1275", "\[Rule]", "1558"}], ",", 
       RowBox[{"1275", "\[Rule]", "1276"}], ",", 
       RowBox[{"147", "\[Rule]", "524"}], ",", 
       RowBox[{"147", "\[Rule]", "430"}], ",", 
       RowBox[{"147", "\[Rule]", "148"}], ",", 
       RowBox[{"805", "\[Rule]", "524"}], ",", 
       RowBox[{"805", "\[Rule]", "1182"}], ",", 
       RowBox[{"805", "\[Rule]", "1182"}], ",", 
       RowBox[{"805", "\[Rule]", "430"}], ",", 
       RowBox[{"805", "\[Rule]", "1088"}], ",", 
       RowBox[{"805", "\[Rule]", "1088"}], ",", 
       RowBox[{"805", "\[Rule]", "806"}], ",", 
       RowBox[{"523", "\[Rule]", "242"}], ",", 
       RowBox[{"523", "\[Rule]", "242"}], ",", 
       RowBox[{"523", "\[Rule]", "900"}], ",", 
       RowBox[{"523", "\[Rule]", "900"}], ",", 
       RowBox[{"523", "\[Rule]", "148"}], ",", 
       RowBox[{"523", "\[Rule]", "806"}], ",", 
       RowBox[{"523", "\[Rule]", "524"}], ",", 
       RowBox[{"1463", "\[Rule]", "1182"}], ",", 
       RowBox[{"1463", "\[Rule]", "1182"}], ",", 
       RowBox[{"1463", "\[Rule]", "1840"}], ",", 
       RowBox[{"1463", "\[Rule]", "1840"}], ",", 
       RowBox[{"1463", "\[Rule]", "1088"}], ",", 
       RowBox[{"1463", "\[Rule]", "1088"}], ",", 
       RowBox[{"1463", "\[Rule]", "1746"}], ",", 
       RowBox[{"1463", "\[Rule]", "1746"}], ",", 
       RowBox[{"1463", "\[Rule]", "1464"}], ",", 
       RowBox[{"1181", "\[Rule]", "900"}], ",", 
       RowBox[{"1181", "\[Rule]", "900"}], ",", 
       RowBox[{"1181", "\[Rule]", "1558"}], ",", 
       RowBox[{"1181", "\[Rule]", "1558"}], ",", 
       RowBox[{"1181", "\[Rule]", "806"}], ",", 
       RowBox[{"1181", "\[Rule]", "806"}], ",", 
       RowBox[{"1181", "\[Rule]", "1464"}], ",", 
       RowBox[{"1181", "\[Rule]", "1464"}], ",", 
       RowBox[{"1181", "\[Rule]", "1182"}], ",", 
       RowBox[{"53", "\[Rule]", "430"}], ",", 
       RowBox[{"53", "\[Rule]", "430"}], ",", 
       RowBox[{"53", "\[Rule]", "54"}], ",", 
       RowBox[{"711", "\[Rule]", "430"}], ",", 
       RowBox[{"711", "\[Rule]", "430"}], ",", 
       RowBox[{"711", "\[Rule]", "1088"}], ",", 
       RowBox[{"711", "\[Rule]", "712"}], ",", 
       RowBox[{"429", "\[Rule]", "148"}], ",", 
       RowBox[{"429", "\[Rule]", "806"}], ",", 
       RowBox[{"429", "\[Rule]", "54"}], ",", 
       RowBox[{"429", "\[Rule]", "54"}], ",", 
       RowBox[{"429", "\[Rule]", "712"}], ",", 
       RowBox[{"429", "\[Rule]", "712"}], ",", 
       RowBox[{"429", "\[Rule]", "430"}], ",", 
       RowBox[{"1087", "\[Rule]", "806"}], ",", 
       RowBox[{"1087", "\[Rule]", "806"}], ",", 
       RowBox[{"1087", "\[Rule]", "1464"}], ",", 
       RowBox[{"1087", "\[Rule]", "1464"}], ",", 
       RowBox[{"1087", "\[Rule]", "712"}], ",", 
       RowBox[{"1087", "\[Rule]", "1370"}], ",", 
       RowBox[{"1087", "\[Rule]", "1088"}], ",", 
       RowBox[{"2309", "\[Rule]", "1934"}], ",", 
       RowBox[{"2309", "\[Rule]", "1934"}], ",", 
       RowBox[{"2309", "\[Rule]", "2310"}], ",", 
       RowBox[{"2215", "\[Rule]", "1934"}], ",", 
       RowBox[{"2215", "\[Rule]", "1934"}], ",", 
       RowBox[{"2215", "\[Rule]", "1840"}], ",", 
       RowBox[{"2215", "\[Rule]", "1840"}], ",", 
       RowBox[{"2215", "\[Rule]", "2216"}], ",", 
       RowBox[{"1933", "\[Rule]", "1652"}], ",", 
       RowBox[{"1933", "\[Rule]", "1652"}], ",", 
       RowBox[{"1933", "\[Rule]", "2310"}], ",", 
       RowBox[{"1933", "\[Rule]", "2310"}], ",", 
       RowBox[{"1933", "\[Rule]", "1558"}], ",", 
       RowBox[{"1933", "\[Rule]", "1558"}], ",", 
       RowBox[{"1933", "\[Rule]", "2216"}], ",", 
       RowBox[{"1933", "\[Rule]", "2216"}], ",", 
       RowBox[{"1933", "\[Rule]", "1934"}], ",", 
       RowBox[{"2121", "\[Rule]", "1840"}], ",", 
       RowBox[{"2121", "\[Rule]", "1840"}], ",", 
       RowBox[{"2121", "\[Rule]", "1746"}], ",", 
       RowBox[{"2121", "\[Rule]", "1746"}], ",", 
       RowBox[{"2121", "\[Rule]", "2122"}], ",", 
       RowBox[{"1839", "\[Rule]", "1558"}], ",", 
       RowBox[{"1839", "\[Rule]", "1558"}], ",", 
       RowBox[{"1839", "\[Rule]", "2216"}], ",", 
       RowBox[{"1839", "\[Rule]", "2216"}], ",", 
       RowBox[{"1839", "\[Rule]", "1464"}], ",", 
       RowBox[{"1839", "\[Rule]", "1464"}], ",", 
       RowBox[{"1839", "\[Rule]", "2122"}], ",", 
       RowBox[{"1839", "\[Rule]", "2122"}], ",", 
       RowBox[{"1839", "\[Rule]", "1840"}], ",", 
       RowBox[{"1369", "\[Rule]", "1088"}], ",", 
       RowBox[{"1369", "\[Rule]", "1746"}], ",", 
       RowBox[{"1369", "\[Rule]", "1746"}], ",", 
       RowBox[{"1369", "\[Rule]", "1370"}], ",", 
       RowBox[{"2027", "\[Rule]", "1746"}], ",", 
       RowBox[{"2027", "\[Rule]", "1746"}], ",", 
       RowBox[{"2027", "\[Rule]", "2028"}], ",", 
       RowBox[{"1745", "\[Rule]", "1464"}], ",", 
       RowBox[{"1745", "\[Rule]", "1464"}], ",", 
       RowBox[{"1745", "\[Rule]", "2122"}], ",", 
       RowBox[{"1745", "\[Rule]", "2122"}], ",", 
       RowBox[{"1745", "\[Rule]", "1370"}], ",", 
       RowBox[{"1745", "\[Rule]", "1370"}], ",", 
       RowBox[{"1745", "\[Rule]", "2028"}], ",", 
       RowBox[{"1745", "\[Rule]", "2028"}], ",", 
       RowBox[{"1745", "\[Rule]", "1746"}], ",", 
       RowBox[{"574", "\[Rule]", "585"}], ",", 
       RowBox[{"574", "\[Rule]", "575"}], ",", 
       RowBox[{"574", "\[Rule]", "571"}], ",", 
       RowBox[{"292", "\[Rule]", "303"}], ",", 
       RowBox[{"292", "\[Rule]", "293"}], ",", 
       RowBox[{"292", "\[Rule]", "289"}], ",", 
       RowBox[{"1232", "\[Rule]", "1243"}], ",", 
       RowBox[{"1232", "\[Rule]", "1233"}], ",", 
       RowBox[{"1232", "\[Rule]", "1229"}], ",", 
       RowBox[{"950", "\[Rule]", "961"}], ",", 
       RowBox[{"950", "\[Rule]", "951"}], ",", 
       RowBox[{"950", "\[Rule]", "947"}], ",", 
       RowBox[{"480", "\[Rule]", "491"}], ",", 
       RowBox[{"480", "\[Rule]", "481"}], ",", 
       RowBox[{"480", "\[Rule]", "477"}], ",", 
       RowBox[{"198", "\[Rule]", "209"}], ",", 
       RowBox[{"198", "\[Rule]", "199"}], ",", 
       RowBox[{"198", "\[Rule]", "195"}], ",", 
       RowBox[{"1138", "\[Rule]", "1149"}], ",", 
       RowBox[{"1138", "\[Rule]", "1139"}], ",", 
       RowBox[{"1138", "\[Rule]", "1135"}], ",", 
       RowBox[{"856", "\[Rule]", "867"}], ",", 
       RowBox[{"856", "\[Rule]", "857"}], ",", 
       RowBox[{"856", "\[Rule]", "853"}], ",", 
       RowBox[{"584", "\[Rule]", "571"}], ",", 
       RowBox[{"584", "\[Rule]", "597"}], ",", 
       RowBox[{"584", "\[Rule]", "585"}], ",", 
       RowBox[{"302", "\[Rule]", "289"}], ",", 
       RowBox[{"302", "\[Rule]", "315"}], ",", 
       RowBox[{"302", "\[Rule]", "303"}], ",", 
       RowBox[{"1242", "\[Rule]", "1229"}], ",", 
       RowBox[{"1242", "\[Rule]", "1255"}], ",", 
       RowBox[{"1242", "\[Rule]", "1243"}], ",", 
       RowBox[{"960", "\[Rule]", "947"}], ",", 
       RowBox[{"960", "\[Rule]", "973"}], ",", 
       RowBox[{"960", "\[Rule]", "961"}], ",", 
       RowBox[{"490", "\[Rule]", "477"}], ",", 
       RowBox[{"490", "\[Rule]", "503"}], ",", 
       RowBox[{"490", "\[Rule]", "491"}], ",", 
       RowBox[{"208", "\[Rule]", "195"}], ",", 
       RowBox[{"208", "\[Rule]", "221"}], ",", 
       RowBox[{"208", "\[Rule]", "209"}], ",", 
       RowBox[{"1148", "\[Rule]", "1135"}], ",", 
       RowBox[{"1148", "\[Rule]", "1161"}], ",", 
       RowBox[{"1148", "\[Rule]", "1149"}], ",", 
       RowBox[{"866", "\[Rule]", "853"}], ",", 
       RowBox[{"866", "\[Rule]", "879"}], ",", 
       RowBox[{"866", "\[Rule]", "867"}], ",", 
       RowBox[{"1890", "\[Rule]", "1901"}], ",", 
       RowBox[{"1890", "\[Rule]", "1891"}], ",", 
       RowBox[{"1890", "\[Rule]", "1887"}], ",", 
       RowBox[{"1608", "\[Rule]", "1619"}], ",", 
       RowBox[{"1608", "\[Rule]", "1609"}], ",", 
       RowBox[{"1608", "\[Rule]", "1605"}], ",", 
       RowBox[{"1796", "\[Rule]", "1807"}], ",", 
       RowBox[{"1796", "\[Rule]", "1797"}], ",", 
       RowBox[{"1796", "\[Rule]", "1793"}], ",", 
       RowBox[{"1514", "\[Rule]", "1525"}], ",", 
       RowBox[{"1514", "\[Rule]", "1515"}], ",", 
       RowBox[{"1514", "\[Rule]", "1511"}], ",", 
       RowBox[{"1900", "\[Rule]", "1887"}], ",", 
       RowBox[{"1900", "\[Rule]", "1913"}], ",", 
       RowBox[{"1900", "\[Rule]", "1901"}], ",", 
       RowBox[{"1618", "\[Rule]", "1605"}], ",", 
       RowBox[{"1618", "\[Rule]", "1631"}], ",", 
       RowBox[{"1618", "\[Rule]", "1619"}], ",", 
       RowBox[{"1806", "\[Rule]", "1793"}], ",", 
       RowBox[{"1806", "\[Rule]", "1819"}], ",", 
       RowBox[{"1806", "\[Rule]", "1807"}], ",", 
       RowBox[{"1524", "\[Rule]", "1511"}], ",", 
       RowBox[{"1524", "\[Rule]", "1537"}], ",", 
       RowBox[{"1524", "\[Rule]", "1525"}], ",", 
       RowBox[{"386", "\[Rule]", "397"}], ",", 
       RowBox[{"386", "\[Rule]", "387"}], ",", 
       RowBox[{"386", "\[Rule]", "383"}], ",", 
       RowBox[{"104", "\[Rule]", "115"}], ",", 
       RowBox[{"104", "\[Rule]", "105"}], ",", 
       RowBox[{"104", "\[Rule]", "101"}], ",", 
       RowBox[{"1044", "\[Rule]", "1055"}], ",", 
       RowBox[{"1044", "\[Rule]", "1045"}], ",", 
       RowBox[{"1044", "\[Rule]", "1041"}], ",", 
       RowBox[{"762", "\[Rule]", "773"}], ",", 
       RowBox[{"762", "\[Rule]", "763"}], ",", 
       RowBox[{"762", "\[Rule]", "759"}], ",", 
       RowBox[{"396", "\[Rule]", "383"}], ",", 
       RowBox[{"396", "\[Rule]", "409"}], ",", 
       RowBox[{"396", "\[Rule]", "397"}], ",", 
       RowBox[{"114", "\[Rule]", "101"}], ",", 
       RowBox[{"114", "\[Rule]", "127"}], ",", 
       RowBox[{"114", "\[Rule]", "115"}], ",", 
       RowBox[{"1054", "\[Rule]", "1041"}], ",", 
       RowBox[{"1054", "\[Rule]", "1067"}], ",", 
       RowBox[{"1054", "\[Rule]", "1055"}], ",", 
       RowBox[{"772", "\[Rule]", "759"}], ",", 
       RowBox[{"772", "\[Rule]", "785"}], ",", 
       RowBox[{"772", "\[Rule]", "773"}], ",", 
       RowBox[{"1702", "\[Rule]", "1713"}], ",", 
       RowBox[{"1702", "\[Rule]", "1703"}], ",", 
       RowBox[{"1702", "\[Rule]", "1699"}], ",", 
       RowBox[{"1420", "\[Rule]", "1431"}], ",", 
       RowBox[{"1420", "\[Rule]", "1421"}], ",", 
       RowBox[{"1420", "\[Rule]", "1417"}], ",", 
       RowBox[{"1712", "\[Rule]", "1699"}], ",", 
       RowBox[{"1712", "\[Rule]", "1725"}], ",", 
       RowBox[{"1712", "\[Rule]", "1713"}], ",", 
       RowBox[{"1430", "\[Rule]", "1417"}], ",", 
       RowBox[{"1430", "\[Rule]", "1443"}], ",", 
       RowBox[{"1430", "\[Rule]", "1431"}], ",", 
       RowBox[{"596", "\[Rule]", "607"}], ",", 
       RowBox[{"596", "\[Rule]", "597"}], ",", 
       RowBox[{"596", "\[Rule]", "593"}], ",", 
       RowBox[{"314", "\[Rule]", "325"}], ",", 
       RowBox[{"314", "\[Rule]", "315"}], ",", 
       RowBox[{"314", "\[Rule]", "311"}], ",", 
       RowBox[{"1254", "\[Rule]", "1265"}], ",", 
       RowBox[{"1254", "\[Rule]", "1255"}], ",", 
       RowBox[{"1254", "\[Rule]", "1251"}], ",", 
       RowBox[{"972", "\[Rule]", "983"}], ",", 
       RowBox[{"972", "\[Rule]", "973"}], ",", 
       RowBox[{"972", "\[Rule]", "969"}], ",", 
       RowBox[{"502", "\[Rule]", "513"}], ",", 
       RowBox[{"502", "\[Rule]", "503"}], ",", 
       RowBox[{"502", "\[Rule]", "499"}], ",", 
       RowBox[{"220", "\[Rule]", "231"}], ",", 
       RowBox[{"220", "\[Rule]", "221"}], ",", 
       RowBox[{"220", "\[Rule]", "217"}], ",", 
       RowBox[{"1160", "\[Rule]", "1171"}], ",", 
       RowBox[{"1160", "\[Rule]", "1161"}], ",", 
       RowBox[{"1160", "\[Rule]", "1157"}], ",", 
       RowBox[{"878", "\[Rule]", "889"}], ",", 
       RowBox[{"878", "\[Rule]", "879"}], ",", 
       RowBox[{"878", "\[Rule]", "875"}], ",", 
       RowBox[{"1912", "\[Rule]", "1923"}], ",", 
       RowBox[{"1912", "\[Rule]", "1913"}], ",", 
       RowBox[{"1912", "\[Rule]", "1909"}], ",", 
       RowBox[{"1630", "\[Rule]", "1641"}], ",", 
       RowBox[{"1630", "\[Rule]", "1631"}], ",", 
       RowBox[{"1630", "\[Rule]", "1627"}], ",", 
       RowBox[{"1818", "\[Rule]", "1829"}], ",", 
       RowBox[{"1818", "\[Rule]", "1819"}], ",", 
       RowBox[{"1818", "\[Rule]", "1815"}], ",", 
       RowBox[{"1536", "\[Rule]", "1547"}], ",", 
       RowBox[{"1536", "\[Rule]", "1537"}], ",", 
       RowBox[{"1536", "\[Rule]", "1533"}], ",", 
       RowBox[{"408", "\[Rule]", "419"}], ",", 
       RowBox[{"408", "\[Rule]", "409"}], ",", 
       RowBox[{"408", "\[Rule]", "405"}], ",", 
       RowBox[{"126", "\[Rule]", "137"}], ",", 
       RowBox[{"126", "\[Rule]", "127"}], ",", 
       RowBox[{"126", "\[Rule]", "123"}], ",", 
       RowBox[{"784", "\[Rule]", "795"}], ",", 
       RowBox[{"784", "\[Rule]", "785"}], ",", 
       RowBox[{"784", "\[Rule]", "781"}], ",", 
       RowBox[{"1066", "\[Rule]", "1077"}], ",", 
       RowBox[{"1066", "\[Rule]", "1067"}], ",", 
       RowBox[{"1066", "\[Rule]", "1063"}], ",", 
       RowBox[{"1724", "\[Rule]", "1735"}], ",", 
       RowBox[{"1724", "\[Rule]", "1725"}], ",", 
       RowBox[{"1724", "\[Rule]", "1721"}], ",", 
       RowBox[{"1442", "\[Rule]", "1453"}], ",", 
       RowBox[{"1442", "\[Rule]", "1443"}], ",", 
       RowBox[{"1442", "\[Rule]", "1439"}], ",", 
       RowBox[{"10", "\[Rule]", "21"}], ",", 
       RowBox[{"10", "\[Rule]", "11"}], ",", 
       RowBox[{"10", "\[Rule]", "7"}], ",", 
       RowBox[{"668", "\[Rule]", "679"}], ",", 
       RowBox[{"668", "\[Rule]", "669"}], ",", 
       RowBox[{"668", "\[Rule]", "665"}], ",", 
       RowBox[{"20", "\[Rule]", "7"}], ",", 
       RowBox[{"20", "\[Rule]", "33"}], ",", 
       RowBox[{"20", "\[Rule]", "21"}], ",", 
       RowBox[{"678", "\[Rule]", "665"}], ",", 
       RowBox[{"678", "\[Rule]", "691"}], ",", 
       RowBox[{"678", "\[Rule]", "679"}], ",", 
       RowBox[{"1326", "\[Rule]", "1337"}], ",", 
       RowBox[{"1326", "\[Rule]", "1327"}], ",", 
       RowBox[{"1326", "\[Rule]", "1323"}], ",", 
       RowBox[{"1336", "\[Rule]", "1323"}], ",", 
       RowBox[{"1336", "\[Rule]", "1349"}], ",", 
       RowBox[{"1336", "\[Rule]", "1337"}], ",", 
       RowBox[{"32", "\[Rule]", "43"}], ",", 
       RowBox[{"32", "\[Rule]", "33"}], ",", 
       RowBox[{"32", "\[Rule]", "29"}], ",", 
       RowBox[{"690", "\[Rule]", "701"}], ",", 
       RowBox[{"690", "\[Rule]", "691"}], ",", 
       RowBox[{"690", "\[Rule]", "687"}], ",", 
       RowBox[{"1348", "\[Rule]", "1359"}], ",", 
       RowBox[{"1348", "\[Rule]", "1349"}], ",", 
       RowBox[{"1348", "\[Rule]", "1345"}], ",", 
       RowBox[{"606", "\[Rule]", "593"}], ",", 
       RowBox[{"606", "\[Rule]", "619"}], ",", 
       RowBox[{"606", "\[Rule]", "607"}], ",", 
       RowBox[{"324", "\[Rule]", "311"}], ",", 
       RowBox[{"324", "\[Rule]", "337"}], ",", 
       RowBox[{"324", "\[Rule]", "325"}], ",", 
       RowBox[{"1264", "\[Rule]", "1251"}], ",", 
       RowBox[{"1264", "\[Rule]", "1277"}], ",", 
       RowBox[{"1264", "\[Rule]", "1265"}], ",", 
       RowBox[{"982", "\[Rule]", "969"}], ",", 
       RowBox[{"982", "\[Rule]", "995"}], ",", 
       RowBox[{"982", "\[Rule]", "983"}], ",", 
       RowBox[{"512", "\[Rule]", "499"}], ",", 
       RowBox[{"512", "\[Rule]", "525"}], ",", 
       RowBox[{"512", "\[Rule]", "513"}], ",", 
       RowBox[{"230", "\[Rule]", "217"}], ",", 
       RowBox[{"230", "\[Rule]", "243"}], ",", 
       RowBox[{"230", "\[Rule]", "231"}], ",", 
       RowBox[{"1170", "\[Rule]", "1157"}], ",", 
       RowBox[{"1170", "\[Rule]", "1183"}], ",", 
       RowBox[{"1170", "\[Rule]", "1171"}], ",", 
       RowBox[{"888", "\[Rule]", "875"}], ",", 
       RowBox[{"888", "\[Rule]", "901"}], ",", 
       RowBox[{"888", "\[Rule]", "889"}], ",", 
       RowBox[{"1922", "\[Rule]", "1909"}], ",", 
       RowBox[{"1922", "\[Rule]", "1935"}], ",", 
       RowBox[{"1922", "\[Rule]", "1923"}], ",", 
       RowBox[{"1640", "\[Rule]", "1627"}], ",", 
       RowBox[{"1640", "\[Rule]", "1653"}], ",", 
       RowBox[{"1640", "\[Rule]", "1641"}], ",", 
       RowBox[{"1828", "\[Rule]", "1815"}], ",", 
       RowBox[{"1828", "\[Rule]", "1841"}], ",", 
       RowBox[{"1828", "\[Rule]", "1829"}], ",", 
       RowBox[{"1546", "\[Rule]", "1533"}], ",", 
       RowBox[{"1546", "\[Rule]", "1559"}], ",", 
       RowBox[{"1546", "\[Rule]", "1547"}], ",", 
       RowBox[{"418", "\[Rule]", "405"}], ",", 
       RowBox[{"418", "\[Rule]", "431"}], ",", 
       RowBox[{"418", "\[Rule]", "419"}], ",", 
       RowBox[{"136", "\[Rule]", "123"}], ",", 
       RowBox[{"136", "\[Rule]", "149"}], ",", 
       RowBox[{"136", "\[Rule]", "137"}], ",", 
       RowBox[{"1076", "\[Rule]", "1063"}], ",", 
       RowBox[{"1076", "\[Rule]", "1089"}], ",", 
       RowBox[{"1076", "\[Rule]", "1077"}], ",", 
       RowBox[{"794", "\[Rule]", "781"}], ",", 
       RowBox[{"794", "\[Rule]", "807"}], ",", 
       RowBox[{"794", "\[Rule]", "795"}], ",", 
       RowBox[{"1734", "\[Rule]", "1721"}], ",", 
       RowBox[{"1734", "\[Rule]", "1747"}], ",", 
       RowBox[{"1734", "\[Rule]", "1735"}], ",", 
       RowBox[{"1452", "\[Rule]", "1439"}], ",", 
       RowBox[{"1452", "\[Rule]", "1465"}], ",", 
       RowBox[{"1452", "\[Rule]", "1453"}], ",", 
       RowBox[{"42", "\[Rule]", "29"}], ",", 
       RowBox[{"42", "\[Rule]", "55"}], ",", 
       RowBox[{"42", "\[Rule]", "43"}], ",", 
       RowBox[{"700", "\[Rule]", "687"}], ",", 
       RowBox[{"700", "\[Rule]", "713"}], ",", 
       RowBox[{"700", "\[Rule]", "701"}], ",", 
       RowBox[{"1358", "\[Rule]", "1345"}], ",", 
       RowBox[{"1358", "\[Rule]", "1371"}], ",", 
       RowBox[{"1358", "\[Rule]", "1359"}], ",", 
       RowBox[{"2266", "\[Rule]", "2277"}], ",", 
       RowBox[{"2266", "\[Rule]", "2267"}], ",", 
       RowBox[{"2266", "\[Rule]", "2263"}], ",", 
       RowBox[{"2172", "\[Rule]", "2183"}], ",", 
       RowBox[{"2172", "\[Rule]", "2173"}], ",", 
       RowBox[{"2172", "\[Rule]", "2169"}], ",", 
       RowBox[{"2276", "\[Rule]", "2263"}], ",", 
       RowBox[{"2276", "\[Rule]", "2289"}], ",", 
       RowBox[{"2276", "\[Rule]", "2277"}], ",", 
       RowBox[{"2182", "\[Rule]", "2169"}], ",", 
       RowBox[{"2182", "\[Rule]", "2195"}], ",", 
       RowBox[{"2182", "\[Rule]", "2183"}], ",", 
       RowBox[{"2078", "\[Rule]", "2089"}], ",", 
       RowBox[{"2078", "\[Rule]", "2079"}], ",", 
       RowBox[{"2078", "\[Rule]", "2075"}], ",", 
       RowBox[{"2088", "\[Rule]", "2075"}], ",", 
       RowBox[{"2088", "\[Rule]", "2101"}], ",", 
       RowBox[{"2088", "\[Rule]", "2089"}], ",", 
       RowBox[{"2288", "\[Rule]", "2299"}], ",", 
       RowBox[{"2288", "\[Rule]", "2289"}], ",", 
       RowBox[{"2288", "\[Rule]", "2285"}], ",", 
       RowBox[{"2194", "\[Rule]", "2205"}], ",", 
       RowBox[{"2194", "\[Rule]", "2195"}], ",", 
       RowBox[{"2194", "\[Rule]", "2191"}], ",", 
       RowBox[{"2100", "\[Rule]", "2111"}], ",", 
       RowBox[{"2100", "\[Rule]", "2101"}], ",", 
       RowBox[{"2100", "\[Rule]", "2097"}], ",", 
       RowBox[{"1984", "\[Rule]", "1995"}], ",", 
       RowBox[{"1984", "\[Rule]", "1985"}], ",", 
       RowBox[{"1984", "\[Rule]", "1981"}], ",", 
       RowBox[{"1994", "\[Rule]", "1981"}], ",", 
       RowBox[{"1994", "\[Rule]", "2007"}], ",", 
       RowBox[{"1994", "\[Rule]", "1995"}], ",", 
       RowBox[{"2006", "\[Rule]", "2017"}], ",", 
       RowBox[{"2006", "\[Rule]", "2007"}], ",", 
       RowBox[{"2006", "\[Rule]", "2003"}], ",", 
       RowBox[{"2298", "\[Rule]", "2285"}], ",", 
       RowBox[{"2298", "\[Rule]", "2311"}], ",", 
       RowBox[{"2298", "\[Rule]", "2299"}], ",", 
       RowBox[{"2204", "\[Rule]", "2191"}], ",", 
       RowBox[{"2204", "\[Rule]", "2217"}], ",", 
       RowBox[{"2204", "\[Rule]", "2205"}], ",", 
       RowBox[{"2110", "\[Rule]", "2097"}], ",", 
       RowBox[{"2110", "\[Rule]", "2123"}], ",", 
       RowBox[{"2110", "\[Rule]", "2111"}], ",", 
       RowBox[{"2016", "\[Rule]", "2003"}], ",", 
       RowBox[{"2016", "\[Rule]", "2029"}], ",", 
       RowBox[{"2016", "\[Rule]", "2017"}], ",", 
       RowBox[{"618", "\[Rule]", "631"}], ",", 
       RowBox[{"618", "\[Rule]", "619"}], ",", 
       RowBox[{"336", "\[Rule]", "349"}], ",", 
       RowBox[{"336", "\[Rule]", "337"}], ",", 
       RowBox[{"1276", "\[Rule]", "1289"}], ",", 
       RowBox[{"1276", "\[Rule]", "1277"}], ",", 
       RowBox[{"994", "\[Rule]", "1007"}], ",", 
       RowBox[{"994", "\[Rule]", "995"}], ",", 
       RowBox[{"524", "\[Rule]", "537"}], ",", 
       RowBox[{"524", "\[Rule]", "525"}], ",", 
       RowBox[{"242", "\[Rule]", "255"}], ",", 
       RowBox[{"242", "\[Rule]", "243"}], ",", 
       RowBox[{"1182", "\[Rule]", "1195"}], ",", 
       RowBox[{"1182", "\[Rule]", "1183"}], ",", 
       RowBox[{"900", "\[Rule]", "913"}], ",", 
       RowBox[{"900", "\[Rule]", "901"}], ",", 
       RowBox[{"1934", "\[Rule]", "1947"}], ",", 
       RowBox[{"1934", "\[Rule]", "1935"}], ",", 
       RowBox[{"1652", "\[Rule]", "1665"}], ",", 
       RowBox[{"1652", "\[Rule]", "1653"}], ",", 
       RowBox[{"1840", "\[Rule]", "1853"}], ",", 
       RowBox[{"1840", "\[Rule]", "1841"}], ",", 
       RowBox[{"1558", "\[Rule]", "1571"}], ",", 
       RowBox[{"1558", "\[Rule]", "1559"}], ",", 
       RowBox[{"430", "\[Rule]", "443"}], ",", 
       RowBox[{"430", "\[Rule]", "431"}], ",", 
       RowBox[{"148", "\[Rule]", "161"}], ",", 
       RowBox[{"148", "\[Rule]", "149"}], ",", 
       RowBox[{"1088", "\[Rule]", "1101"}], ",", 
       RowBox[{"1088", "\[Rule]", "1089"}], ",", 
       RowBox[{"806", "\[Rule]", "819"}], ",", 
       RowBox[{"806", "\[Rule]", "807"}], ",", 
       RowBox[{"1746", "\[Rule]", "1759"}], ",", 
       RowBox[{"1746", "\[Rule]", "1747"}], ",", 
       RowBox[{"1464", "\[Rule]", "1477"}], ",", 
       RowBox[{"1464", "\[Rule]", "1465"}], ",", 
       RowBox[{"54", "\[Rule]", "67"}], ",", 
       RowBox[{"54", "\[Rule]", "55"}], ",", 
       RowBox[{"712", "\[Rule]", "725"}], ",", 
       RowBox[{"712", "\[Rule]", "713"}], ",", 
       RowBox[{"1370", "\[Rule]", "1383"}], ",", 
       RowBox[{"1370", "\[Rule]", "1371"}], ",", 
       RowBox[{"2310", "\[Rule]", "2323"}], ",", 
       RowBox[{"2310", "\[Rule]", "2311"}], ",", 
       RowBox[{"2216", "\[Rule]", "2229"}], ",", 
       RowBox[{"2216", "\[Rule]", "2217"}], ",", 
       RowBox[{"2122", "\[Rule]", "2135"}], ",", 
       RowBox[{"2122", "\[Rule]", "2123"}], ",", 
       RowBox[{"2028", "\[Rule]", "2041"}], ",", 
       RowBox[{"2028", "\[Rule]", "2029"}], ",", 
       RowBox[{"571", "\[Rule]", "290"}], ",", 
       RowBox[{"571", "\[Rule]", "290"}], ",", 
       RowBox[{"571", "\[Rule]", "948"}], ",", 
       RowBox[{"571", "\[Rule]", "948"}], ",", 
       RowBox[{"571", "\[Rule]", "196"}], ",", 
       RowBox[{"571", "\[Rule]", "196"}], ",", 
       RowBox[{"571", "\[Rule]", "854"}], ",", 
       RowBox[{"571", "\[Rule]", "854"}], ",", 
       RowBox[{"571", "\[Rule]", "572"}], ",", 
       RowBox[{"289", "\[Rule]", "572"}], ",", 
       RowBox[{"289", "\[Rule]", "572"}], ",", 
       RowBox[{"289", "\[Rule]", "290"}], ",", 
       RowBox[{"1229", "\[Rule]", "948"}], ",", 
       RowBox[{"1229", "\[Rule]", "948"}], ",", 
       RowBox[{"1229", "\[Rule]", "1606"}], ",", 
       RowBox[{"1229", "\[Rule]", "1606"}], ",", 
       RowBox[{"1229", "\[Rule]", "854"}], ",", 
       RowBox[{"1229", "\[Rule]", "854"}], ",", 
       RowBox[{"1229", "\[Rule]", "1512"}], ",", 
       RowBox[{"1229", "\[Rule]", "1512"}], ",", 
       RowBox[{"1229", "\[Rule]", "1230"}], ",", 
       RowBox[{"947", "\[Rule]", "572"}], ",", 
       RowBox[{"947", "\[Rule]", "572"}], ",", 
       RowBox[{"947", "\[Rule]", "1230"}], ",", 
       RowBox[{"947", "\[Rule]", "1230"}], ",", 
       RowBox[{"947", "\[Rule]", "948"}], ",", 
       RowBox[{"477", "\[Rule]", "196"}], ",", 
       RowBox[{"477", "\[Rule]", "854"}], ",", 
       RowBox[{"477", "\[Rule]", "854"}], ",", 
       RowBox[{"477", "\[Rule]", "760"}], ",", 
       RowBox[{"477", "\[Rule]", "478"}], ",", 
       RowBox[{"195", "\[Rule]", "572"}], ",", 
       RowBox[{"195", "\[Rule]", "572"}], ",", 
       RowBox[{"195", "\[Rule]", "478"}], ",", 
       RowBox[{"195", "\[Rule]", "196"}], ",", 
       RowBox[{"1135", "\[Rule]", "854"}], ",", 
       RowBox[{"1135", "\[Rule]", "854"}], ",", 
       RowBox[{"1135", "\[Rule]", "1512"}], ",", 
       RowBox[{"1135", "\[Rule]", "1512"}], ",", 
       RowBox[{"1135", "\[Rule]", "760"}], ",", 
       RowBox[{"1135", "\[Rule]", "760"}], ",", 
       RowBox[{"1135", "\[Rule]", "1418"}], ",", 
       RowBox[{"1135", "\[Rule]", "1418"}], ",", 
       RowBox[{"1135", "\[Rule]", "1136"}], ",", 
       RowBox[{"853", "\[Rule]", "572"}], ",", 
       RowBox[{"853", "\[Rule]", "572"}], ",", 
       RowBox[{"853", "\[Rule]", "1230"}], ",", 
       RowBox[{"853", "\[Rule]", "1230"}], ",", 
       RowBox[{"853", "\[Rule]", "478"}], ",", 
       RowBox[{"853", "\[Rule]", "478"}], ",", 
       RowBox[{"853", "\[Rule]", "1136"}], ",", 
       RowBox[{"853", "\[Rule]", "1136"}], ",", 
       RowBox[{"853", "\[Rule]", "854"}], ",", 
       RowBox[{"1887", "\[Rule]", "1606"}], ",", 
       RowBox[{"1887", "\[Rule]", "1606"}], ",", 
       RowBox[{"1887", "\[Rule]", "2264"}], ",", 
       RowBox[{"1887", "\[Rule]", "2264"}], ",", 
       RowBox[{"1887", "\[Rule]", "1512"}], ",", 
       RowBox[{"1887", "\[Rule]", "1512"}], ",", 
       RowBox[{"1887", "\[Rule]", "2170"}], ",", 
       RowBox[{"1887", "\[Rule]", "2170"}], ",", 
       RowBox[{"1887", "\[Rule]", "1888"}], ",", 
       RowBox[{"1605", "\[Rule]", "1230"}], ",", 
       RowBox[{"1605", "\[Rule]", "1230"}], ",", 
       RowBox[{"1605", "\[Rule]", "1888"}], ",", 
       RowBox[{"1605", "\[Rule]", "1888"}], ",", 
       RowBox[{"1605", "\[Rule]", "1606"}], ",", 
       RowBox[{"1793", "\[Rule]", "1512"}], ",", 
       RowBox[{"1793", "\[Rule]", "1512"}], ",", 
       RowBox[{"1793", "\[Rule]", "2170"}], ",", 
       RowBox[{"1793", "\[Rule]", "2170"}], ",", 
       RowBox[{"1793", "\[Rule]", "1418"}], ",", 
       RowBox[{"1793", "\[Rule]", "1418"}], ",", 
       RowBox[{"1793", "\[Rule]", "2076"}], ",", 
       RowBox[{"1793", "\[Rule]", "2076"}], ",", 
       RowBox[{"1793", "\[Rule]", "1794"}], ",", 
       RowBox[{"1511", "\[Rule]", "1230"}], ",", 
       RowBox[{"1511", "\[Rule]", "1230"}], ",", 
       RowBox[{"1511", "\[Rule]", "1888"}], ",", 
       RowBox[{"1511", "\[Rule]", "1888"}], ",", 
       RowBox[{"1511", "\[Rule]", "1136"}], ",", 
       RowBox[{"1511", "\[Rule]", "1136"}], ",", 
       RowBox[{"1511", "\[Rule]", "1794"}], ",", 
       RowBox[{"1511", "\[Rule]", "1794"}], ",", 
       RowBox[{"1511", "\[Rule]", "1512"}], ",", 
       RowBox[{"383", "\[Rule]", "102"}], ",", 
       RowBox[{"383", "\[Rule]", "760"}], ",", 
       RowBox[{"383", "\[Rule]", "8"}], ",", 
       RowBox[{"383", "\[Rule]", "8"}], ",", 
       RowBox[{"383", "\[Rule]", "666"}], ",", 
       RowBox[{"383", "\[Rule]", "666"}], ",", 
       RowBox[{"383", "\[Rule]", "384"}], ",", 
       RowBox[{"101", "\[Rule]", "384"}], ",", 
       RowBox[{"101", "\[Rule]", "102"}], ",", 
       RowBox[{"1041", "\[Rule]", "760"}], ",", 
       RowBox[{"1041", "\[Rule]", "760"}], ",", 
       RowBox[{"1041", "\[Rule]", "1418"}], ",", 
       RowBox[{"1041", "\[Rule]", "1418"}], ",", 
       RowBox[{"1041", "\[Rule]", "666"}], ",", 
       RowBox[{"1041", "\[Rule]", "1324"}], ",", 
       RowBox[{"1041", "\[Rule]", "1042"}], ",", 
       RowBox[{"759", "\[Rule]", "478"}], ",", 
       RowBox[{"759", "\[Rule]", "1136"}], ",", 
       RowBox[{"759", "\[Rule]", "1136"}], ",", 
       RowBox[{"759", "\[Rule]", "384"}], ",", 
       RowBox[{"759", "\[Rule]", "1042"}], ",", 
       RowBox[{"759", "\[Rule]", "1042"}], ",", 
       RowBox[{"759", "\[Rule]", "760"}], ",", 
       RowBox[{"1699", "\[Rule]", "1418"}], ",", 
       RowBox[{"1699", "\[Rule]", "1418"}], ",", 
       RowBox[{"1699", "\[Rule]", "2076"}], ",", 
       RowBox[{"1699", "\[Rule]", "2076"}], ",", 
       RowBox[{"1699", "\[Rule]", "1324"}], ",", 
       RowBox[{"1699", "\[Rule]", "1324"}], ",", 
       RowBox[{"1699", "\[Rule]", "1982"}], ",", 
       RowBox[{"1699", "\[Rule]", "1982"}], ",", 
       RowBox[{"1699", "\[Rule]", "1700"}], ",", 
       RowBox[{"1417", "\[Rule]", "1136"}], ",", 
       RowBox[{"1417", "\[Rule]", "1136"}], ",", 
       RowBox[{"1417", "\[Rule]", "1794"}], ",", 
       RowBox[{"1417", "\[Rule]", "1794"}], ",", 
       RowBox[{"1417", "\[Rule]", "1042"}], ",", 
       RowBox[{"1417", "\[Rule]", "1042"}], ",", 
       RowBox[{"1417", "\[Rule]", "1700"}], ",", 
       RowBox[{"1417", "\[Rule]", "1700"}], ",", 
       RowBox[{"1417", "\[Rule]", "1418"}], ",", 
       RowBox[{"593", "\[Rule]", "312"}], ",", 
       RowBox[{"593", "\[Rule]", "312"}], ",", 
       RowBox[{"593", "\[Rule]", "970"}], ",", 
       RowBox[{"593", "\[Rule]", "970"}], ",", 
       RowBox[{"593", "\[Rule]", "218"}], ",", 
       RowBox[{"593", "\[Rule]", "218"}], ",", 
       RowBox[{"593", "\[Rule]", "876"}], ",", 
       RowBox[{"593", "\[Rule]", "876"}], ",", 
       RowBox[{"593", "\[Rule]", "594"}], ",", 
       RowBox[{"311", "\[Rule]", "594"}], ",", 
       RowBox[{"311", "\[Rule]", "594"}], ",", 
       RowBox[{"311", "\[Rule]", "312"}], ",", 
       RowBox[{"1251", "\[Rule]", "970"}], ",", 
       RowBox[{"1251", "\[Rule]", "970"}], ",", 
       RowBox[{"1251", "\[Rule]", "1628"}], ",", 
       RowBox[{"1251", "\[Rule]", "1628"}], ",", 
       RowBox[{"1251", "\[Rule]", "876"}], ",", 
       RowBox[{"1251", "\[Rule]", "876"}], ",", 
       RowBox[{"1251", "\[Rule]", "1534"}], ",", 
       RowBox[{"1251", "\[Rule]", "1534"}], ",", 
       RowBox[{"1251", "\[Rule]", "1252"}], ",", 
       RowBox[{"969", "\[Rule]", "594"}], ",", 
       RowBox[{"969", "\[Rule]", "594"}], ",", 
       RowBox[{"969", "\[Rule]", "1252"}], ",", 
       RowBox[{"969", "\[Rule]", "1252"}], ",", 
       RowBox[{"969", "\[Rule]", "970"}], ",", 
       RowBox[{"499", "\[Rule]", "218"}], ",", 
       RowBox[{"499", "\[Rule]", "218"}], ",", 
       RowBox[{"499", "\[Rule]", "876"}], ",", 
       RowBox[{"499", "\[Rule]", "876"}], ",", 
       RowBox[{"499", "\[Rule]", "124"}], ",", 
       RowBox[{"499", "\[Rule]", "782"}], ",", 
       RowBox[{"499", "\[Rule]", "500"}], ",", 
       RowBox[{"217", "\[Rule]", "594"}], ",", 
       RowBox[{"217", "\[Rule]", "594"}], ",", 
       RowBox[{"217", "\[Rule]", "500"}], ",", 
       RowBox[{"217", "\[Rule]", "500"}], ",", 
       RowBox[{"217", "\[Rule]", "218"}], ",", 
       RowBox[{"1157", "\[Rule]", "876"}], ",", 
       RowBox[{"1157", "\[Rule]", "876"}], ",", 
       RowBox[{"1157", "\[Rule]", "1534"}], ",", 
       RowBox[{"1157", "\[Rule]", "1534"}], ",", 
       RowBox[{"1157", "\[Rule]", "782"}], ",", 
       RowBox[{"1157", "\[Rule]", "782"}], ",", 
       RowBox[{"1157", "\[Rule]", "1440"}], ",", 
       RowBox[{"1157", "\[Rule]", "1440"}], ",", 
       RowBox[{"1157", "\[Rule]", "1158"}], ",", 
       RowBox[{"875", "\[Rule]", "594"}], ",", 
       RowBox[{"875", "\[Rule]", "594"}], ",", 
       RowBox[{"875", "\[Rule]", "1252"}], ",", 
       RowBox[{"875", "\[Rule]", "1252"}], ",", 
       RowBox[{"875", "\[Rule]", "500"}], ",", 
       RowBox[{"875", "\[Rule]", "500"}], ",", 
       RowBox[{"875", "\[Rule]", "1158"}], ",", 
       RowBox[{"875", "\[Rule]", "1158"}], ",", 
       RowBox[{"875", "\[Rule]", "876"}], ",", 
       RowBox[{"1909", "\[Rule]", "1628"}], ",", 
       RowBox[{"1909", "\[Rule]", "1628"}], ",", 
       RowBox[{"1909", "\[Rule]", "2286"}], ",", 
       RowBox[{"1909", "\[Rule]", "2286"}], ",", 
       RowBox[{"1909", "\[Rule]", "1534"}], ",", 
       RowBox[{"1909", "\[Rule]", "1534"}], ",", 
       RowBox[{"1909", "\[Rule]", "2192"}], ",", 
       RowBox[{"1909", "\[Rule]", "2192"}], ",", 
       RowBox[{"1909", "\[Rule]", "1910"}], ",", 
       RowBox[{"1627", "\[Rule]", "1252"}], ",", 
       RowBox[{"1627", "\[Rule]", "1252"}], ",", 
       RowBox[{"1627", "\[Rule]", "1910"}], ",", 
       RowBox[{"1627", "\[Rule]", "1910"}], ",", 
       RowBox[{"1627", "\[Rule]", "1628"}], ",", 
       RowBox[{"1815", "\[Rule]", "1534"}], ",", 
       RowBox[{"1815", "\[Rule]", "1534"}], ",", 
       RowBox[{"1815", "\[Rule]", "2192"}], ",", 
       RowBox[{"1815", "\[Rule]", "2192"}], ",", 
       RowBox[{"1815", "\[Rule]", "1440"}], ",", 
       RowBox[{"1815", "\[Rule]", "1440"}], ",", 
       RowBox[{"1815", "\[Rule]", "2098"}], ",", 
       RowBox[{"1815", "\[Rule]", "2098"}], ",", 
       RowBox[{"1815", "\[Rule]", "1816"}], ",", 
       RowBox[{"1533", "\[Rule]", "1252"}], ",", 
       RowBox[{"1533", "\[Rule]", "1252"}], ",", 
       RowBox[{"1533", "\[Rule]", "1910"}], ",", 
       RowBox[{"1533", "\[Rule]", "1910"}], ",", 
       RowBox[{"1533", "\[Rule]", "1158"}], ",", 
       RowBox[{"1533", "\[Rule]", "1158"}], ",", 
       RowBox[{"1533", "\[Rule]", "1816"}], ",", 
       RowBox[{"1533", "\[Rule]", "1816"}], ",", 
       RowBox[{"1533", "\[Rule]", "1534"}], ",", 
       RowBox[{"405", "\[Rule]", "124"}], ",", 
       RowBox[{"405", "\[Rule]", "30"}], ",", 
       RowBox[{"405", "\[Rule]", "30"}], ",", 
       RowBox[{"405", "\[Rule]", "688"}], ",", 
       RowBox[{"405", "\[Rule]", "406"}], ",", 
       RowBox[{"123", "\[Rule]", "500"}], ",", 
       RowBox[{"123", "\[Rule]", "406"}], ",", 
       RowBox[{"123", "\[Rule]", "124"}], ",", 
       RowBox[{"781", "\[Rule]", "500"}], ",", 
       RowBox[{"781", "\[Rule]", "1158"}], ",", 
       RowBox[{"781", "\[Rule]", "1158"}], ",", 
       RowBox[{"781", "\[Rule]", "1064"}], ",", 
       RowBox[{"781", "\[Rule]", "782"}], ",", 
       RowBox[{"1063", "\[Rule]", "782"}], ",", 
       RowBox[{"1063", "\[Rule]", "1440"}], ",", 
       RowBox[{"1063", "\[Rule]", "1440"}], ",", 
       RowBox[{"1063", "\[Rule]", "1346"}], ",", 
       RowBox[{"1063", "\[Rule]", "1064"}], ",", 
       RowBox[{"1721", "\[Rule]", "1440"}], ",", 
       RowBox[{"1721", "\[Rule]", "1440"}], ",", 
       RowBox[{"1721", "\[Rule]", "2098"}], ",", 
       RowBox[{"1721", "\[Rule]", "2098"}], ",", 
       RowBox[{"1721", "\[Rule]", "1346"}], ",", 
       RowBox[{"1721", "\[Rule]", "1346"}], ",", 
       RowBox[{"1721", "\[Rule]", "2004"}], ",", 
       RowBox[{"1721", "\[Rule]", "2004"}], ",", 
       RowBox[{"1721", "\[Rule]", "1722"}], ",", 
       RowBox[{"1439", "\[Rule]", "1158"}], ",", 
       RowBox[{"1439", "\[Rule]", "1158"}], ",", 
       RowBox[{"1439", "\[Rule]", "1816"}], ",", 
       RowBox[{"1439", "\[Rule]", "1816"}], ",", 
       RowBox[{"1439", "\[Rule]", "1064"}], ",", 
       RowBox[{"1439", "\[Rule]", "1064"}], ",", 
       RowBox[{"1439", "\[Rule]", "1722"}], ",", 
       RowBox[{"1439", "\[Rule]", "1722"}], ",", 
       RowBox[{"1439", "\[Rule]", "1440"}], ",", 
       RowBox[{"7", "\[Rule]", "384"}], ",", 
       RowBox[{"7", "\[Rule]", "384"}], ",", 
       RowBox[{"7", "\[Rule]", "8"}], ",", 
       RowBox[{"665", "\[Rule]", "384"}], ",", 
       RowBox[{"665", "\[Rule]", "384"}], ",", 
       RowBox[{"665", "\[Rule]", "1042"}], ",", 
       RowBox[{"665", "\[Rule]", "666"}], ",", 
       RowBox[{"1323", "\[Rule]", "1042"}], ",", 
       RowBox[{"1323", "\[Rule]", "1700"}], ",", 
       RowBox[{"1323", "\[Rule]", "1700"}], ",", 
       RowBox[{"1323", "\[Rule]", "1324"}], ",", 
       RowBox[{"29", "\[Rule]", "406"}], ",", 
       RowBox[{"29", "\[Rule]", "406"}], ",", 
       RowBox[{"29", "\[Rule]", "30"}], ",", 
       RowBox[{"687", "\[Rule]", "406"}], ",", 
       RowBox[{"687", "\[Rule]", "688"}], ",", 
       RowBox[{"1345", "\[Rule]", "1064"}], ",", 
       RowBox[{"1345", "\[Rule]", "1722"}], ",", 
       RowBox[{"1345", "\[Rule]", "1722"}], ",", 
       RowBox[{"1345", "\[Rule]", "1346"}], ",", 
       RowBox[{"2263", "\[Rule]", "1888"}], ",", 
       RowBox[{"2263", "\[Rule]", "1888"}], ",", 
       RowBox[{"2263", "\[Rule]", "2264"}], ",", 
       RowBox[{"2169", "\[Rule]", "1888"}], ",", 
       RowBox[{"2169", "\[Rule]", "1888"}], ",", 
       RowBox[{"2169", "\[Rule]", "1794"}], ",", 
       RowBox[{"2169", "\[Rule]", "1794"}], ",", 
       RowBox[{"2169", "\[Rule]", "2170"}], ",", 
       RowBox[{"2075", "\[Rule]", "1794"}], ",", 
       RowBox[{"2075", "\[Rule]", "1794"}], ",", 
       RowBox[{"2075", "\[Rule]", "1700"}], ",", 
       RowBox[{"2075", "\[Rule]", "1700"}], ",", 
       RowBox[{"2075", "\[Rule]", "2076"}], ",", 
       RowBox[{"2285", "\[Rule]", "1910"}], ",", 
       RowBox[{"2285", "\[Rule]", "1910"}], ",", 
       RowBox[{"2285", "\[Rule]", "2286"}], ",", 
       RowBox[{"2191", "\[Rule]", "1910"}], ",", 
       RowBox[{"2191", "\[Rule]", "1910"}], ",", 
       RowBox[{"2191", "\[Rule]", "1816"}], ",", 
       RowBox[{"2191", "\[Rule]", "1816"}], ",", 
       RowBox[{"2191", "\[Rule]", "2192"}], ",", 
       RowBox[{"2097", "\[Rule]", "1816"}], ",", 
       RowBox[{"2097", "\[Rule]", "1816"}], ",", 
       RowBox[{"2097", "\[Rule]", "1722"}], ",", 
       RowBox[{"2097", "\[Rule]", "1722"}], ",", 
       RowBox[{"2097", "\[Rule]", "2098"}], ",", 
       RowBox[{"1981", "\[Rule]", "1700"}], ",", 
       RowBox[{"1981", "\[Rule]", "1700"}], ",", 
       RowBox[{"1981", "\[Rule]", "1982"}], ",", 
       RowBox[{"2003", "\[Rule]", "1722"}], ",", 
       RowBox[{"2003", "\[Rule]", "1722"}], ",", 
       RowBox[{"2003", "\[Rule]", "2004"}], ",", 
       RowBox[{"290", "\[Rule]", "301"}], ",", 
       RowBox[{"290", "\[Rule]", "291"}], ",", 
       RowBox[{"290", "\[Rule]", "287"}], ",", 
       RowBox[{"948", "\[Rule]", "959"}], ",", 
       RowBox[{"948", "\[Rule]", "949"}], ",", 
       RowBox[{"948", "\[Rule]", "945"}], ",", 
       RowBox[{"196", "\[Rule]", "207"}], ",", 
       RowBox[{"196", "\[Rule]", "197"}], ",", 
       RowBox[{"196", "\[Rule]", "193"}], ",", 
       RowBox[{"854", "\[Rule]", "865"}], ",", 
       RowBox[{"854", "\[Rule]", "855"}], ",", 
       RowBox[{"854", "\[Rule]", "851"}], ",", 
       RowBox[{"572", "\[Rule]", "583"}], ",", 
       RowBox[{"572", "\[Rule]", "573"}], ",", 
       RowBox[{"572", "\[Rule]", "569"}], ",", 
       RowBox[{"1606", "\[Rule]", "1617"}], ",", 
       RowBox[{"1606", "\[Rule]", "1607"}], ",", 
       RowBox[{"1606", "\[Rule]", "1603"}], ",", 
       RowBox[{"1512", "\[Rule]", "1523"}], ",", 
       RowBox[{"1512", "\[Rule]", "1513"}], ",", 
       RowBox[{"1512", "\[Rule]", "1509"}], ",", 
       RowBox[{"1230", "\[Rule]", "1241"}], ",", 
       RowBox[{"1230", "\[Rule]", "1231"}], ",", 
       RowBox[{"1230", "\[Rule]", "1227"}], ",", 
       RowBox[{"760", "\[Rule]", "771"}], ",", 
       RowBox[{"760", "\[Rule]", "761"}], ",", 
       RowBox[{"760", "\[Rule]", "757"}], ",", 
       RowBox[{"478", "\[Rule]", "489"}], ",", 
       RowBox[{"478", "\[Rule]", "479"}], ",", 
       RowBox[{"478", "\[Rule]", "475"}], ",", 
       RowBox[{"1418", "\[Rule]", "1429"}], ",", 
       RowBox[{"1418", "\[Rule]", "1419"}], ",", 
       RowBox[{"1418", "\[Rule]", "1415"}], ",", 
       RowBox[{"1136", "\[Rule]", "1147"}], ",", 
       RowBox[{"1136", "\[Rule]", "1137"}], ",", 
       RowBox[{"1136", "\[Rule]", "1133"}], ",", 
       RowBox[{"2264", "\[Rule]", "2275"}], ",", 
       RowBox[{"2264", "\[Rule]", "2265"}], ",", 
       RowBox[{"2264", "\[Rule]", "2261"}], ",", 
       RowBox[{"2170", "\[Rule]", "2181"}], ",", 
       RowBox[{"2170", "\[Rule]", "2171"}], ",", 
       RowBox[{"2170", "\[Rule]", "2167"}], ",", 
       RowBox[{"1888", "\[Rule]", "1899"}], ",", 
       RowBox[{"1888", "\[Rule]", "1889"}], ",", 
       RowBox[{"1888", "\[Rule]", "1885"}], ",", 
       RowBox[{"2076", "\[Rule]", "2087"}], ",", 
       RowBox[{"2076", "\[Rule]", "2077"}], ",", 
       RowBox[{"2076", "\[Rule]", "2073"}], ",", 
       RowBox[{"1794", "\[Rule]", "1805"}], ",", 
       RowBox[{"1794", "\[Rule]", "1795"}], ",", 
       RowBox[{"1794", "\[Rule]", "1791"}], ",", 
       RowBox[{"102", "\[Rule]", "113"}], ",", 
       RowBox[{"102", "\[Rule]", "103"}], ",", 
       RowBox[{"102", "\[Rule]", "99"}], ",", 
       RowBox[{"8", "\[Rule]", "19"}], ",", 
       RowBox[{"8", "\[Rule]", "9"}], ",", 
       RowBox[{"8", "\[Rule]", "5"}], ",", 
       RowBox[{"666", "\[Rule]", "677"}], ",", 
       RowBox[{"666", "\[Rule]", "667"}], ",", 
       RowBox[{"666", "\[Rule]", "663"}], ",", 
       RowBox[{"384", "\[Rule]", "395"}], ",", 
       RowBox[{"384", "\[Rule]", "385"}], ",", 
       RowBox[{"384", "\[Rule]", "381"}], ",", 
       RowBox[{"1324", "\[Rule]", "1335"}], ",", 
       RowBox[{"1324", "\[Rule]", "1325"}], ",", 
       RowBox[{"1324", "\[Rule]", "1321"}], ",", 
       RowBox[{"1042", "\[Rule]", "1053"}], ",", 
       RowBox[{"1042", "\[Rule]", "1043"}], ",", 
       RowBox[{"1042", "\[Rule]", "1039"}], ",", 
       RowBox[{"1982", "\[Rule]", "1993"}], ",", 
       RowBox[{"1982", "\[Rule]", "1983"}], ",", 
       RowBox[{"1982", "\[Rule]", "1979"}], ",", 
       RowBox[{"1700", "\[Rule]", "1711"}], ",", 
       RowBox[{"1700", "\[Rule]", "1701"}], ",", 
       RowBox[{"1700", "\[Rule]", "1697"}], ",", 
       RowBox[{"312", "\[Rule]", "299"}], ",", 
       RowBox[{"312", "\[Rule]", "323"}], ",", 
       RowBox[{"312", "\[Rule]", "313"}], ",", 
       RowBox[{"312", "\[Rule]", "309"}], ",", 
       RowBox[{"970", "\[Rule]", "957"}], ",", 
       RowBox[{"970", "\[Rule]", "981"}], ",", 
       RowBox[{"970", "\[Rule]", "971"}], ",", 
       RowBox[{"970", "\[Rule]", "967"}], ",", 
       RowBox[{"218", "\[Rule]", "205"}], ",", 
       RowBox[{"218", "\[Rule]", "229"}], ",", 
       RowBox[{"218", "\[Rule]", "219"}], ",", 
       RowBox[{"218", "\[Rule]", "215"}], ",", 
       RowBox[{"876", "\[Rule]", "863"}], ",", 
       RowBox[{"876", "\[Rule]", "887"}], ",", 
       RowBox[{"876", "\[Rule]", "877"}], ",", 
       RowBox[{"876", "\[Rule]", "873"}], ",", 
       RowBox[{"594", "\[Rule]", "581"}], ",", 
       RowBox[{"594", "\[Rule]", "605"}], ",", 
       RowBox[{"594", "\[Rule]", "595"}], ",", 
       RowBox[{"594", "\[Rule]", "591"}], ",", 
       RowBox[{"1628", "\[Rule]", "1615"}], ",", 
       RowBox[{"1628", "\[Rule]", "1639"}], ",", 
       RowBox[{"1628", "\[Rule]", "1629"}], ",", 
       RowBox[{"1628", "\[Rule]", "1625"}], ",", 
       RowBox[{"1534", "\[Rule]", "1521"}], ",", 
       RowBox[{"1534", "\[Rule]", "1545"}], ",", 
       RowBox[{"1534", "\[Rule]", "1535"}], ",", 
       RowBox[{"1534", "\[Rule]", "1531"}], ",", 
       RowBox[{"1252", "\[Rule]", "1239"}], ",", 
       RowBox[{"1252", "\[Rule]", "1263"}], ",", 
       RowBox[{"1252", "\[Rule]", "1253"}], ",", 
       RowBox[{"1252", "\[Rule]", "1249"}], ",", 
       RowBox[{"124", "\[Rule]", "111"}], ",", 
       RowBox[{"124", "\[Rule]", "135"}], ",", 
       RowBox[{"124", "\[Rule]", "125"}], ",", 
       RowBox[{"124", "\[Rule]", "121"}], ",", 
       RowBox[{"782", "\[Rule]", "769"}], ",", 
       RowBox[{"782", "\[Rule]", "793"}], ",", 
       RowBox[{"782", "\[Rule]", "783"}], ",", 
       RowBox[{"782", "\[Rule]", "779"}], ",", 
       RowBox[{"500", "\[Rule]", "487"}], ",", 
       RowBox[{"500", "\[Rule]", "511"}], ",", 
       RowBox[{"500", "\[Rule]", "501"}], ",", 
       RowBox[{"500", "\[Rule]", "497"}], ",", 
       RowBox[{"1440", "\[Rule]", "1427"}], ",", 
       RowBox[{"1440", "\[Rule]", "1451"}], ",", 
       RowBox[{"1440", "\[Rule]", "1441"}], ",", 
       RowBox[{"1440", "\[Rule]", "1437"}], ",", 
       RowBox[{"1158", "\[Rule]", "1145"}], ",", 
       RowBox[{"1158", "\[Rule]", "1169"}], ",", 
       RowBox[{"1158", "\[Rule]", "1159"}], ",", 
       RowBox[{"1158", "\[Rule]", "1155"}], ",", 
       RowBox[{"2286", "\[Rule]", "2273"}], ",", 
       RowBox[{"2286", "\[Rule]", "2297"}], ",", 
       RowBox[{"2286", "\[Rule]", "2287"}], ",", 
       RowBox[{"2286", "\[Rule]", "2283"}], ",", 
       RowBox[{"2192", "\[Rule]", "2179"}], ",", 
       RowBox[{"2192", "\[Rule]", "2203"}], ",", 
       RowBox[{"2192", "\[Rule]", "2193"}], ",", 
       RowBox[{"2192", "\[Rule]", "2189"}], ",", 
       RowBox[{"1910", "\[Rule]", "1897"}], ",", 
       RowBox[{"1910", "\[Rule]", "1921"}], ",", 
       RowBox[{"1910", "\[Rule]", "1911"}], ",", 
       RowBox[{"1910", "\[Rule]", "1907"}], ",", 
       RowBox[{"2098", "\[Rule]", "2085"}], ",", 
       RowBox[{"2098", "\[Rule]", "2109"}], ",", 
       RowBox[{"2098", "\[Rule]", "2099"}], ",", 
       RowBox[{"2098", "\[Rule]", "2095"}], ",", 
       RowBox[{"1816", "\[Rule]", "1803"}], ",", 
       RowBox[{"1816", "\[Rule]", "1827"}], ",", 
       RowBox[{"1816", "\[Rule]", "1817"}], ",", 
       RowBox[{"1816", "\[Rule]", "1813"}], ",", 
       RowBox[{"30", "\[Rule]", "17"}], ",", 
       RowBox[{"30", "\[Rule]", "41"}], ",", 
       RowBox[{"30", "\[Rule]", "31"}], ",", 
       RowBox[{"30", "\[Rule]", "27"}], ",", 
       RowBox[{"688", "\[Rule]", "675"}], ",", 
       RowBox[{"688", "\[Rule]", "699"}], ",", 
       RowBox[{"688", "\[Rule]", "689"}], ",", 
       RowBox[{"688", "\[Rule]", "685"}], ",", 
       RowBox[{"406", "\[Rule]", "393"}], ",", 
       RowBox[{"406", "\[Rule]", "417"}], ",", 
       RowBox[{"406", "\[Rule]", "407"}], ",", 
       RowBox[{"406", "\[Rule]", "403"}], ",", 
       RowBox[{"1064", "\[Rule]", "1051"}], ",", 
       RowBox[{"1064", "\[Rule]", "1075"}], ",", 
       RowBox[{"1064", "\[Rule]", "1065"}], ",", 
       RowBox[{"1064", "\[Rule]", "1061"}], ",", 
       RowBox[{"1346", "\[Rule]", "1333"}], ",", 
       RowBox[{"1346", "\[Rule]", "1357"}], ",", 
       RowBox[{"1346", "\[Rule]", "1347"}], ",", 
       RowBox[{"1346", "\[Rule]", "1343"}], ",", 
       RowBox[{"2004", "\[Rule]", "1991"}], ",", 
       RowBox[{"2004", "\[Rule]", "2015"}], ",", 
       RowBox[{"2004", "\[Rule]", "2005"}], ",", 
       RowBox[{"2004", "\[Rule]", "2001"}], ",", 
       RowBox[{"1722", "\[Rule]", "1709"}], ",", 
       RowBox[{"1722", "\[Rule]", "1733"}], ",", 
       RowBox[{"1722", "\[Rule]", "1723"}], ",", 
       RowBox[{"1722", "\[Rule]", "1719"}], ",", 
       RowBox[{"287", "\[Rule]", "570"}], ",", 
       RowBox[{"287", "\[Rule]", "570"}], ",", 
       RowBox[{"287", "\[Rule]", "288"}], ",", 
       RowBox[{"945", "\[Rule]", "570"}], ",", 
       RowBox[{"945", "\[Rule]", "570"}], ",", 
       RowBox[{"945", "\[Rule]", "1228"}], ",", 
       RowBox[{"945", "\[Rule]", "1228"}], ",", 
       RowBox[{"945", "\[Rule]", "946"}], ",", 
       RowBox[{"193", "\[Rule]", "570"}], ",", 
       RowBox[{"193", "\[Rule]", "570"}], ",", 
       RowBox[{"193", "\[Rule]", "476"}], ",", 
       RowBox[{"193", "\[Rule]", "476"}], ",", 
       RowBox[{"193", "\[Rule]", "194"}], ",", 
       RowBox[{"851", "\[Rule]", "570"}], ",", 
       RowBox[{"851", "\[Rule]", "570"}], ",", 
       RowBox[{"851", "\[Rule]", "1228"}], ",", 
       RowBox[{"851", "\[Rule]", "1228"}], ",", 
       RowBox[{"851", "\[Rule]", "476"}], ",", 
       RowBox[{"851", "\[Rule]", "476"}], ",", 
       RowBox[{"851", "\[Rule]", "1134"}], ",", 
       RowBox[{"851", "\[Rule]", "1134"}], ",", 
       RowBox[{"851", "\[Rule]", "852"}], ",", 
       RowBox[{"569", "\[Rule]", "288"}], ",", 
       RowBox[{"569", "\[Rule]", "288"}], ",", 
       RowBox[{"569", "\[Rule]", "946"}], ",", 
       RowBox[{"569", "\[Rule]", "946"}], ",", 
       RowBox[{"569", "\[Rule]", "194"}], ",", 
       RowBox[{"569", "\[Rule]", "194"}], ",", 
       RowBox[{"569", "\[Rule]", "852"}], ",", 
       RowBox[{"569", "\[Rule]", "852"}], ",", 
       RowBox[{"569", "\[Rule]", "570"}], ",", 
       RowBox[{"1603", "\[Rule]", "1228"}], ",", 
       RowBox[{"1603", "\[Rule]", "1228"}], ",", 
       RowBox[{"1603", "\[Rule]", "1886"}], ",", 
       RowBox[{"1603", "\[Rule]", "1886"}], ",", 
       RowBox[{"1603", "\[Rule]", "1604"}], ",", 
       RowBox[{"1509", "\[Rule]", "1228"}], ",", 
       RowBox[{"1509", "\[Rule]", "1228"}], ",", 
       RowBox[{"1509", "\[Rule]", "1886"}], ",", 
       RowBox[{"1509", "\[Rule]", "1886"}], ",", 
       RowBox[{"1509", "\[Rule]", "1134"}], ",", 
       RowBox[{"1509", "\[Rule]", "1134"}], ",", 
       RowBox[{"1509", "\[Rule]", "1792"}], ",", 
       RowBox[{"1509", "\[Rule]", "1792"}], ",", 
       RowBox[{"1509", "\[Rule]", "1510"}], ",", 
       RowBox[{"1227", "\[Rule]", "946"}], ",", 
       RowBox[{"1227", "\[Rule]", "946"}], ",", 
       RowBox[{"1227", "\[Rule]", "1604"}], ",", 
       RowBox[{"1227", "\[Rule]", "1604"}], ",", 
       RowBox[{"1227", "\[Rule]", "852"}], ",", 
       RowBox[{"1227", "\[Rule]", "852"}], ",", 
       RowBox[{"1227", "\[Rule]", "1510"}], ",", 
       RowBox[{"1227", "\[Rule]", "1510"}], ",", 
       RowBox[{"1227", "\[Rule]", "1228"}], ",", 
       RowBox[{"757", "\[Rule]", "476"}], ",", 
       RowBox[{"757", "\[Rule]", "1134"}], ",", 
       RowBox[{"757", "\[Rule]", "1134"}], ",", 
       RowBox[{"757", "\[Rule]", "382"}], ",", 
       RowBox[{"757", "\[Rule]", "1040"}], ",", 
       RowBox[{"757", "\[Rule]", "1040"}], ",", 
       RowBox[{"757", "\[Rule]", "758"}], ",", 
       RowBox[{"475", "\[Rule]", "194"}], ",", 
       RowBox[{"475", "\[Rule]", "194"}], ",", 
       RowBox[{"475", "\[Rule]", "852"}], ",", 
       RowBox[{"475", "\[Rule]", "852"}], ",", 
       RowBox[{"475", "\[Rule]", "100"}], ",", 
       RowBox[{"475", "\[Rule]", "758"}], ",", 
       RowBox[{"475", "\[Rule]", "476"}], ",", 
       RowBox[{"1415", "\[Rule]", "1134"}], ",", 
       RowBox[{"1415", "\[Rule]", "1134"}], ",", 
       RowBox[{"1415", "\[Rule]", "1792"}], ",", 
       RowBox[{"1415", "\[Rule]", "1792"}], ",", 
       RowBox[{"1415", "\[Rule]", "1040"}], ",", 
       RowBox[{"1415", "\[Rule]", "1040"}], ",", 
       RowBox[{"1415", "\[Rule]", "1698"}], ",", 
       RowBox[{"1415", "\[Rule]", "1698"}], ",", 
       RowBox[{"1415", "\[Rule]", "1416"}], ",", 
       RowBox[{"1133", "\[Rule]", "852"}], ",", 
       RowBox[{"1133", "\[Rule]", "852"}], ",", 
       RowBox[{"1133", "\[Rule]", "1510"}], ",", 
       RowBox[{"1133", "\[Rule]", "1510"}], ",", 
       RowBox[{"1133", "\[Rule]", "758"}], ",", 
       RowBox[{"1133", "\[Rule]", "758"}], ",", 
       RowBox[{"1133", "\[Rule]", "1416"}], ",", 
       RowBox[{"1133", "\[Rule]", "1416"}], ",", 
       RowBox[{"1133", "\[Rule]", "1134"}], ",", 
       RowBox[{"2261", "\[Rule]", "1886"}], ",", 
       RowBox[{"2261", "\[Rule]", "1886"}], ",", 
       RowBox[{"2261", "\[Rule]", "2262"}], ",", 
       RowBox[{"2167", "\[Rule]", "1886"}], ",", 
       RowBox[{"2167", "\[Rule]", "1886"}], ",", 
       RowBox[{"2167", "\[Rule]", "1792"}], ",", 
       RowBox[{"2167", "\[Rule]", "1792"}], ",", 
       RowBox[{"2167", "\[Rule]", "2168"}], ",", 
       RowBox[{"1885", "\[Rule]", "1604"}], ",", 
       RowBox[{"1885", "\[Rule]", "1604"}], ",", 
       RowBox[{"1885", "\[Rule]", "2262"}], ",", 
       RowBox[{"1885", "\[Rule]", "2262"}], ",", 
       RowBox[{"1885", "\[Rule]", "1510"}], ",", 
       RowBox[{"1885", "\[Rule]", "1510"}], ",", 
       RowBox[{"1885", "\[Rule]", "2168"}], ",", 
       RowBox[{"1885", "\[Rule]", "2168"}], ",", 
       RowBox[{"1885", "\[Rule]", "1886"}], ",", 
       RowBox[{"2073", "\[Rule]", "1792"}], ",", 
       RowBox[{"2073", "\[Rule]", "1792"}], ",", 
       RowBox[{"2073", "\[Rule]", "1698"}], ",", 
       RowBox[{"2073", "\[Rule]", "1698"}], ",", 
       RowBox[{"2073", "\[Rule]", "2074"}], ",", 
       RowBox[{"1791", "\[Rule]", "1510"}], ",", 
       RowBox[{"1791", "\[Rule]", "1510"}], ",", 
       RowBox[{"1791", "\[Rule]", "2168"}], ",", 
       RowBox[{"1791", "\[Rule]", "2168"}], ",", 
       RowBox[{"1791", "\[Rule]", "1416"}], ",", 
       RowBox[{"1791", "\[Rule]", "1416"}], ",", 
       RowBox[{"1791", "\[Rule]", "2074"}], ",", 
       RowBox[{"1791", "\[Rule]", "2074"}], ",", 
       RowBox[{"1791", "\[Rule]", "1792"}], ",", 
       RowBox[{"99", "\[Rule]", "476"}], ",", 
       RowBox[{"99", "\[Rule]", "382"}], ",", 
       RowBox[{"99", "\[Rule]", "100"}], ",", 
       RowBox[{"5", "\[Rule]", "382"}], ",", 
       RowBox[{"5", "\[Rule]", "382"}], ",", 
       RowBox[{"5", "\[Rule]", "6"}], ",", 
       RowBox[{"663", "\[Rule]", "382"}], ",", 
       RowBox[{"663", "\[Rule]", "382"}], ",", 
       RowBox[{"663", "\[Rule]", "1040"}], ",", 
       RowBox[{"663", "\[Rule]", "664"}], ",", 
       RowBox[{"381", "\[Rule]", "100"}], ",", 
       RowBox[{"381", "\[Rule]", "758"}], ",", 
       RowBox[{"381", "\[Rule]", "6"}], ",", 
       RowBox[{"381", "\[Rule]", "6"}], ",", 
       RowBox[{"381", "\[Rule]", "664"}], ",", 
       RowBox[{"381", "\[Rule]", "664"}], ",", 
       RowBox[{"381", "\[Rule]", "382"}], ",", 
       RowBox[{"1321", "\[Rule]", "1040"}], ",", 
       RowBox[{"1321", "\[Rule]", "1698"}], ",", 
       RowBox[{"1321", "\[Rule]", "1698"}], ",", 
       RowBox[{"1321", "\[Rule]", "1322"}], ",", 
       RowBox[{"1039", "\[Rule]", "758"}], ",", 
       RowBox[{"1039", "\[Rule]", "758"}], ",", 
       RowBox[{"1039", "\[Rule]", "1416"}], ",", 
       RowBox[{"1039", "\[Rule]", "1416"}], ",", 
       RowBox[{"1039", "\[Rule]", "664"}], ",", 
       RowBox[{"1039", "\[Rule]", "1322"}], ",", 
       RowBox[{"1039", "\[Rule]", "1040"}], ",", 
       RowBox[{"1979", "\[Rule]", "1698"}], ",", 
       RowBox[{"1979", "\[Rule]", "1698"}], ",", 
       RowBox[{"1979", "\[Rule]", "1980"}], ",", 
       RowBox[{"1697", "\[Rule]", "1416"}], ",", 
       RowBox[{"1697", "\[Rule]", "1416"}], ",", 
       RowBox[{"1697", "\[Rule]", "2074"}], ",", 
       RowBox[{"1697", "\[Rule]", "2074"}], ",", 
       RowBox[{"1697", "\[Rule]", "1322"}], ",", 
       RowBox[{"1697", "\[Rule]", "1322"}], ",", 
       RowBox[{"1697", "\[Rule]", "1980"}], ",", 
       RowBox[{"1697", "\[Rule]", "1980"}], ",", 
       RowBox[{"1697", "\[Rule]", "1698"}], ",", 
       RowBox[{"299", "\[Rule]", "582"}], ",", 
       RowBox[{"299", "\[Rule]", "582"}], ",", 
       RowBox[{"299", "\[Rule]", "300"}], ",", 
       RowBox[{"309", "\[Rule]", "592"}], ",", 
       RowBox[{"309", "\[Rule]", "592"}], ",", 
       RowBox[{"309", "\[Rule]", "310"}], ",", 
       RowBox[{"957", "\[Rule]", "582"}], ",", 
       RowBox[{"957", "\[Rule]", "582"}], ",", 
       RowBox[{"957", "\[Rule]", "1240"}], ",", 
       RowBox[{"957", "\[Rule]", "1240"}], ",", 
       RowBox[{"957", "\[Rule]", "958"}], ",", 
       RowBox[{"967", "\[Rule]", "592"}], ",", 
       RowBox[{"967", "\[Rule]", "592"}], ",", 
       RowBox[{"967", "\[Rule]", "1250"}], ",", 
       RowBox[{"967", "\[Rule]", "1250"}], ",", 
       RowBox[{"967", "\[Rule]", "968"}], ",", 
       RowBox[{"205", "\[Rule]", "582"}], ",", 
       RowBox[{"205", "\[Rule]", "582"}], ",", 
       RowBox[{"205", "\[Rule]", "488"}], ",", 
       RowBox[{"205", "\[Rule]", "488"}], ",", 
       RowBox[{"205", "\[Rule]", "206"}], ",", 
       RowBox[{"215", "\[Rule]", "592"}], ",", 
       RowBox[{"215", "\[Rule]", "592"}], ",", 
       RowBox[{"215", "\[Rule]", "498"}], ",", 
       RowBox[{"215", "\[Rule]", "498"}], ",", 
       RowBox[{"215", "\[Rule]", "216"}], ",", 
       RowBox[{"863", "\[Rule]", "582"}], ",", 
       RowBox[{"863", "\[Rule]", "582"}], ",", 
       RowBox[{"863", "\[Rule]", "1240"}], ",", 
       RowBox[{"863", "\[Rule]", "1240"}], ",", 
       RowBox[{"863", "\[Rule]", "488"}], ",", 
       RowBox[{"863", "\[Rule]", "488"}], ",", 
       RowBox[{"863", "\[Rule]", "1146"}], ",", 
       RowBox[{"863", "\[Rule]", "1146"}], ",", 
       RowBox[{"863", "\[Rule]", "864"}], ",", 
       RowBox[{"873", "\[Rule]", "592"}], ",", 
       RowBox[{"873", "\[Rule]", "592"}], ",", 
       RowBox[{"873", "\[Rule]", "1250"}], ",", 
       RowBox[{"873", "\[Rule]", "1250"}], ",", 
       RowBox[{"873", "\[Rule]", "498"}], ",", 
       RowBox[{"873", "\[Rule]", "498"}], ",", 
       RowBox[{"873", "\[Rule]", "1156"}], ",", 
       RowBox[{"873", "\[Rule]", "1156"}], ",", 
       RowBox[{"873", "\[Rule]", "874"}], ",", 
       RowBox[{"581", "\[Rule]", "300"}], ",", 
       RowBox[{"581", "\[Rule]", "300"}], ",", 
       RowBox[{"581", "\[Rule]", "958"}], ",", 
       RowBox[{"581", "\[Rule]", "958"}], ",", 
       RowBox[{"581", "\[Rule]", "206"}], ",", 
       RowBox[{"581", "\[Rule]", "206"}], ",", 
       RowBox[{"581", "\[Rule]", "864"}], ",", 
       RowBox[{"581", "\[Rule]", "864"}], ",", 
       RowBox[{"581", "\[Rule]", "582"}], ",", 
       RowBox[{"591", "\[Rule]", "310"}], ",", 
       RowBox[{"591", "\[Rule]", "310"}], ",", 
       RowBox[{"591", "\[Rule]", "968"}], ",", 
       RowBox[{"591", "\[Rule]", "968"}], ",", 
       RowBox[{"591", "\[Rule]", "216"}], ",", 
       RowBox[{"591", "\[Rule]", "216"}], ",", 
       RowBox[{"591", "\[Rule]", "874"}], ",", 
       RowBox[{"591", "\[Rule]", "874"}], ",", 
       RowBox[{"591", "\[Rule]", "592"}], ",", 
       RowBox[{"1615", "\[Rule]", "1240"}], ",", 
       RowBox[{"1615", "\[Rule]", "1240"}], ",", 
       RowBox[{"1615", "\[Rule]", "1898"}], ",", 
       RowBox[{"1615", "\[Rule]", "1898"}], ",", 
       RowBox[{"1615", "\[Rule]", "1616"}], ",", 
       RowBox[{"1625", "\[Rule]", "1250"}], ",", 
       RowBox[{"1625", "\[Rule]", "1250"}], ",", 
       RowBox[{"1625", "\[Rule]", "1908"}], ",", 
       RowBox[{"1625", "\[Rule]", "1908"}], ",", 
       RowBox[{"1625", "\[Rule]", "1626"}], ",", 
       RowBox[{"1521", "\[Rule]", "1240"}], ",", 
       RowBox[{"1521", "\[Rule]", "1240"}], ",", 
       RowBox[{"1521", "\[Rule]", "1898"}], ",", 
       RowBox[{"1521", "\[Rule]", "1898"}], ",", 
       RowBox[{"1521", "\[Rule]", "1146"}], ",", 
       RowBox[{"1521", "\[Rule]", "1146"}], ",", 
       RowBox[{"1521", "\[Rule]", "1804"}], ",", 
       RowBox[{"1521", "\[Rule]", "1804"}], ",", 
       RowBox[{"1521", "\[Rule]", "1522"}], ",", 
       RowBox[{"1531", "\[Rule]", "1250"}], ",", 
       RowBox[{"1531", "\[Rule]", "1250"}], ",", 
       RowBox[{"1531", "\[Rule]", "1908"}], ",", 
       RowBox[{"1531", "\[Rule]", "1908"}], ",", 
       RowBox[{"1531", "\[Rule]", "1156"}], ",", 
       RowBox[{"1531", "\[Rule]", "1156"}], ",", 
       RowBox[{"1531", "\[Rule]", "1814"}], ",", 
       RowBox[{"1531", "\[Rule]", "1814"}], ",", 
       RowBox[{"1531", "\[Rule]", "1532"}], ",", 
       RowBox[{"1239", "\[Rule]", "958"}], ",", 
       RowBox[{"1239", "\[Rule]", "958"}], ",", 
       RowBox[{"1239", "\[Rule]", "1616"}], ",", 
       RowBox[{"1239", "\[Rule]", "1616"}], ",", 
       RowBox[{"1239", "\[Rule]", "864"}], ",", 
       RowBox[{"1239", "\[Rule]", "864"}], ",", 
       RowBox[{"1239", "\[Rule]", "1522"}], ",", 
       RowBox[{"1239", "\[Rule]", "1522"}], ",", 
       RowBox[{"1239", "\[Rule]", "1240"}], ",", 
       RowBox[{"1249", "\[Rule]", "968"}], ",", 
       RowBox[{"1249", "\[Rule]", "968"}], ",", 
       RowBox[{"1249", "\[Rule]", "1626"}], ",", 
       RowBox[{"1249", "\[Rule]", "1626"}], ",", 
       RowBox[{"1249", "\[Rule]", "874"}], ",", 
       RowBox[{"1249", "\[Rule]", "874"}], ",", 
       RowBox[{"1249", "\[Rule]", "1532"}], ",", 
       RowBox[{"1249", "\[Rule]", "1532"}], ",", 
       RowBox[{"1249", "\[Rule]", "1250"}], ",", 
       RowBox[{"111", "\[Rule]", "488"}], ",", 
       RowBox[{"111", "\[Rule]", "394"}], ",", 
       RowBox[{"111", "\[Rule]", "112"}], ",", 
       RowBox[{"121", "\[Rule]", "498"}], ",", 
       RowBox[{"121", "\[Rule]", "404"}], ",", 
       RowBox[{"121", "\[Rule]", "122"}], ",", 
       RowBox[{"769", "\[Rule]", "488"}], ",", 
       RowBox[{"769", "\[Rule]", "1146"}], ",", 
       RowBox[{"769", "\[Rule]", "1146"}], ",", 
       RowBox[{"769", "\[Rule]", "394"}], ",", 
       RowBox[{"769", "\[Rule]", "1052"}], ",", 
       RowBox[{"769", "\[Rule]", "1052"}], ",", 
       RowBox[{"769", "\[Rule]", "770"}], ",", 
       RowBox[{"779", "\[Rule]", "498"}], ",", 
       RowBox[{"779", "\[Rule]", "1156"}], ",", 
       RowBox[{"779", "\[Rule]", "1156"}], ",", 
       RowBox[{"779", "\[Rule]", "404"}], ",", 
       RowBox[{"779", "\[Rule]", "1062"}], ",", 
       RowBox[{"779", "\[Rule]", "1062"}], ",", 
       RowBox[{"779", "\[Rule]", "780"}], ",", 
       RowBox[{"487", "\[Rule]", "206"}], ",", 
       RowBox[{"487", "\[Rule]", "206"}], ",", 
       RowBox[{"487", "\[Rule]", "864"}], ",", 
       RowBox[{"487", "\[Rule]", "864"}], ",", 
       RowBox[{"487", "\[Rule]", "112"}], ",", 
       RowBox[{"487", "\[Rule]", "770"}], ",", 
       RowBox[{"487", "\[Rule]", "488"}], ",", 
       RowBox[{"497", "\[Rule]", "216"}], ",", 
       RowBox[{"497", "\[Rule]", "216"}], ",", 
       RowBox[{"497", "\[Rule]", "874"}], ",", 
       RowBox[{"497", "\[Rule]", "874"}], ",", 
       RowBox[{"497", "\[Rule]", "122"}], ",", 
       RowBox[{"497", "\[Rule]", "780"}], ",", 
       RowBox[{"497", "\[Rule]", "498"}], ",", 
       RowBox[{"1427", "\[Rule]", "1146"}], ",", 
       RowBox[{"1427", "\[Rule]", "1146"}], ",", 
       RowBox[{"1427", "\[Rule]", "1804"}], ",", 
       RowBox[{"1427", "\[Rule]", "1804"}], ",", 
       RowBox[{"1427", "\[Rule]", "1052"}], ",", 
       RowBox[{"1427", "\[Rule]", "1052"}], ",", 
       RowBox[{"1427", "\[Rule]", "1710"}], ",", 
       RowBox[{"1427", "\[Rule]", "1710"}], ",", 
       RowBox[{"1427", "\[Rule]", "1428"}], ",", 
       RowBox[{"1437", "\[Rule]", "1156"}], ",", 
       RowBox[{"1437", "\[Rule]", "1156"}], ",", 
       RowBox[{"1437", "\[Rule]", "1814"}], ",", 
       RowBox[{"1437", "\[Rule]", "1814"}], ",", 
       RowBox[{"1437", "\[Rule]", "1062"}], ",", 
       RowBox[{"1437", "\[Rule]", "1062"}], ",", 
       RowBox[{"1437", "\[Rule]", "1720"}], ",", 
       RowBox[{"1437", "\[Rule]", "1720"}], ",", 
       RowBox[{"1437", "\[Rule]", "1438"}], ",", 
       RowBox[{"1145", "\[Rule]", "864"}], ",", 
       RowBox[{"1145", "\[Rule]", "864"}], ",", 
       RowBox[{"1145", "\[Rule]", "1522"}], ",", 
       RowBox[{"1145", "\[Rule]", "1522"}], ",", 
       RowBox[{"1145", "\[Rule]", "770"}], ",", 
       RowBox[{"1145", "\[Rule]", "770"}], ",", 
       RowBox[{"1145", "\[Rule]", "1428"}], ",", 
       RowBox[{"1145", "\[Rule]", "1428"}], ",", 
       RowBox[{"1145", "\[Rule]", "1146"}], ",", 
       RowBox[{"1155", "\[Rule]", "874"}], ",", 
       RowBox[{"1155", "\[Rule]", "874"}], ",", 
       RowBox[{"1155", "\[Rule]", "1532"}], ",", 
       RowBox[{"1155", "\[Rule]", "1532"}], ",", 
       RowBox[{"1155", "\[Rule]", "780"}], ",", 
       RowBox[{"1155", "\[Rule]", "780"}], ",", 
       RowBox[{"1155", "\[Rule]", "1438"}], ",", 
       RowBox[{"1155", "\[Rule]", "1438"}], ",", 
       RowBox[{"1155", "\[Rule]", "1156"}], ",", 
       RowBox[{"2273", "\[Rule]", "1898"}], ",", 
       RowBox[{"2273", "\[Rule]", "1898"}], ",", 
       RowBox[{"2273", "\[Rule]", "2274"}], ",", 
       RowBox[{"2283", "\[Rule]", "1908"}], ",", 
       RowBox[{"2283", "\[Rule]", "1908"}], ",", 
       RowBox[{"2283", "\[Rule]", "2284"}], ",", 
       RowBox[{"2179", "\[Rule]", "1898"}], ",", 
       RowBox[{"2179", "\[Rule]", "1898"}], ",", 
       RowBox[{"2179", "\[Rule]", "1804"}], ",", 
       RowBox[{"2179", "\[Rule]", "1804"}], ",", 
       RowBox[{"2179", "\[Rule]", "2180"}], ",", 
       RowBox[{"2189", "\[Rule]", "1908"}], ",", 
       RowBox[{"2189", "\[Rule]", "1908"}], ",", 
       RowBox[{"2189", "\[Rule]", "1814"}], ",", 
       RowBox[{"2189", "\[Rule]", "1814"}], ",", 
       RowBox[{"2189", "\[Rule]", "2190"}], ",", 
       RowBox[{"1897", "\[Rule]", "1616"}], ",", 
       RowBox[{"1897", "\[Rule]", "1616"}], ",", 
       RowBox[{"1897", "\[Rule]", "2274"}], ",", 
       RowBox[{"1897", "\[Rule]", "2274"}], ",", 
       RowBox[{"1897", "\[Rule]", "1522"}], ",", 
       RowBox[{"1897", "\[Rule]", "1522"}], ",", 
       RowBox[{"1897", "\[Rule]", "2180"}], ",", 
       RowBox[{"1897", "\[Rule]", "2180"}], ",", 
       RowBox[{"1897", "\[Rule]", "1898"}], ",", 
       RowBox[{"1907", "\[Rule]", "1626"}], ",", 
       RowBox[{"1907", "\[Rule]", "1626"}], ",", 
       RowBox[{"1907", "\[Rule]", "2284"}], ",", 
       RowBox[{"1907", "\[Rule]", "2284"}], ",", 
       RowBox[{"1907", "\[Rule]", "1532"}], ",", 
       RowBox[{"1907", "\[Rule]", "1532"}], ",", 
       RowBox[{"1907", "\[Rule]", "2190"}], ",", 
       RowBox[{"1907", "\[Rule]", "2190"}], ",", 
       RowBox[{"1907", "\[Rule]", "1908"}], ",", 
       RowBox[{"2085", "\[Rule]", "1804"}], ",", 
       RowBox[{"2085", "\[Rule]", "1804"}], ",", 
       RowBox[{"2085", "\[Rule]", "1710"}], ",", 
       RowBox[{"2085", "\[Rule]", "1710"}], ",", 
       RowBox[{"2085", "\[Rule]", "2086"}], ",", 
       RowBox[{"2095", "\[Rule]", "1814"}], ",", 
       RowBox[{"2095", "\[Rule]", "1814"}], ",", 
       RowBox[{"2095", "\[Rule]", "1720"}], ",", 
       RowBox[{"2095", "\[Rule]", "1720"}], ",", 
       RowBox[{"2095", "\[Rule]", "2096"}], ",", 
       RowBox[{"1803", "\[Rule]", "1522"}], ",", 
       RowBox[{"1803", "\[Rule]", "1522"}], ",", 
       RowBox[{"1803", "\[Rule]", "2180"}], ",", 
       RowBox[{"1803", "\[Rule]", "2180"}], ",", 
       RowBox[{"1803", "\[Rule]", "1428"}], ",", 
       RowBox[{"1803", "\[Rule]", "1428"}], ",", 
       RowBox[{"1803", "\[Rule]", "2086"}], ",", 
       RowBox[{"1803", "\[Rule]", "2086"}], ",", 
       RowBox[{"1803", "\[Rule]", "1804"}], ",", 
       RowBox[{"1813", "\[Rule]", "1532"}], ",", 
       RowBox[{"1813", "\[Rule]", "1532"}], ",", 
       RowBox[{"1813", "\[Rule]", "2190"}], ",", 
       RowBox[{"1813", "\[Rule]", "2190"}], ",", 
       RowBox[{"1813", "\[Rule]", "1438"}], ",", 
       RowBox[{"1813", "\[Rule]", "1438"}], ",", 
       RowBox[{"1813", "\[Rule]", "2096"}], ",", 
       RowBox[{"1813", "\[Rule]", "2096"}], ",", 
       RowBox[{"1813", "\[Rule]", "1814"}], ",", 
       RowBox[{"17", "\[Rule]", "394"}], ",", 
       RowBox[{"17", "\[Rule]", "394"}], ",", 
       RowBox[{"17", "\[Rule]", "18"}], ",", 
       RowBox[{"27", "\[Rule]", "404"}], ",", 
       RowBox[{"27", "\[Rule]", "404"}], ",", 
       RowBox[{"27", "\[Rule]", "28"}], ",", 
       RowBox[{"675", "\[Rule]", "394"}], ",", 
       RowBox[{"675", "\[Rule]", "394"}], ",", 
       RowBox[{"675", "\[Rule]", "1052"}], ",", 
       RowBox[{"675", "\[Rule]", "676"}], ",", 
       RowBox[{"685", "\[Rule]", "404"}], ",", 
       RowBox[{"685", "\[Rule]", "404"}], ",", 
       RowBox[{"685", "\[Rule]", "1062"}], ",", 
       RowBox[{"685", "\[Rule]", "686"}], ",", 
       RowBox[{"393", "\[Rule]", "112"}], ",", 
       RowBox[{"393", "\[Rule]", "770"}], ",", 
       RowBox[{"393", "\[Rule]", "18"}], ",", 
       RowBox[{"393", "\[Rule]", "18"}], ",", 
       RowBox[{"393", "\[Rule]", "676"}], ",", 
       RowBox[{"393", "\[Rule]", "676"}], ",", 
       RowBox[{"393", "\[Rule]", "394"}], ",", 
       RowBox[{"403", "\[Rule]", "122"}], ",", 
       RowBox[{"403", "\[Rule]", "780"}], ",", 
       RowBox[{"403", "\[Rule]", "28"}], ",", 
       RowBox[{"403", "\[Rule]", "28"}], ",", 
       RowBox[{"403", "\[Rule]", "686"}], ",", 
       RowBox[{"403", "\[Rule]", "686"}], ",", 
       RowBox[{"403", "\[Rule]", "404"}], ",", 
       RowBox[{"1051", "\[Rule]", "770"}], ",", 
       RowBox[{"1051", "\[Rule]", "770"}], ",", 
       RowBox[{"1051", "\[Rule]", "1428"}], ",", 
       RowBox[{"1051", "\[Rule]", "1428"}], ",", 
       RowBox[{"1051", "\[Rule]", "676"}], ",", 
       RowBox[{"1051", "\[Rule]", "1334"}], ",", 
       RowBox[{"1051", "\[Rule]", "1052"}], ",", 
       RowBox[{"1061", "\[Rule]", "780"}], ",", 
       RowBox[{"1061", "\[Rule]", "780"}], ",", 
       RowBox[{"1061", "\[Rule]", "1438"}], ",", 
       RowBox[{"1061", "\[Rule]", "1438"}], ",", 
       RowBox[{"1061", "\[Rule]", "686"}], ",", 
       RowBox[{"1061", "\[Rule]", "1344"}], ",", 
       RowBox[{"1061", "\[Rule]", "1062"}], ",", 
       RowBox[{"1333", "\[Rule]", "1052"}], ",", 
       RowBox[{"1333", "\[Rule]", "1710"}], ",", 
       RowBox[{"1333", "\[Rule]", "1710"}], ",", 
       RowBox[{"1333", "\[Rule]", "1334"}], ",", 
       RowBox[{"1343", "\[Rule]", "1062"}], ",", 
       RowBox[{"1343", "\[Rule]", "1720"}], ",", 
       RowBox[{"1343", "\[Rule]", "1720"}], ",", 
       RowBox[{"1343", "\[Rule]", "1344"}], ",", 
       RowBox[{"1991", "\[Rule]", "1710"}], ",", 
       RowBox[{"1991", "\[Rule]", "1710"}], ",", 
       RowBox[{"1991", "\[Rule]", "1992"}], ",", 
       RowBox[{"2001", "\[Rule]", "1720"}], ",", 
       RowBox[{"2001", "\[Rule]", "1720"}], ",", 
       RowBox[{"2001", "\[Rule]", "2002"}], ",", 
       RowBox[{"1709", "\[Rule]", "1428"}], ",", 
       RowBox[{"1709", "\[Rule]", "1428"}], ",", 
       RowBox[{"1709", "\[Rule]", "2086"}], ",", 
       RowBox[{"1709", "\[Rule]", "2086"}], ",", 
       RowBox[{"1709", "\[Rule]", "1334"}], ",", 
       RowBox[{"1709", "\[Rule]", "1334"}], ",", 
       RowBox[{"1709", "\[Rule]", "1992"}], ",", 
       RowBox[{"1709", "\[Rule]", "1992"}], ",", 
       RowBox[{"1709", "\[Rule]", "1710"}], ",", 
       RowBox[{"1719", "\[Rule]", "1438"}], ",", 
       RowBox[{"1719", "\[Rule]", "1438"}], ",", 
       RowBox[{"1719", "\[Rule]", "2096"}], ",", 
       RowBox[{"1719", "\[Rule]", "2096"}], ",", 
       RowBox[{"1719", "\[Rule]", "1344"}], ",", 
       RowBox[{"1719", "\[Rule]", "1344"}], ",", 
       RowBox[{"1719", "\[Rule]", "2002"}], ",", 
       RowBox[{"1719", "\[Rule]", "2002"}], ",", 
       RowBox[{"1719", "\[Rule]", "1720"}], ",", 
       RowBox[{"570", "\[Rule]", "571"}], ",", 
       RowBox[{"570", "\[Rule]", "567"}], ",", 
       RowBox[{"288", "\[Rule]", "289"}], ",", 
       RowBox[{"288", "\[Rule]", "285"}], ",", 
       RowBox[{"1228", "\[Rule]", "1229"}], ",", 
       RowBox[{"1228", "\[Rule]", "1225"}], ",", 
       RowBox[{"946", "\[Rule]", "947"}], ",", 
       RowBox[{"946", "\[Rule]", "943"}], ",", 
       RowBox[{"476", "\[Rule]", "477"}], ",", 
       RowBox[{"476", "\[Rule]", "473"}], ",", 
       RowBox[{"194", "\[Rule]", "195"}], ",", 
       RowBox[{"194", "\[Rule]", "191"}], ",", 
       RowBox[{"1134", "\[Rule]", "1135"}], ",", 
       RowBox[{"1134", "\[Rule]", "1131"}], ",", 
       RowBox[{"852", "\[Rule]", "853"}], ",", 
       RowBox[{"852", "\[Rule]", "849"}], ",", 
       RowBox[{"1886", "\[Rule]", "1887"}], ",", 
       RowBox[{"1886", "\[Rule]", "1883"}], ",", 
       RowBox[{"1604", "\[Rule]", "1605"}], ",", 
       RowBox[{"1604", "\[Rule]", "1601"}], ",", 
       RowBox[{"1792", "\[Rule]", "1793"}], ",", 
       RowBox[{"1792", "\[Rule]", "1789"}], ",", 
       RowBox[{"1510", "\[Rule]", "1511"}], ",", 
       RowBox[{"1510", "\[Rule]", "1507"}], ",", 
       RowBox[{"382", "\[Rule]", "383"}], ",", 
       RowBox[{"382", "\[Rule]", "379"}], ",", 
       RowBox[{"1040", "\[Rule]", "1041"}], ",", 
       RowBox[{"1040", "\[Rule]", "1037"}], ",", 
       RowBox[{"758", "\[Rule]", "759"}], ",", 
       RowBox[{"758", "\[Rule]", "755"}], ",", 
       RowBox[{"100", "\[Rule]", "101"}], ",", 
       RowBox[{"100", "\[Rule]", "97"}], ",", 
       RowBox[{"1698", "\[Rule]", "1699"}], ",", 
       RowBox[{"1698", "\[Rule]", "1695"}], ",", 
       RowBox[{"1416", "\[Rule]", "1417"}], ",", 
       RowBox[{"1416", "\[Rule]", "1413"}], ",", 
       RowBox[{"2262", "\[Rule]", "2263"}], ",", 
       RowBox[{"2262", "\[Rule]", "2259"}], ",", 
       RowBox[{"2168", "\[Rule]", "2169"}], ",", 
       RowBox[{"2168", "\[Rule]", "2165"}], ",", 
       RowBox[{"2074", "\[Rule]", "2075"}], ",", 
       RowBox[{"2074", "\[Rule]", "2071"}], ",", 
       RowBox[{"6", "\[Rule]", "7"}], ",", 
       RowBox[{"6", "\[Rule]", "3"}], ",", 
       RowBox[{"664", "\[Rule]", "665"}], ",", 
       RowBox[{"664", "\[Rule]", "661"}], ",", 
       RowBox[{"1322", "\[Rule]", "1323"}], ",", 
       RowBox[{"1322", "\[Rule]", "1319"}], ",", 
       RowBox[{"1980", "\[Rule]", "1981"}], ",", 
       RowBox[{"1980", "\[Rule]", "1977"}], ",", 
       RowBox[{"582", "\[Rule]", "567"}], ",", 
       RowBox[{"582", "\[Rule]", "593"}], ",", 
       RowBox[{"582", "\[Rule]", "579"}], ",", 
       RowBox[{"300", "\[Rule]", "285"}], ",", 
       RowBox[{"300", "\[Rule]", "311"}], ",", 
       RowBox[{"300", "\[Rule]", "297"}], ",", 
       RowBox[{"592", "\[Rule]", "579"}], ",", 
       RowBox[{"592", "\[Rule]", "593"}], ",", 
       RowBox[{"310", "\[Rule]", "297"}], ",", 
       RowBox[{"310", "\[Rule]", "311"}], ",", 
       RowBox[{"1240", "\[Rule]", "1225"}], ",", 
       RowBox[{"1240", "\[Rule]", "1251"}], ",", 
       RowBox[{"1240", "\[Rule]", "1237"}], ",", 
       RowBox[{"958", "\[Rule]", "943"}], ",", 
       RowBox[{"958", "\[Rule]", "969"}], ",", 
       RowBox[{"958", "\[Rule]", "955"}], ",", 
       RowBox[{"1250", "\[Rule]", "1237"}], ",", 
       RowBox[{"1250", "\[Rule]", "1251"}], ",", 
       RowBox[{"968", "\[Rule]", "955"}], ",", 
       RowBox[{"968", "\[Rule]", "969"}], ",", 
       RowBox[{"488", "\[Rule]", "473"}], ",", 
       RowBox[{"488", "\[Rule]", "499"}], ",", 
       RowBox[{"488", "\[Rule]", "485"}], ",", 
       RowBox[{"206", "\[Rule]", "191"}], ",", 
       RowBox[{"206", "\[Rule]", "217"}], ",", 
       RowBox[{"206", "\[Rule]", "203"}], ",", 
       RowBox[{"498", "\[Rule]", "485"}], ",", 
       RowBox[{"498", "\[Rule]", "499"}], ",", 
       RowBox[{"216", "\[Rule]", "203"}], ",", 
       RowBox[{"216", "\[Rule]", "217"}], ",", 
       RowBox[{"1146", "\[Rule]", "1131"}], ",", 
       RowBox[{"1146", "\[Rule]", "1157"}], ",", 
       RowBox[{"1146", "\[Rule]", "1143"}], ",", 
       RowBox[{"864", "\[Rule]", "849"}], ",", 
       RowBox[{"864", "\[Rule]", "875"}], ",", 
       RowBox[{"864", "\[Rule]", "861"}], ",", 
       RowBox[{"1156", "\[Rule]", "1143"}], ",", 
       RowBox[{"1156", "\[Rule]", "1157"}], ",", 
       RowBox[{"874", "\[Rule]", "861"}], ",", 
       RowBox[{"874", "\[Rule]", "875"}], ",", 
       RowBox[{"1898", "\[Rule]", "1883"}], ",", 
       RowBox[{"1898", "\[Rule]", "1909"}], ",", 
       RowBox[{"1898", "\[Rule]", "1895"}], ",", 
       RowBox[{"1616", "\[Rule]", "1601"}], ",", 
       RowBox[{"1616", "\[Rule]", "1627"}], ",", 
       RowBox[{"1616", "\[Rule]", "1613"}], ",", 
       RowBox[{"1908", "\[Rule]", "1895"}], ",", 
       RowBox[{"1908", "\[Rule]", "1909"}], ",", 
       RowBox[{"1626", "\[Rule]", "1613"}], ",", 
       RowBox[{"1626", "\[Rule]", "1627"}], ",", 
       RowBox[{"1804", "\[Rule]", "1789"}], ",", 
       RowBox[{"1804", "\[Rule]", "1815"}], ",", 
       RowBox[{"1804", "\[Rule]", "1801"}], ",", 
       RowBox[{"1522", "\[Rule]", "1507"}], ",", 
       RowBox[{"1522", "\[Rule]", "1533"}], ",", 
       RowBox[{"1522", "\[Rule]", "1519"}], ",", 
       RowBox[{"1814", "\[Rule]", "1801"}], ",", 
       RowBox[{"1814", "\[Rule]", "1815"}], ",", 
       RowBox[{"1532", "\[Rule]", "1519"}], ",", 
       RowBox[{"1532", "\[Rule]", "1533"}], ",", 
       RowBox[{"394", "\[Rule]", "379"}], ",", 
       RowBox[{"394", "\[Rule]", "405"}], ",", 
       RowBox[{"394", "\[Rule]", "391"}], ",", 
       RowBox[{"112", "\[Rule]", "97"}], ",", 
       RowBox[{"112", "\[Rule]", "123"}], ",", 
       RowBox[{"112", "\[Rule]", "109"}], ",", 
       RowBox[{"404", "\[Rule]", "391"}], ",", 
       RowBox[{"404", "\[Rule]", "405"}], ",", 
       RowBox[{"122", "\[Rule]", "109"}], ",", 
       RowBox[{"122", "\[Rule]", "123"}], ",", 
       RowBox[{"1052", "\[Rule]", "1037"}], ",", 
       RowBox[{"1052", "\[Rule]", "1063"}], ",", 
       RowBox[{"1052", "\[Rule]", "1049"}], ",", 
       RowBox[{"770", "\[Rule]", "755"}], ",", 
       RowBox[{"770", "\[Rule]", "781"}], ",", 
       RowBox[{"770", "\[Rule]", "767"}], ",", 
       RowBox[{"1062", "\[Rule]", "1049"}], ",", 
       RowBox[{"1062", "\[Rule]", "1063"}], ",", 
       RowBox[{"780", "\[Rule]", "767"}], ",", 
       RowBox[{"780", "\[Rule]", "781"}], ",", 
       RowBox[{"1710", "\[Rule]", "1695"}], ",", 
       RowBox[{"1710", "\[Rule]", "1721"}], ",", 
       RowBox[{"1710", "\[Rule]", "1707"}], ",", 
       RowBox[{"1428", "\[Rule]", "1413"}], ",", 
       RowBox[{"1428", "\[Rule]", "1439"}], ",", 
       RowBox[{"1428", "\[Rule]", "1425"}], ",", 
       RowBox[{"1720", "\[Rule]", "1707"}], ",", 
       RowBox[{"1720", "\[Rule]", "1721"}], ",", 
       RowBox[{"1438", "\[Rule]", "1425"}], ",", 
       RowBox[{"1438", "\[Rule]", "1439"}], ",", 
       RowBox[{"2274", "\[Rule]", "2259"}], ",", 
       RowBox[{"2274", "\[Rule]", "2285"}], ",", 
       RowBox[{"2274", "\[Rule]", "2271"}], ",", 
       RowBox[{"2284", "\[Rule]", "2271"}], ",", 
       RowBox[{"2284", "\[Rule]", "2285"}], ",", 
       RowBox[{"2180", "\[Rule]", "2165"}], ",", 
       RowBox[{"2180", "\[Rule]", "2191"}], ",", 
       RowBox[{"2180", "\[Rule]", "2177"}], ",", 
       RowBox[{"2190", "\[Rule]", "2177"}], ",", 
       RowBox[{"2190", "\[Rule]", "2191"}], ",", 
       RowBox[{"2086", "\[Rule]", "2071"}], ",", 
       RowBox[{"2086", "\[Rule]", "2097"}], ",", 
       RowBox[{"2086", "\[Rule]", "2083"}], ",", 
       RowBox[{"2096", "\[Rule]", "2083"}], ",", 
       RowBox[{"2096", "\[Rule]", "2097"}], ",", 
       RowBox[{"18", "\[Rule]", "3"}], ",", 
       RowBox[{"18", "\[Rule]", "29"}], ",", 
       RowBox[{"18", "\[Rule]", "15"}], ",", 
       RowBox[{"28", "\[Rule]", "15"}], ",", 
       RowBox[{"28", "\[Rule]", "29"}], ",", 
       RowBox[{"676", "\[Rule]", "661"}], ",", 
       RowBox[{"676", "\[Rule]", "687"}], ",", 
       RowBox[{"676", "\[Rule]", "673"}], ",", 
       RowBox[{"686", "\[Rule]", "673"}], ",", 
       RowBox[{"686", "\[Rule]", "687"}], ",", 
       RowBox[{"1334", "\[Rule]", "1319"}], ",", 
       RowBox[{"1334", "\[Rule]", "1345"}], ",", 
       RowBox[{"1334", "\[Rule]", "1331"}], ",", 
       RowBox[{"1344", "\[Rule]", "1331"}], ",", 
       RowBox[{"1344", "\[Rule]", "1345"}], ",", 
       RowBox[{"1992", "\[Rule]", "1977"}], ",", 
       RowBox[{"1992", "\[Rule]", "2003"}], ",", 
       RowBox[{"1992", "\[Rule]", "1989"}], ",", 
       RowBox[{"2002", "\[Rule]", "1989"}], ",", 
       RowBox[{"2002", "\[Rule]", "2003"}], ",", 
       RowBox[{"567", "\[Rule]", "286"}], ",", 
       RowBox[{"567", "\[Rule]", "286"}], ",", 
       RowBox[{"567", "\[Rule]", "944"}], ",", 
       RowBox[{"567", "\[Rule]", "944"}], ",", 
       RowBox[{"567", "\[Rule]", "192"}], ",", 
       RowBox[{"567", "\[Rule]", "192"}], ",", 
       RowBox[{"567", "\[Rule]", "850"}], ",", 
       RowBox[{"567", "\[Rule]", "850"}], ",", 
       RowBox[{"567", "\[Rule]", "568"}], ",", 
       RowBox[{"285", "\[Rule]", "568"}], ",", 
       RowBox[{"285", "\[Rule]", "568"}], ",", 
       RowBox[{"285", "\[Rule]", "286"}], ",", 
       RowBox[{"1225", "\[Rule]", "944"}], ",", 
       RowBox[{"1225", "\[Rule]", "944"}], ",", 
       RowBox[{"1225", "\[Rule]", "1602"}], ",", 
       RowBox[{"1225", "\[Rule]", "1602"}], ",", 
       RowBox[{"1225", "\[Rule]", "850"}], ",", 
       RowBox[{"1225", "\[Rule]", "850"}], ",", 
       RowBox[{"1225", "\[Rule]", "1508"}], ",", 
       RowBox[{"1225", "\[Rule]", "1508"}], ",", 
       RowBox[{"1225", "\[Rule]", "1226"}], ",", 
       RowBox[{"943", "\[Rule]", "568"}], ",", 
       RowBox[{"943", "\[Rule]", "568"}], ",", 
       RowBox[{"943", "\[Rule]", "1226"}], ",", 
       RowBox[{"943", "\[Rule]", "1226"}], ",", 
       RowBox[{"943", "\[Rule]", "944"}], ",", 
       RowBox[{"473", "\[Rule]", "192"}], ",", 
       RowBox[{"473", "\[Rule]", "192"}], ",", 
       RowBox[{"473", "\[Rule]", "850"}], ",", 
       RowBox[{"473", "\[Rule]", "850"}], ",", 
       RowBox[{"473", "\[Rule]", "98"}], ",", 
       RowBox[{"473", "\[Rule]", "756"}], ",", 
       RowBox[{"473", "\[Rule]", "474"}], ",", 
       RowBox[{"191", "\[Rule]", "568"}], ",", 
       RowBox[{"191", "\[Rule]", "568"}], ",", 
       RowBox[{"191", "\[Rule]", "474"}], ",", 
       RowBox[{"191", "\[Rule]", "474"}], ",", 
       RowBox[{"191", "\[Rule]", "192"}], ",", 
       RowBox[{"1131", "\[Rule]", "850"}], ",", 
       RowBox[{"1131", "\[Rule]", "850"}], ",", 
       RowBox[{"1131", "\[Rule]", "1508"}], ",", 
       RowBox[{"1131", "\[Rule]", "1508"}], ",", 
       RowBox[{"1131", "\[Rule]", "756"}], ",", 
       RowBox[{"1131", "\[Rule]", "756"}], ",", 
       RowBox[{"1131", "\[Rule]", "1414"}], ",", 
       RowBox[{"1131", "\[Rule]", "1414"}], ",", 
       RowBox[{"1131", "\[Rule]", "1132"}], ",", 
       RowBox[{"849", "\[Rule]", "568"}], ",", 
       RowBox[{"849", "\[Rule]", "568"}], ",", 
       RowBox[{"849", "\[Rule]", "1226"}], ",", 
       RowBox[{"849", "\[Rule]", "1226"}], ",", 
       RowBox[{"849", "\[Rule]", "474"}], ",", 
       RowBox[{"849", "\[Rule]", "474"}], ",", 
       RowBox[{"849", "\[Rule]", "1132"}], ",", 
       RowBox[{"849", "\[Rule]", "1132"}], ",", 
       RowBox[{"849", "\[Rule]", "850"}], ",", 
       RowBox[{"1883", "\[Rule]", "1602"}], ",", 
       RowBox[{"1883", "\[Rule]", "1602"}], ",", 
       RowBox[{"1883", "\[Rule]", "2260"}], ",", 
       RowBox[{"1883", "\[Rule]", "2260"}], ",", 
       RowBox[{"1883", "\[Rule]", "1508"}], ",", 
       RowBox[{"1883", "\[Rule]", "1508"}], ",", 
       RowBox[{"1883", "\[Rule]", "2166"}], ",", 
       RowBox[{"1883", "\[Rule]", "2166"}], ",", 
       RowBox[{"1883", "\[Rule]", "1884"}], ",", 
       RowBox[{"1601", "\[Rule]", "1226"}], ",", 
       RowBox[{"1601", "\[Rule]", "1226"}], ",", 
       RowBox[{"1601", "\[Rule]", "1884"}], ",", 
       RowBox[{"1601", "\[Rule]", "1884"}], ",", 
       RowBox[{"1601", "\[Rule]", "1602"}], ",", 
       RowBox[{"1789", "\[Rule]", "1508"}], ",", 
       RowBox[{"1789", "\[Rule]", "1508"}], ",", 
       RowBox[{"1789", "\[Rule]", "2166"}], ",", 
       RowBox[{"1789", "\[Rule]", "2166"}], ",", 
       RowBox[{"1789", "\[Rule]", "1414"}], ",", 
       RowBox[{"1789", "\[Rule]", "1414"}], ",", 
       RowBox[{"1789", "\[Rule]", "2072"}], ",", 
       RowBox[{"1789", "\[Rule]", "2072"}], ",", 
       RowBox[{"1789", "\[Rule]", "1790"}], ",", 
       RowBox[{"1507", "\[Rule]", "1226"}], ",", 
       RowBox[{"1507", "\[Rule]", "1226"}], ",", 
       RowBox[{"1507", "\[Rule]", "1884"}], ",", 
       RowBox[{"1507", "\[Rule]", "1884"}], ",", 
       RowBox[{"1507", "\[Rule]", "1132"}], ",", 
       RowBox[{"1507", "\[Rule]", "1132"}], ",", 
       RowBox[{"1507", "\[Rule]", "1790"}], ",", 
       RowBox[{"1507", "\[Rule]", "1790"}], ",", 
       RowBox[{"1507", "\[Rule]", "1508"}], ",", 
       RowBox[{"379", "\[Rule]", "756"}], ",", 
       RowBox[{"379", "\[Rule]", "4"}], ",", 
       RowBox[{"379", "\[Rule]", "662"}], ",", 
       RowBox[{"379", "\[Rule]", "662"}], ",", 
       RowBox[{"379", "\[Rule]", "380"}], ",", 
       RowBox[{"1037", "\[Rule]", "756"}], ",", 
       RowBox[{"1037", "\[Rule]", "756"}], ",", 
       RowBox[{"1037", "\[Rule]", "1414"}], ",", 
       RowBox[{"1037", "\[Rule]", "1414"}], ",", 
       RowBox[{"1037", "\[Rule]", "662"}], ",", 
       RowBox[{"1037", "\[Rule]", "1320"}], ",", 
       RowBox[{"1037", "\[Rule]", "1038"}], ",", 
       RowBox[{"755", "\[Rule]", "474"}], ",", 
       RowBox[{"755", "\[Rule]", "1132"}], ",", 
       RowBox[{"755", "\[Rule]", "1132"}], ",", 
       RowBox[{"755", "\[Rule]", "380"}], ",", 
       RowBox[{"755", "\[Rule]", "1038"}], ",", 
       RowBox[{"755", "\[Rule]", "1038"}], ",", 
       RowBox[{"755", "\[Rule]", "756"}], ",", 
       RowBox[{"97", "\[Rule]", "474"}], ",", 
       RowBox[{"97", "\[Rule]", "98"}], ",", 
       RowBox[{"1695", "\[Rule]", "1414"}], ",", 
       RowBox[{"1695", "\[Rule]", "1414"}], ",", 
       RowBox[{"1695", "\[Rule]", "2072"}], ",", 
       RowBox[{"1695", "\[Rule]", "2072"}], ",", 
       RowBox[{"1695", "\[Rule]", "1320"}], ",", 
       RowBox[{"1695", "\[Rule]", "1320"}], ",", 
       RowBox[{"1695", "\[Rule]", "1978"}], ",", 
       RowBox[{"1695", "\[Rule]", "1978"}], ",", 
       RowBox[{"1695", "\[Rule]", "1696"}], ",", 
       RowBox[{"1413", "\[Rule]", "1132"}], ",", 
       RowBox[{"1413", "\[Rule]", "1132"}], ",", 
       RowBox[{"1413", "\[Rule]", "1790"}], ",", 
       RowBox[{"1413", "\[Rule]", "1790"}], ",", 
       RowBox[{"1413", "\[Rule]", "1038"}], ",", 
       RowBox[{"1413", "\[Rule]", "1038"}], ",", 
       RowBox[{"1413", "\[Rule]", "1696"}], ",", 
       RowBox[{"1413", "\[Rule]", "1696"}], ",", 
       RowBox[{"1413", "\[Rule]", "1414"}], ",", 
       RowBox[{"2259", "\[Rule]", "1884"}], ",", 
       RowBox[{"2259", "\[Rule]", "1884"}], ",", 
       RowBox[{"2259", "\[Rule]", "2260"}], ",", 
       RowBox[{"2165", "\[Rule]", "1884"}], ",", 
       RowBox[{"2165", "\[Rule]", "1884"}], ",", 
       RowBox[{"2165", "\[Rule]", "1790"}], ",", 
       RowBox[{"2165", "\[Rule]", "1790"}], ",", 
       RowBox[{"2165", "\[Rule]", "2166"}], ",", 
       RowBox[{"2071", "\[Rule]", "1790"}], ",", 
       RowBox[{"2071", "\[Rule]", "1790"}], ",", 
       RowBox[{"2071", "\[Rule]", "1696"}], ",", 
       RowBox[{"2071", "\[Rule]", "1696"}], ",", 
       RowBox[{"2071", "\[Rule]", "2072"}], ",", 
       RowBox[{"3", "\[Rule]", "380"}], ",", 
       RowBox[{"3", "\[Rule]", "4"}], ",", 
       RowBox[{"661", "\[Rule]", "380"}], ",", 
       RowBox[{"661", "\[Rule]", "380"}], ",", 
       RowBox[{"661", "\[Rule]", "1038"}], ",", 
       RowBox[{"661", "\[Rule]", "662"}], ",", 
       RowBox[{"1319", "\[Rule]", "1038"}], ",", 
       RowBox[{"1319", "\[Rule]", "1696"}], ",", 
       RowBox[{"1319", "\[Rule]", "1696"}], ",", 
       RowBox[{"1319", "\[Rule]", "1320"}], ",", 
       RowBox[{"1977", "\[Rule]", "1696"}], ",", 
       RowBox[{"1977", "\[Rule]", "1696"}], ",", 
       RowBox[{"1977", "\[Rule]", "1978"}], ",", 
       RowBox[{"579", "\[Rule]", "298"}], ",", 
       RowBox[{"579", "\[Rule]", "298"}], ",", 
       RowBox[{"579", "\[Rule]", "956"}], ",", 
       RowBox[{"579", "\[Rule]", "956"}], ",", 
       RowBox[{"579", "\[Rule]", "204"}], ",", 
       RowBox[{"579", "\[Rule]", "204"}], ",", 
       RowBox[{"579", "\[Rule]", "862"}], ",", 
       RowBox[{"579", "\[Rule]", "862"}], ",", 
       RowBox[{"579", "\[Rule]", "580"}], ",", 
       RowBox[{"297", "\[Rule]", "580"}], ",", 
       RowBox[{"297", "\[Rule]", "580"}], ",", 
       RowBox[{"297", "\[Rule]", "298"}], ",", 
       RowBox[{"1237", "\[Rule]", "956"}], ",", 
       RowBox[{"1237", "\[Rule]", "956"}], ",", 
       RowBox[{"1237", "\[Rule]", "1614"}], ",", 
       RowBox[{"1237", "\[Rule]", "1614"}], ",", 
       RowBox[{"1237", "\[Rule]", "862"}], ",", 
       RowBox[{"1237", "\[Rule]", "862"}], ",", 
       RowBox[{"1237", "\[Rule]", "1520"}], ",", 
       RowBox[{"1237", "\[Rule]", "1520"}], ",", 
       RowBox[{"1237", "\[Rule]", "1238"}], ",", 
       RowBox[{"955", "\[Rule]", "580"}], ",", 
       RowBox[{"955", "\[Rule]", "580"}], ",", 
       RowBox[{"955", "\[Rule]", "1238"}], ",", 
       RowBox[{"955", "\[Rule]", "1238"}], ",", 
       RowBox[{"955", "\[Rule]", "956"}], ",", 
       RowBox[{"485", "\[Rule]", "204"}], ",", 
       RowBox[{"485", "\[Rule]", "204"}], ",", 
       RowBox[{"485", "\[Rule]", "862"}], ",", 
       RowBox[{"485", "\[Rule]", "862"}], ",", 
       RowBox[{"485", "\[Rule]", "110"}], ",", 
       RowBox[{"485", "\[Rule]", "768"}], ",", 
       RowBox[{"485", "\[Rule]", "486"}], ",", 
       RowBox[{"203", "\[Rule]", "580"}], ",", 
       RowBox[{"203", "\[Rule]", "580"}], ",", 
       RowBox[{"203", "\[Rule]", "486"}], ",", 
       RowBox[{"203", "\[Rule]", "486"}], ",", 
       RowBox[{"203", "\[Rule]", "204"}], ",", 
       RowBox[{"1143", "\[Rule]", "862"}], ",", 
       RowBox[{"1143", "\[Rule]", "862"}], ",", 
       RowBox[{"1143", "\[Rule]", "1520"}], ",", 
       RowBox[{"1143", "\[Rule]", "1520"}], ",", 
       RowBox[{"1143", "\[Rule]", "768"}], ",", 
       RowBox[{"1143", "\[Rule]", "768"}], ",", 
       RowBox[{"1143", "\[Rule]", "1426"}], ",", 
       RowBox[{"1143", "\[Rule]", "1426"}], ",", 
       RowBox[{"1143", "\[Rule]", "1144"}], ",", 
       RowBox[{"861", "\[Rule]", "580"}], ",", 
       RowBox[{"861", "\[Rule]", "580"}], ",", 
       RowBox[{"861", "\[Rule]", "1238"}], ",", 
       RowBox[{"861", "\[Rule]", "1238"}], ",", 
       RowBox[{"861", "\[Rule]", "486"}], ",", 
       RowBox[{"861", "\[Rule]", "486"}], ",", 
       RowBox[{"861", "\[Rule]", "1144"}], ",", 
       RowBox[{"861", "\[Rule]", "1144"}], ",", 
       RowBox[{"861", "\[Rule]", "862"}], ",", 
       RowBox[{"1895", "\[Rule]", "1614"}], ",", 
       RowBox[{"1895", "\[Rule]", "1614"}], ",", 
       RowBox[{"1895", "\[Rule]", "2272"}], ",", 
       RowBox[{"1895", "\[Rule]", "2272"}], ",", 
       RowBox[{"1895", "\[Rule]", "1520"}], ",", 
       RowBox[{"1895", "\[Rule]", "1520"}], ",", 
       RowBox[{"1895", "\[Rule]", "2178"}], ",", 
       RowBox[{"1895", "\[Rule]", "2178"}], ",", 
       RowBox[{"1895", "\[Rule]", "1896"}], ",", 
       RowBox[{"1613", "\[Rule]", "1238"}], ",", 
       RowBox[{"1613", "\[Rule]", "1238"}], ",", 
       RowBox[{"1613", "\[Rule]", "1896"}], ",", 
       RowBox[{"1613", "\[Rule]", "1896"}], ",", 
       RowBox[{"1613", "\[Rule]", "1614"}], ",", 
       RowBox[{"1801", "\[Rule]", "1520"}], ",", 
       RowBox[{"1801", "\[Rule]", "1520"}], ",", 
       RowBox[{"1801", "\[Rule]", "2178"}], ",", 
       RowBox[{"1801", "\[Rule]", "2178"}], ",", 
       RowBox[{"1801", "\[Rule]", "1426"}], ",", 
       RowBox[{"1801", "\[Rule]", "1426"}], ",", 
       RowBox[{"1801", "\[Rule]", "2084"}], ",", 
       RowBox[{"1801", "\[Rule]", "2084"}], ",", 
       RowBox[{"1801", "\[Rule]", "1802"}], ",", 
       RowBox[{"1519", "\[Rule]", "1238"}], ",", 
       RowBox[{"1519", "\[Rule]", "1238"}], ",", 
       RowBox[{"1519", "\[Rule]", "1896"}], ",", 
       RowBox[{"1519", "\[Rule]", "1896"}], ",", 
       RowBox[{"1519", "\[Rule]", "1144"}], ",", 
       RowBox[{"1519", "\[Rule]", "1144"}], ",", 
       RowBox[{"1519", "\[Rule]", "1802"}], ",", 
       RowBox[{"1519", "\[Rule]", "1802"}], ",", 
       RowBox[{"1519", "\[Rule]", "1520"}], ",", 
       RowBox[{"391", "\[Rule]", "110"}], ",", 
       RowBox[{"391", "\[Rule]", "768"}], ",", 
       RowBox[{"391", "\[Rule]", "16"}], ",", 
       RowBox[{"391", "\[Rule]", "674"}], ",", 
       RowBox[{"391", "\[Rule]", "392"}], ",", 
       RowBox[{"109", "\[Rule]", "486"}], ",", 
       RowBox[{"109", "\[Rule]", "392"}], ",", 
       RowBox[{"109", "\[Rule]", "110"}], ",", 
       RowBox[{"1049", "\[Rule]", "768"}], ",", 
       RowBox[{"1049", "\[Rule]", "768"}], ",", 
       RowBox[{"1049", "\[Rule]", "1426"}], ",", 
       RowBox[{"1049", "\[Rule]", "1426"}], ",", 
       RowBox[{"1049", "\[Rule]", "674"}], ",", 
       RowBox[{"1049", "\[Rule]", "1332"}], ",", 
       RowBox[{"1049", "\[Rule]", "1050"}], ",", 
       RowBox[{"767", "\[Rule]", "486"}], ",", 
       RowBox[{"767", "\[Rule]", "1144"}], ",", 
       RowBox[{"767", "\[Rule]", "1144"}], ",", 
       RowBox[{"767", "\[Rule]", "392"}], ",", 
       RowBox[{"767", "\[Rule]", "1050"}], ",", 
       RowBox[{"767", "\[Rule]", "1050"}], ",", 
       RowBox[{"767", "\[Rule]", "768"}], ",", 
       RowBox[{"1707", "\[Rule]", "1426"}], ",", 
       RowBox[{"1707", "\[Rule]", "1426"}], ",", 
       RowBox[{"1707", "\[Rule]", "2084"}], ",", 
       RowBox[{"1707", "\[Rule]", "2084"}], ",", 
       RowBox[{"1707", "\[Rule]", "1332"}], ",", 
       RowBox[{"1707", "\[Rule]", "1332"}], ",", 
       RowBox[{"1707", "\[Rule]", "1990"}], ",", 
       RowBox[{"1707", "\[Rule]", "1990"}], ",", 
       RowBox[{"1707", "\[Rule]", "1708"}], ",", 
       RowBox[{"1425", "\[Rule]", "1144"}], ",", 
       RowBox[{"1425", "\[Rule]", "1144"}], ",", 
       RowBox[{"1425", "\[Rule]", "1802"}], ",", 
       RowBox[{"1425", "\[Rule]", "1802"}], ",", 
       RowBox[{"1425", "\[Rule]", "1050"}], ",", 
       RowBox[{"1425", "\[Rule]", "1050"}], ",", 
       RowBox[{"1425", "\[Rule]", "1708"}], ",", 
       RowBox[{"1425", "\[Rule]", "1708"}], ",", 
       RowBox[{"1425", "\[Rule]", "1426"}], ",", 
       RowBox[{"2271", "\[Rule]", "1896"}], ",", 
       RowBox[{"2271", "\[Rule]", "1896"}], ",", 
       RowBox[{"2271", "\[Rule]", "2272"}], ",", 
       RowBox[{"2177", "\[Rule]", "1896"}], ",", 
       RowBox[{"2177", "\[Rule]", "1896"}], ",", 
       RowBox[{"2177", "\[Rule]", "1802"}], ",", 
       RowBox[{"2177", "\[Rule]", "1802"}], ",", 
       RowBox[{"2177", "\[Rule]", "2178"}], ",", 
       RowBox[{"2083", "\[Rule]", "1802"}], ",", 
       RowBox[{"2083", "\[Rule]", "1802"}], ",", 
       RowBox[{"2083", "\[Rule]", "1708"}], ",", 
       RowBox[{"2083", "\[Rule]", "1708"}], ",", 
       RowBox[{"2083", "\[Rule]", "2084"}], ",", 
       RowBox[{"15", "\[Rule]", "392"}], ",", 
       RowBox[{"15", "\[Rule]", "16"}], ",", 
       RowBox[{"673", "\[Rule]", "392"}], ",", 
       RowBox[{"673", "\[Rule]", "1050"}], ",", 
       RowBox[{"673", "\[Rule]", "674"}], ",", 
       RowBox[{"1331", "\[Rule]", "1050"}], ",", 
       RowBox[{"1331", "\[Rule]", "1708"}], ",", 
       RowBox[{"1331", "\[Rule]", "1708"}], ",", 
       RowBox[{"1331", "\[Rule]", "1332"}], ",", 
       RowBox[{"1989", "\[Rule]", "1708"}], ",", 
       RowBox[{"1989", "\[Rule]", "1708"}], ",", 
       RowBox[{"1989", "\[Rule]", "1990"}], ",", 
       RowBox[{"286", "\[Rule]", "299"}], ",", 
       RowBox[{"286", "\[Rule]", "287"}], ",", 
       RowBox[{"286", "\[Rule]", "283"}], ",", 
       RowBox[{"944", "\[Rule]", "957"}], ",", 
       RowBox[{"944", "\[Rule]", "945"}], ",", 
       RowBox[{"944", "\[Rule]", "941"}], ",", 
       RowBox[{"192", "\[Rule]", "205"}], ",", 
       RowBox[{"192", "\[Rule]", "193"}], ",", 
       RowBox[{"192", "\[Rule]", "189"}], ",", 
       RowBox[{"850", "\[Rule]", "863"}], ",", 
       RowBox[{"850", "\[Rule]", "851"}], ",", 
       RowBox[{"850", "\[Rule]", "847"}], ",", 
       RowBox[{"568", "\[Rule]", "581"}], ",", 
       RowBox[{"568", "\[Rule]", "569"}], ",", 
       RowBox[{"568", "\[Rule]", "565"}], ",", 
       RowBox[{"1602", "\[Rule]", "1615"}], ",", 
       RowBox[{"1602", "\[Rule]", "1603"}], ",", 
       RowBox[{"1602", "\[Rule]", "1599"}], ",", 
       RowBox[{"1508", "\[Rule]", "1521"}], ",", 
       RowBox[{"1508", "\[Rule]", "1509"}], ",", 
       RowBox[{"1508", "\[Rule]", "1505"}], ",", 
       RowBox[{"1226", "\[Rule]", "1239"}], ",", 
       RowBox[{"1226", "\[Rule]", "1227"}], ",", 
       RowBox[{"1226", "\[Rule]", "1223"}], ",", 
       RowBox[{"98", "\[Rule]", "111"}], ",", 
       RowBox[{"98", "\[Rule]", "99"}], ",", 
       RowBox[{"98", "\[Rule]", "95"}], ",", 
       RowBox[{"756", "\[Rule]", "769"}], ",", 
       RowBox[{"756", "\[Rule]", "757"}], ",", 
       RowBox[{"756", "\[Rule]", "753"}], ",", 
       RowBox[{"474", "\[Rule]", "487"}], ",", 
       RowBox[{"474", "\[Rule]", "475"}], ",", 
       RowBox[{"474", "\[Rule]", "471"}], ",", 
       RowBox[{"1414", "\[Rule]", "1427"}], ",", 
       RowBox[{"1414", "\[Rule]", "1415"}], ",", 
       RowBox[{"1414", "\[Rule]", "1411"}], ",", 
       RowBox[{"1132", "\[Rule]", "1145"}], ",", 
       RowBox[{"1132", "\[Rule]", "1133"}], ",", 
       RowBox[{"1132", "\[Rule]", "1129"}], ",", 
       RowBox[{"2260", "\[Rule]", "2273"}], ",", 
       RowBox[{"2260", "\[Rule]", "2261"}], ",", 
       RowBox[{"2260", "\[Rule]", "2257"}], ",", 
       RowBox[{"2166", "\[Rule]", "2179"}], ",", 
       RowBox[{"2166", "\[Rule]", "2167"}], ",", 
       RowBox[{"2166", "\[Rule]", "2163"}], ",", 
       RowBox[{"1884", "\[Rule]", "1897"}], ",", 
       RowBox[{"1884", "\[Rule]", "1885"}], ",", 
       RowBox[{"1884", "\[Rule]", "1881"}], ",", 
       RowBox[{"2072", "\[Rule]", "2085"}], ",", 
       RowBox[{"2072", "\[Rule]", "2073"}], ",", 
       RowBox[{"2072", "\[Rule]", "2069"}], ",", 
       RowBox[{"1790", "\[Rule]", "1803"}], ",", 
       RowBox[{"1790", "\[Rule]", "1791"}], ",", 
       RowBox[{"1790", "\[Rule]", "1787"}], ",", 
       RowBox[{"4", "\[Rule]", "17"}], ",", 
       RowBox[{"4", "\[Rule]", "5"}], ",", 
       RowBox[{"4", "\[Rule]", "1"}], ",", 
       RowBox[{"662", "\[Rule]", "675"}], ",", 
       RowBox[{"662", "\[Rule]", "663"}], ",", 
       RowBox[{"662", "\[Rule]", "659"}], ",", 
       RowBox[{"380", "\[Rule]", "393"}], ",", 
       RowBox[{"380", "\[Rule]", "381"}], ",", 
       RowBox[{"380", "\[Rule]", "377"}], ",", 
       RowBox[{"1320", "\[Rule]", "1333"}], ",", 
       RowBox[{"1320", "\[Rule]", "1321"}], ",", 
       RowBox[{"1320", "\[Rule]", "1317"}], ",", 
       RowBox[{"1038", "\[Rule]", "1051"}], ",", 
       RowBox[{"1038", "\[Rule]", "1039"}], ",", 
       RowBox[{"1038", "\[Rule]", "1035"}], ",", 
       RowBox[{"1978", "\[Rule]", "1991"}], ",", 
       RowBox[{"1978", "\[Rule]", "1979"}], ",", 
       RowBox[{"1978", "\[Rule]", "1975"}], ",", 
       RowBox[{"1696", "\[Rule]", "1709"}], ",", 
       RowBox[{"1696", "\[Rule]", "1697"}], ",", 
       RowBox[{"1696", "\[Rule]", "1693"}], ",", 
       RowBox[{"298", "\[Rule]", "283"}], ",", 
       RowBox[{"298", "\[Rule]", "309"}], ",", 
       RowBox[{"298", "\[Rule]", "299"}], ",", 
       RowBox[{"956", "\[Rule]", "941"}], ",", 
       RowBox[{"956", "\[Rule]", "967"}], ",", 
       RowBox[{"956", "\[Rule]", "957"}], ",", 
       RowBox[{"204", "\[Rule]", "189"}], ",", 
       RowBox[{"204", "\[Rule]", "215"}], ",", 
       RowBox[{"204", "\[Rule]", "205"}], ",", 
       RowBox[{"862", "\[Rule]", "847"}], ",", 
       RowBox[{"862", "\[Rule]", "873"}], ",", 
       RowBox[{"862", "\[Rule]", "863"}], ",", 
       RowBox[{"580", "\[Rule]", "565"}], ",", 
       RowBox[{"580", "\[Rule]", "591"}], ",", 
       RowBox[{"580", "\[Rule]", "581"}], ",", 
       RowBox[{"1614", "\[Rule]", "1599"}], ",", 
       RowBox[{"1614", "\[Rule]", "1625"}], ",", 
       RowBox[{"1614", "\[Rule]", "1615"}], ",", 
       RowBox[{"1520", "\[Rule]", "1505"}], ",", 
       RowBox[{"1520", "\[Rule]", "1531"}], ",", 
       RowBox[{"1520", "\[Rule]", "1521"}], ",", 
       RowBox[{"1238", "\[Rule]", "1223"}], ",", 
       RowBox[{"1238", "\[Rule]", "1249"}], ",", 
       RowBox[{"1238", "\[Rule]", "1239"}], ",", 
       RowBox[{"110", "\[Rule]", "95"}], ",", 
       RowBox[{"110", "\[Rule]", "121"}], ",", 
       RowBox[{"110", "\[Rule]", "111"}], ",", 
       RowBox[{"768", "\[Rule]", "753"}], ",", 
       RowBox[{"768", "\[Rule]", "779"}], ",", 
       RowBox[{"768", "\[Rule]", "769"}], ",", 
       RowBox[{"486", "\[Rule]", "471"}], ",", 
       RowBox[{"486", "\[Rule]", "497"}], ",", 
       RowBox[{"486", "\[Rule]", "487"}], ",", 
       RowBox[{"1426", "\[Rule]", "1411"}], ",", 
       RowBox[{"1426", "\[Rule]", "1437"}], ",", 
       RowBox[{"1426", "\[Rule]", "1427"}], ",", 
       RowBox[{"1144", "\[Rule]", "1129"}], ",", 
       RowBox[{"1144", "\[Rule]", "1155"}], ",", 
       RowBox[{"1144", "\[Rule]", "1145"}], ",", 
       RowBox[{"2272", "\[Rule]", "2257"}], ",", 
       RowBox[{"2272", "\[Rule]", "2283"}], ",", 
       RowBox[{"2272", "\[Rule]", "2273"}], ",", 
       RowBox[{"2178", "\[Rule]", "2163"}], ",", 
       RowBox[{"2178", "\[Rule]", "2189"}], ",", 
       RowBox[{"2178", "\[Rule]", "2179"}], ",", 
       RowBox[{"1896", "\[Rule]", "1881"}], ",", 
       RowBox[{"1896", "\[Rule]", "1907"}], ",", 
       RowBox[{"1896", "\[Rule]", "1897"}], ",", 
       RowBox[{"2084", "\[Rule]", "2069"}], ",", 
       RowBox[{"2084", "\[Rule]", "2095"}], ",", 
       RowBox[{"2084", "\[Rule]", "2085"}], ",", 
       RowBox[{"1802", "\[Rule]", "1787"}], ",", 
       RowBox[{"1802", "\[Rule]", "1813"}], ",", 
       RowBox[{"1802", "\[Rule]", "1803"}], ",", 
       RowBox[{"16", "\[Rule]", "1"}], ",", 
       RowBox[{"16", "\[Rule]", "27"}], ",", 
       RowBox[{"16", "\[Rule]", "17"}], ",", 
       RowBox[{"674", "\[Rule]", "659"}], ",", 
       RowBox[{"674", "\[Rule]", "685"}], ",", 
       RowBox[{"674", "\[Rule]", "675"}], ",", 
       RowBox[{"392", "\[Rule]", "377"}], ",", 
       RowBox[{"392", "\[Rule]", "403"}], ",", 
       RowBox[{"392", "\[Rule]", "393"}], ",", 
       RowBox[{"1332", "\[Rule]", "1317"}], ",", 
       RowBox[{"1332", "\[Rule]", "1343"}], ",", 
       RowBox[{"1332", "\[Rule]", "1333"}], ",", 
       RowBox[{"1050", "\[Rule]", "1035"}], ",", 
       RowBox[{"1050", "\[Rule]", "1061"}], ",", 
       RowBox[{"1050", "\[Rule]", "1051"}], ",", 
       RowBox[{"1990", "\[Rule]", "1975"}], ",", 
       RowBox[{"1990", "\[Rule]", "2001"}], ",", 
       RowBox[{"1990", "\[Rule]", "1991"}], ",", 
       RowBox[{"1708", "\[Rule]", "1693"}], ",", 
       RowBox[{"1708", "\[Rule]", "1719"}], ",", 
       RowBox[{"1708", "\[Rule]", "1709"}], ",", 
       RowBox[{"283", "\[Rule]", "566"}], ",", 
       RowBox[{"283", "\[Rule]", "566"}], ",", 
       RowBox[{"283", "\[Rule]", "284"}], ",", 
       RowBox[{"941", "\[Rule]", "566"}], ",", 
       RowBox[{"941", "\[Rule]", "566"}], ",", 
       RowBox[{"941", "\[Rule]", "1224"}], ",", 
       RowBox[{"941", "\[Rule]", "1224"}], ",", 
       RowBox[{"941", "\[Rule]", "942"}], ",", 
       RowBox[{"189", "\[Rule]", "566"}], ",", 
       RowBox[{"189", "\[Rule]", "566"}], ",", 
       RowBox[{"189", "\[Rule]", "472"}], ",", 
       RowBox[{"189", "\[Rule]", "472"}], ",", 
       RowBox[{"189", "\[Rule]", "190"}], ",", 
       RowBox[{"847", "\[Rule]", "566"}], ",", 
       RowBox[{"847", "\[Rule]", "566"}], ",", 
       RowBox[{"847", "\[Rule]", "1224"}], ",", 
       RowBox[{"847", "\[Rule]", "1224"}], ",", 
       RowBox[{"847", "\[Rule]", "472"}], ",", 
       RowBox[{"847", "\[Rule]", "472"}], ",", 
       RowBox[{"847", "\[Rule]", "1130"}], ",", 
       RowBox[{"847", "\[Rule]", "1130"}], ",", 
       RowBox[{"847", "\[Rule]", "848"}], ",", 
       RowBox[{"565", "\[Rule]", "284"}], ",", 
       RowBox[{"565", "\[Rule]", "284"}], ",", 
       RowBox[{"565", "\[Rule]", "942"}], ",", 
       RowBox[{"565", "\[Rule]", "942"}], ",", 
       RowBox[{"565", "\[Rule]", "190"}], ",", 
       RowBox[{"565", "\[Rule]", "190"}], ",", 
       RowBox[{"565", "\[Rule]", "848"}], ",", 
       RowBox[{"565", "\[Rule]", "848"}], ",", 
       RowBox[{"565", "\[Rule]", "566"}], ",", 
       RowBox[{"1599", "\[Rule]", "1224"}], ",", 
       RowBox[{"1599", "\[Rule]", "1224"}], ",", 
       RowBox[{"1599", "\[Rule]", "1882"}], ",", 
       RowBox[{"1599", "\[Rule]", "1882"}], ",", 
       RowBox[{"1599", "\[Rule]", "1600"}], ",", 
       RowBox[{"1505", "\[Rule]", "1224"}], ",", 
       RowBox[{"1505", "\[Rule]", "1224"}], ",", 
       RowBox[{"1505", "\[Rule]", "1882"}], ",", 
       RowBox[{"1505", "\[Rule]", "1882"}], ",", 
       RowBox[{"1505", "\[Rule]", "1130"}], ",", 
       RowBox[{"1505", "\[Rule]", "1130"}], ",", 
       RowBox[{"1505", "\[Rule]", "1788"}], ",", 
       RowBox[{"1505", "\[Rule]", "1788"}], ",", 
       RowBox[{"1505", "\[Rule]", "1506"}], ",", 
       RowBox[{"1223", "\[Rule]", "942"}], ",", 
       RowBox[{"1223", "\[Rule]", "942"}], ",", 
       RowBox[{"1223", "\[Rule]", "1600"}], ",", 
       RowBox[{"1223", "\[Rule]", "1600"}], ",", 
       RowBox[{"1223", "\[Rule]", "848"}], ",", 
       RowBox[{"1223", "\[Rule]", "848"}], ",", 
       RowBox[{"1223", "\[Rule]", "1506"}], ",", 
       RowBox[{"1223", "\[Rule]", "1506"}], ",", 
       RowBox[{"1223", "\[Rule]", "1224"}], ",", 
       RowBox[{"95", "\[Rule]", "472"}], ",", 
       RowBox[{"95", "\[Rule]", "378"}], ",", 
       RowBox[{"95", "\[Rule]", "96"}], ",", 
       RowBox[{"753", "\[Rule]", "472"}], ",", 
       RowBox[{"753", "\[Rule]", "1130"}], ",", 
       RowBox[{"753", "\[Rule]", "1130"}], ",", 
       RowBox[{"753", "\[Rule]", "378"}], ",", 
       RowBox[{"753", "\[Rule]", "1036"}], ",", 
       RowBox[{"753", "\[Rule]", "1036"}], ",", 
       RowBox[{"753", "\[Rule]", "754"}], ",", 
       RowBox[{"471", "\[Rule]", "190"}], ",", 
       RowBox[{"471", "\[Rule]", "190"}], ",", 
       RowBox[{"471", "\[Rule]", "848"}], ",", 
       RowBox[{"471", "\[Rule]", "848"}], ",", 
       RowBox[{"471", "\[Rule]", "96"}], ",", 
       RowBox[{"471", "\[Rule]", "754"}], ",", 
       RowBox[{"471", "\[Rule]", "472"}], ",", 
       RowBox[{"1411", "\[Rule]", "1130"}], ",", 
       RowBox[{"1411", "\[Rule]", "1130"}], ",", 
       RowBox[{"1411", "\[Rule]", "1788"}], ",", 
       RowBox[{"1411", "\[Rule]", "1788"}], ",", 
       RowBox[{"1411", "\[Rule]", "1036"}], ",", 
       RowBox[{"1411", "\[Rule]", "1036"}], ",", 
       RowBox[{"1411", "\[Rule]", "1694"}], ",", 
       RowBox[{"1411", "\[Rule]", "1694"}], ",", 
       RowBox[{"1411", "\[Rule]", "1412"}], ",", 
       RowBox[{"1129", "\[Rule]", "848"}], ",", 
       RowBox[{"1129", "\[Rule]", "848"}], ",", 
       RowBox[{"1129", "\[Rule]", "1506"}], ",", 
       RowBox[{"1129", "\[Rule]", "1506"}], ",", 
       RowBox[{"1129", "\[Rule]", "754"}], ",", 
       RowBox[{"1129", "\[Rule]", "754"}], ",", 
       RowBox[{"1129", "\[Rule]", "1412"}], ",", 
       RowBox[{"1129", "\[Rule]", "1412"}], ",", 
       RowBox[{"1129", "\[Rule]", "1130"}], ",", 
       RowBox[{"2257", "\[Rule]", "1882"}], ",", 
       RowBox[{"2257", "\[Rule]", "1882"}], ",", 
       RowBox[{"2257", "\[Rule]", "2258"}], ",", 
       RowBox[{"2163", "\[Rule]", "1882"}], ",", 
       RowBox[{"2163", "\[Rule]", "1882"}], ",", 
       RowBox[{"2163", "\[Rule]", "1788"}], ",", 
       RowBox[{"2163", "\[Rule]", "1788"}], ",", 
       RowBox[{"2163", "\[Rule]", "2164"}], ",", 
       RowBox[{"1881", "\[Rule]", "1600"}], ",", 
       RowBox[{"1881", "\[Rule]", "1600"}], ",", 
       RowBox[{"1881", "\[Rule]", "2258"}], ",", 
       RowBox[{"1881", "\[Rule]", "2258"}], ",", 
       RowBox[{"1881", "\[Rule]", "1506"}], ",", 
       RowBox[{"1881", "\[Rule]", "1506"}], ",", 
       RowBox[{"1881", "\[Rule]", "2164"}], ",", 
       RowBox[{"1881", "\[Rule]", "2164"}], ",", 
       RowBox[{"1881", "\[Rule]", "1882"}], ",", 
       RowBox[{"2069", "\[Rule]", "1788"}], ",", 
       RowBox[{"2069", "\[Rule]", "1788"}], ",", 
       RowBox[{"2069", "\[Rule]", "1694"}], ",", 
       RowBox[{"2069", "\[Rule]", "1694"}], ",", 
       RowBox[{"2069", "\[Rule]", "2070"}], ",", 
       RowBox[{"1787", "\[Rule]", "1506"}], ",", 
       RowBox[{"1787", "\[Rule]", "1506"}], ",", 
       RowBox[{"1787", "\[Rule]", "2164"}], ",", 
       RowBox[{"1787", "\[Rule]", "2164"}], ",", 
       RowBox[{"1787", "\[Rule]", "1412"}], ",", 
       RowBox[{"1787", "\[Rule]", "1412"}], ",", 
       RowBox[{"1787", "\[Rule]", "2070"}], ",", 
       RowBox[{"1787", "\[Rule]", "2070"}], ",", 
       RowBox[{"1787", "\[Rule]", "1788"}], ",", 
       RowBox[{"1", "\[Rule]", "378"}], ",", 
       RowBox[{"1", "\[Rule]", "378"}], ",", 
       RowBox[{"1", "\[Rule]", "2"}], ",", 
       RowBox[{"659", "\[Rule]", "378"}], ",", 
       RowBox[{"659", "\[Rule]", "378"}], ",", 
       RowBox[{"659", "\[Rule]", "1036"}], ",", 
       RowBox[{"659", "\[Rule]", "660"}], ",", 
       RowBox[{"377", "\[Rule]", "96"}], ",", 
       RowBox[{"377", "\[Rule]", "754"}], ",", 
       RowBox[{"377", "\[Rule]", "2"}], ",", 
       RowBox[{"377", "\[Rule]", "2"}], ",", 
       RowBox[{"377", "\[Rule]", "660"}], ",", 
       RowBox[{"377", "\[Rule]", "660"}], ",", 
       RowBox[{"377", "\[Rule]", "378"}], ",", 
       RowBox[{"1317", "\[Rule]", "1036"}], ",", 
       RowBox[{"1317", "\[Rule]", "1694"}], ",", 
       RowBox[{"1317", "\[Rule]", "1694"}], ",", 
       RowBox[{"1317", "\[Rule]", "1318"}], ",", 
       RowBox[{"1035", "\[Rule]", "754"}], ",", 
       RowBox[{"1035", "\[Rule]", "754"}], ",", 
       RowBox[{"1035", "\[Rule]", "1412"}], ",", 
       RowBox[{"1035", "\[Rule]", "1412"}], ",", 
       RowBox[{"1035", "\[Rule]", "660"}], ",", 
       RowBox[{"1035", "\[Rule]", "1318"}], ",", 
       RowBox[{"1035", "\[Rule]", "1036"}], ",", 
       RowBox[{"1975", "\[Rule]", "1694"}], ",", 
       RowBox[{"1975", "\[Rule]", "1694"}], ",", 
       RowBox[{"1975", "\[Rule]", "1976"}], ",", 
       RowBox[{"1693", "\[Rule]", "1412"}], ",", 
       RowBox[{"1693", "\[Rule]", "1412"}], ",", 
       RowBox[{"1693", "\[Rule]", "2070"}], ",", 
       RowBox[{"1693", "\[Rule]", "2070"}], ",", 
       RowBox[{"1693", "\[Rule]", "1318"}], ",", 
       RowBox[{"1693", "\[Rule]", "1318"}], ",", 
       RowBox[{"1693", "\[Rule]", "1976"}], ",", 
       RowBox[{"1693", "\[Rule]", "1976"}], ",", 
       RowBox[{"1693", "\[Rule]", "1694"}], ",", 
       RowBox[{"566", "\[Rule]", "579"}], ",", 
       RowBox[{"566", "\[Rule]", "567"}], ",", 
       RowBox[{"284", "\[Rule]", "297"}], ",", 
       RowBox[{"284", "\[Rule]", "285"}], ",", 
       RowBox[{"1224", "\[Rule]", "1237"}], ",", 
       RowBox[{"1224", "\[Rule]", "1225"}], ",", 
       RowBox[{"942", "\[Rule]", "955"}], ",", 
       RowBox[{"942", "\[Rule]", "943"}], ",", 
       RowBox[{"472", "\[Rule]", "485"}], ",", 
       RowBox[{"472", "\[Rule]", "473"}], ",", 
       RowBox[{"190", "\[Rule]", "203"}], ",", 
       RowBox[{"190", "\[Rule]", "191"}], ",", 
       RowBox[{"1130", "\[Rule]", "1143"}], ",", 
       RowBox[{"1130", "\[Rule]", "1131"}], ",", 
       RowBox[{"848", "\[Rule]", "861"}], ",", 
       RowBox[{"848", "\[Rule]", "849"}], ",", 
       RowBox[{"1882", "\[Rule]", "1895"}], ",", 
       RowBox[{"1882", "\[Rule]", "1883"}], ",", 
       RowBox[{"1600", "\[Rule]", "1613"}], ",", 
       RowBox[{"1600", "\[Rule]", "1601"}], ",", 
       RowBox[{"1788", "\[Rule]", "1801"}], ",", 
       RowBox[{"1788", "\[Rule]", "1789"}], ",", 
       RowBox[{"1506", "\[Rule]", "1519"}], ",", 
       RowBox[{"1506", "\[Rule]", "1507"}], ",", 
       RowBox[{"378", "\[Rule]", "391"}], ",", 
       RowBox[{"378", "\[Rule]", "379"}], ",", 
       RowBox[{"96", "\[Rule]", "109"}], ",", 
       RowBox[{"96", "\[Rule]", "97"}], ",", 
       RowBox[{"1036", "\[Rule]", "1049"}], ",", 
       RowBox[{"1036", "\[Rule]", "1037"}], ",", 
       RowBox[{"754", "\[Rule]", "767"}], ",", 
       RowBox[{"754", "\[Rule]", "755"}], ",", 
       RowBox[{"1694", "\[Rule]", "1707"}], ",", 
       RowBox[{"1694", "\[Rule]", "1695"}], ",", 
       RowBox[{"1412", "\[Rule]", "1425"}], ",", 
       RowBox[{"1412", "\[Rule]", "1413"}], ",", 
       RowBox[{"2258", "\[Rule]", "2271"}], ",", 
       RowBox[{"2258", "\[Rule]", "2259"}], ",", 
       RowBox[{"2164", "\[Rule]", "2177"}], ",", 
       RowBox[{"2164", "\[Rule]", "2165"}], ",", 
       RowBox[{"2070", "\[Rule]", "2083"}], ",", 
       RowBox[{"2070", "\[Rule]", "2071"}], ",", 
       RowBox[{"2", "\[Rule]", "15"}], ",", 
       RowBox[{"2", "\[Rule]", "3"}], ",", 
       RowBox[{"660", "\[Rule]", "673"}], ",", 
       RowBox[{"660", "\[Rule]", "661"}], ",", 
       RowBox[{"1318", "\[Rule]", "1331"}], ",", 
       RowBox[{"1318", "\[Rule]", "1319"}], ",", 
       RowBox[{"1976", "\[Rule]", "1989"}], ",", 
       RowBox[{"1976", "\[Rule]", "1977"}]}], "}"}], ",", 
     RowBox[{"EdgeWeight", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "c", ",", "d", ",", "i", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "i", ",", "c", ",", "d", ",", "i", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "c", ",", "g", ",", "i", ",", "c", ",", "g", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", 
        "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "i", ",", "c", ",", "d", ",", "i", ",", 
        "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "c", ",", 
        "d", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "g", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "i", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "i", ",", "b", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "e", ",", "f", ",", "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "e", ",", 
        "f", ",", "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "e", ",", "f", ",", "g", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "c", ",", "g", ",", "i", ",", "b", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "e", ",", "f", ",", "g", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "c", ",", 
        "d", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "e", ",", "f", ",", "g", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "e", ",", "f", ",", 
        "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "e", ",", 
        "f", ",", "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "e", ",", 
        "f", ",", "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "e", ",", "f", ",", "g", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "g", ",", 
        "h", ",", "i", ",", "g", ",", "h", ",", "i", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "g", ",", "h", ",", "i", ",", "g", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "c", ",", 
        "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "g", ",", "h", ",", 
        "i", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "g", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "g", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "b", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "e", ",", "f", ",", "i", ",", "e", ",", 
        "f", ",", "i", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "i", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "i", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", "b", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "g", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "a", ",", "c", ",", 
        "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "g", ",", "i", ",", 
        "h", ",", "i", ",", "g", ",", "h", ",", "i", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "i", ",", "f", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "d", ",", "g", ",", "h", ",", "i", ",", "b", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "g", ",", "h", ",", 
        "i", ",", "g", ",", "h", ",", "i", ",", "g", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "f", ",", "i", ",", "c", ",", "d", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "b", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", 
        "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "d", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "g", ",", "h", ",", "i", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "g", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "b", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "c", ",", "e", ",", 
        "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "e", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "i", ",", 
        "f", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "f", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "i", ",", "d", ",", "i", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", "c", ",", "i", ",", 
        "e", ",", "f", ",", "i", ",", "e", ",", "f", ",", "i", ",", "e", ",", 
        "f", ",", "i", ",", "e", ",", "f", ",", "i", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "e", ",", "i", ",", 
        "e", ",", "f", ",", "i", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "f", ",", "i", ",", "e", ",", 
        "f", ",", "i", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "e", ",", "i", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", 
        "b", ",", "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", "b", ",", 
        "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", "b", ",", "i", ",", 
        "a", ",", "b", ",", "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", 
        "b", ",", "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", "b", ",", 
        "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", "b", ",", "i", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "f", ",", "i", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "e", ",", 
        "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", "b", ",", "i", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "i", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "f", ",", "i", ",", 
        "b", ",", "i", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "i", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", 
        "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "i", ",", "b", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "h", ",", "i", ",", "c", ",", "d", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", "e", ",", 
        "f", ",", "g", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "i", ",", "c", ",", "d", ",", "i", ",", "b", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", 
        "b", ",", "i", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "g", ",", "h", ",", 
        "i", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "g", ",", "i", ",", "c", ",", "g", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "i", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", "b", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "b", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "b", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", "g", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "c", ",", "i", ",", "a", ",", 
        "c", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "i", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "b", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u"}], "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"init8", "=", 
   RowBox[{"{", "93", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bad8", "=", 
   RowBox[{"{", 
    RowBox[{
    "2", ",", "100", ",", "198", ",", "296", ",", "394", ",", "490", ",", 
     "588", ",", "686", ",", "784", ",", "882", ",", "980", ",", "1076", ",", 
     "1174", ",", "1272", ",", "1370", ",", "1468", ",", "1566", ",", "1664", 
     ",", "1762", ",", "1860", ",", "1958", ",", "2056", ",", "2154", ",", 
     "2252", ",", "2350", ",", "1", ",", "99", ",", "197", ",", "295", ",", 
     "393", ",", "489", ",", "587", ",", "685", ",", "783", ",", "881", ",", 
     "979", ",", "1075", ",", "1173", ",", "1271", ",", "1369", ",", "1467", 
     ",", "1565", ",", "1663", ",", "1761", ",", "1859", ",", "1957", ",", 
     "2055", ",", "2153", ",", "2251", ",", "2349"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lag8", "=", "15"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"graphical8", "=", "0"}], ";"}]}], "Input",
 CellChangeTimes->{{3.694056211510635*^9, 3.69405623174298*^9}, {
  3.694056323709104*^9, 3.694056344940049*^9}, {3.694056389881823*^9, 
  3.694056390571538*^9}, {3.69405643143198*^9, 3.694056461294148*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"main", "[", 
  RowBox[{"g8", ",", "init8", ",", "bad8", ",", "lag8", ",", "graphical8"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6940565009037848`*^9, 3.694056510007988*^9}}],

Cell[CellGroupData[{

Cell[BoxData["\<\"Under delay = 0 :\"\>"], "Print",
 CellChangeTimes->{3.6940565429045887`*^9, 3.694147953285407*^9, 
  3.714821177180286*^9}],

Cell[BoxData["\<\"(*hidden for the sake of space*)\"\>"], "Print",
 CellChangeTimes->{3.6940565429045887`*^9, 3.694147953285407*^9, 
  3.7148211771812553`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Under delay = \"\>", "\[InvisibleSpace]", "1", 
   "\[InvisibleSpace]", "\<\" :\"\>"}],
  SequenceForm["Under delay = ", 1, " :"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6940565429045887`*^9, 3.694147953285407*^9, 
  3.714821177182149*^9}],

Cell[BoxData["\<\"(*hidden for the sake of space*)\"\>"], "Print",
 CellChangeTimes->{3.6940565429045887`*^9, 3.694147953285407*^9, 
  3.714821180137137*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Under delay = \"\>", "\[InvisibleSpace]", "2", 
   "\[InvisibleSpace]", "\<\" :\"\>"}],
  SequenceForm["Under delay = ", 2, " :"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6940565429045887`*^9, 3.694147953285407*^9, 
  3.714821180138157*^9}],

Cell[BoxData["\<\"(*hidden for the sake of space*)\"\>"], "Print",
 CellChangeTimes->{3.6940565429045887`*^9, 3.694147953285407*^9, 
  3.714821188498865*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Under delay = \"\>", "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\" :\"\>"}],
  SequenceForm["Under delay = ", 3, " :"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6940565429045887`*^9, 3.694147953285407*^9, 
  3.714821188553424*^9}],

Cell[BoxData["\<\"(*hidden for the sake of space*)\"\>"], "Print",
 CellChangeTimes->{3.6940565429045887`*^9, 3.694147953285407*^9, 
  3.714821221904846*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Not possible for sure-winning anymore under delay=\"\>", 
   "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\" with uncontrollable states \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "1568", ",", "1580", ",", "1942", ",", "308", ",", "966", ",", "590", ",",
      "992", ",", "320", ",", "978", ",", "884", ",", "602", ",", "894", ",", 
     "1650", ",", "1274", ",", "1260", ",", "1678", ",", "1662", ",", "1286", 
     ",", "1552", ",", "1270", ",", "1176", ",", "1564", ",", "1470", ",", 
     "1188", ",", "1482", ",", "2336", ",", "1960", ",", "2320", ",", "1944", 
     ",", "2348", ",", "2254", ",", "1972", ",", "2332", ",", "2238", ",", 
     "1956", ",", "1862", ",", "1846", ",", "2250", ",", "2156", ",", "1874", 
     ",", "2140", ",", "1858", ",", "2046", ",", "1764", ",", "2152", ",", 
     "2058", ",", "1776", ",", "322", ",", "306", ",", "964", ",", "212", ",",
      "332", ",", "990", ",", "600", ",", "318", ",", "976", ",", "224", ",", 
     "1648", ",", "1676", ",", "1660", ",", "1750", ",", "1374", ",", "1386", 
     ",", "2322", ",", "2306", ",", "2334", ",", "2240", ",", "2318", ",", 
     "2224", ",", "2346", ",", "2330", ",", "2236", ",", "2142", ",", "2048", 
     ",", "2126", ",", "2032", ",", "2060", ",", "2138", ",", "2044", ",", 
     "294", ",", "200", ",", "576", ",", "304", ",", "210", ",", "868", ",", 
     "586", ",", "492", ",", "880", ",", "504", ",", "786", ",", "1162", ",", 
     "796", ",", "1454", ",", "1172", ",", "1078", ",", "1466", ",", "1090", 
     ",", "1372", ",", "2030", ",", "1748", ",", "1384", ",", "2042", ",", 
     "1760", ",", "292", ",", "302", ",", "208", ",", "32", ",", "690", ",", 
     "42", ",", "700", ",", "1358", ",", "2016", ",", "2028", ",", "196", ",",
      "478", ",", "102", ",", "782", ",", "30", ",", "688", ",", "406", ",", 
     "1064", ",", "6", ",", "18", ",", "28", ",", "676", ",", "98", ",", "4", 
     ",", "380", ",", "16", ",", "674", ",", "392", ",", "626", ",", "330", 
     ",", "1284", ",", "922", ",", "988", ",", "250", ",", "896", ",", "908", 
     ",", "612", ",", "1646", ",", "1312", ",", "1296", ",", "1970", ",", 
     "1592", ",", "1954", ",", "1674", ",", "1658", ",", "2304", ",", "1554", 
     ",", "1928", ",", "2316", ",", "2222", ",", "1578", ",", "1940", ",", 
     "1848", ",", "1474", ",", "1754", ",", "2128", ",", "2034", ",", "1472", 
     ",", "1484", ",", "1378", ",", "1752", ",", "1966", ",", "2344", ",", 
     "2328", ",", "1872", ",", "2234", ",", "358", ",", "342", ",", "640", 
     ",", "624", ",", "344", ",", "1016", ",", "1000", ",", "1298", ",", 
     "920", ",", "1216", ",", "1282", ",", "1002", ",", "638", ",", "248", 
     ",", "906", ",", "610", ",", "328", ",", "1268", ",", "986", ",", "262", 
     ",", "530", ",", "234", ",", "1634", ",", "1926", ",", "1644", ",", 
     "1458", ",", "2210", ",", "1930", ",", "1556", ",", "1836", ",", "2116", 
     ",", "1834", ",", "1832", ",", "1550", ",", "1364", ",", "2022", ",", 
     "1740", ",", "1738", ",", "1082", ",", "1362", ",", "370", ",", "354", 
     ",", "652", ",", "636", ",", "356", ",", "1028", ",", "1012", ",", 
     "1310", ",", "1294", ",", "1014", ",", "1686", ",", "1670", ",", "1968", 
     ",", "1952", ",", "1672", ",", "340", ",", "998", ",", "1938", ",", 
     "1656", ",", "1576", ",", "1200", ",", "1590", ",", "1562", ",", "2292", 
     ",", "2132", ",", "1742", ",", "1850", ",", "1180", ",", "1460", ",", 
     "1756", ",", "2130", ",", "2302", ",", "2208", ",", "2114", ",", "2038", 
     ",", "1366", ",", "2036", ",", "2020", ",", "2314", ",", "2220", ",", 
     "2340", ",", "1964", ",", "2342", ",", "2246", ",", "1870", ",", "2248", 
     ",", "2326", ",", "2232", ",", "962", ",", "316", ",", "974", ",", "222",
      ",", "598", ",", "1632", ",", "1258", ",", "1164", ",", "1538", ",", 
     "1256", ",", "506", ",", "226", ",", "604", ",", "240", ",", "898", ",", 
     "614", ",", "252", ",", "910", ",", "510", ",", "520", ",", "228", ",", 
     "238", ",", "236", ",", "264", ",", "532", ",", "132", ",", "142", ",", 
     "790", ",", "800", ",", "508", ",", "518", ",", "516", ",", "544", ",", 
     "276", ",", "934", ",", "1190", ",", "1202", ",", "154", ",", "812", ",",
      "412", ",", "422", ",", "130", ",", "140", ",", "128", ",", "1542", ",",
      "1448", ",", "1166", ",", "1070", ",", "1822", ",", "1728", ",", "1446",
      ",", "1444", ",", "36", ",", "46", ",", "34", ",", "1080", ",", "1178", 
     ",", "1084", ",", "1462", ",", "706", ",", "718", ",", "1096", ",", 
     "1368", ",", "1380", ",", "1486", ",", "1392", ",", "1376", ",", "1108", 
     ",", "1766", ",", "1498", ",", "1404", ",", "1390", ",", "1094", ",", 
     "704", ",", "694", ",", "692", ",", "38", ",", "48", ",", "696", ",", 
     "414", ",", "424", ",", "60", ",", "436", ",", "416", ",", "426", ",", 
     "134", ",", "144", ",", "438", ",", "156", ",", "450", ",", "168", ",", 
     "788", ",", "804", ",", "816", ",", "1192", ",", "828", ",", "1204", ",",
      "802", ",", "814", ",", "146", ",", "158", ",", "522", ",", "534", ",", 
     "170", ",", "546", ",", "536", ",", "548", ",", "560", ",", "1194", ",", 
     "1206", ",", "1218", ",", "798", ",", "840", ",", "826", ",", "182", ",",
      "558", ",", "40", ",", "50", ",", "62", ",", "74", ",", "708", ",", 
     "720", ",", "52", ",", "64", ",", "710", ",", "722", ",", "428", ",", 
     "440", ",", "76", ",", "734", ",", "452", ",", "442", ",", "160", ",", 
     "454", ",", "172", ",", "466", ",", "184", ",", "66", ",", "78", ",", 
     "90", ",", "1086", ",", "1098", ",", "1110", ",", "1100", ",", "818", 
     ",", "1112", ",", "830", ",", "174", ",", "832", ",", "186", ",", "844", 
     ",", "1124", ",", "842", ",", "724", ",", "736", ",", "80", ",", "738", 
     ",", "456", ",", "470", ",", "94", ",", "92", ",", "750", ",", "468", 
     ",", "748", ",", "732", ",", "88", ",", "746", ",", "464", ",", "1122", 
     ",", "410", ",", "93"}], "}"}], "\[InvisibleSpace]", "\<\".\\n\"\>"}],
  SequenceForm[
  "Not possible for sure-winning anymore under delay=", 3, 
   " with uncontrollable states ", CompressedData["
1:eJwl1XFE33kcx/HPdV23y0mSzCTdZDLJZGYmmZyZJEmSdJmf5JzpkvvjnGTm
TJKcM8lkkiSTJEkykyTJZJI5STKTSWZOkiT3eLs/nr1e7/fn/X2/P5/v7/v9
9kPm16bur1JKM/6U5qRUgZFvU7otXv86pYaslA7offE2/Q1tcv20V+15dkrH
GOb7kfNNSvn0VG4UxfwbuUl+k5Z+l9K0/vl0lFbQrSspLfDF/Bt+kn+AO9gU
P0YT305r6SU+6vuzOBdf+Fr7q8Kafe04Tz2/z7faaw3/jj+Q71E7hD68R4c9
/YICs7NQghU98+gcvUmv4TXfgYSGmGkP39M2XPA3zNiwfN+8W3Gv+E4z68TH
4h7+jBbQwbgvdNbc5/wdLPO1tJ1+1m8nzsef8wd8mWsr4xz6lmJe35v0NW1Q
d6DuGGty++q6aJ4ZJXROzYhcuf5apQIUY1I+Q6VTn/V8OiE3wPfSOpqt9wt9
9nBu/QkdQqf1bs1K4/fGvNl3xRN0kP4Rg9y3AjoQ94qfjfspfh61WHXdrrhR
/l/xivgtMvhHflau3HVX0cgvq+uypxY8Mb8HrfyZ/XxCgetG6YoDZfFHfL+a
M1sZ5DP8Q/Un1nfFOfF7yB1Zz5j3zIzHdN61E2YNigvjnaA/xt5jP8iTa1Zz
yL/lN3FPzya5Xj0zGNK3D51xD62dxG9hPQ+n/EjMw5we4xiInmoPrf0t/l1c
HuvxfNBrOLGHZmzFPDVj1hb02xM3yV9iPN4RnFpvsXYS7wpy3cMZ+bLQeF7p
ejzL/AYtEi/RVfOr7WOL7rsvLc7wSP8js4bivvKf6LmaD9bbrX+hT9V38Rf8
MH9p/Yr4o/gzjuPVkSuU+zNqUKSuFBfyOfLZKEWheEp+ypx5vFBbIR6LPJ6K
h+JZRI79TDvnsLpKlMRzJDcV3xyUqanEddyNXqjGorVVs7bimRC3ijuxhR48
QrP8oV67fB+68UBuxTWLWMANfW9hiX9pb9OoFi/QcbzCM/FfWOTH6GrU0UJn
KsMtTMe+6AK9TivjOVDzErl6F+FVnINeRVl8ZyIXZ8FqnN01D3EPi3Fu6+W0
CjWow5rcO9yObxXW+e2s/7//S6iP74d4jV+OM0QNnaHbUUNr0YC26GtuHVpQ
j6r45tKa+L7FDLoc3+P4ZkRtfJ/jfwoa5T/QDX3foyOep3he5HbEx3Qv3nG5
o9h3vFvxG9Kf5P4DAY/ZjA==
   "], ".\n"],
  Editable->False]], "Print",
 CellChangeTimes->{3.6940565429045887`*^9, 3.694147953285407*^9, 
  3.714821221958921*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Computation time under increasing delays : \\n\"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "7.712000000000003`", ",", "10.672000000000011`", ",", 
     "19.04400000000001`", ",", "52.468`"}], "}"}]}],
  SequenceForm[
  "Computation time under increasing delays : \n", {7.712000000000003, 
   10.672000000000011`, 19.04400000000001, 52.468}],
  Editable->False]], "Print",
 CellChangeTimes->{3.6940565429045887`*^9, 3.694147953285407*^9, 
  3.714821221961726*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Escp. 7 x 8", "Subsection",
 CellChangeTimes->{{3.7255920323979263`*^9, 3.725592036996545*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"g9", "=", 
   RowBox[{"Graph", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"107", "\[Rule]", "540"}], ",", 
       RowBox[{"107", "\[Rule]", "540"}], ",", 
       RowBox[{"107", "\[Rule]", "108"}], ",", 
       RowBox[{"540", "\[Rule]", "523"}], ",", 
       RowBox[{"540", "\[Rule]", "537"}], ",", 
       RowBox[{"108", "\[Rule]", "91"}], ",", 
       RowBox[{"108", "\[Rule]", "105"}], ",", 
       RowBox[{"523", "\[Rule]", "200"}], ",", 
       RowBox[{"523", "\[Rule]", "1064"}], ",", 
       RowBox[{"523", "\[Rule]", "92"}], ",", 
       RowBox[{"523", "\[Rule]", "92"}], ",", 
       RowBox[{"523", "\[Rule]", "956"}], ",", 
       RowBox[{"523", "\[Rule]", "956"}], ",", 
       RowBox[{"523", "\[Rule]", "524"}], ",", 
       RowBox[{"537", "\[Rule]", "214"}], ",", 
       RowBox[{"537", "\[Rule]", "1078"}], ",", 
       RowBox[{"537", "\[Rule]", "106"}], ",", 
       RowBox[{"537", "\[Rule]", "106"}], ",", 
       RowBox[{"537", "\[Rule]", "970"}], ",", 
       RowBox[{"537", "\[Rule]", "970"}], ",", 
       RowBox[{"537", "\[Rule]", "538"}], ",", 
       RowBox[{"91", "\[Rule]", "524"}], ",", 
       RowBox[{"91", "\[Rule]", "524"}], ",", 
       RowBox[{"91", "\[Rule]", "92"}], ",", 
       RowBox[{"105", "\[Rule]", "538"}], ",", 
       RowBox[{"105", "\[Rule]", "538"}], ",", 
       RowBox[{"105", "\[Rule]", "106"}], ",", 
       RowBox[{"200", "\[Rule]", "183"}], ",", 
       RowBox[{"200", "\[Rule]", "215"}], ",", 
       RowBox[{"200", "\[Rule]", "197"}], ",", 
       RowBox[{"1064", "\[Rule]", "1047"}], ",", 
       RowBox[{"1064", "\[Rule]", "1079"}], ",", 
       RowBox[{"1064", "\[Rule]", "1061"}], ",", 
       RowBox[{"92", "\[Rule]", "75"}], ",", 
       RowBox[{"92", "\[Rule]", "107"}], ",", 
       RowBox[{"92", "\[Rule]", "89"}], ",", 
       RowBox[{"956", "\[Rule]", "939"}], ",", 
       RowBox[{"956", "\[Rule]", "971"}], ",", 
       RowBox[{"956", "\[Rule]", "953"}], ",", 
       RowBox[{"524", "\[Rule]", "507"}], ",", 
       RowBox[{"524", "\[Rule]", "539"}], ",", 
       RowBox[{"524", "\[Rule]", "521"}], ",", 
       RowBox[{"214", "\[Rule]", "197"}], ",", 
       RowBox[{"214", "\[Rule]", "215"}], ",", 
       RowBox[{"214", "\[Rule]", "211"}], ",", 
       RowBox[{"1078", "\[Rule]", "1061"}], ",", 
       RowBox[{"1078", "\[Rule]", "1079"}], ",", 
       RowBox[{"1078", "\[Rule]", "1075"}], ",", 
       RowBox[{"106", "\[Rule]", "89"}], ",", 
       RowBox[{"106", "\[Rule]", "107"}], ",", 
       RowBox[{"106", "\[Rule]", "103"}], ",", 
       RowBox[{"970", "\[Rule]", "953"}], ",", 
       RowBox[{"970", "\[Rule]", "971"}], ",", 
       RowBox[{"970", "\[Rule]", "967"}], ",", 
       RowBox[{"538", "\[Rule]", "521"}], ",", 
       RowBox[{"538", "\[Rule]", "539"}], ",", 
       RowBox[{"538", "\[Rule]", "535"}], ",", 
       RowBox[{"183", "\[Rule]", "616"}], ",", 
       RowBox[{"183", "\[Rule]", "508"}], ",", 
       RowBox[{"183", "\[Rule]", "184"}], ",", 
       RowBox[{"215", "\[Rule]", "648"}], ",", 
       RowBox[{"215", "\[Rule]", "540"}], ",", 
       RowBox[{"215", "\[Rule]", "216"}], ",", 
       RowBox[{"197", "\[Rule]", "630"}], ",", 
       RowBox[{"197", "\[Rule]", "522"}], ",", 
       RowBox[{"197", "\[Rule]", "198"}], ",", 
       RowBox[{"1047", "\[Rule]", "616"}], ",", 
       RowBox[{"1047", "\[Rule]", "1480"}], ",", 
       RowBox[{"1047", "\[Rule]", "1480"}], ",", 
       RowBox[{"1047", "\[Rule]", "508"}], ",", 
       RowBox[{"1047", "\[Rule]", "1372"}], ",", 
       RowBox[{"1047", "\[Rule]", "1372"}], ",", 
       RowBox[{"1047", "\[Rule]", "1048"}], ",", 
       RowBox[{"1079", "\[Rule]", "648"}], ",", 
       RowBox[{"1079", "\[Rule]", "1512"}], ",", 
       RowBox[{"1079", "\[Rule]", "1512"}], ",", 
       RowBox[{"1079", "\[Rule]", "540"}], ",", 
       RowBox[{"1079", "\[Rule]", "1404"}], ",", 
       RowBox[{"1079", "\[Rule]", "1404"}], ",", 
       RowBox[{"1079", "\[Rule]", "1080"}], ",", 
       RowBox[{"1061", "\[Rule]", "630"}], ",", 
       RowBox[{"1061", "\[Rule]", "1494"}], ",", 
       RowBox[{"1061", "\[Rule]", "1494"}], ",", 
       RowBox[{"1061", "\[Rule]", "522"}], ",", 
       RowBox[{"1061", "\[Rule]", "1386"}], ",", 
       RowBox[{"1061", "\[Rule]", "1386"}], ",", 
       RowBox[{"1061", "\[Rule]", "1062"}], ",", 
       RowBox[{"75", "\[Rule]", "508"}], ",", 
       RowBox[{"75", "\[Rule]", "508"}], ",", 
       RowBox[{"75", "\[Rule]", "76"}], ",", 
       RowBox[{"89", "\[Rule]", "522"}], ",", 
       RowBox[{"89", "\[Rule]", "522"}], ",", 
       RowBox[{"89", "\[Rule]", "90"}], ",", 
       RowBox[{"939", "\[Rule]", "508"}], ",", 
       RowBox[{"939", "\[Rule]", "508"}], ",", 
       RowBox[{"939", "\[Rule]", "1372"}], ",", 
       RowBox[{"939", "\[Rule]", "940"}], ",", 
       RowBox[{"971", "\[Rule]", "540"}], ",", 
       RowBox[{"971", "\[Rule]", "540"}], ",", 
       RowBox[{"971", "\[Rule]", "1404"}], ",", 
       RowBox[{"971", "\[Rule]", "972"}], ",", 
       RowBox[{"953", "\[Rule]", "522"}], ",", 
       RowBox[{"953", "\[Rule]", "522"}], ",", 
       RowBox[{"953", "\[Rule]", "1386"}], ",", 
       RowBox[{"953", "\[Rule]", "954"}], ",", 
       RowBox[{"507", "\[Rule]", "184"}], ",", 
       RowBox[{"507", "\[Rule]", "1048"}], ",", 
       RowBox[{"507", "\[Rule]", "76"}], ",", 
       RowBox[{"507", "\[Rule]", "76"}], ",", 
       RowBox[{"507", "\[Rule]", "940"}], ",", 
       RowBox[{"507", "\[Rule]", "940"}], ",", 
       RowBox[{"507", "\[Rule]", "508"}], ",", 
       RowBox[{"539", "\[Rule]", "216"}], ",", 
       RowBox[{"539", "\[Rule]", "1080"}], ",", 
       RowBox[{"539", "\[Rule]", "108"}], ",", 
       RowBox[{"539", "\[Rule]", "108"}], ",", 
       RowBox[{"539", "\[Rule]", "972"}], ",", 
       RowBox[{"539", "\[Rule]", "972"}], ",", 
       RowBox[{"539", "\[Rule]", "540"}], ",", 
       RowBox[{"521", "\[Rule]", "198"}], ",", 
       RowBox[{"521", "\[Rule]", "1062"}], ",", 
       RowBox[{"521", "\[Rule]", "90"}], ",", 
       RowBox[{"521", "\[Rule]", "90"}], ",", 
       RowBox[{"521", "\[Rule]", "954"}], ",", 
       RowBox[{"521", "\[Rule]", "954"}], ",", 
       RowBox[{"521", "\[Rule]", "522"}], ",", 
       RowBox[{"211", "\[Rule]", "644"}], ",", 
       RowBox[{"211", "\[Rule]", "536"}], ",", 
       RowBox[{"211", "\[Rule]", "212"}], ",", 
       RowBox[{"1075", "\[Rule]", "644"}], ",", 
       RowBox[{"1075", "\[Rule]", "1508"}], ",", 
       RowBox[{"1075", "\[Rule]", "1508"}], ",", 
       RowBox[{"1075", "\[Rule]", "536"}], ",", 
       RowBox[{"1075", "\[Rule]", "1400"}], ",", 
       RowBox[{"1075", "\[Rule]", "1400"}], ",", 
       RowBox[{"1075", "\[Rule]", "1076"}], ",", 
       RowBox[{"103", "\[Rule]", "536"}], ",", 
       RowBox[{"103", "\[Rule]", "536"}], ",", 
       RowBox[{"103", "\[Rule]", "104"}], ",", 
       RowBox[{"967", "\[Rule]", "536"}], ",", 
       RowBox[{"967", "\[Rule]", "536"}], ",", 
       RowBox[{"967", "\[Rule]", "1400"}], ",", 
       RowBox[{"967", "\[Rule]", "968"}], ",", 
       RowBox[{"535", "\[Rule]", "212"}], ",", 
       RowBox[{"535", "\[Rule]", "1076"}], ",", 
       RowBox[{"535", "\[Rule]", "104"}], ",", 
       RowBox[{"535", "\[Rule]", "104"}], ",", 
       RowBox[{"535", "\[Rule]", "968"}], ",", 
       RowBox[{"535", "\[Rule]", "968"}], ",", 
       RowBox[{"535", "\[Rule]", "536"}], ",", 
       RowBox[{"616", "\[Rule]", "599"}], ",", 
       RowBox[{"616", "\[Rule]", "631"}], ",", 
       RowBox[{"616", "\[Rule]", "613"}], ",", 
       RowBox[{"508", "\[Rule]", "491"}], ",", 
       RowBox[{"508", "\[Rule]", "523"}], ",", 
       RowBox[{"508", "\[Rule]", "505"}], ",", 
       RowBox[{"184", "\[Rule]", "167"}], ",", 
       RowBox[{"184", "\[Rule]", "199"}], ",", 
       RowBox[{"184", "\[Rule]", "181"}], ",", 
       RowBox[{"648", "\[Rule]", "631"}], ",", 
       RowBox[{"648", "\[Rule]", "645"}], ",", 
       RowBox[{"216", "\[Rule]", "199"}], ",", 
       RowBox[{"216", "\[Rule]", "213"}], ",", 
       RowBox[{"630", "\[Rule]", "613"}], ",", 
       RowBox[{"630", "\[Rule]", "645"}], ",", 
       RowBox[{"630", "\[Rule]", "631"}], ",", 
       RowBox[{"630", "\[Rule]", "627"}], ",", 
       RowBox[{"522", "\[Rule]", "505"}], ",", 
       RowBox[{"522", "\[Rule]", "537"}], ",", 
       RowBox[{"522", "\[Rule]", "523"}], ",", 
       RowBox[{"522", "\[Rule]", "519"}], ",", 
       RowBox[{"198", "\[Rule]", "181"}], ",", 
       RowBox[{"198", "\[Rule]", "213"}], ",", 
       RowBox[{"198", "\[Rule]", "199"}], ",", 
       RowBox[{"198", "\[Rule]", "195"}], ",", 
       RowBox[{"1480", "\[Rule]", "1463"}], ",", 
       RowBox[{"1480", "\[Rule]", "1495"}], ",", 
       RowBox[{"1480", "\[Rule]", "1477"}], ",", 
       RowBox[{"1372", "\[Rule]", "1355"}], ",", 
       RowBox[{"1372", "\[Rule]", "1387"}], ",", 
       RowBox[{"1372", "\[Rule]", "1369"}], ",", 
       RowBox[{"1048", "\[Rule]", "1031"}], ",", 
       RowBox[{"1048", "\[Rule]", "1063"}], ",", 
       RowBox[{"1048", "\[Rule]", "1045"}], ",", 
       RowBox[{"1512", "\[Rule]", "1495"}], ",", 
       RowBox[{"1512", "\[Rule]", "1509"}], ",", 
       RowBox[{"1404", "\[Rule]", "1387"}], ",", 
       RowBox[{"1404", "\[Rule]", "1401"}], ",", 
       RowBox[{"1080", "\[Rule]", "1063"}], ",", 
       RowBox[{"1080", "\[Rule]", "1077"}], ",", 
       RowBox[{"1494", "\[Rule]", "1477"}], ",", 
       RowBox[{"1494", "\[Rule]", "1509"}], ",", 
       RowBox[{"1494", "\[Rule]", "1495"}], ",", 
       RowBox[{"1494", "\[Rule]", "1491"}], ",", 
       RowBox[{"1386", "\[Rule]", "1369"}], ",", 
       RowBox[{"1386", "\[Rule]", "1401"}], ",", 
       RowBox[{"1386", "\[Rule]", "1387"}], ",", 
       RowBox[{"1386", "\[Rule]", "1383"}], ",", 
       RowBox[{"1062", "\[Rule]", "1045"}], ",", 
       RowBox[{"1062", "\[Rule]", "1077"}], ",", 
       RowBox[{"1062", "\[Rule]", "1063"}], ",", 
       RowBox[{"1062", "\[Rule]", "1059"}], ",", 
       RowBox[{"76", "\[Rule]", "59"}], ",", 
       RowBox[{"76", "\[Rule]", "91"}], ",", 
       RowBox[{"76", "\[Rule]", "73"}], ",", 
       RowBox[{"90", "\[Rule]", "73"}], ",", 
       RowBox[{"90", "\[Rule]", "105"}], ",", 
       RowBox[{"90", "\[Rule]", "91"}], ",", 
       RowBox[{"90", "\[Rule]", "87"}], ",", 
       RowBox[{"940", "\[Rule]", "923"}], ",", 
       RowBox[{"940", "\[Rule]", "955"}], ",", 
       RowBox[{"940", "\[Rule]", "937"}], ",", 
       RowBox[{"972", "\[Rule]", "955"}], ",", 
       RowBox[{"972", "\[Rule]", "969"}], ",", 
       RowBox[{"954", "\[Rule]", "937"}], ",", 
       RowBox[{"954", "\[Rule]", "969"}], ",", 
       RowBox[{"954", "\[Rule]", "955"}], ",", 
       RowBox[{"954", "\[Rule]", "951"}], ",", 
       RowBox[{"644", "\[Rule]", "627"}], ",", 
       RowBox[{"644", "\[Rule]", "645"}], ",", 
       RowBox[{"644", "\[Rule]", "641"}], ",", 
       RowBox[{"536", "\[Rule]", "519"}], ",", 
       RowBox[{"536", "\[Rule]", "537"}], ",", 
       RowBox[{"536", "\[Rule]", "533"}], ",", 
       RowBox[{"212", "\[Rule]", "195"}], ",", 
       RowBox[{"212", "\[Rule]", "213"}], ",", 
       RowBox[{"212", "\[Rule]", "209"}], ",", 
       RowBox[{"1508", "\[Rule]", "1491"}], ",", 
       RowBox[{"1508", "\[Rule]", "1509"}], ",", 
       RowBox[{"1508", "\[Rule]", "1505"}], ",", 
       RowBox[{"1400", "\[Rule]", "1383"}], ",", 
       RowBox[{"1400", "\[Rule]", "1401"}], ",", 
       RowBox[{"1400", "\[Rule]", "1397"}], ",", 
       RowBox[{"1076", "\[Rule]", "1059"}], ",", 
       RowBox[{"1076", "\[Rule]", "1077"}], ",", 
       RowBox[{"1076", "\[Rule]", "1073"}], ",", 
       RowBox[{"104", "\[Rule]", "87"}], ",", 
       RowBox[{"104", "\[Rule]", "105"}], ",", 
       RowBox[{"104", "\[Rule]", "101"}], ",", 
       RowBox[{"968", "\[Rule]", "951"}], ",", 
       RowBox[{"968", "\[Rule]", "969"}], ",", 
       RowBox[{"968", "\[Rule]", "965"}], ",", 
       RowBox[{"599", "\[Rule]", "276"}], ",", 
       RowBox[{"599", "\[Rule]", "276"}], ",", 
       RowBox[{"599", "\[Rule]", "1140"}], ",", 
       RowBox[{"599", "\[Rule]", "1140"}], ",", 
       RowBox[{"599", "\[Rule]", "168"}], ",", 
       RowBox[{"599", "\[Rule]", "1032"}], ",", 
       RowBox[{"599", "\[Rule]", "600"}], ",", 
       RowBox[{"631", "\[Rule]", "308"}], ",", 
       RowBox[{"631", "\[Rule]", "308"}], ",", 
       RowBox[{"631", "\[Rule]", "1172"}], ",", 
       RowBox[{"631", "\[Rule]", "1172"}], ",", 
       RowBox[{"631", "\[Rule]", "200"}], ",", 
       RowBox[{"631", "\[Rule]", "1064"}], ",", 
       RowBox[{"631", "\[Rule]", "632"}], ",", 
       RowBox[{"613", "\[Rule]", "290"}], ",", 
       RowBox[{"613", "\[Rule]", "290"}], ",", 
       RowBox[{"613", "\[Rule]", "1154"}], ",", 
       RowBox[{"613", "\[Rule]", "1154"}], ",", 
       RowBox[{"613", "\[Rule]", "182"}], ",", 
       RowBox[{"613", "\[Rule]", "1046"}], ",", 
       RowBox[{"613", "\[Rule]", "614"}], ",", 
       RowBox[{"491", "\[Rule]", "168"}], ",", 
       RowBox[{"491", "\[Rule]", "1032"}], ",", 
       RowBox[{"491", "\[Rule]", "60"}], ",", 
       RowBox[{"491", "\[Rule]", "60"}], ",", 
       RowBox[{"491", "\[Rule]", "924"}], ",", 
       RowBox[{"491", "\[Rule]", "924"}], ",", 
       RowBox[{"491", "\[Rule]", "492"}], ",", 
       RowBox[{"505", "\[Rule]", "182"}], ",", 
       RowBox[{"505", "\[Rule]", "1046"}], ",", 
       RowBox[{"505", "\[Rule]", "74"}], ",", 
       RowBox[{"505", "\[Rule]", "74"}], ",", 
       RowBox[{"505", "\[Rule]", "938"}], ",", 
       RowBox[{"505", "\[Rule]", "938"}], ",", 
       RowBox[{"505", "\[Rule]", "506"}], ",", 
       RowBox[{"167", "\[Rule]", "600"}], ",", 
       RowBox[{"167", "\[Rule]", "492"}], ",", 
       RowBox[{"167", "\[Rule]", "168"}], ",", 
       RowBox[{"199", "\[Rule]", "632"}], ",", 
       RowBox[{"199", "\[Rule]", "524"}], ",", 
       RowBox[{"199", "\[Rule]", "200"}], ",", 
       RowBox[{"181", "\[Rule]", "614"}], ",", 
       RowBox[{"181", "\[Rule]", "506"}], ",", 
       RowBox[{"181", "\[Rule]", "182"}], ",", 
       RowBox[{"645", "\[Rule]", "322"}], ",", 
       RowBox[{"645", "\[Rule]", "322"}], ",", 
       RowBox[{"645", "\[Rule]", "1186"}], ",", 
       RowBox[{"645", "\[Rule]", "1186"}], ",", 
       RowBox[{"645", "\[Rule]", "214"}], ",", 
       RowBox[{"645", "\[Rule]", "1078"}], ",", 
       RowBox[{"645", "\[Rule]", "646"}], ",", 
       RowBox[{"213", "\[Rule]", "646"}], ",", 
       RowBox[{"213", "\[Rule]", "538"}], ",", 
       RowBox[{"213", "\[Rule]", "214"}], ",", 
       RowBox[{"627", "\[Rule]", "304"}], ",", 
       RowBox[{"627", "\[Rule]", "304"}], ",", 
       RowBox[{"627", "\[Rule]", "1168"}], ",", 
       RowBox[{"627", "\[Rule]", "1168"}], ",", 
       RowBox[{"627", "\[Rule]", "196"}], ",", 
       RowBox[{"627", "\[Rule]", "1060"}], ",", 
       RowBox[{"627", "\[Rule]", "628"}], ",", 
       RowBox[{"519", "\[Rule]", "196"}], ",", 
       RowBox[{"519", "\[Rule]", "1060"}], ",", 
       RowBox[{"519", "\[Rule]", "88"}], ",", 
       RowBox[{"519", "\[Rule]", "88"}], ",", 
       RowBox[{"519", "\[Rule]", "952"}], ",", 
       RowBox[{"519", "\[Rule]", "952"}], ",", 
       RowBox[{"519", "\[Rule]", "520"}], ",", 
       RowBox[{"195", "\[Rule]", "628"}], ",", 
       RowBox[{"195", "\[Rule]", "520"}], ",", 
       RowBox[{"195", "\[Rule]", "196"}], ",", 
       RowBox[{"1463", "\[Rule]", "1140"}], ",", 
       RowBox[{"1463", "\[Rule]", "1140"}], ",", 
       RowBox[{"1463", "\[Rule]", "2004"}], ",", 
       RowBox[{"1463", "\[Rule]", "2004"}], ",", 
       RowBox[{"1463", "\[Rule]", "1032"}], ",", 
       RowBox[{"1463", "\[Rule]", "1032"}], ",", 
       RowBox[{"1463", "\[Rule]", "1896"}], ",", 
       RowBox[{"1463", "\[Rule]", "1896"}], ",", 
       RowBox[{"1463", "\[Rule]", "1464"}], ",", 
       RowBox[{"1495", "\[Rule]", "1172"}], ",", 
       RowBox[{"1495", "\[Rule]", "1172"}], ",", 
       RowBox[{"1495", "\[Rule]", "2036"}], ",", 
       RowBox[{"1495", "\[Rule]", "2036"}], ",", 
       RowBox[{"1495", "\[Rule]", "1064"}], ",", 
       RowBox[{"1495", "\[Rule]", "1064"}], ",", 
       RowBox[{"1495", "\[Rule]", "1928"}], ",", 
       RowBox[{"1495", "\[Rule]", "1928"}], ",", 
       RowBox[{"1495", "\[Rule]", "1496"}], ",", 
       RowBox[{"1477", "\[Rule]", "1154"}], ",", 
       RowBox[{"1477", "\[Rule]", "1154"}], ",", 
       RowBox[{"1477", "\[Rule]", "2018"}], ",", 
       RowBox[{"1477", "\[Rule]", "2018"}], ",", 
       RowBox[{"1477", "\[Rule]", "1046"}], ",", 
       RowBox[{"1477", "\[Rule]", "1046"}], ",", 
       RowBox[{"1477", "\[Rule]", "1910"}], ",", 
       RowBox[{"1477", "\[Rule]", "1910"}], ",", 
       RowBox[{"1477", "\[Rule]", "1478"}], ",", 
       RowBox[{"1355", "\[Rule]", "1032"}], ",", 
       RowBox[{"1355", "\[Rule]", "1032"}], ",", 
       RowBox[{"1355", "\[Rule]", "1896"}], ",", 
       RowBox[{"1355", "\[Rule]", "1896"}], ",", 
       RowBox[{"1355", "\[Rule]", "924"}], ",", 
       RowBox[{"1355", "\[Rule]", "1788"}], ",", 
       RowBox[{"1355", "\[Rule]", "1356"}], ",", 
       RowBox[{"1387", "\[Rule]", "1064"}], ",", 
       RowBox[{"1387", "\[Rule]", "1064"}], ",", 
       RowBox[{"1387", "\[Rule]", "1928"}], ",", 
       RowBox[{"1387", "\[Rule]", "1928"}], ",", 
       RowBox[{"1387", "\[Rule]", "956"}], ",", 
       RowBox[{"1387", "\[Rule]", "1820"}], ",", 
       RowBox[{"1387", "\[Rule]", "1388"}], ",", 
       RowBox[{"1369", "\[Rule]", "1046"}], ",", 
       RowBox[{"1369", "\[Rule]", "1046"}], ",", 
       RowBox[{"1369", "\[Rule]", "1910"}], ",", 
       RowBox[{"1369", "\[Rule]", "1910"}], ",", 
       RowBox[{"1369", "\[Rule]", "938"}], ",", 
       RowBox[{"1369", "\[Rule]", "1802"}], ",", 
       RowBox[{"1369", "\[Rule]", "1370"}], ",", 
       RowBox[{"1031", "\[Rule]", "600"}], ",", 
       RowBox[{"1031", "\[Rule]", "1464"}], ",", 
       RowBox[{"1031", "\[Rule]", "1464"}], ",", 
       RowBox[{"1031", "\[Rule]", "492"}], ",", 
       RowBox[{"1031", "\[Rule]", "1356"}], ",", 
       RowBox[{"1031", "\[Rule]", "1356"}], ",", 
       RowBox[{"1031", "\[Rule]", "1032"}], ",", 
       RowBox[{"1063", "\[Rule]", "632"}], ",", 
       RowBox[{"1063", "\[Rule]", "1496"}], ",", 
       RowBox[{"1063", "\[Rule]", "1496"}], ",", 
       RowBox[{"1063", "\[Rule]", "524"}], ",", 
       RowBox[{"1063", "\[Rule]", "1388"}], ",", 
       RowBox[{"1063", "\[Rule]", "1388"}], ",", 
       RowBox[{"1063", "\[Rule]", "1064"}], ",", 
       RowBox[{"1045", "\[Rule]", "614"}], ",", 
       RowBox[{"1045", "\[Rule]", "1478"}], ",", 
       RowBox[{"1045", "\[Rule]", "1478"}], ",", 
       RowBox[{"1045", "\[Rule]", "506"}], ",", 
       RowBox[{"1045", "\[Rule]", "1370"}], ",", 
       RowBox[{"1045", "\[Rule]", "1370"}], ",", 
       RowBox[{"1045", "\[Rule]", "1046"}], ",", 
       RowBox[{"1509", "\[Rule]", "1186"}], ",", 
       RowBox[{"1509", "\[Rule]", "1186"}], ",", 
       RowBox[{"1509", "\[Rule]", "2050"}], ",", 
       RowBox[{"1509", "\[Rule]", "2050"}], ",", 
       RowBox[{"1509", "\[Rule]", "1078"}], ",", 
       RowBox[{"1509", "\[Rule]", "1078"}], ",", 
       RowBox[{"1509", "\[Rule]", "1942"}], ",", 
       RowBox[{"1509", "\[Rule]", "1942"}], ",", 
       RowBox[{"1509", "\[Rule]", "1510"}], ",", 
       RowBox[{"1401", "\[Rule]", "1078"}], ",", 
       RowBox[{"1401", "\[Rule]", "1078"}], ",", 
       RowBox[{"1401", "\[Rule]", "1942"}], ",", 
       RowBox[{"1401", "\[Rule]", "1942"}], ",", 
       RowBox[{"1401", "\[Rule]", "970"}], ",", 
       RowBox[{"1401", "\[Rule]", "1834"}], ",", 
       RowBox[{"1401", "\[Rule]", "1402"}], ",", 
       RowBox[{"1077", "\[Rule]", "646"}], ",", 
       RowBox[{"1077", "\[Rule]", "1510"}], ",", 
       RowBox[{"1077", "\[Rule]", "1510"}], ",", 
       RowBox[{"1077", "\[Rule]", "538"}], ",", 
       RowBox[{"1077", "\[Rule]", "1402"}], ",", 
       RowBox[{"1077", "\[Rule]", "1402"}], ",", 
       RowBox[{"1077", "\[Rule]", "1078"}], ",", 
       RowBox[{"1491", "\[Rule]", "1168"}], ",", 
       RowBox[{"1491", "\[Rule]", "1168"}], ",", 
       RowBox[{"1491", "\[Rule]", "2032"}], ",", 
       RowBox[{"1491", "\[Rule]", "2032"}], ",", 
       RowBox[{"1491", "\[Rule]", "1060"}], ",", 
       RowBox[{"1491", "\[Rule]", "1060"}], ",", 
       RowBox[{"1491", "\[Rule]", "1924"}], ",", 
       RowBox[{"1491", "\[Rule]", "1924"}], ",", 
       RowBox[{"1491", "\[Rule]", "1492"}], ",", 
       RowBox[{"1383", "\[Rule]", "1060"}], ",", 
       RowBox[{"1383", "\[Rule]", "1060"}], ",", 
       RowBox[{"1383", "\[Rule]", "1924"}], ",", 
       RowBox[{"1383", "\[Rule]", "1924"}], ",", 
       RowBox[{"1383", "\[Rule]", "952"}], ",", 
       RowBox[{"1383", "\[Rule]", "1816"}], ",", 
       RowBox[{"1383", "\[Rule]", "1384"}], ",", 
       RowBox[{"1059", "\[Rule]", "628"}], ",", 
       RowBox[{"1059", "\[Rule]", "1492"}], ",", 
       RowBox[{"1059", "\[Rule]", "1492"}], ",", 
       RowBox[{"1059", "\[Rule]", "520"}], ",", 
       RowBox[{"1059", "\[Rule]", "1384"}], ",", 
       RowBox[{"1059", "\[Rule]", "1384"}], ",", 
       RowBox[{"1059", "\[Rule]", "1060"}], ",", 
       RowBox[{"59", "\[Rule]", "492"}], ",", 
       RowBox[{"59", "\[Rule]", "492"}], ",", 
       RowBox[{"59", "\[Rule]", "60"}], ",", 
       RowBox[{"73", "\[Rule]", "506"}], ",", 
       RowBox[{"73", "\[Rule]", "506"}], ",", 
       RowBox[{"73", "\[Rule]", "74"}], ",", 
       RowBox[{"87", "\[Rule]", "520"}], ",", 
       RowBox[{"87", "\[Rule]", "520"}], ",", 
       RowBox[{"87", "\[Rule]", "88"}], ",", 
       RowBox[{"923", "\[Rule]", "492"}], ",", 
       RowBox[{"923", "\[Rule]", "492"}], ",", 
       RowBox[{"923", "\[Rule]", "1356"}], ",", 
       RowBox[{"923", "\[Rule]", "924"}], ",", 
       RowBox[{"955", "\[Rule]", "524"}], ",", 
       RowBox[{"955", "\[Rule]", "524"}], ",", 
       RowBox[{"955", "\[Rule]", "1388"}], ",", 
       RowBox[{"955", "\[Rule]", "956"}], ",", 
       RowBox[{"937", "\[Rule]", "506"}], ",", 
       RowBox[{"937", "\[Rule]", "506"}], ",", 
       RowBox[{"937", "\[Rule]", "1370"}], ",", 
       RowBox[{"937", "\[Rule]", "938"}], ",", 
       RowBox[{"969", "\[Rule]", "538"}], ",", 
       RowBox[{"969", "\[Rule]", "538"}], ",", 
       RowBox[{"969", "\[Rule]", "1402"}], ",", 
       RowBox[{"969", "\[Rule]", "970"}], ",", 
       RowBox[{"951", "\[Rule]", "520"}], ",", 
       RowBox[{"951", "\[Rule]", "520"}], ",", 
       RowBox[{"951", "\[Rule]", "1384"}], ",", 
       RowBox[{"951", "\[Rule]", "952"}], ",", 
       RowBox[{"641", "\[Rule]", "318"}], ",", 
       RowBox[{"641", "\[Rule]", "318"}], ",", 
       RowBox[{"641", "\[Rule]", "1182"}], ",", 
       RowBox[{"641", "\[Rule]", "1182"}], ",", 
       RowBox[{"641", "\[Rule]", "210"}], ",", 
       RowBox[{"641", "\[Rule]", "1074"}], ",", 
       RowBox[{"641", "\[Rule]", "642"}], ",", 
       RowBox[{"533", "\[Rule]", "210"}], ",", 
       RowBox[{"533", "\[Rule]", "1074"}], ",", 
       RowBox[{"533", "\[Rule]", "102"}], ",", 
       RowBox[{"533", "\[Rule]", "102"}], ",", 
       RowBox[{"533", "\[Rule]", "966"}], ",", 
       RowBox[{"533", "\[Rule]", "966"}], ",", 
       RowBox[{"533", "\[Rule]", "534"}], ",", 
       RowBox[{"209", "\[Rule]", "642"}], ",", 
       RowBox[{"209", "\[Rule]", "534"}], ",", 
       RowBox[{"209", "\[Rule]", "210"}], ",", 
       RowBox[{"1505", "\[Rule]", "1182"}], ",", 
       RowBox[{"1505", "\[Rule]", "1182"}], ",", 
       RowBox[{"1505", "\[Rule]", "2046"}], ",", 
       RowBox[{"1505", "\[Rule]", "2046"}], ",", 
       RowBox[{"1505", "\[Rule]", "1074"}], ",", 
       RowBox[{"1505", "\[Rule]", "1074"}], ",", 
       RowBox[{"1505", "\[Rule]", "1938"}], ",", 
       RowBox[{"1505", "\[Rule]", "1938"}], ",", 
       RowBox[{"1505", "\[Rule]", "1506"}], ",", 
       RowBox[{"1397", "\[Rule]", "1074"}], ",", 
       RowBox[{"1397", "\[Rule]", "1074"}], ",", 
       RowBox[{"1397", "\[Rule]", "1938"}], ",", 
       RowBox[{"1397", "\[Rule]", "1938"}], ",", 
       RowBox[{"1397", "\[Rule]", "966"}], ",", 
       RowBox[{"1397", "\[Rule]", "1830"}], ",", 
       RowBox[{"1397", "\[Rule]", "1398"}], ",", 
       RowBox[{"1073", "\[Rule]", "642"}], ",", 
       RowBox[{"1073", "\[Rule]", "1506"}], ",", 
       RowBox[{"1073", "\[Rule]", "1506"}], ",", 
       RowBox[{"1073", "\[Rule]", "534"}], ",", 
       RowBox[{"1073", "\[Rule]", "1398"}], ",", 
       RowBox[{"1073", "\[Rule]", "1398"}], ",", 
       RowBox[{"1073", "\[Rule]", "1074"}], ",", 
       RowBox[{"101", "\[Rule]", "534"}], ",", 
       RowBox[{"101", "\[Rule]", "534"}], ",", 
       RowBox[{"101", "\[Rule]", "102"}], ",", 
       RowBox[{"965", "\[Rule]", "534"}], ",", 
       RowBox[{"965", "\[Rule]", "534"}], ",", 
       RowBox[{"965", "\[Rule]", "1398"}], ",", 
       RowBox[{"965", "\[Rule]", "966"}], ",", 
       RowBox[{"276", "\[Rule]", "261"}], ",", 
       RowBox[{"276", "\[Rule]", "291"}], ",", 
       RowBox[{"276", "\[Rule]", "273"}], ",", 
       RowBox[{"1140", "\[Rule]", "1125"}], ",", 
       RowBox[{"1140", "\[Rule]", "1155"}], ",", 
       RowBox[{"1140", "\[Rule]", "1137"}], ",", 
       RowBox[{"168", "\[Rule]", "153"}], ",", 
       RowBox[{"168", "\[Rule]", "183"}], ",", 
       RowBox[{"168", "\[Rule]", "165"}], ",", 
       RowBox[{"1032", "\[Rule]", "1017"}], ",", 
       RowBox[{"1032", "\[Rule]", "1047"}], ",", 
       RowBox[{"1032", "\[Rule]", "1029"}], ",", 
       RowBox[{"600", "\[Rule]", "585"}], ",", 
       RowBox[{"600", "\[Rule]", "615"}], ",", 
       RowBox[{"600", "\[Rule]", "597"}], ",", 
       RowBox[{"308", "\[Rule]", "291"}], ",", 
       RowBox[{"308", "\[Rule]", "323"}], ",", 
       RowBox[{"308", "\[Rule]", "305"}], ",", 
       RowBox[{"1172", "\[Rule]", "1155"}], ",", 
       RowBox[{"1172", "\[Rule]", "1187"}], ",", 
       RowBox[{"1172", "\[Rule]", "1169"}], ",", 
       RowBox[{"632", "\[Rule]", "615"}], ",", 
       RowBox[{"632", "\[Rule]", "647"}], ",", 
       RowBox[{"632", "\[Rule]", "629"}], ",", 
       RowBox[{"290", "\[Rule]", "273"}], ",", 
       RowBox[{"290", "\[Rule]", "305"}], ",", 
       RowBox[{"290", "\[Rule]", "291"}], ",", 
       RowBox[{"290", "\[Rule]", "287"}], ",", 
       RowBox[{"1154", "\[Rule]", "1137"}], ",", 
       RowBox[{"1154", "\[Rule]", "1169"}], ",", 
       RowBox[{"1154", "\[Rule]", "1155"}], ",", 
       RowBox[{"1154", "\[Rule]", "1151"}], ",", 
       RowBox[{"182", "\[Rule]", "165"}], ",", 
       RowBox[{"182", "\[Rule]", "197"}], ",", 
       RowBox[{"182", "\[Rule]", "183"}], ",", 
       RowBox[{"182", "\[Rule]", "179"}], ",", 
       RowBox[{"1046", "\[Rule]", "1029"}], ",", 
       RowBox[{"1046", "\[Rule]", "1061"}], ",", 
       RowBox[{"1046", "\[Rule]", "1047"}], ",", 
       RowBox[{"1046", "\[Rule]", "1043"}], ",", 
       RowBox[{"614", "\[Rule]", "597"}], ",", 
       RowBox[{"614", "\[Rule]", "629"}], ",", 
       RowBox[{"614", "\[Rule]", "615"}], ",", 
       RowBox[{"614", "\[Rule]", "611"}], ",", 
       RowBox[{"60", "\[Rule]", "45"}], ",", 
       RowBox[{"60", "\[Rule]", "75"}], ",", 
       RowBox[{"60", "\[Rule]", "57"}], ",", 
       RowBox[{"924", "\[Rule]", "909"}], ",", 
       RowBox[{"924", "\[Rule]", "939"}], ",", 
       RowBox[{"924", "\[Rule]", "921"}], ",", 
       RowBox[{"492", "\[Rule]", "477"}], ",", 
       RowBox[{"492", "\[Rule]", "507"}], ",", 
       RowBox[{"492", "\[Rule]", "489"}], ",", 
       RowBox[{"74", "\[Rule]", "57"}], ",", 
       RowBox[{"74", "\[Rule]", "89"}], ",", 
       RowBox[{"74", "\[Rule]", "75"}], ",", 
       RowBox[{"74", "\[Rule]", "71"}], ",", 
       RowBox[{"938", "\[Rule]", "921"}], ",", 
       RowBox[{"938", "\[Rule]", "953"}], ",", 
       RowBox[{"938", "\[Rule]", "939"}], ",", 
       RowBox[{"938", "\[Rule]", "935"}], ",", 
       RowBox[{"506", "\[Rule]", "489"}], ",", 
       RowBox[{"506", "\[Rule]", "521"}], ",", 
       RowBox[{"506", "\[Rule]", "507"}], ",", 
       RowBox[{"506", "\[Rule]", "503"}], ",", 
       RowBox[{"322", "\[Rule]", "305"}], ",", 
       RowBox[{"322", "\[Rule]", "323"}], ",", 
       RowBox[{"322", "\[Rule]", "319"}], ",", 
       RowBox[{"1186", "\[Rule]", "1169"}], ",", 
       RowBox[{"1186", "\[Rule]", "1187"}], ",", 
       RowBox[{"1186", "\[Rule]", "1183"}], ",", 
       RowBox[{"646", "\[Rule]", "629"}], ",", 
       RowBox[{"646", "\[Rule]", "647"}], ",", 
       RowBox[{"646", "\[Rule]", "643"}], ",", 
       RowBox[{"304", "\[Rule]", "287"}], ",", 
       RowBox[{"304", "\[Rule]", "319"}], ",", 
       RowBox[{"304", "\[Rule]", "305"}], ",", 
       RowBox[{"304", "\[Rule]", "301"}], ",", 
       RowBox[{"1168", "\[Rule]", "1151"}], ",", 
       RowBox[{"1168", "\[Rule]", "1183"}], ",", 
       RowBox[{"1168", "\[Rule]", "1169"}], ",", 
       RowBox[{"1168", "\[Rule]", "1165"}], ",", 
       RowBox[{"196", "\[Rule]", "179"}], ",", 
       RowBox[{"196", "\[Rule]", "211"}], ",", 
       RowBox[{"196", "\[Rule]", "197"}], ",", 
       RowBox[{"196", "\[Rule]", "193"}], ",", 
       RowBox[{"1060", "\[Rule]", "1043"}], ",", 
       RowBox[{"1060", "\[Rule]", "1075"}], ",", 
       RowBox[{"1060", "\[Rule]", "1061"}], ",", 
       RowBox[{"1060", "\[Rule]", "1057"}], ",", 
       RowBox[{"628", "\[Rule]", "611"}], ",", 
       RowBox[{"628", "\[Rule]", "643"}], ",", 
       RowBox[{"628", "\[Rule]", "629"}], ",", 
       RowBox[{"628", "\[Rule]", "625"}], ",", 
       RowBox[{"88", "\[Rule]", "71"}], ",", 
       RowBox[{"88", "\[Rule]", "103"}], ",", 
       RowBox[{"88", "\[Rule]", "89"}], ",", 
       RowBox[{"88", "\[Rule]", "85"}], ",", 
       RowBox[{"952", "\[Rule]", "935"}], ",", 
       RowBox[{"952", "\[Rule]", "967"}], ",", 
       RowBox[{"952", "\[Rule]", "953"}], ",", 
       RowBox[{"952", "\[Rule]", "949"}], ",", 
       RowBox[{"520", "\[Rule]", "503"}], ",", 
       RowBox[{"520", "\[Rule]", "535"}], ",", 
       RowBox[{"520", "\[Rule]", "521"}], ",", 
       RowBox[{"520", "\[Rule]", "517"}], ",", 
       RowBox[{"2004", "\[Rule]", "1989"}], ",", 
       RowBox[{"2004", "\[Rule]", "2019"}], ",", 
       RowBox[{"2004", "\[Rule]", "2001"}], ",", 
       RowBox[{"1896", "\[Rule]", "1881"}], ",", 
       RowBox[{"1896", "\[Rule]", "1911"}], ",", 
       RowBox[{"1896", "\[Rule]", "1893"}], ",", 
       RowBox[{"1464", "\[Rule]", "1449"}], ",", 
       RowBox[{"1464", "\[Rule]", "1479"}], ",", 
       RowBox[{"1464", "\[Rule]", "1461"}], ",", 
       RowBox[{"2036", "\[Rule]", "2019"}], ",", 
       RowBox[{"2036", "\[Rule]", "2051"}], ",", 
       RowBox[{"2036", "\[Rule]", "2033"}], ",", 
       RowBox[{"1928", "\[Rule]", "1911"}], ",", 
       RowBox[{"1928", "\[Rule]", "1943"}], ",", 
       RowBox[{"1928", "\[Rule]", "1925"}], ",", 
       RowBox[{"1496", "\[Rule]", "1479"}], ",", 
       RowBox[{"1496", "\[Rule]", "1511"}], ",", 
       RowBox[{"1496", "\[Rule]", "1493"}], ",", 
       RowBox[{"2018", "\[Rule]", "2001"}], ",", 
       RowBox[{"2018", "\[Rule]", "2033"}], ",", 
       RowBox[{"2018", "\[Rule]", "2019"}], ",", 
       RowBox[{"2018", "\[Rule]", "2015"}], ",", 
       RowBox[{"1910", "\[Rule]", "1893"}], ",", 
       RowBox[{"1910", "\[Rule]", "1925"}], ",", 
       RowBox[{"1910", "\[Rule]", "1911"}], ",", 
       RowBox[{"1910", "\[Rule]", "1907"}], ",", 
       RowBox[{"1478", "\[Rule]", "1461"}], ",", 
       RowBox[{"1478", "\[Rule]", "1493"}], ",", 
       RowBox[{"1478", "\[Rule]", "1479"}], ",", 
       RowBox[{"1478", "\[Rule]", "1475"}], ",", 
       RowBox[{"1788", "\[Rule]", "1773"}], ",", 
       RowBox[{"1788", "\[Rule]", "1803"}], ",", 
       RowBox[{"1788", "\[Rule]", "1785"}], ",", 
       RowBox[{"1356", "\[Rule]", "1341"}], ",", 
       RowBox[{"1356", "\[Rule]", "1371"}], ",", 
       RowBox[{"1356", "\[Rule]", "1353"}], ",", 
       RowBox[{"1820", "\[Rule]", "1803"}], ",", 
       RowBox[{"1820", "\[Rule]", "1835"}], ",", 
       RowBox[{"1820", "\[Rule]", "1817"}], ",", 
       RowBox[{"1388", "\[Rule]", "1371"}], ",", 
       RowBox[{"1388", "\[Rule]", "1403"}], ",", 
       RowBox[{"1388", "\[Rule]", "1385"}], ",", 
       RowBox[{"1802", "\[Rule]", "1785"}], ",", 
       RowBox[{"1802", "\[Rule]", "1817"}], ",", 
       RowBox[{"1802", "\[Rule]", "1803"}], ",", 
       RowBox[{"1802", "\[Rule]", "1799"}], ",", 
       RowBox[{"1370", "\[Rule]", "1353"}], ",", 
       RowBox[{"1370", "\[Rule]", "1385"}], ",", 
       RowBox[{"1370", "\[Rule]", "1371"}], ",", 
       RowBox[{"1370", "\[Rule]", "1367"}], ",", 
       RowBox[{"2050", "\[Rule]", "2033"}], ",", 
       RowBox[{"2050", "\[Rule]", "2051"}], ",", 
       RowBox[{"2050", "\[Rule]", "2047"}], ",", 
       RowBox[{"1942", "\[Rule]", "1925"}], ",", 
       RowBox[{"1942", "\[Rule]", "1943"}], ",", 
       RowBox[{"1942", "\[Rule]", "1939"}], ",", 
       RowBox[{"1510", "\[Rule]", "1493"}], ",", 
       RowBox[{"1510", "\[Rule]", "1511"}], ",", 
       RowBox[{"1510", "\[Rule]", "1507"}], ",", 
       RowBox[{"1834", "\[Rule]", "1817"}], ",", 
       RowBox[{"1834", "\[Rule]", "1835"}], ",", 
       RowBox[{"1834", "\[Rule]", "1831"}], ",", 
       RowBox[{"1402", "\[Rule]", "1385"}], ",", 
       RowBox[{"1402", "\[Rule]", "1403"}], ",", 
       RowBox[{"1402", "\[Rule]", "1399"}], ",", 
       RowBox[{"2032", "\[Rule]", "2015"}], ",", 
       RowBox[{"2032", "\[Rule]", "2047"}], ",", 
       RowBox[{"2032", "\[Rule]", "2033"}], ",", 
       RowBox[{"2032", "\[Rule]", "2029"}], ",", 
       RowBox[{"1924", "\[Rule]", "1907"}], ",", 
       RowBox[{"1924", "\[Rule]", "1939"}], ",", 
       RowBox[{"1924", "\[Rule]", "1925"}], ",", 
       RowBox[{"1924", "\[Rule]", "1921"}], ",", 
       RowBox[{"1492", "\[Rule]", "1475"}], ",", 
       RowBox[{"1492", "\[Rule]", "1507"}], ",", 
       RowBox[{"1492", "\[Rule]", "1493"}], ",", 
       RowBox[{"1492", "\[Rule]", "1489"}], ",", 
       RowBox[{"1816", "\[Rule]", "1799"}], ",", 
       RowBox[{"1816", "\[Rule]", "1831"}], ",", 
       RowBox[{"1816", "\[Rule]", "1817"}], ",", 
       RowBox[{"1816", "\[Rule]", "1813"}], ",", 
       RowBox[{"1384", "\[Rule]", "1367"}], ",", 
       RowBox[{"1384", "\[Rule]", "1399"}], ",", 
       RowBox[{"1384", "\[Rule]", "1385"}], ",", 
       RowBox[{"1384", "\[Rule]", "1381"}], ",", 
       RowBox[{"318", "\[Rule]", "301"}], ",", 
       RowBox[{"318", "\[Rule]", "319"}], ",", 
       RowBox[{"318", "\[Rule]", "315"}], ",", 
       RowBox[{"1182", "\[Rule]", "1165"}], ",", 
       RowBox[{"1182", "\[Rule]", "1183"}], ",", 
       RowBox[{"1182", "\[Rule]", "1179"}], ",", 
       RowBox[{"210", "\[Rule]", "193"}], ",", 
       RowBox[{"210", "\[Rule]", "211"}], ",", 
       RowBox[{"210", "\[Rule]", "207"}], ",", 
       RowBox[{"1074", "\[Rule]", "1057"}], ",", 
       RowBox[{"1074", "\[Rule]", "1075"}], ",", 
       RowBox[{"1074", "\[Rule]", "1071"}], ",", 
       RowBox[{"642", "\[Rule]", "625"}], ",", 
       RowBox[{"642", "\[Rule]", "643"}], ",", 
       RowBox[{"642", "\[Rule]", "639"}], ",", 
       RowBox[{"102", "\[Rule]", "85"}], ",", 
       RowBox[{"102", "\[Rule]", "103"}], ",", 
       RowBox[{"102", "\[Rule]", "99"}], ",", 
       RowBox[{"966", "\[Rule]", "949"}], ",", 
       RowBox[{"966", "\[Rule]", "967"}], ",", 
       RowBox[{"966", "\[Rule]", "963"}], ",", 
       RowBox[{"534", "\[Rule]", "517"}], ",", 
       RowBox[{"534", "\[Rule]", "535"}], ",", 
       RowBox[{"534", "\[Rule]", "531"}], ",", 
       RowBox[{"2046", "\[Rule]", "2029"}], ",", 
       RowBox[{"2046", "\[Rule]", "2047"}], ",", 
       RowBox[{"2046", "\[Rule]", "2043"}], ",", 
       RowBox[{"1938", "\[Rule]", "1921"}], ",", 
       RowBox[{"1938", "\[Rule]", "1939"}], ",", 
       RowBox[{"1938", "\[Rule]", "1935"}], ",", 
       RowBox[{"1506", "\[Rule]", "1489"}], ",", 
       RowBox[{"1506", "\[Rule]", "1507"}], ",", 
       RowBox[{"1506", "\[Rule]", "1503"}], ",", 
       RowBox[{"1830", "\[Rule]", "1813"}], ",", 
       RowBox[{"1830", "\[Rule]", "1831"}], ",", 
       RowBox[{"1830", "\[Rule]", "1827"}], ",", 
       RowBox[{"1398", "\[Rule]", "1381"}], ",", 
       RowBox[{"1398", "\[Rule]", "1399"}], ",", 
       RowBox[{"1398", "\[Rule]", "1395"}], ",", 
       RowBox[{"261", "\[Rule]", "694"}], ",", 
       RowBox[{"261", "\[Rule]", "694"}], ",", 
       RowBox[{"261", "\[Rule]", "586"}], ",", 
       RowBox[{"261", "\[Rule]", "586"}], ",", 
       RowBox[{"261", "\[Rule]", "262"}], ",", 
       RowBox[{"291", "\[Rule]", "724"}], ",", 
       RowBox[{"291", "\[Rule]", "724"}], ",", 
       RowBox[{"291", "\[Rule]", "616"}], ",", 
       RowBox[{"291", "\[Rule]", "616"}], ",", 
       RowBox[{"291", "\[Rule]", "292"}], ",", 
       RowBox[{"273", "\[Rule]", "706"}], ",", 
       RowBox[{"273", "\[Rule]", "706"}], ",", 
       RowBox[{"273", "\[Rule]", "598"}], ",", 
       RowBox[{"273", "\[Rule]", "598"}], ",", 
       RowBox[{"273", "\[Rule]", "274"}], ",", 
       RowBox[{"1125", "\[Rule]", "694"}], ",", 
       RowBox[{"1125", "\[Rule]", "694"}], ",", 
       RowBox[{"1125", "\[Rule]", "1558"}], ",", 
       RowBox[{"1125", "\[Rule]", "1558"}], ",", 
       RowBox[{"1125", "\[Rule]", "586"}], ",", 
       RowBox[{"1125", "\[Rule]", "586"}], ",", 
       RowBox[{"1125", "\[Rule]", "1450"}], ",", 
       RowBox[{"1125", "\[Rule]", "1450"}], ",", 
       RowBox[{"1125", "\[Rule]", "1126"}], ",", 
       RowBox[{"1155", "\[Rule]", "724"}], ",", 
       RowBox[{"1155", "\[Rule]", "724"}], ",", 
       RowBox[{"1155", "\[Rule]", "1588"}], ",", 
       RowBox[{"1155", "\[Rule]", "1588"}], ",", 
       RowBox[{"1155", "\[Rule]", "616"}], ",", 
       RowBox[{"1155", "\[Rule]", "616"}], ",", 
       RowBox[{"1155", "\[Rule]", "1480"}], ",", 
       RowBox[{"1155", "\[Rule]", "1480"}], ",", 
       RowBox[{"1155", "\[Rule]", "1156"}], ",", 
       RowBox[{"1137", "\[Rule]", "706"}], ",", 
       RowBox[{"1137", "\[Rule]", "706"}], ",", 
       RowBox[{"1137", "\[Rule]", "1570"}], ",", 
       RowBox[{"1137", "\[Rule]", "1570"}], ",", 
       RowBox[{"1137", "\[Rule]", "598"}], ",", 
       RowBox[{"1137", "\[Rule]", "598"}], ",", 
       RowBox[{"1137", "\[Rule]", "1462"}], ",", 
       RowBox[{"1137", "\[Rule]", "1462"}], ",", 
       RowBox[{"1137", "\[Rule]", "1138"}], ",", 
       RowBox[{"153", "\[Rule]", "586"}], ",", 
       RowBox[{"153", "\[Rule]", "478"}], ",", 
       RowBox[{"153", "\[Rule]", "154"}], ",", 
       RowBox[{"165", "\[Rule]", "598"}], ",", 
       RowBox[{"165", "\[Rule]", "490"}], ",", 
       RowBox[{"165", "\[Rule]", "166"}], ",", 
       RowBox[{"1017", "\[Rule]", "586"}], ",", 
       RowBox[{"1017", "\[Rule]", "1450"}], ",", 
       RowBox[{"1017", "\[Rule]", "1450"}], ",", 
       RowBox[{"1017", "\[Rule]", "478"}], ",", 
       RowBox[{"1017", "\[Rule]", "1342"}], ",", 
       RowBox[{"1017", "\[Rule]", "1342"}], ",", 
       RowBox[{"1017", "\[Rule]", "1018"}], ",", 
       RowBox[{"1029", "\[Rule]", "598"}], ",", 
       RowBox[{"1029", "\[Rule]", "1462"}], ",", 
       RowBox[{"1029", "\[Rule]", "1462"}], ",", 
       RowBox[{"1029", "\[Rule]", "490"}], ",", 
       RowBox[{"1029", "\[Rule]", "1354"}], ",", 
       RowBox[{"1029", "\[Rule]", "1354"}], ",", 
       RowBox[{"1029", "\[Rule]", "1030"}], ",", 
       RowBox[{"585", "\[Rule]", "262"}], ",", 
       RowBox[{"585", "\[Rule]", "262"}], ",", 
       RowBox[{"585", "\[Rule]", "1126"}], ",", 
       RowBox[{"585", "\[Rule]", "1126"}], ",", 
       RowBox[{"585", "\[Rule]", "154"}], ",", 
       RowBox[{"585", "\[Rule]", "1018"}], ",", 
       RowBox[{"585", "\[Rule]", "586"}], ",", 
       RowBox[{"615", "\[Rule]", "292"}], ",", 
       RowBox[{"615", "\[Rule]", "292"}], ",", 
       RowBox[{"615", "\[Rule]", "1156"}], ",", 
       RowBox[{"615", "\[Rule]", "1156"}], ",", 
       RowBox[{"615", "\[Rule]", "184"}], ",", 
       RowBox[{"615", "\[Rule]", "1048"}], ",", 
       RowBox[{"615", "\[Rule]", "616"}], ",", 
       RowBox[{"597", "\[Rule]", "274"}], ",", 
       RowBox[{"597", "\[Rule]", "274"}], ",", 
       RowBox[{"597", "\[Rule]", "1138"}], ",", 
       RowBox[{"597", "\[Rule]", "1138"}], ",", 
       RowBox[{"597", "\[Rule]", "166"}], ",", 
       RowBox[{"597", "\[Rule]", "1030"}], ",", 
       RowBox[{"597", "\[Rule]", "598"}], ",", 
       RowBox[{"323", "\[Rule]", "756"}], ",", 
       RowBox[{"323", "\[Rule]", "756"}], ",", 
       RowBox[{"323", "\[Rule]", "648"}], ",", 
       RowBox[{"323", "\[Rule]", "648"}], ",", 
       RowBox[{"323", "\[Rule]", "324"}], ",", 
       RowBox[{"305", "\[Rule]", "738"}], ",", 
       RowBox[{"305", "\[Rule]", "738"}], ",", 
       RowBox[{"305", "\[Rule]", "630"}], ",", 
       RowBox[{"305", "\[Rule]", "630"}], ",", 
       RowBox[{"305", "\[Rule]", "306"}], ",", 
       RowBox[{"1187", "\[Rule]", "756"}], ",", 
       RowBox[{"1187", "\[Rule]", "756"}], ",", 
       RowBox[{"1187", "\[Rule]", "1620"}], ",", 
       RowBox[{"1187", "\[Rule]", "1620"}], ",", 
       RowBox[{"1187", "\[Rule]", "648"}], ",", 
       RowBox[{"1187", "\[Rule]", "648"}], ",", 
       RowBox[{"1187", "\[Rule]", "1512"}], ",", 
       RowBox[{"1187", "\[Rule]", "1512"}], ",", 
       RowBox[{"1187", "\[Rule]", "1188"}], ",", 
       RowBox[{"1169", "\[Rule]", "738"}], ",", 
       RowBox[{"1169", "\[Rule]", "738"}], ",", 
       RowBox[{"1169", "\[Rule]", "1602"}], ",", 
       RowBox[{"1169", "\[Rule]", "1602"}], ",", 
       RowBox[{"1169", "\[Rule]", "630"}], ",", 
       RowBox[{"1169", "\[Rule]", "630"}], ",", 
       RowBox[{"1169", "\[Rule]", "1494"}], ",", 
       RowBox[{"1169", "\[Rule]", "1494"}], ",", 
       RowBox[{"1169", "\[Rule]", "1170"}], ",", 
       RowBox[{"647", "\[Rule]", "324"}], ",", 
       RowBox[{"647", "\[Rule]", "324"}], ",", 
       RowBox[{"647", "\[Rule]", "1188"}], ",", 
       RowBox[{"647", "\[Rule]", "1188"}], ",", 
       RowBox[{"647", "\[Rule]", "216"}], ",", 
       RowBox[{"647", "\[Rule]", "1080"}], ",", 
       RowBox[{"647", "\[Rule]", "648"}], ",", 
       RowBox[{"629", "\[Rule]", "306"}], ",", 
       RowBox[{"629", "\[Rule]", "306"}], ",", 
       RowBox[{"629", "\[Rule]", "1170"}], ",", 
       RowBox[{"629", "\[Rule]", "1170"}], ",", 
       RowBox[{"629", "\[Rule]", "198"}], ",", 
       RowBox[{"629", "\[Rule]", "1062"}], ",", 
       RowBox[{"629", "\[Rule]", "630"}], ",", 
       RowBox[{"287", "\[Rule]", "720"}], ",", 
       RowBox[{"287", "\[Rule]", "720"}], ",", 
       RowBox[{"287", "\[Rule]", "612"}], ",", 
       RowBox[{"287", "\[Rule]", "612"}], ",", 
       RowBox[{"287", "\[Rule]", "288"}], ",", 
       RowBox[{"1151", "\[Rule]", "720"}], ",", 
       RowBox[{"1151", "\[Rule]", "720"}], ",", 
       RowBox[{"1151", "\[Rule]", "1584"}], ",", 
       RowBox[{"1151", "\[Rule]", "1584"}], ",", 
       RowBox[{"1151", "\[Rule]", "612"}], ",", 
       RowBox[{"1151", "\[Rule]", "612"}], ",", 
       RowBox[{"1151", "\[Rule]", "1476"}], ",", 
       RowBox[{"1151", "\[Rule]", "1476"}], ",", 
       RowBox[{"1151", "\[Rule]", "1152"}], ",", 
       RowBox[{"179", "\[Rule]", "612"}], ",", 
       RowBox[{"179", "\[Rule]", "504"}], ",", 
       RowBox[{"179", "\[Rule]", "180"}], ",", 
       RowBox[{"1043", "\[Rule]", "612"}], ",", 
       RowBox[{"1043", "\[Rule]", "1476"}], ",", 
       RowBox[{"1043", "\[Rule]", "1476"}], ",", 
       RowBox[{"1043", "\[Rule]", "504"}], ",", 
       RowBox[{"1043", "\[Rule]", "1368"}], ",", 
       RowBox[{"1043", "\[Rule]", "1368"}], ",", 
       RowBox[{"1043", "\[Rule]", "1044"}], ",", 
       RowBox[{"611", "\[Rule]", "288"}], ",", 
       RowBox[{"611", "\[Rule]", "288"}], ",", 
       RowBox[{"611", "\[Rule]", "1152"}], ",", 
       RowBox[{"611", "\[Rule]", "1152"}], ",", 
       RowBox[{"611", "\[Rule]", "180"}], ",", 
       RowBox[{"611", "\[Rule]", "1044"}], ",", 
       RowBox[{"611", "\[Rule]", "612"}], ",", 
       RowBox[{"45", "\[Rule]", "478"}], ",", 
       RowBox[{"45", "\[Rule]", "478"}], ",", 
       RowBox[{"45", "\[Rule]", "46"}], ",", 
       RowBox[{"57", "\[Rule]", "490"}], ",", 
       RowBox[{"57", "\[Rule]", "490"}], ",", 
       RowBox[{"57", "\[Rule]", "58"}], ",", 
       RowBox[{"909", "\[Rule]", "478"}], ",", 
       RowBox[{"909", "\[Rule]", "478"}], ",", 
       RowBox[{"909", "\[Rule]", "1342"}], ",", 
       RowBox[{"909", "\[Rule]", "910"}], ",", 
       RowBox[{"921", "\[Rule]", "490"}], ",", 
       RowBox[{"921", "\[Rule]", "490"}], ",", 
       RowBox[{"921", "\[Rule]", "1354"}], ",", 
       RowBox[{"921", "\[Rule]", "922"}], ",", 
       RowBox[{"477", "\[Rule]", "154"}], ",", 
       RowBox[{"477", "\[Rule]", "1018"}], ",", 
       RowBox[{"477", "\[Rule]", "46"}], ",", 
       RowBox[{"477", "\[Rule]", "46"}], ",", 
       RowBox[{"477", "\[Rule]", "910"}], ",", 
       RowBox[{"477", "\[Rule]", "910"}], ",", 
       RowBox[{"477", "\[Rule]", "478"}], ",", 
       RowBox[{"489", "\[Rule]", "166"}], ",", 
       RowBox[{"489", "\[Rule]", "1030"}], ",", 
       RowBox[{"489", "\[Rule]", "58"}], ",", 
       RowBox[{"489", "\[Rule]", "58"}], ",", 
       RowBox[{"489", "\[Rule]", "922"}], ",", 
       RowBox[{"489", "\[Rule]", "922"}], ",", 
       RowBox[{"489", "\[Rule]", "490"}], ",", 
       RowBox[{"71", "\[Rule]", "504"}], ",", 
       RowBox[{"71", "\[Rule]", "504"}], ",", 
       RowBox[{"71", "\[Rule]", "72"}], ",", 
       RowBox[{"935", "\[Rule]", "504"}], ",", 
       RowBox[{"935", "\[Rule]", "504"}], ",", 
       RowBox[{"935", "\[Rule]", "1368"}], ",", 
       RowBox[{"935", "\[Rule]", "936"}], ",", 
       RowBox[{"503", "\[Rule]", "180"}], ",", 
       RowBox[{"503", "\[Rule]", "1044"}], ",", 
       RowBox[{"503", "\[Rule]", "72"}], ",", 
       RowBox[{"503", "\[Rule]", "72"}], ",", 
       RowBox[{"503", "\[Rule]", "936"}], ",", 
       RowBox[{"503", "\[Rule]", "936"}], ",", 
       RowBox[{"503", "\[Rule]", "504"}], ",", 
       RowBox[{"319", "\[Rule]", "752"}], ",", 
       RowBox[{"319", "\[Rule]", "752"}], ",", 
       RowBox[{"319", "\[Rule]", "644"}], ",", 
       RowBox[{"319", "\[Rule]", "644"}], ",", 
       RowBox[{"319", "\[Rule]", "320"}], ",", 
       RowBox[{"1183", "\[Rule]", "752"}], ",", 
       RowBox[{"1183", "\[Rule]", "752"}], ",", 
       RowBox[{"1183", "\[Rule]", "1616"}], ",", 
       RowBox[{"1183", "\[Rule]", "1616"}], ",", 
       RowBox[{"1183", "\[Rule]", "644"}], ",", 
       RowBox[{"1183", "\[Rule]", "644"}], ",", 
       RowBox[{"1183", "\[Rule]", "1508"}], ",", 
       RowBox[{"1183", "\[Rule]", "1508"}], ",", 
       RowBox[{"1183", "\[Rule]", "1184"}], ",", 
       RowBox[{"643", "\[Rule]", "320"}], ",", 
       RowBox[{"643", "\[Rule]", "320"}], ",", 
       RowBox[{"643", "\[Rule]", "1184"}], ",", 
       RowBox[{"643", "\[Rule]", "1184"}], ",", 
       RowBox[{"643", "\[Rule]", "212"}], ",", 
       RowBox[{"643", "\[Rule]", "1076"}], ",", 
       RowBox[{"643", "\[Rule]", "644"}], ",", 
       RowBox[{"301", "\[Rule]", "734"}], ",", 
       RowBox[{"301", "\[Rule]", "734"}], ",", 
       RowBox[{"301", "\[Rule]", "626"}], ",", 
       RowBox[{"301", "\[Rule]", "626"}], ",", 
       RowBox[{"301", "\[Rule]", "302"}], ",", 
       RowBox[{"1165", "\[Rule]", "734"}], ",", 
       RowBox[{"1165", "\[Rule]", "734"}], ",", 
       RowBox[{"1165", "\[Rule]", "1598"}], ",", 
       RowBox[{"1165", "\[Rule]", "1598"}], ",", 
       RowBox[{"1165", "\[Rule]", "626"}], ",", 
       RowBox[{"1165", "\[Rule]", "626"}], ",", 
       RowBox[{"1165", "\[Rule]", "1490"}], ",", 
       RowBox[{"1165", "\[Rule]", "1490"}], ",", 
       RowBox[{"1165", "\[Rule]", "1166"}], ",", 
       RowBox[{"193", "\[Rule]", "626"}], ",", 
       RowBox[{"193", "\[Rule]", "518"}], ",", 
       RowBox[{"193", "\[Rule]", "194"}], ",", 
       RowBox[{"1057", "\[Rule]", "626"}], ",", 
       RowBox[{"1057", "\[Rule]", "1490"}], ",", 
       RowBox[{"1057", "\[Rule]", "1490"}], ",", 
       RowBox[{"1057", "\[Rule]", "518"}], ",", 
       RowBox[{"1057", "\[Rule]", "1382"}], ",", 
       RowBox[{"1057", "\[Rule]", "1382"}], ",", 
       RowBox[{"1057", "\[Rule]", "1058"}], ",", 
       RowBox[{"625", "\[Rule]", "302"}], ",", 
       RowBox[{"625", "\[Rule]", "302"}], ",", 
       RowBox[{"625", "\[Rule]", "1166"}], ",", 
       RowBox[{"625", "\[Rule]", "1166"}], ",", 
       RowBox[{"625", "\[Rule]", "194"}], ",", 
       RowBox[{"625", "\[Rule]", "1058"}], ",", 
       RowBox[{"625", "\[Rule]", "626"}], ",", 
       RowBox[{"85", "\[Rule]", "518"}], ",", 
       RowBox[{"85", "\[Rule]", "518"}], ",", 
       RowBox[{"85", "\[Rule]", "86"}], ",", 
       RowBox[{"949", "\[Rule]", "518"}], ",", 
       RowBox[{"949", "\[Rule]", "518"}], ",", 
       RowBox[{"949", "\[Rule]", "1382"}], ",", 
       RowBox[{"949", "\[Rule]", "950"}], ",", 
       RowBox[{"517", "\[Rule]", "194"}], ",", 
       RowBox[{"517", "\[Rule]", "1058"}], ",", 
       RowBox[{"517", "\[Rule]", "86"}], ",", 
       RowBox[{"517", "\[Rule]", "86"}], ",", 
       RowBox[{"517", "\[Rule]", "950"}], ",", 
       RowBox[{"517", "\[Rule]", "950"}], ",", 
       RowBox[{"517", "\[Rule]", "518"}], ",", 
       RowBox[{"1989", "\[Rule]", "1558"}], ",", 
       RowBox[{"1989", "\[Rule]", "1558"}], ",", 
       RowBox[{"1989", "\[Rule]", "2422"}], ",", 
       RowBox[{"1989", "\[Rule]", "2422"}], ",", 
       RowBox[{"1989", "\[Rule]", "1450"}], ",", 
       RowBox[{"1989", "\[Rule]", "1450"}], ",", 
       RowBox[{"1989", "\[Rule]", "2314"}], ",", 
       RowBox[{"1989", "\[Rule]", "2314"}], ",", 
       RowBox[{"1989", "\[Rule]", "1990"}], ",", 
       RowBox[{"2019", "\[Rule]", "1588"}], ",", 
       RowBox[{"2019", "\[Rule]", "1588"}], ",", 
       RowBox[{"2019", "\[Rule]", "2452"}], ",", 
       RowBox[{"2019", "\[Rule]", "2452"}], ",", 
       RowBox[{"2019", "\[Rule]", "1480"}], ",", 
       RowBox[{"2019", "\[Rule]", "1480"}], ",", 
       RowBox[{"2019", "\[Rule]", "2344"}], ",", 
       RowBox[{"2019", "\[Rule]", "2344"}], ",", 
       RowBox[{"2019", "\[Rule]", "2020"}], ",", 
       RowBox[{"2001", "\[Rule]", "1570"}], ",", 
       RowBox[{"2001", "\[Rule]", "1570"}], ",", 
       RowBox[{"2001", "\[Rule]", "2434"}], ",", 
       RowBox[{"2001", "\[Rule]", "2434"}], ",", 
       RowBox[{"2001", "\[Rule]", "1462"}], ",", 
       RowBox[{"2001", "\[Rule]", "1462"}], ",", 
       RowBox[{"2001", "\[Rule]", "2326"}], ",", 
       RowBox[{"2001", "\[Rule]", "2326"}], ",", 
       RowBox[{"2001", "\[Rule]", "2002"}], ",", 
       RowBox[{"1881", "\[Rule]", "1450"}], ",", 
       RowBox[{"1881", "\[Rule]", "1450"}], ",", 
       RowBox[{"1881", "\[Rule]", "2314"}], ",", 
       RowBox[{"1881", "\[Rule]", "2314"}], ",", 
       RowBox[{"1881", "\[Rule]", "1342"}], ",", 
       RowBox[{"1881", "\[Rule]", "1342"}], ",", 
       RowBox[{"1881", "\[Rule]", "2206"}], ",", 
       RowBox[{"1881", "\[Rule]", "2206"}], ",", 
       RowBox[{"1881", "\[Rule]", "1882"}], ",", 
       RowBox[{"1911", "\[Rule]", "1480"}], ",", 
       RowBox[{"1911", "\[Rule]", "1480"}], ",", 
       RowBox[{"1911", "\[Rule]", "2344"}], ",", 
       RowBox[{"1911", "\[Rule]", "2344"}], ",", 
       RowBox[{"1911", "\[Rule]", "1372"}], ",", 
       RowBox[{"1911", "\[Rule]", "1372"}], ",", 
       RowBox[{"1911", "\[Rule]", "2236"}], ",", 
       RowBox[{"1911", "\[Rule]", "2236"}], ",", 
       RowBox[{"1911", "\[Rule]", "1912"}], ",", 
       RowBox[{"1893", "\[Rule]", "1462"}], ",", 
       RowBox[{"1893", "\[Rule]", "1462"}], ",", 
       RowBox[{"1893", "\[Rule]", "2326"}], ",", 
       RowBox[{"1893", "\[Rule]", "2326"}], ",", 
       RowBox[{"1893", "\[Rule]", "1354"}], ",", 
       RowBox[{"1893", "\[Rule]", "1354"}], ",", 
       RowBox[{"1893", "\[Rule]", "2218"}], ",", 
       RowBox[{"1893", "\[Rule]", "2218"}], ",", 
       RowBox[{"1893", "\[Rule]", "1894"}], ",", 
       RowBox[{"1449", "\[Rule]", "1126"}], ",", 
       RowBox[{"1449", "\[Rule]", "1126"}], ",", 
       RowBox[{"1449", "\[Rule]", "1990"}], ",", 
       RowBox[{"1449", "\[Rule]", "1990"}], ",", 
       RowBox[{"1449", "\[Rule]", "1018"}], ",", 
       RowBox[{"1449", "\[Rule]", "1018"}], ",", 
       RowBox[{"1449", "\[Rule]", "1882"}], ",", 
       RowBox[{"1449", "\[Rule]", "1882"}], ",", 
       RowBox[{"1449", "\[Rule]", "1450"}], ",", 
       RowBox[{"1479", "\[Rule]", "1156"}], ",", 
       RowBox[{"1479", "\[Rule]", "1156"}], ",", 
       RowBox[{"1479", "\[Rule]", "2020"}], ",", 
       RowBox[{"1479", "\[Rule]", "2020"}], ",", 
       RowBox[{"1479", "\[Rule]", "1048"}], ",", 
       RowBox[{"1479", "\[Rule]", "1048"}], ",", 
       RowBox[{"1479", "\[Rule]", "1912"}], ",", 
       RowBox[{"1479", "\[Rule]", "1912"}], ",", 
       RowBox[{"1479", "\[Rule]", "1480"}], ",", 
       RowBox[{"1461", "\[Rule]", "1138"}], ",", 
       RowBox[{"1461", "\[Rule]", "1138"}], ",", 
       RowBox[{"1461", "\[Rule]", "2002"}], ",", 
       RowBox[{"1461", "\[Rule]", "2002"}], ",", 
       RowBox[{"1461", "\[Rule]", "1030"}], ",", 
       RowBox[{"1461", "\[Rule]", "1030"}], ",", 
       RowBox[{"1461", "\[Rule]", "1894"}], ",", 
       RowBox[{"1461", "\[Rule]", "1894"}], ",", 
       RowBox[{"1461", "\[Rule]", "1462"}], ",", 
       RowBox[{"2051", "\[Rule]", "1620"}], ",", 
       RowBox[{"2051", "\[Rule]", "1620"}], ",", 
       RowBox[{"2051", "\[Rule]", "2484"}], ",", 
       RowBox[{"2051", "\[Rule]", "2484"}], ",", 
       RowBox[{"2051", "\[Rule]", "1512"}], ",", 
       RowBox[{"2051", "\[Rule]", "1512"}], ",", 
       RowBox[{"2051", "\[Rule]", "2376"}], ",", 
       RowBox[{"2051", "\[Rule]", "2376"}], ",", 
       RowBox[{"2051", "\[Rule]", "2052"}], ",", 
       RowBox[{"2033", "\[Rule]", "1602"}], ",", 
       RowBox[{"2033", "\[Rule]", "1602"}], ",", 
       RowBox[{"2033", "\[Rule]", "2466"}], ",", 
       RowBox[{"2033", "\[Rule]", "2466"}], ",", 
       RowBox[{"2033", "\[Rule]", "1494"}], ",", 
       RowBox[{"2033", "\[Rule]", "1494"}], ",", 
       RowBox[{"2033", "\[Rule]", "2358"}], ",", 
       RowBox[{"2033", "\[Rule]", "2358"}], ",", 
       RowBox[{"2033", "\[Rule]", "2034"}], ",", 
       RowBox[{"1943", "\[Rule]", "1512"}], ",", 
       RowBox[{"1943", "\[Rule]", "1512"}], ",", 
       RowBox[{"1943", "\[Rule]", "2376"}], ",", 
       RowBox[{"1943", "\[Rule]", "2376"}], ",", 
       RowBox[{"1943", "\[Rule]", "1404"}], ",", 
       RowBox[{"1943", "\[Rule]", "1404"}], ",", 
       RowBox[{"1943", "\[Rule]", "2268"}], ",", 
       RowBox[{"1943", "\[Rule]", "2268"}], ",", 
       RowBox[{"1943", "\[Rule]", "1944"}], ",", 
       RowBox[{"1925", "\[Rule]", "1494"}], ",", 
       RowBox[{"1925", "\[Rule]", "1494"}], ",", 
       RowBox[{"1925", "\[Rule]", "2358"}], ",", 
       RowBox[{"1925", "\[Rule]", "2358"}], ",", 
       RowBox[{"1925", "\[Rule]", "1386"}], ",", 
       RowBox[{"1925", "\[Rule]", "1386"}], ",", 
       RowBox[{"1925", "\[Rule]", "2250"}], ",", 
       RowBox[{"1925", "\[Rule]", "2250"}], ",", 
       RowBox[{"1925", "\[Rule]", "1926"}], ",", 
       RowBox[{"1511", "\[Rule]", "1188"}], ",", 
       RowBox[{"1511", "\[Rule]", "1188"}], ",", 
       RowBox[{"1511", "\[Rule]", "2052"}], ",", 
       RowBox[{"1511", "\[Rule]", "2052"}], ",", 
       RowBox[{"1511", "\[Rule]", "1080"}], ",", 
       RowBox[{"1511", "\[Rule]", "1080"}], ",", 
       RowBox[{"1511", "\[Rule]", "1944"}], ",", 
       RowBox[{"1511", "\[Rule]", "1944"}], ",", 
       RowBox[{"1511", "\[Rule]", "1512"}], ",", 
       RowBox[{"1493", "\[Rule]", "1170"}], ",", 
       RowBox[{"1493", "\[Rule]", "1170"}], ",", 
       RowBox[{"1493", "\[Rule]", "2034"}], ",", 
       RowBox[{"1493", "\[Rule]", "2034"}], ",", 
       RowBox[{"1493", "\[Rule]", "1062"}], ",", 
       RowBox[{"1493", "\[Rule]", "1062"}], ",", 
       RowBox[{"1493", "\[Rule]", "1926"}], ",", 
       RowBox[{"1493", "\[Rule]", "1926"}], ",", 
       RowBox[{"1493", "\[Rule]", "1494"}], ",", 
       RowBox[{"2015", "\[Rule]", "1584"}], ",", 
       RowBox[{"2015", "\[Rule]", "2448"}], ",", 
       RowBox[{"2015", "\[Rule]", "1476"}], ",", 
       RowBox[{"2015", "\[Rule]", "1476"}], ",", 
       RowBox[{"2015", "\[Rule]", "2340"}], ",", 
       RowBox[{"2015", "\[Rule]", "2340"}], ",", 
       RowBox[{"2015", "\[Rule]", "2016"}], ",", 
       RowBox[{"1907", "\[Rule]", "1476"}], ",", 
       RowBox[{"1907", "\[Rule]", "1476"}], ",", 
       RowBox[{"1907", "\[Rule]", "2340"}], ",", 
       RowBox[{"1907", "\[Rule]", "2340"}], ",", 
       RowBox[{"1907", "\[Rule]", "1368"}], ",", 
       RowBox[{"1907", "\[Rule]", "1368"}], ",", 
       RowBox[{"1907", "\[Rule]", "2232"}], ",", 
       RowBox[{"1907", "\[Rule]", "2232"}], ",", 
       RowBox[{"1907", "\[Rule]", "1908"}], ",", 
       RowBox[{"1475", "\[Rule]", "1152"}], ",", 
       RowBox[{"1475", "\[Rule]", "1152"}], ",", 
       RowBox[{"1475", "\[Rule]", "2016"}], ",", 
       RowBox[{"1475", "\[Rule]", "2016"}], ",", 
       RowBox[{"1475", "\[Rule]", "1044"}], ",", 
       RowBox[{"1475", "\[Rule]", "1044"}], ",", 
       RowBox[{"1475", "\[Rule]", "1908"}], ",", 
       RowBox[{"1475", "\[Rule]", "1908"}], ",", 
       RowBox[{"1475", "\[Rule]", "1476"}], ",", 
       RowBox[{"1773", "\[Rule]", "1342"}], ",", 
       RowBox[{"1773", "\[Rule]", "2206"}], ",", 
       RowBox[{"1773", "\[Rule]", "2206"}], ",", 
       RowBox[{"1773", "\[Rule]", "1774"}], ",", 
       RowBox[{"1803", "\[Rule]", "1372"}], ",", 
       RowBox[{"1803", "\[Rule]", "2236"}], ",", 
       RowBox[{"1803", "\[Rule]", "2236"}], ",", 
       RowBox[{"1803", "\[Rule]", "1804"}], ",", 
       RowBox[{"1785", "\[Rule]", "1354"}], ",", 
       RowBox[{"1785", "\[Rule]", "2218"}], ",", 
       RowBox[{"1785", "\[Rule]", "2218"}], ",", 
       RowBox[{"1785", "\[Rule]", "1786"}], ",", 
       RowBox[{"1341", "\[Rule]", "1018"}], ",", 
       RowBox[{"1341", "\[Rule]", "1018"}], ",", 
       RowBox[{"1341", "\[Rule]", "1882"}], ",", 
       RowBox[{"1341", "\[Rule]", "1882"}], ",", 
       RowBox[{"1341", "\[Rule]", "910"}], ",", 
       RowBox[{"1341", "\[Rule]", "1774"}], ",", 
       RowBox[{"1341", "\[Rule]", "1342"}], ",", 
       RowBox[{"1371", "\[Rule]", "1048"}], ",", 
       RowBox[{"1371", "\[Rule]", "1048"}], ",", 
       RowBox[{"1371", "\[Rule]", "1912"}], ",", 
       RowBox[{"1371", "\[Rule]", "1912"}], ",", 
       RowBox[{"1371", "\[Rule]", "940"}], ",", 
       RowBox[{"1371", "\[Rule]", "1804"}], ",", 
       RowBox[{"1371", "\[Rule]", "1372"}], ",", 
       RowBox[{"1353", "\[Rule]", "1030"}], ",", 
       RowBox[{"1353", "\[Rule]", "1030"}], ",", 
       RowBox[{"1353", "\[Rule]", "1894"}], ",", 
       RowBox[{"1353", "\[Rule]", "1894"}], ",", 
       RowBox[{"1353", "\[Rule]", "922"}], ",", 
       RowBox[{"1353", "\[Rule]", "1786"}], ",", 
       RowBox[{"1353", "\[Rule]", "1354"}], ",", 
       RowBox[{"1835", "\[Rule]", "1404"}], ",", 
       RowBox[{"1835", "\[Rule]", "2268"}], ",", 
       RowBox[{"1835", "\[Rule]", "2268"}], ",", 
       RowBox[{"1835", "\[Rule]", "1836"}], ",", 
       RowBox[{"1817", "\[Rule]", "1386"}], ",", 
       RowBox[{"1817", "\[Rule]", "2250"}], ",", 
       RowBox[{"1817", "\[Rule]", "2250"}], ",", 
       RowBox[{"1817", "\[Rule]", "1818"}], ",", 
       RowBox[{"1403", "\[Rule]", "1080"}], ",", 
       RowBox[{"1403", "\[Rule]", "1080"}], ",", 
       RowBox[{"1403", "\[Rule]", "1944"}], ",", 
       RowBox[{"1403", "\[Rule]", "1944"}], ",", 
       RowBox[{"1403", "\[Rule]", "972"}], ",", 
       RowBox[{"1403", "\[Rule]", "1836"}], ",", 
       RowBox[{"1403", "\[Rule]", "1404"}], ",", 
       RowBox[{"1385", "\[Rule]", "1062"}], ",", 
       RowBox[{"1385", "\[Rule]", "1062"}], ",", 
       RowBox[{"1385", "\[Rule]", "1926"}], ",", 
       RowBox[{"1385", "\[Rule]", "1926"}], ",", 
       RowBox[{"1385", "\[Rule]", "954"}], ",", 
       RowBox[{"1385", "\[Rule]", "1818"}], ",", 
       RowBox[{"1385", "\[Rule]", "1386"}], ",", 
       RowBox[{"1799", "\[Rule]", "1368"}], ",", 
       RowBox[{"1799", "\[Rule]", "2232"}], ",", 
       RowBox[{"1799", "\[Rule]", "2232"}], ",", 
       RowBox[{"1799", "\[Rule]", "1800"}], ",", 
       RowBox[{"1367", "\[Rule]", "1044"}], ",", 
       RowBox[{"1367", "\[Rule]", "1044"}], ",", 
       RowBox[{"1367", "\[Rule]", "1908"}], ",", 
       RowBox[{"1367", "\[Rule]", "1908"}], ",", 
       RowBox[{"1367", "\[Rule]", "936"}], ",", 
       RowBox[{"1367", "\[Rule]", "1800"}], ",", 
       RowBox[{"1367", "\[Rule]", "1368"}], ",", 
       RowBox[{"2047", "\[Rule]", "1616"}], ",", 
       RowBox[{"2047", "\[Rule]", "1616"}], ",", 
       RowBox[{"2047", "\[Rule]", "2480"}], ",", 
       RowBox[{"2047", "\[Rule]", "2480"}], ",", 
       RowBox[{"2047", "\[Rule]", "1508"}], ",", 
       RowBox[{"2047", "\[Rule]", "1508"}], ",", 
       RowBox[{"2047", "\[Rule]", "2372"}], ",", 
       RowBox[{"2047", "\[Rule]", "2372"}], ",", 
       RowBox[{"2047", "\[Rule]", "2048"}], ",", 
       RowBox[{"1939", "\[Rule]", "1508"}], ",", 
       RowBox[{"1939", "\[Rule]", "1508"}], ",", 
       RowBox[{"1939", "\[Rule]", "2372"}], ",", 
       RowBox[{"1939", "\[Rule]", "2372"}], ",", 
       RowBox[{"1939", "\[Rule]", "1400"}], ",", 
       RowBox[{"1939", "\[Rule]", "1400"}], ",", 
       RowBox[{"1939", "\[Rule]", "2264"}], ",", 
       RowBox[{"1939", "\[Rule]", "2264"}], ",", 
       RowBox[{"1939", "\[Rule]", "1940"}], ",", 
       RowBox[{"1507", "\[Rule]", "1184"}], ",", 
       RowBox[{"1507", "\[Rule]", "1184"}], ",", 
       RowBox[{"1507", "\[Rule]", "2048"}], ",", 
       RowBox[{"1507", "\[Rule]", "2048"}], ",", 
       RowBox[{"1507", "\[Rule]", "1076"}], ",", 
       RowBox[{"1507", "\[Rule]", "1076"}], ",", 
       RowBox[{"1507", "\[Rule]", "1940"}], ",", 
       RowBox[{"1507", "\[Rule]", "1940"}], ",", 
       RowBox[{"1507", "\[Rule]", "1508"}], ",", 
       RowBox[{"1831", "\[Rule]", "1400"}], ",", 
       RowBox[{"1831", "\[Rule]", "2264"}], ",", 
       RowBox[{"1831", "\[Rule]", "2264"}], ",", 
       RowBox[{"1831", "\[Rule]", "1832"}], ",", 
       RowBox[{"1399", "\[Rule]", "1076"}], ",", 
       RowBox[{"1399", "\[Rule]", "1076"}], ",", 
       RowBox[{"1399", "\[Rule]", "1940"}], ",", 
       RowBox[{"1399", "\[Rule]", "1940"}], ",", 
       RowBox[{"1399", "\[Rule]", "968"}], ",", 
       RowBox[{"1399", "\[Rule]", "1832"}], ",", 
       RowBox[{"1399", "\[Rule]", "1400"}], ",", 
       RowBox[{"2029", "\[Rule]", "1598"}], ",", 
       RowBox[{"2029", "\[Rule]", "1598"}], ",", 
       RowBox[{"2029", "\[Rule]", "2462"}], ",", 
       RowBox[{"2029", "\[Rule]", "1490"}], ",", 
       RowBox[{"2029", "\[Rule]", "1490"}], ",", 
       RowBox[{"2029", "\[Rule]", "2354"}], ",", 
       RowBox[{"2029", "\[Rule]", "2030"}], ",", 
       RowBox[{"1921", "\[Rule]", "1490"}], ",", 
       RowBox[{"1921", "\[Rule]", "1490"}], ",", 
       RowBox[{"1921", "\[Rule]", "2354"}], ",", 
       RowBox[{"1921", "\[Rule]", "2354"}], ",", 
       RowBox[{"1921", "\[Rule]", "1382"}], ",", 
       RowBox[{"1921", "\[Rule]", "1382"}], ",", 
       RowBox[{"1921", "\[Rule]", "2246"}], ",", 
       RowBox[{"1921", "\[Rule]", "2246"}], ",", 
       RowBox[{"1921", "\[Rule]", "1922"}], ",", 
       RowBox[{"1489", "\[Rule]", "1166"}], ",", 
       RowBox[{"1489", "\[Rule]", "1166"}], ",", 
       RowBox[{"1489", "\[Rule]", "2030"}], ",", 
       RowBox[{"1489", "\[Rule]", "2030"}], ",", 
       RowBox[{"1489", "\[Rule]", "1058"}], ",", 
       RowBox[{"1489", "\[Rule]", "1058"}], ",", 
       RowBox[{"1489", "\[Rule]", "1922"}], ",", 
       RowBox[{"1489", "\[Rule]", "1922"}], ",", 
       RowBox[{"1489", "\[Rule]", "1490"}], ",", 
       RowBox[{"1813", "\[Rule]", "1382"}], ",", 
       RowBox[{"1813", "\[Rule]", "2246"}], ",", 
       RowBox[{"1813", "\[Rule]", "2246"}], ",", 
       RowBox[{"1813", "\[Rule]", "1814"}], ",", 
       RowBox[{"1381", "\[Rule]", "1058"}], ",", 
       RowBox[{"1381", "\[Rule]", "1058"}], ",", 
       RowBox[{"1381", "\[Rule]", "1922"}], ",", 
       RowBox[{"1381", "\[Rule]", "1922"}], ",", 
       RowBox[{"1381", "\[Rule]", "950"}], ",", 
       RowBox[{"1381", "\[Rule]", "1814"}], ",", 
       RowBox[{"1381", "\[Rule]", "1382"}], ",", 
       RowBox[{"315", "\[Rule]", "748"}], ",", 
       RowBox[{"315", "\[Rule]", "748"}], ",", 
       RowBox[{"315", "\[Rule]", "640"}], ",", 
       RowBox[{"315", "\[Rule]", "640"}], ",", 
       RowBox[{"315", "\[Rule]", "316"}], ",", 
       RowBox[{"1179", "\[Rule]", "748"}], ",", 
       RowBox[{"1179", "\[Rule]", "748"}], ",", 
       RowBox[{"1179", "\[Rule]", "1612"}], ",", 
       RowBox[{"1179", "\[Rule]", "1612"}], ",", 
       RowBox[{"1179", "\[Rule]", "640"}], ",", 
       RowBox[{"1179", "\[Rule]", "640"}], ",", 
       RowBox[{"1179", "\[Rule]", "1504"}], ",", 
       RowBox[{"1179", "\[Rule]", "1504"}], ",", 
       RowBox[{"1179", "\[Rule]", "1180"}], ",", 
       RowBox[{"207", "\[Rule]", "640"}], ",", 
       RowBox[{"207", "\[Rule]", "532"}], ",", 
       RowBox[{"207", "\[Rule]", "208"}], ",", 
       RowBox[{"1071", "\[Rule]", "640"}], ",", 
       RowBox[{"1071", "\[Rule]", "1504"}], ",", 
       RowBox[{"1071", "\[Rule]", "1504"}], ",", 
       RowBox[{"1071", "\[Rule]", "532"}], ",", 
       RowBox[{"1071", "\[Rule]", "1396"}], ",", 
       RowBox[{"1071", "\[Rule]", "1396"}], ",", 
       RowBox[{"1071", "\[Rule]", "1072"}], ",", 
       RowBox[{"639", "\[Rule]", "316"}], ",", 
       RowBox[{"639", "\[Rule]", "316"}], ",", 
       RowBox[{"639", "\[Rule]", "1180"}], ",", 
       RowBox[{"639", "\[Rule]", "1180"}], ",", 
       RowBox[{"639", "\[Rule]", "208"}], ",", 
       RowBox[{"639", "\[Rule]", "1072"}], ",", 
       RowBox[{"639", "\[Rule]", "640"}], ",", 
       RowBox[{"99", "\[Rule]", "532"}], ",", 
       RowBox[{"99", "\[Rule]", "532"}], ",", 
       RowBox[{"99", "\[Rule]", "100"}], ",", 
       RowBox[{"963", "\[Rule]", "532"}], ",", 
       RowBox[{"963", "\[Rule]", "532"}], ",", 
       RowBox[{"963", "\[Rule]", "1396"}], ",", 
       RowBox[{"963", "\[Rule]", "964"}], ",", 
       RowBox[{"531", "\[Rule]", "208"}], ",", 
       RowBox[{"531", "\[Rule]", "1072"}], ",", 
       RowBox[{"531", "\[Rule]", "100"}], ",", 
       RowBox[{"531", "\[Rule]", "100"}], ",", 
       RowBox[{"531", "\[Rule]", "964"}], ",", 
       RowBox[{"531", "\[Rule]", "964"}], ",", 
       RowBox[{"531", "\[Rule]", "532"}], ",", 
       RowBox[{"2043", "\[Rule]", "1612"}], ",", 
       RowBox[{"2043", "\[Rule]", "1612"}], ",", 
       RowBox[{"2043", "\[Rule]", "2476"}], ",", 
       RowBox[{"2043", "\[Rule]", "2476"}], ",", 
       RowBox[{"2043", "\[Rule]", "1504"}], ",", 
       RowBox[{"2043", "\[Rule]", "1504"}], ",", 
       RowBox[{"2043", "\[Rule]", "2368"}], ",", 
       RowBox[{"2043", "\[Rule]", "2368"}], ",", 
       RowBox[{"2043", "\[Rule]", "2044"}], ",", 
       RowBox[{"1935", "\[Rule]", "1504"}], ",", 
       RowBox[{"1935", "\[Rule]", "1504"}], ",", 
       RowBox[{"1935", "\[Rule]", "2368"}], ",", 
       RowBox[{"1935", "\[Rule]", "2368"}], ",", 
       RowBox[{"1935", "\[Rule]", "1396"}], ",", 
       RowBox[{"1935", "\[Rule]", "1396"}], ",", 
       RowBox[{"1935", "\[Rule]", "2260"}], ",", 
       RowBox[{"1935", "\[Rule]", "2260"}], ",", 
       RowBox[{"1935", "\[Rule]", "1936"}], ",", 
       RowBox[{"1503", "\[Rule]", "1180"}], ",", 
       RowBox[{"1503", "\[Rule]", "1180"}], ",", 
       RowBox[{"1503", "\[Rule]", "2044"}], ",", 
       RowBox[{"1503", "\[Rule]", "2044"}], ",", 
       RowBox[{"1503", "\[Rule]", "1072"}], ",", 
       RowBox[{"1503", "\[Rule]", "1072"}], ",", 
       RowBox[{"1503", "\[Rule]", "1936"}], ",", 
       RowBox[{"1503", "\[Rule]", "1936"}], ",", 
       RowBox[{"1503", "\[Rule]", "1504"}], ",", 
       RowBox[{"1827", "\[Rule]", "1396"}], ",", 
       RowBox[{"1827", "\[Rule]", "2260"}], ",", 
       RowBox[{"1827", "\[Rule]", "2260"}], ",", 
       RowBox[{"1827", "\[Rule]", "1828"}], ",", 
       RowBox[{"1395", "\[Rule]", "1072"}], ",", 
       RowBox[{"1395", "\[Rule]", "1072"}], ",", 
       RowBox[{"1395", "\[Rule]", "1936"}], ",", 
       RowBox[{"1395", "\[Rule]", "1936"}], ",", 
       RowBox[{"1395", "\[Rule]", "964"}], ",", 
       RowBox[{"1395", "\[Rule]", "1828"}], ",", 
       RowBox[{"1395", "\[Rule]", "1396"}], ",", 
       RowBox[{"694", "\[Rule]", "677"}], ",", 
       RowBox[{"694", "\[Rule]", "707"}], ",", 
       RowBox[{"694", "\[Rule]", "691"}], ",", 
       RowBox[{"586", "\[Rule]", "569"}], ",", 
       RowBox[{"586", "\[Rule]", "599"}], ",", 
       RowBox[{"586", "\[Rule]", "583"}], ",", 
       RowBox[{"262", "\[Rule]", "245"}], ",", 
       RowBox[{"262", "\[Rule]", "275"}], ",", 
       RowBox[{"262", "\[Rule]", "259"}], ",", 
       RowBox[{"724", "\[Rule]", "707"}], ",", 
       RowBox[{"724", "\[Rule]", "739"}], ",", 
       RowBox[{"724", "\[Rule]", "721"}], ",", 
       RowBox[{"292", "\[Rule]", "275"}], ",", 
       RowBox[{"292", "\[Rule]", "307"}], ",", 
       RowBox[{"292", "\[Rule]", "289"}], ",", 
       RowBox[{"706", "\[Rule]", "691"}], ",", 
       RowBox[{"706", "\[Rule]", "721"}], ",", 
       RowBox[{"706", "\[Rule]", "707"}], ",", 
       RowBox[{"706", "\[Rule]", "703"}], ",", 
       RowBox[{"598", "\[Rule]", "583"}], ",", 
       RowBox[{"598", "\[Rule]", "613"}], ",", 
       RowBox[{"598", "\[Rule]", "599"}], ",", 
       RowBox[{"598", "\[Rule]", "595"}], ",", 
       RowBox[{"274", "\[Rule]", "259"}], ",", 
       RowBox[{"274", "\[Rule]", "289"}], ",", 
       RowBox[{"274", "\[Rule]", "275"}], ",", 
       RowBox[{"274", "\[Rule]", "271"}], ",", 
       RowBox[{"1558", "\[Rule]", "1541"}], ",", 
       RowBox[{"1558", "\[Rule]", "1571"}], ",", 
       RowBox[{"1558", "\[Rule]", "1555"}], ",", 
       RowBox[{"1450", "\[Rule]", "1433"}], ",", 
       RowBox[{"1450", "\[Rule]", "1463"}], ",", 
       RowBox[{"1450", "\[Rule]", "1447"}], ",", 
       RowBox[{"1126", "\[Rule]", "1109"}], ",", 
       RowBox[{"1126", "\[Rule]", "1139"}], ",", 
       RowBox[{"1126", "\[Rule]", "1123"}], ",", 
       RowBox[{"1588", "\[Rule]", "1571"}], ",", 
       RowBox[{"1588", "\[Rule]", "1603"}], ",", 
       RowBox[{"1588", "\[Rule]", "1585"}], ",", 
       RowBox[{"1156", "\[Rule]", "1139"}], ",", 
       RowBox[{"1156", "\[Rule]", "1171"}], ",", 
       RowBox[{"1156", "\[Rule]", "1153"}], ",", 
       RowBox[{"1570", "\[Rule]", "1555"}], ",", 
       RowBox[{"1570", "\[Rule]", "1585"}], ",", 
       RowBox[{"1570", "\[Rule]", "1571"}], ",", 
       RowBox[{"1570", "\[Rule]", "1567"}], ",", 
       RowBox[{"1462", "\[Rule]", "1447"}], ",", 
       RowBox[{"1462", "\[Rule]", "1477"}], ",", 
       RowBox[{"1462", "\[Rule]", "1463"}], ",", 
       RowBox[{"1462", "\[Rule]", "1459"}], ",", 
       RowBox[{"1138", "\[Rule]", "1123"}], ",", 
       RowBox[{"1138", "\[Rule]", "1153"}], ",", 
       RowBox[{"1138", "\[Rule]", "1139"}], ",", 
       RowBox[{"1138", "\[Rule]", "1135"}], ",", 
       RowBox[{"478", "\[Rule]", "461"}], ",", 
       RowBox[{"478", "\[Rule]", "491"}], ",", 
       RowBox[{"478", "\[Rule]", "475"}], ",", 
       RowBox[{"154", "\[Rule]", "137"}], ",", 
       RowBox[{"154", "\[Rule]", "167"}], ",", 
       RowBox[{"154", "\[Rule]", "151"}], ",", 
       RowBox[{"490", "\[Rule]", "475"}], ",", 
       RowBox[{"490", "\[Rule]", "505"}], ",", 
       RowBox[{"490", "\[Rule]", "491"}], ",", 
       RowBox[{"490", "\[Rule]", "487"}], ",", 
       RowBox[{"166", "\[Rule]", "151"}], ",", 
       RowBox[{"166", "\[Rule]", "181"}], ",", 
       RowBox[{"166", "\[Rule]", "167"}], ",", 
       RowBox[{"166", "\[Rule]", "163"}], ",", 
       RowBox[{"1342", "\[Rule]", "1325"}], ",", 
       RowBox[{"1342", "\[Rule]", "1355"}], ",", 
       RowBox[{"1342", "\[Rule]", "1339"}], ",", 
       RowBox[{"1018", "\[Rule]", "1001"}], ",", 
       RowBox[{"1018", "\[Rule]", "1031"}], ",", 
       RowBox[{"1018", "\[Rule]", "1015"}], ",", 
       RowBox[{"1354", "\[Rule]", "1339"}], ",", 
       RowBox[{"1354", "\[Rule]", "1369"}], ",", 
       RowBox[{"1354", "\[Rule]", "1355"}], ",", 
       RowBox[{"1354", "\[Rule]", "1351"}], ",", 
       RowBox[{"1030", "\[Rule]", "1015"}], ",", 
       RowBox[{"1030", "\[Rule]", "1045"}], ",", 
       RowBox[{"1030", "\[Rule]", "1031"}], ",", 
       RowBox[{"1030", "\[Rule]", "1027"}], ",", 
       RowBox[{"756", "\[Rule]", "739"}], ",", 
       RowBox[{"756", "\[Rule]", "753"}], ",", 
       RowBox[{"324", "\[Rule]", "307"}], ",", 
       RowBox[{"324", "\[Rule]", "321"}], ",", 
       RowBox[{"738", "\[Rule]", "721"}], ",", 
       RowBox[{"738", "\[Rule]", "753"}], ",", 
       RowBox[{"738", "\[Rule]", "739"}], ",", 
       RowBox[{"738", "\[Rule]", "735"}], ",", 
       RowBox[{"306", "\[Rule]", "289"}], ",", 
       RowBox[{"306", "\[Rule]", "321"}], ",", 
       RowBox[{"306", "\[Rule]", "307"}], ",", 
       RowBox[{"306", "\[Rule]", "303"}], ",", 
       RowBox[{"1620", "\[Rule]", "1603"}], ",", 
       RowBox[{"1620", "\[Rule]", "1617"}], ",", 
       RowBox[{"1188", "\[Rule]", "1171"}], ",", 
       RowBox[{"1188", "\[Rule]", "1185"}], ",", 
       RowBox[{"1602", "\[Rule]", "1585"}], ",", 
       RowBox[{"1602", "\[Rule]", "1617"}], ",", 
       RowBox[{"1602", "\[Rule]", "1603"}], ",", 
       RowBox[{"1602", "\[Rule]", "1599"}], ",", 
       RowBox[{"1170", "\[Rule]", "1153"}], ",", 
       RowBox[{"1170", "\[Rule]", "1185"}], ",", 
       RowBox[{"1170", "\[Rule]", "1171"}], ",", 
       RowBox[{"1170", "\[Rule]", "1167"}], ",", 
       RowBox[{"720", "\[Rule]", "703"}], ",", 
       RowBox[{"720", "\[Rule]", "735"}], ",", 
       RowBox[{"720", "\[Rule]", "721"}], ",", 
       RowBox[{"720", "\[Rule]", "717"}], ",", 
       RowBox[{"612", "\[Rule]", "595"}], ",", 
       RowBox[{"612", "\[Rule]", "627"}], ",", 
       RowBox[{"612", "\[Rule]", "613"}], ",", 
       RowBox[{"612", "\[Rule]", "609"}], ",", 
       RowBox[{"288", "\[Rule]", "271"}], ",", 
       RowBox[{"288", "\[Rule]", "303"}], ",", 
       RowBox[{"288", "\[Rule]", "289"}], ",", 
       RowBox[{"288", "\[Rule]", "285"}], ",", 
       RowBox[{"1584", "\[Rule]", "1567"}], ",", 
       RowBox[{"1584", "\[Rule]", "1599"}], ",", 
       RowBox[{"1584", "\[Rule]", "1585"}], ",", 
       RowBox[{"1584", "\[Rule]", "1581"}], ",", 
       RowBox[{"1476", "\[Rule]", "1459"}], ",", 
       RowBox[{"1476", "\[Rule]", "1491"}], ",", 
       RowBox[{"1476", "\[Rule]", "1477"}], ",", 
       RowBox[{"1476", "\[Rule]", "1473"}], ",", 
       RowBox[{"1152", "\[Rule]", "1135"}], ",", 
       RowBox[{"1152", "\[Rule]", "1167"}], ",", 
       RowBox[{"1152", "\[Rule]", "1153"}], ",", 
       RowBox[{"1152", "\[Rule]", "1149"}], ",", 
       RowBox[{"504", "\[Rule]", "487"}], ",", 
       RowBox[{"504", "\[Rule]", "519"}], ",", 
       RowBox[{"504", "\[Rule]", "505"}], ",", 
       RowBox[{"504", "\[Rule]", "501"}], ",", 
       RowBox[{"180", "\[Rule]", "163"}], ",", 
       RowBox[{"180", "\[Rule]", "195"}], ",", 
       RowBox[{"180", "\[Rule]", "181"}], ",", 
       RowBox[{"180", "\[Rule]", "177"}], ",", 
       RowBox[{"1368", "\[Rule]", "1351"}], ",", 
       RowBox[{"1368", "\[Rule]", "1383"}], ",", 
       RowBox[{"1368", "\[Rule]", "1369"}], ",", 
       RowBox[{"1368", "\[Rule]", "1365"}], ",", 
       RowBox[{"1044", "\[Rule]", "1027"}], ",", 
       RowBox[{"1044", "\[Rule]", "1059"}], ",", 
       RowBox[{"1044", "\[Rule]", "1045"}], ",", 
       RowBox[{"1044", "\[Rule]", "1041"}], ",", 
       RowBox[{"46", "\[Rule]", "29"}], ",", 
       RowBox[{"46", "\[Rule]", "59"}], ",", 
       RowBox[{"46", "\[Rule]", "43"}], ",", 
       RowBox[{"58", "\[Rule]", "43"}], ",", 
       RowBox[{"58", "\[Rule]", "73"}], ",", 
       RowBox[{"58", "\[Rule]", "59"}], ",", 
       RowBox[{"58", "\[Rule]", "55"}], ",", 
       RowBox[{"910", "\[Rule]", "893"}], ",", 
       RowBox[{"910", "\[Rule]", "923"}], ",", 
       RowBox[{"910", "\[Rule]", "907"}], ",", 
       RowBox[{"922", "\[Rule]", "907"}], ",", 
       RowBox[{"922", "\[Rule]", "937"}], ",", 
       RowBox[{"922", "\[Rule]", "923"}], ",", 
       RowBox[{"922", "\[Rule]", "919"}], ",", 
       RowBox[{"72", "\[Rule]", "55"}], ",", 
       RowBox[{"72", "\[Rule]", "87"}], ",", 
       RowBox[{"72", "\[Rule]", "73"}], ",", 
       RowBox[{"72", "\[Rule]", "69"}], ",", 
       RowBox[{"936", "\[Rule]", "919"}], ",", 
       RowBox[{"936", "\[Rule]", "951"}], ",", 
       RowBox[{"936", "\[Rule]", "937"}], ",", 
       RowBox[{"936", "\[Rule]", "933"}], ",", 
       RowBox[{"752", "\[Rule]", "735"}], ",", 
       RowBox[{"752", "\[Rule]", "753"}], ",", 
       RowBox[{"752", "\[Rule]", "749"}], ",", 
       RowBox[{"320", "\[Rule]", "303"}], ",", 
       RowBox[{"320", "\[Rule]", "321"}], ",", 
       RowBox[{"320", "\[Rule]", "317"}], ",", 
       RowBox[{"1616", "\[Rule]", "1599"}], ",", 
       RowBox[{"1616", "\[Rule]", "1617"}], ",", 
       RowBox[{"1616", "\[Rule]", "1613"}], ",", 
       RowBox[{"1184", "\[Rule]", "1167"}], ",", 
       RowBox[{"1184", "\[Rule]", "1185"}], ",", 
       RowBox[{"1184", "\[Rule]", "1181"}], ",", 
       RowBox[{"734", "\[Rule]", "717"}], ",", 
       RowBox[{"734", "\[Rule]", "749"}], ",", 
       RowBox[{"734", "\[Rule]", "735"}], ",", 
       RowBox[{"734", "\[Rule]", "731"}], ",", 
       RowBox[{"626", "\[Rule]", "609"}], ",", 
       RowBox[{"626", "\[Rule]", "641"}], ",", 
       RowBox[{"626", "\[Rule]", "627"}], ",", 
       RowBox[{"626", "\[Rule]", "623"}], ",", 
       RowBox[{"302", "\[Rule]", "285"}], ",", 
       RowBox[{"302", "\[Rule]", "317"}], ",", 
       RowBox[{"302", "\[Rule]", "303"}], ",", 
       RowBox[{"302", "\[Rule]", "299"}], ",", 
       RowBox[{"1598", "\[Rule]", "1581"}], ",", 
       RowBox[{"1598", "\[Rule]", "1613"}], ",", 
       RowBox[{"1598", "\[Rule]", "1599"}], ",", 
       RowBox[{"1598", "\[Rule]", "1595"}], ",", 
       RowBox[{"1490", "\[Rule]", "1473"}], ",", 
       RowBox[{"1490", "\[Rule]", "1505"}], ",", 
       RowBox[{"1490", "\[Rule]", "1491"}], ",", 
       RowBox[{"1490", "\[Rule]", "1487"}], ",", 
       RowBox[{"1166", "\[Rule]", "1149"}], ",", 
       RowBox[{"1166", "\[Rule]", "1181"}], ",", 
       RowBox[{"1166", "\[Rule]", "1167"}], ",", 
       RowBox[{"1166", "\[Rule]", "1163"}], ",", 
       RowBox[{"518", "\[Rule]", "501"}], ",", 
       RowBox[{"518", "\[Rule]", "533"}], ",", 
       RowBox[{"518", "\[Rule]", "519"}], ",", 
       RowBox[{"518", "\[Rule]", "515"}], ",", 
       RowBox[{"194", "\[Rule]", "177"}], ",", 
       RowBox[{"194", "\[Rule]", "209"}], ",", 
       RowBox[{"194", "\[Rule]", "195"}], ",", 
       RowBox[{"194", "\[Rule]", "191"}], ",", 
       RowBox[{"1382", "\[Rule]", "1365"}], ",", 
       RowBox[{"1382", "\[Rule]", "1397"}], ",", 
       RowBox[{"1382", "\[Rule]", "1383"}], ",", 
       RowBox[{"1382", "\[Rule]", "1379"}], ",", 
       RowBox[{"1058", "\[Rule]", "1041"}], ",", 
       RowBox[{"1058", "\[Rule]", "1073"}], ",", 
       RowBox[{"1058", "\[Rule]", "1059"}], ",", 
       RowBox[{"1058", "\[Rule]", "1055"}], ",", 
       RowBox[{"86", "\[Rule]", "69"}], ",", 
       RowBox[{"86", "\[Rule]", "101"}], ",", 
       RowBox[{"86", "\[Rule]", "87"}], ",", 
       RowBox[{"86", "\[Rule]", "83"}], ",", 
       RowBox[{"950", "\[Rule]", "933"}], ",", 
       RowBox[{"950", "\[Rule]", "965"}], ",", 
       RowBox[{"950", "\[Rule]", "951"}], ",", 
       RowBox[{"950", "\[Rule]", "947"}], ",", 
       RowBox[{"2422", "\[Rule]", "2405"}], ",", 
       RowBox[{"2422", "\[Rule]", "2435"}], ",", 
       RowBox[{"2422", "\[Rule]", "2419"}], ",", 
       RowBox[{"2314", "\[Rule]", "2297"}], ",", 
       RowBox[{"2314", "\[Rule]", "2327"}], ",", 
       RowBox[{"2314", "\[Rule]", "2311"}], ",", 
       RowBox[{"1990", "\[Rule]", "1973"}], ",", 
       RowBox[{"1990", "\[Rule]", "2003"}], ",", 
       RowBox[{"1990", "\[Rule]", "1987"}], ",", 
       RowBox[{"2452", "\[Rule]", "2435"}], ",", 
       RowBox[{"2452", "\[Rule]", "2467"}], ",", 
       RowBox[{"2452", "\[Rule]", "2449"}], ",", 
       RowBox[{"2344", "\[Rule]", "2327"}], ",", 
       RowBox[{"2344", "\[Rule]", "2359"}], ",", 
       RowBox[{"2344", "\[Rule]", "2341"}], ",", 
       RowBox[{"2020", "\[Rule]", "2003"}], ",", 
       RowBox[{"2020", "\[Rule]", "2035"}], ",", 
       RowBox[{"2020", "\[Rule]", "2017"}], ",", 
       RowBox[{"2434", "\[Rule]", "2419"}], ",", 
       RowBox[{"2434", "\[Rule]", "2449"}], ",", 
       RowBox[{"2434", "\[Rule]", "2435"}], ",", 
       RowBox[{"2434", "\[Rule]", "2431"}], ",", 
       RowBox[{"2326", "\[Rule]", "2311"}], ",", 
       RowBox[{"2326", "\[Rule]", "2341"}], ",", 
       RowBox[{"2326", "\[Rule]", "2327"}], ",", 
       RowBox[{"2326", "\[Rule]", "2323"}], ",", 
       RowBox[{"2002", "\[Rule]", "1987"}], ",", 
       RowBox[{"2002", "\[Rule]", "2017"}], ",", 
       RowBox[{"2002", "\[Rule]", "2003"}], ",", 
       RowBox[{"2002", "\[Rule]", "1999"}], ",", 
       RowBox[{"2206", "\[Rule]", "2189"}], ",", 
       RowBox[{"2206", "\[Rule]", "2219"}], ",", 
       RowBox[{"2206", "\[Rule]", "2203"}], ",", 
       RowBox[{"1882", "\[Rule]", "1865"}], ",", 
       RowBox[{"1882", "\[Rule]", "1895"}], ",", 
       RowBox[{"1882", "\[Rule]", "1879"}], ",", 
       RowBox[{"2236", "\[Rule]", "2219"}], ",", 
       RowBox[{"2236", "\[Rule]", "2251"}], ",", 
       RowBox[{"2236", "\[Rule]", "2233"}], ",", 
       RowBox[{"1912", "\[Rule]", "1895"}], ",", 
       RowBox[{"1912", "\[Rule]", "1927"}], ",", 
       RowBox[{"1912", "\[Rule]", "1909"}], ",", 
       RowBox[{"2218", "\[Rule]", "2203"}], ",", 
       RowBox[{"2218", "\[Rule]", "2233"}], ",", 
       RowBox[{"2218", "\[Rule]", "2219"}], ",", 
       RowBox[{"2218", "\[Rule]", "2215"}], ",", 
       RowBox[{"1894", "\[Rule]", "1879"}], ",", 
       RowBox[{"1894", "\[Rule]", "1909"}], ",", 
       RowBox[{"1894", "\[Rule]", "1895"}], ",", 
       RowBox[{"1894", "\[Rule]", "1891"}], ",", 
       RowBox[{"2484", "\[Rule]", "2467"}], ",", 
       RowBox[{"2484", "\[Rule]", "2481"}], ",", 
       RowBox[{"2376", "\[Rule]", "2359"}], ",", 
       RowBox[{"2376", "\[Rule]", "2373"}], ",", 
       RowBox[{"2052", "\[Rule]", "2035"}], ",", 
       RowBox[{"2052", "\[Rule]", "2049"}], ",", 
       RowBox[{"2466", "\[Rule]", "2449"}], ",", 
       RowBox[{"2466", "\[Rule]", "2481"}], ",", 
       RowBox[{"2466", "\[Rule]", "2467"}], ",", 
       RowBox[{"2466", "\[Rule]", "2463"}], ",", 
       RowBox[{"2358", "\[Rule]", "2341"}], ",", 
       RowBox[{"2358", "\[Rule]", "2373"}], ",", 
       RowBox[{"2358", "\[Rule]", "2359"}], ",", 
       RowBox[{"2358", "\[Rule]", "2355"}], ",", 
       RowBox[{"2034", "\[Rule]", "2017"}], ",", 
       RowBox[{"2034", "\[Rule]", "2049"}], ",", 
       RowBox[{"2034", "\[Rule]", "2035"}], ",", 
       RowBox[{"2034", "\[Rule]", "2031"}], ",", 
       RowBox[{"2268", "\[Rule]", "2251"}], ",", 
       RowBox[{"2268", "\[Rule]", "2265"}], ",", 
       RowBox[{"1944", "\[Rule]", "1927"}], ",", 
       RowBox[{"1944", "\[Rule]", "1941"}], ",", 
       RowBox[{"2250", "\[Rule]", "2233"}], ",", 
       RowBox[{"2250", "\[Rule]", "2265"}], ",", 
       RowBox[{"2250", "\[Rule]", "2251"}], ",", 
       RowBox[{"2250", "\[Rule]", "2247"}], ",", 
       RowBox[{"1926", "\[Rule]", "1909"}], ",", 
       RowBox[{"1926", "\[Rule]", "1941"}], ",", 
       RowBox[{"1926", "\[Rule]", "1927"}], ",", 
       RowBox[{"1926", "\[Rule]", "1923"}], ",", 
       RowBox[{"2448", "\[Rule]", "2431"}], ",", 
       RowBox[{"2448", "\[Rule]", "2463"}], ",", 
       RowBox[{"2448", "\[Rule]", "2449"}], ",", 
       RowBox[{"2448", "\[Rule]", "2445"}], ",", 
       RowBox[{"2340", "\[Rule]", "2323"}], ",", 
       RowBox[{"2340", "\[Rule]", "2355"}], ",", 
       RowBox[{"2340", "\[Rule]", "2341"}], ",", 
       RowBox[{"2340", "\[Rule]", "2337"}], ",", 
       RowBox[{"2016", "\[Rule]", "1999"}], ",", 
       RowBox[{"2016", "\[Rule]", "2031"}], ",", 
       RowBox[{"2016", "\[Rule]", "2017"}], ",", 
       RowBox[{"2016", "\[Rule]", "2013"}], ",", 
       RowBox[{"2232", "\[Rule]", "2215"}], ",", 
       RowBox[{"2232", "\[Rule]", "2247"}], ",", 
       RowBox[{"2232", "\[Rule]", "2233"}], ",", 
       RowBox[{"2232", "\[Rule]", "2229"}], ",", 
       RowBox[{"1908", "\[Rule]", "1891"}], ",", 
       RowBox[{"1908", "\[Rule]", "1923"}], ",", 
       RowBox[{"1908", "\[Rule]", "1909"}], ",", 
       RowBox[{"1908", "\[Rule]", "1905"}], ",", 
       RowBox[{"1774", "\[Rule]", "1757"}], ",", 
       RowBox[{"1774", "\[Rule]", "1787"}], ",", 
       RowBox[{"1774", "\[Rule]", "1771"}], ",", 
       RowBox[{"1804", "\[Rule]", "1787"}], ",", 
       RowBox[{"1804", "\[Rule]", "1819"}], ",", 
       RowBox[{"1804", "\[Rule]", "1801"}], ",", 
       RowBox[{"1786", "\[Rule]", "1771"}], ",", 
       RowBox[{"1786", "\[Rule]", "1801"}], ",", 
       RowBox[{"1786", "\[Rule]", "1787"}], ",", 
       RowBox[{"1786", "\[Rule]", "1783"}], ",", 
       RowBox[{"1836", "\[Rule]", "1819"}], ",", 
       RowBox[{"1836", "\[Rule]", "1833"}], ",", 
       RowBox[{"1818", "\[Rule]", "1801"}], ",", 
       RowBox[{"1818", "\[Rule]", "1833"}], ",", 
       RowBox[{"1818", "\[Rule]", "1819"}], ",", 
       RowBox[{"1818", "\[Rule]", "1815"}], ",", 
       RowBox[{"1800", "\[Rule]", "1783"}], ",", 
       RowBox[{"1800", "\[Rule]", "1815"}], ",", 
       RowBox[{"1800", "\[Rule]", "1801"}], ",", 
       RowBox[{"1800", "\[Rule]", "1797"}], ",", 
       RowBox[{"2480", "\[Rule]", "2463"}], ",", 
       RowBox[{"2480", "\[Rule]", "2481"}], ",", 
       RowBox[{"2480", "\[Rule]", "2477"}], ",", 
       RowBox[{"2372", "\[Rule]", "2355"}], ",", 
       RowBox[{"2372", "\[Rule]", "2373"}], ",", 
       RowBox[{"2372", "\[Rule]", "2369"}], ",", 
       RowBox[{"2048", "\[Rule]", "2031"}], ",", 
       RowBox[{"2048", "\[Rule]", "2049"}], ",", 
       RowBox[{"2048", "\[Rule]", "2045"}], ",", 
       RowBox[{"2264", "\[Rule]", "2247"}], ",", 
       RowBox[{"2264", "\[Rule]", "2265"}], ",", 
       RowBox[{"2264", "\[Rule]", "2261"}], ",", 
       RowBox[{"1940", "\[Rule]", "1923"}], ",", 
       RowBox[{"1940", "\[Rule]", "1941"}], ",", 
       RowBox[{"1940", "\[Rule]", "1937"}], ",", 
       RowBox[{"1832", "\[Rule]", "1815"}], ",", 
       RowBox[{"1832", "\[Rule]", "1833"}], ",", 
       RowBox[{"1832", "\[Rule]", "1829"}], ",", 
       RowBox[{"2462", "\[Rule]", "2445"}], ",", 
       RowBox[{"2462", "\[Rule]", "2477"}], ",", 
       RowBox[{"2462", "\[Rule]", "2463"}], ",", 
       RowBox[{"2462", "\[Rule]", "2459"}], ",", 
       RowBox[{"2354", "\[Rule]", "2337"}], ",", 
       RowBox[{"2354", "\[Rule]", "2369"}], ",", 
       RowBox[{"2354", "\[Rule]", "2355"}], ",", 
       RowBox[{"2354", "\[Rule]", "2351"}], ",", 
       RowBox[{"2030", "\[Rule]", "2013"}], ",", 
       RowBox[{"2030", "\[Rule]", "2045"}], ",", 
       RowBox[{"2030", "\[Rule]", "2031"}], ",", 
       RowBox[{"2030", "\[Rule]", "2027"}], ",", 
       RowBox[{"2246", "\[Rule]", "2229"}], ",", 
       RowBox[{"2246", "\[Rule]", "2261"}], ",", 
       RowBox[{"2246", "\[Rule]", "2247"}], ",", 
       RowBox[{"2246", "\[Rule]", "2243"}], ",", 
       RowBox[{"1922", "\[Rule]", "1905"}], ",", 
       RowBox[{"1922", "\[Rule]", "1937"}], ",", 
       RowBox[{"1922", "\[Rule]", "1923"}], ",", 
       RowBox[{"1922", "\[Rule]", "1919"}], ",", 
       RowBox[{"1814", "\[Rule]", "1797"}], ",", 
       RowBox[{"1814", "\[Rule]", "1829"}], ",", 
       RowBox[{"1814", "\[Rule]", "1815"}], ",", 
       RowBox[{"1814", "\[Rule]", "1811"}], ",", 
       RowBox[{"748", "\[Rule]", "731"}], ",", 
       RowBox[{"748", "\[Rule]", "749"}], ",", 
       RowBox[{"748", "\[Rule]", "745"}], ",", 
       RowBox[{"640", "\[Rule]", "623"}], ",", 
       RowBox[{"640", "\[Rule]", "641"}], ",", 
       RowBox[{"640", "\[Rule]", "637"}], ",", 
       RowBox[{"316", "\[Rule]", "299"}], ",", 
       RowBox[{"316", "\[Rule]", "317"}], ",", 
       RowBox[{"316", "\[Rule]", "313"}], ",", 
       RowBox[{"1612", "\[Rule]", "1595"}], ",", 
       RowBox[{"1612", "\[Rule]", "1613"}], ",", 
       RowBox[{"1612", "\[Rule]", "1609"}], ",", 
       RowBox[{"1504", "\[Rule]", "1487"}], ",", 
       RowBox[{"1504", "\[Rule]", "1505"}], ",", 
       RowBox[{"1504", "\[Rule]", "1501"}], ",", 
       RowBox[{"1180", "\[Rule]", "1163"}], ",", 
       RowBox[{"1180", "\[Rule]", "1181"}], ",", 
       RowBox[{"1180", "\[Rule]", "1177"}], ",", 
       RowBox[{"532", "\[Rule]", "515"}], ",", 
       RowBox[{"532", "\[Rule]", "533"}], ",", 
       RowBox[{"532", "\[Rule]", "529"}], ",", 
       RowBox[{"208", "\[Rule]", "191"}], ",", 
       RowBox[{"208", "\[Rule]", "209"}], ",", 
       RowBox[{"208", "\[Rule]", "205"}], ",", 
       RowBox[{"1396", "\[Rule]", "1379"}], ",", 
       RowBox[{"1396", "\[Rule]", "1397"}], ",", 
       RowBox[{"1396", "\[Rule]", "1393"}], ",", 
       RowBox[{"1072", "\[Rule]", "1055"}], ",", 
       RowBox[{"1072", "\[Rule]", "1073"}], ",", 
       RowBox[{"1072", "\[Rule]", "1069"}], ",", 
       RowBox[{"100", "\[Rule]", "83"}], ",", 
       RowBox[{"100", "\[Rule]", "101"}], ",", 
       RowBox[{"100", "\[Rule]", "97"}], ",", 
       RowBox[{"964", "\[Rule]", "947"}], ",", 
       RowBox[{"964", "\[Rule]", "965"}], ",", 
       RowBox[{"964", "\[Rule]", "961"}], ",", 
       RowBox[{"2476", "\[Rule]", "2459"}], ",", 
       RowBox[{"2476", "\[Rule]", "2477"}], ",", 
       RowBox[{"2476", "\[Rule]", "2473"}], ",", 
       RowBox[{"2368", "\[Rule]", "2351"}], ",", 
       RowBox[{"2368", "\[Rule]", "2369"}], ",", 
       RowBox[{"2368", "\[Rule]", "2365"}], ",", 
       RowBox[{"2044", "\[Rule]", "2027"}], ",", 
       RowBox[{"2044", "\[Rule]", "2045"}], ",", 
       RowBox[{"2044", "\[Rule]", "2041"}], ",", 
       RowBox[{"2260", "\[Rule]", "2243"}], ",", 
       RowBox[{"2260", "\[Rule]", "2261"}], ",", 
       RowBox[{"2260", "\[Rule]", "2257"}], ",", 
       RowBox[{"1936", "\[Rule]", "1919"}], ",", 
       RowBox[{"1936", "\[Rule]", "1937"}], ",", 
       RowBox[{"1936", "\[Rule]", "1933"}], ",", 
       RowBox[{"1828", "\[Rule]", "1811"}], ",", 
       RowBox[{"1828", "\[Rule]", "1829"}], ",", 
       RowBox[{"1828", "\[Rule]", "1825"}], ",", 
       RowBox[{"677", "\[Rule]", "354"}], ",", 
       RowBox[{"677", "\[Rule]", "354"}], ",", 
       RowBox[{"677", "\[Rule]", "1218"}], ",", 
       RowBox[{"677", "\[Rule]", "1218"}], ",", 
       RowBox[{"677", "\[Rule]", "246"}], ",", 
       RowBox[{"677", "\[Rule]", "246"}], ",", 
       RowBox[{"677", "\[Rule]", "1110"}], ",", 
       RowBox[{"677", "\[Rule]", "1110"}], ",", 
       RowBox[{"677", "\[Rule]", "678"}], ",", 
       RowBox[{"707", "\[Rule]", "384"}], ",", 
       RowBox[{"707", "\[Rule]", "384"}], ",", 
       RowBox[{"707", "\[Rule]", "1248"}], ",", 
       RowBox[{"707", "\[Rule]", "1248"}], ",", 
       RowBox[{"707", "\[Rule]", "276"}], ",", 
       RowBox[{"707", "\[Rule]", "276"}], ",", 
       RowBox[{"707", "\[Rule]", "1140"}], ",", 
       RowBox[{"707", "\[Rule]", "1140"}], ",", 
       RowBox[{"707", "\[Rule]", "708"}], ",", 
       RowBox[{"691", "\[Rule]", "368"}], ",", 
       RowBox[{"691", "\[Rule]", "368"}], ",", 
       RowBox[{"691", "\[Rule]", "1232"}], ",", 
       RowBox[{"691", "\[Rule]", "1232"}], ",", 
       RowBox[{"691", "\[Rule]", "260"}], ",", 
       RowBox[{"691", "\[Rule]", "260"}], ",", 
       RowBox[{"691", "\[Rule]", "1124"}], ",", 
       RowBox[{"691", "\[Rule]", "1124"}], ",", 
       RowBox[{"691", "\[Rule]", "692"}], ",", 
       RowBox[{"569", "\[Rule]", "246"}], ",", 
       RowBox[{"569", "\[Rule]", "246"}], ",", 
       RowBox[{"569", "\[Rule]", "1110"}], ",", 
       RowBox[{"569", "\[Rule]", "1110"}], ",", 
       RowBox[{"569", "\[Rule]", "138"}], ",", 
       RowBox[{"569", "\[Rule]", "1002"}], ",", 
       RowBox[{"569", "\[Rule]", "570"}], ",", 
       RowBox[{"583", "\[Rule]", "260"}], ",", 
       RowBox[{"583", "\[Rule]", "260"}], ",", 
       RowBox[{"583", "\[Rule]", "1124"}], ",", 
       RowBox[{"583", "\[Rule]", "1124"}], ",", 
       RowBox[{"583", "\[Rule]", "152"}], ",", 
       RowBox[{"583", "\[Rule]", "1016"}], ",", 
       RowBox[{"583", "\[Rule]", "584"}], ",", 
       RowBox[{"245", "\[Rule]", "678"}], ",", 
       RowBox[{"245", "\[Rule]", "678"}], ",", 
       RowBox[{"245", "\[Rule]", "570"}], ",", 
       RowBox[{"245", "\[Rule]", "570"}], ",", 
       RowBox[{"245", "\[Rule]", "246"}], ",", 
       RowBox[{"275", "\[Rule]", "708"}], ",", 
       RowBox[{"275", "\[Rule]", "708"}], ",", 
       RowBox[{"275", "\[Rule]", "600"}], ",", 
       RowBox[{"275", "\[Rule]", "600"}], ",", 
       RowBox[{"275", "\[Rule]", "276"}], ",", 
       RowBox[{"259", "\[Rule]", "692"}], ",", 
       RowBox[{"259", "\[Rule]", "692"}], ",", 
       RowBox[{"259", "\[Rule]", "584"}], ",", 
       RowBox[{"259", "\[Rule]", "584"}], ",", 
       RowBox[{"259", "\[Rule]", "260"}], ",", 
       RowBox[{"739", "\[Rule]", "416"}], ",", 
       RowBox[{"739", "\[Rule]", "416"}], ",", 
       RowBox[{"739", "\[Rule]", "1280"}], ",", 
       RowBox[{"739", "\[Rule]", "1280"}], ",", 
       RowBox[{"739", "\[Rule]", "308"}], ",", 
       RowBox[{"739", "\[Rule]", "308"}], ",", 
       RowBox[{"739", "\[Rule]", "1172"}], ",", 
       RowBox[{"739", "\[Rule]", "1172"}], ",", 
       RowBox[{"739", "\[Rule]", "740"}], ",", 
       RowBox[{"721", "\[Rule]", "398"}], ",", 
       RowBox[{"721", "\[Rule]", "398"}], ",", 
       RowBox[{"721", "\[Rule]", "1262"}], ",", 
       RowBox[{"721", "\[Rule]", "1262"}], ",", 
       RowBox[{"721", "\[Rule]", "290"}], ",", 
       RowBox[{"721", "\[Rule]", "290"}], ",", 
       RowBox[{"721", "\[Rule]", "1154"}], ",", 
       RowBox[{"721", "\[Rule]", "1154"}], ",", 
       RowBox[{"721", "\[Rule]", "722"}], ",", 
       RowBox[{"307", "\[Rule]", "740"}], ",", 
       RowBox[{"307", "\[Rule]", "740"}], ",", 
       RowBox[{"307", "\[Rule]", "632"}], ",", 
       RowBox[{"307", "\[Rule]", "632"}], ",", 
       RowBox[{"307", "\[Rule]", "308"}], ",", 
       RowBox[{"289", "\[Rule]", "722"}], ",", 
       RowBox[{"289", "\[Rule]", "722"}], ",", 
       RowBox[{"289", "\[Rule]", "614"}], ",", 
       RowBox[{"289", "\[Rule]", "614"}], ",", 
       RowBox[{"289", "\[Rule]", "290"}], ",", 
       RowBox[{"703", "\[Rule]", "380"}], ",", 
       RowBox[{"703", "\[Rule]", "380"}], ",", 
       RowBox[{"703", "\[Rule]", "1244"}], ",", 
       RowBox[{"703", "\[Rule]", "1244"}], ",", 
       RowBox[{"703", "\[Rule]", "272"}], ",", 
       RowBox[{"703", "\[Rule]", "272"}], ",", 
       RowBox[{"703", "\[Rule]", "1136"}], ",", 
       RowBox[{"703", "\[Rule]", "1136"}], ",", 
       RowBox[{"703", "\[Rule]", "704"}], ",", 
       RowBox[{"595", "\[Rule]", "272"}], ",", 
       RowBox[{"595", "\[Rule]", "272"}], ",", 
       RowBox[{"595", "\[Rule]", "1136"}], ",", 
       RowBox[{"595", "\[Rule]", "1136"}], ",", 
       RowBox[{"595", "\[Rule]", "164"}], ",", 
       RowBox[{"595", "\[Rule]", "1028"}], ",", 
       RowBox[{"595", "\[Rule]", "596"}], ",", 
       RowBox[{"271", "\[Rule]", "704"}], ",", 
       RowBox[{"271", "\[Rule]", "704"}], ",", 
       RowBox[{"271", "\[Rule]", "596"}], ",", 
       RowBox[{"271", "\[Rule]", "596"}], ",", 
       RowBox[{"271", "\[Rule]", "272"}], ",", 
       RowBox[{"1541", "\[Rule]", "1218"}], ",", 
       RowBox[{"1541", "\[Rule]", "1218"}], ",", 
       RowBox[{"1541", "\[Rule]", "2082"}], ",", 
       RowBox[{"1541", "\[Rule]", "2082"}], ",", 
       RowBox[{"1541", "\[Rule]", "1110"}], ",", 
       RowBox[{"1541", "\[Rule]", "1110"}], ",", 
       RowBox[{"1541", "\[Rule]", "1974"}], ",", 
       RowBox[{"1541", "\[Rule]", "1974"}], ",", 
       RowBox[{"1541", "\[Rule]", "1542"}], ",", 
       RowBox[{"1571", "\[Rule]", "1248"}], ",", 
       RowBox[{"1571", "\[Rule]", "1248"}], ",", 
       RowBox[{"1571", "\[Rule]", "2112"}], ",", 
       RowBox[{"1571", "\[Rule]", "2112"}], ",", 
       RowBox[{"1571", "\[Rule]", "1140"}], ",", 
       RowBox[{"1571", "\[Rule]", "1140"}], ",", 
       RowBox[{"1571", "\[Rule]", "2004"}], ",", 
       RowBox[{"1571", "\[Rule]", "2004"}], ",", 
       RowBox[{"1571", "\[Rule]", "1572"}], ",", 
       RowBox[{"1555", "\[Rule]", "1232"}], ",", 
       RowBox[{"1555", "\[Rule]", "1232"}], ",", 
       RowBox[{"1555", "\[Rule]", "2096"}], ",", 
       RowBox[{"1555", "\[Rule]", "2096"}], ",", 
       RowBox[{"1555", "\[Rule]", "1124"}], ",", 
       RowBox[{"1555", "\[Rule]", "1124"}], ",", 
       RowBox[{"1555", "\[Rule]", "1988"}], ",", 
       RowBox[{"1555", "\[Rule]", "1988"}], ",", 
       RowBox[{"1555", "\[Rule]", "1556"}], ",", 
       RowBox[{"1433", "\[Rule]", "1110"}], ",", 
       RowBox[{"1433", "\[Rule]", "1110"}], ",", 
       RowBox[{"1433", "\[Rule]", "1974"}], ",", 
       RowBox[{"1433", "\[Rule]", "1974"}], ",", 
       RowBox[{"1433", "\[Rule]", "1002"}], ",", 
       RowBox[{"1433", "\[Rule]", "1002"}], ",", 
       RowBox[{"1433", "\[Rule]", "1866"}], ",", 
       RowBox[{"1433", "\[Rule]", "1866"}], ",", 
       RowBox[{"1433", "\[Rule]", "1434"}], ",", 
       RowBox[{"1447", "\[Rule]", "1124"}], ",", 
       RowBox[{"1447", "\[Rule]", "1124"}], ",", 
       RowBox[{"1447", "\[Rule]", "1988"}], ",", 
       RowBox[{"1447", "\[Rule]", "1988"}], ",", 
       RowBox[{"1447", "\[Rule]", "1016"}], ",", 
       RowBox[{"1447", "\[Rule]", "1016"}], ",", 
       RowBox[{"1447", "\[Rule]", "1880"}], ",", 
       RowBox[{"1447", "\[Rule]", "1880"}], ",", 
       RowBox[{"1447", "\[Rule]", "1448"}], ",", 
       RowBox[{"1109", "\[Rule]", "678"}], ",", 
       RowBox[{"1109", "\[Rule]", "678"}], ",", 
       RowBox[{"1109", "\[Rule]", "1542"}], ",", 
       RowBox[{"1109", "\[Rule]", "1542"}], ",", 
       RowBox[{"1109", "\[Rule]", "570"}], ",", 
       RowBox[{"1109", "\[Rule]", "570"}], ",", 
       RowBox[{"1109", "\[Rule]", "1434"}], ",", 
       RowBox[{"1109", "\[Rule]", "1434"}], ",", 
       RowBox[{"1109", "\[Rule]", "1110"}], ",", 
       RowBox[{"1139", "\[Rule]", "708"}], ",", 
       RowBox[{"1139", "\[Rule]", "708"}], ",", 
       RowBox[{"1139", "\[Rule]", "1572"}], ",", 
       RowBox[{"1139", "\[Rule]", "1572"}], ",", 
       RowBox[{"1139", "\[Rule]", "600"}], ",", 
       RowBox[{"1139", "\[Rule]", "600"}], ",", 
       RowBox[{"1139", "\[Rule]", "1464"}], ",", 
       RowBox[{"1139", "\[Rule]", "1464"}], ",", 
       RowBox[{"1139", "\[Rule]", "1140"}], ",", 
       RowBox[{"1123", "\[Rule]", "692"}], ",", 
       RowBox[{"1123", "\[Rule]", "692"}], ",", 
       RowBox[{"1123", "\[Rule]", "1556"}], ",", 
       RowBox[{"1123", "\[Rule]", "1556"}], ",", 
       RowBox[{"1123", "\[Rule]", "584"}], ",", 
       RowBox[{"1123", "\[Rule]", "584"}], ",", 
       RowBox[{"1123", "\[Rule]", "1448"}], ",", 
       RowBox[{"1123", "\[Rule]", "1448"}], ",", 
       RowBox[{"1123", "\[Rule]", "1124"}], ",", 
       RowBox[{"1603", "\[Rule]", "1280"}], ",", 
       RowBox[{"1603", "\[Rule]", "1280"}], ",", 
       RowBox[{"1603", "\[Rule]", "2144"}], ",", 
       RowBox[{"1603", "\[Rule]", "2144"}], ",", 
       RowBox[{"1603", "\[Rule]", "1172"}], ",", 
       RowBox[{"1603", "\[Rule]", "1172"}], ",", 
       RowBox[{"1603", "\[Rule]", "2036"}], ",", 
       RowBox[{"1603", "\[Rule]", "2036"}], ",", 
       RowBox[{"1603", "\[Rule]", "1604"}], ",", 
       RowBox[{"1585", "\[Rule]", "1262"}], ",", 
       RowBox[{"1585", "\[Rule]", "1262"}], ",", 
       RowBox[{"1585", "\[Rule]", "2126"}], ",", 
       RowBox[{"1585", "\[Rule]", "2126"}], ",", 
       RowBox[{"1585", "\[Rule]", "1154"}], ",", 
       RowBox[{"1585", "\[Rule]", "1154"}], ",", 
       RowBox[{"1585", "\[Rule]", "2018"}], ",", 
       RowBox[{"1585", "\[Rule]", "2018"}], ",", 
       RowBox[{"1585", "\[Rule]", "1586"}], ",", 
       RowBox[{"1171", "\[Rule]", "740"}], ",", 
       RowBox[{"1171", "\[Rule]", "740"}], ",", 
       RowBox[{"1171", "\[Rule]", "1604"}], ",", 
       RowBox[{"1171", "\[Rule]", "1604"}], ",", 
       RowBox[{"1171", "\[Rule]", "632"}], ",", 
       RowBox[{"1171", "\[Rule]", "632"}], ",", 
       RowBox[{"1171", "\[Rule]", "1496"}], ",", 
       RowBox[{"1171", "\[Rule]", "1496"}], ",", 
       RowBox[{"1171", "\[Rule]", "1172"}], ",", 
       RowBox[{"1153", "\[Rule]", "722"}], ",", 
       RowBox[{"1153", "\[Rule]", "722"}], ",", 
       RowBox[{"1153", "\[Rule]", "1586"}], ",", 
       RowBox[{"1153", "\[Rule]", "1586"}], ",", 
       RowBox[{"1153", "\[Rule]", "614"}], ",", 
       RowBox[{"1153", "\[Rule]", "614"}], ",", 
       RowBox[{"1153", "\[Rule]", "1478"}], ",", 
       RowBox[{"1153", "\[Rule]", "1478"}], ",", 
       RowBox[{"1153", "\[Rule]", "1154"}], ",", 
       RowBox[{"1567", "\[Rule]", "1244"}], ",", 
       RowBox[{"1567", "\[Rule]", "1244"}], ",", 
       RowBox[{"1567", "\[Rule]", "2108"}], ",", 
       RowBox[{"1567", "\[Rule]", "2108"}], ",", 
       RowBox[{"1567", "\[Rule]", "1136"}], ",", 
       RowBox[{"1567", "\[Rule]", "1136"}], ",", 
       RowBox[{"1567", "\[Rule]", "2000"}], ",", 
       RowBox[{"1567", "\[Rule]", "2000"}], ",", 
       RowBox[{"1567", "\[Rule]", "1568"}], ",", 
       RowBox[{"1459", "\[Rule]", "1136"}], ",", 
       RowBox[{"1459", "\[Rule]", "1136"}], ",", 
       RowBox[{"1459", "\[Rule]", "2000"}], ",", 
       RowBox[{"1459", "\[Rule]", "2000"}], ",", 
       RowBox[{"1459", "\[Rule]", "1028"}], ",", 
       RowBox[{"1459", "\[Rule]", "1028"}], ",", 
       RowBox[{"1459", "\[Rule]", "1892"}], ",", 
       RowBox[{"1459", "\[Rule]", "1892"}], ",", 
       RowBox[{"1459", "\[Rule]", "1460"}], ",", 
       RowBox[{"1135", "\[Rule]", "704"}], ",", 
       RowBox[{"1135", "\[Rule]", "704"}], ",", 
       RowBox[{"1135", "\[Rule]", "1568"}], ",", 
       RowBox[{"1135", "\[Rule]", "1568"}], ",", 
       RowBox[{"1135", "\[Rule]", "596"}], ",", 
       RowBox[{"1135", "\[Rule]", "596"}], ",", 
       RowBox[{"1135", "\[Rule]", "1460"}], ",", 
       RowBox[{"1135", "\[Rule]", "1460"}], ",", 
       RowBox[{"1135", "\[Rule]", "1136"}], ",", 
       RowBox[{"461", "\[Rule]", "138"}], ",", 
       RowBox[{"461", "\[Rule]", "1002"}], ",", 
       RowBox[{"461", "\[Rule]", "30"}], ",", 
       RowBox[{"461", "\[Rule]", "30"}], ",", 
       RowBox[{"461", "\[Rule]", "894"}], ",", 
       RowBox[{"461", "\[Rule]", "894"}], ",", 
       RowBox[{"461", "\[Rule]", "462"}], ",", 
       RowBox[{"475", "\[Rule]", "152"}], ",", 
       RowBox[{"475", "\[Rule]", "1016"}], ",", 
       RowBox[{"475", "\[Rule]", "44"}], ",", 
       RowBox[{"475", "\[Rule]", "44"}], ",", 
       RowBox[{"475", "\[Rule]", "908"}], ",", 
       RowBox[{"475", "\[Rule]", "908"}], ",", 
       RowBox[{"475", "\[Rule]", "476"}], ",", 
       RowBox[{"137", "\[Rule]", "570"}], ",", 
       RowBox[{"137", "\[Rule]", "462"}], ",", 
       RowBox[{"137", "\[Rule]", "138"}], ",", 
       RowBox[{"151", "\[Rule]", "584"}], ",", 
       RowBox[{"151", "\[Rule]", "476"}], ",", 
       RowBox[{"151", "\[Rule]", "152"}], ",", 
       RowBox[{"487", "\[Rule]", "164"}], ",", 
       RowBox[{"487", "\[Rule]", "1028"}], ",", 
       RowBox[{"487", "\[Rule]", "56"}], ",", 
       RowBox[{"487", "\[Rule]", "56"}], ",", 
       RowBox[{"487", "\[Rule]", "920"}], ",", 
       RowBox[{"487", "\[Rule]", "920"}], ",", 
       RowBox[{"487", "\[Rule]", "488"}], ",", 
       RowBox[{"163", "\[Rule]", "596"}], ",", 
       RowBox[{"163", "\[Rule]", "488"}], ",", 
       RowBox[{"163", "\[Rule]", "164"}], ",", 
       RowBox[{"1325", "\[Rule]", "1002"}], ",", 
       RowBox[{"1325", "\[Rule]", "1002"}], ",", 
       RowBox[{"1325", "\[Rule]", "1866"}], ",", 
       RowBox[{"1325", "\[Rule]", "1866"}], ",", 
       RowBox[{"1325", "\[Rule]", "894"}], ",", 
       RowBox[{"1325", "\[Rule]", "1758"}], ",", 
       RowBox[{"1325", "\[Rule]", "1326"}], ",", 
       RowBox[{"1339", "\[Rule]", "1016"}], ",", 
       RowBox[{"1339", "\[Rule]", "1016"}], ",", 
       RowBox[{"1339", "\[Rule]", "1880"}], ",", 
       RowBox[{"1339", "\[Rule]", "1880"}], ",", 
       RowBox[{"1339", "\[Rule]", "908"}], ",", 
       RowBox[{"1339", "\[Rule]", "1772"}], ",", 
       RowBox[{"1339", "\[Rule]", "1340"}], ",", 
       RowBox[{"1001", "\[Rule]", "570"}], ",", 
       RowBox[{"1001", "\[Rule]", "1434"}], ",", 
       RowBox[{"1001", "\[Rule]", "1434"}], ",", 
       RowBox[{"1001", "\[Rule]", "462"}], ",", 
       RowBox[{"1001", "\[Rule]", "1326"}], ",", 
       RowBox[{"1001", "\[Rule]", "1326"}], ",", 
       RowBox[{"1001", "\[Rule]", "1002"}], ",", 
       RowBox[{"1015", "\[Rule]", "584"}], ",", 
       RowBox[{"1015", "\[Rule]", "1448"}], ",", 
       RowBox[{"1015", "\[Rule]", "1448"}], ",", 
       RowBox[{"1015", "\[Rule]", "476"}], ",", 
       RowBox[{"1015", "\[Rule]", "1340"}], ",", 
       RowBox[{"1015", "\[Rule]", "1340"}], ",", 
       RowBox[{"1015", "\[Rule]", "1016"}], ",", 
       RowBox[{"1351", "\[Rule]", "1028"}], ",", 
       RowBox[{"1351", "\[Rule]", "1028"}], ",", 
       RowBox[{"1351", "\[Rule]", "1892"}], ",", 
       RowBox[{"1351", "\[Rule]", "1892"}], ",", 
       RowBox[{"1351", "\[Rule]", "920"}], ",", 
       RowBox[{"1351", "\[Rule]", "1784"}], ",", 
       RowBox[{"1351", "\[Rule]", "1352"}], ",", 
       RowBox[{"1027", "\[Rule]", "596"}], ",", 
       RowBox[{"1027", "\[Rule]", "1460"}], ",", 
       RowBox[{"1027", "\[Rule]", "1460"}], ",", 
       RowBox[{"1027", "\[Rule]", "488"}], ",", 
       RowBox[{"1027", "\[Rule]", "1352"}], ",", 
       RowBox[{"1027", "\[Rule]", "1352"}], ",", 
       RowBox[{"1027", "\[Rule]", "1028"}], ",", 
       RowBox[{"753", "\[Rule]", "430"}], ",", 
       RowBox[{"753", "\[Rule]", "430"}], ",", 
       RowBox[{"753", "\[Rule]", "1294"}], ",", 
       RowBox[{"753", "\[Rule]", "1294"}], ",", 
       RowBox[{"753", "\[Rule]", "322"}], ",", 
       RowBox[{"753", "\[Rule]", "322"}], ",", 
       RowBox[{"753", "\[Rule]", "1186"}], ",", 
       RowBox[{"753", "\[Rule]", "1186"}], ",", 
       RowBox[{"753", "\[Rule]", "754"}], ",", 
       RowBox[{"321", "\[Rule]", "754"}], ",", 
       RowBox[{"321", "\[Rule]", "754"}], ",", 
       RowBox[{"321", "\[Rule]", "646"}], ",", 
       RowBox[{"321", "\[Rule]", "646"}], ",", 
       RowBox[{"321", "\[Rule]", "322"}], ",", 
       RowBox[{"735", "\[Rule]", "412"}], ",", 
       RowBox[{"735", "\[Rule]", "412"}], ",", 
       RowBox[{"735", "\[Rule]", "1276"}], ",", 
       RowBox[{"735", "\[Rule]", "1276"}], ",", 
       RowBox[{"735", "\[Rule]", "304"}], ",", 
       RowBox[{"735", "\[Rule]", "304"}], ",", 
       RowBox[{"735", "\[Rule]", "1168"}], ",", 
       RowBox[{"735", "\[Rule]", "1168"}], ",", 
       RowBox[{"735", "\[Rule]", "736"}], ",", 
       RowBox[{"303", "\[Rule]", "736"}], ",", 
       RowBox[{"303", "\[Rule]", "736"}], ",", 
       RowBox[{"303", "\[Rule]", "628"}], ",", 
       RowBox[{"303", "\[Rule]", "628"}], ",", 
       RowBox[{"303", "\[Rule]", "304"}], ",", 
       RowBox[{"1617", "\[Rule]", "1294"}], ",", 
       RowBox[{"1617", "\[Rule]", "1294"}], ",", 
       RowBox[{"1617", "\[Rule]", "2158"}], ",", 
       RowBox[{"1617", "\[Rule]", "2158"}], ",", 
       RowBox[{"1617", "\[Rule]", "1186"}], ",", 
       RowBox[{"1617", "\[Rule]", "1186"}], ",", 
       RowBox[{"1617", "\[Rule]", "2050"}], ",", 
       RowBox[{"1617", "\[Rule]", "2050"}], ",", 
       RowBox[{"1617", "\[Rule]", "1618"}], ",", 
       RowBox[{"1185", "\[Rule]", "754"}], ",", 
       RowBox[{"1185", "\[Rule]", "754"}], ",", 
       RowBox[{"1185", "\[Rule]", "1618"}], ",", 
       RowBox[{"1185", "\[Rule]", "1618"}], ",", 
       RowBox[{"1185", "\[Rule]", "646"}], ",", 
       RowBox[{"1185", "\[Rule]", "646"}], ",", 
       RowBox[{"1185", "\[Rule]", "1510"}], ",", 
       RowBox[{"1185", "\[Rule]", "1510"}], ",", 
       RowBox[{"1185", "\[Rule]", "1186"}], ",", 
       RowBox[{"1599", "\[Rule]", "1276"}], ",", 
       RowBox[{"1599", "\[Rule]", "1276"}], ",", 
       RowBox[{"1599", "\[Rule]", "2140"}], ",", 
       RowBox[{"1599", "\[Rule]", "2140"}], ",", 
       RowBox[{"1599", "\[Rule]", "1168"}], ",", 
       RowBox[{"1599", "\[Rule]", "1168"}], ",", 
       RowBox[{"1599", "\[Rule]", "2032"}], ",", 
       RowBox[{"1599", "\[Rule]", "2032"}], ",", 
       RowBox[{"1599", "\[Rule]", "1600"}], ",", 
       RowBox[{"1167", "\[Rule]", "736"}], ",", 
       RowBox[{"1167", "\[Rule]", "736"}], ",", 
       RowBox[{"1167", "\[Rule]", "1600"}], ",", 
       RowBox[{"1167", "\[Rule]", "1600"}], ",", 
       RowBox[{"1167", "\[Rule]", "628"}], ",", 
       RowBox[{"1167", "\[Rule]", "628"}], ",", 
       RowBox[{"1167", "\[Rule]", "1492"}], ",", 
       RowBox[{"1167", "\[Rule]", "1492"}], ",", 
       RowBox[{"1167", "\[Rule]", "1168"}], ",", 
       RowBox[{"717", "\[Rule]", "394"}], ",", 
       RowBox[{"717", "\[Rule]", "394"}], ",", 
       RowBox[{"717", "\[Rule]", "1258"}], ",", 
       RowBox[{"717", "\[Rule]", "1258"}], ",", 
       RowBox[{"717", "\[Rule]", "286"}], ",", 
       RowBox[{"717", "\[Rule]", "286"}], ",", 
       RowBox[{"717", "\[Rule]", "1150"}], ",", 
       RowBox[{"717", "\[Rule]", "1150"}], ",", 
       RowBox[{"717", "\[Rule]", "718"}], ",", 
       RowBox[{"609", "\[Rule]", "286"}], ",", 
       RowBox[{"609", "\[Rule]", "286"}], ",", 
       RowBox[{"609", "\[Rule]", "1150"}], ",", 
       RowBox[{"609", "\[Rule]", "1150"}], ",", 
       RowBox[{"609", "\[Rule]", "178"}], ",", 
       RowBox[{"609", "\[Rule]", "1042"}], ",", 
       RowBox[{"609", "\[Rule]", "610"}], ",", 
       RowBox[{"285", "\[Rule]", "718"}], ",", 
       RowBox[{"285", "\[Rule]", "718"}], ",", 
       RowBox[{"285", "\[Rule]", "610"}], ",", 
       RowBox[{"285", "\[Rule]", "610"}], ",", 
       RowBox[{"285", "\[Rule]", "286"}], ",", 
       RowBox[{"1581", "\[Rule]", "1258"}], ",", 
       RowBox[{"1581", "\[Rule]", "1258"}], ",", 
       RowBox[{"1581", "\[Rule]", "2122"}], ",", 
       RowBox[{"1581", "\[Rule]", "2122"}], ",", 
       RowBox[{"1581", "\[Rule]", "1150"}], ",", 
       RowBox[{"1581", "\[Rule]", "1150"}], ",", 
       RowBox[{"1581", "\[Rule]", "2014"}], ",", 
       RowBox[{"1581", "\[Rule]", "2014"}], ",", 
       RowBox[{"1581", "\[Rule]", "1582"}], ",", 
       RowBox[{"1473", "\[Rule]", "1150"}], ",", 
       RowBox[{"1473", "\[Rule]", "1150"}], ",", 
       RowBox[{"1473", "\[Rule]", "2014"}], ",", 
       RowBox[{"1473", "\[Rule]", "2014"}], ",", 
       RowBox[{"1473", "\[Rule]", "1042"}], ",", 
       RowBox[{"1473", "\[Rule]", "1042"}], ",", 
       RowBox[{"1473", "\[Rule]", "1906"}], ",", 
       RowBox[{"1473", "\[Rule]", "1906"}], ",", 
       RowBox[{"1473", "\[Rule]", "1474"}], ",", 
       RowBox[{"1149", "\[Rule]", "718"}], ",", 
       RowBox[{"1149", "\[Rule]", "718"}], ",", 
       RowBox[{"1149", "\[Rule]", "1582"}], ",", 
       RowBox[{"1149", "\[Rule]", "1582"}], ",", 
       RowBox[{"1149", "\[Rule]", "610"}], ",", 
       RowBox[{"1149", "\[Rule]", "610"}], ",", 
       RowBox[{"1149", "\[Rule]", "1474"}], ",", 
       RowBox[{"1149", "\[Rule]", "1474"}], ",", 
       RowBox[{"1149", "\[Rule]", "1150"}], ",", 
       RowBox[{"501", "\[Rule]", "178"}], ",", 
       RowBox[{"501", "\[Rule]", "1042"}], ",", 
       RowBox[{"501", "\[Rule]", "70"}], ",", 
       RowBox[{"501", "\[Rule]", "70"}], ",", 
       RowBox[{"501", "\[Rule]", "934"}], ",", 
       RowBox[{"501", "\[Rule]", "934"}], ",", 
       RowBox[{"501", "\[Rule]", "502"}], ",", 
       RowBox[{"177", "\[Rule]", "610"}], ",", 
       RowBox[{"177", "\[Rule]", "502"}], ",", 
       RowBox[{"177", "\[Rule]", "178"}], ",", 
       RowBox[{"1365", "\[Rule]", "1042"}], ",", 
       RowBox[{"1365", "\[Rule]", "1042"}], ",", 
       RowBox[{"1365", "\[Rule]", "1906"}], ",", 
       RowBox[{"1365", "\[Rule]", "1906"}], ",", 
       RowBox[{"1365", "\[Rule]", "934"}], ",", 
       RowBox[{"1365", "\[Rule]", "1798"}], ",", 
       RowBox[{"1365", "\[Rule]", "1366"}], ",", 
       RowBox[{"1041", "\[Rule]", "610"}], ",", 
       RowBox[{"1041", "\[Rule]", "1474"}], ",", 
       RowBox[{"1041", "\[Rule]", "1474"}], ",", 
       RowBox[{"1041", "\[Rule]", "502"}], ",", 
       RowBox[{"1041", "\[Rule]", "1366"}], ",", 
       RowBox[{"1041", "\[Rule]", "1366"}], ",", 
       RowBox[{"1041", "\[Rule]", "1042"}], ",", 
       RowBox[{"29", "\[Rule]", "462"}], ",", 
       RowBox[{"29", "\[Rule]", "462"}], ",", 
       RowBox[{"29", "\[Rule]", "30"}], ",", 
       RowBox[{"43", "\[Rule]", "476"}], ",", 
       RowBox[{"43", "\[Rule]", "476"}], ",", 
       RowBox[{"43", "\[Rule]", "44"}], ",", 
       RowBox[{"55", "\[Rule]", "488"}], ",", 
       RowBox[{"55", "\[Rule]", "488"}], ",", 
       RowBox[{"55", "\[Rule]", "56"}], ",", 
       RowBox[{"893", "\[Rule]", "462"}], ",", 
       RowBox[{"893", "\[Rule]", "462"}], ",", 
       RowBox[{"893", "\[Rule]", "1326"}], ",", 
       RowBox[{"893", "\[Rule]", "894"}], ",", 
       RowBox[{"907", "\[Rule]", "476"}], ",", 
       RowBox[{"907", "\[Rule]", "476"}], ",", 
       RowBox[{"907", "\[Rule]", "1340"}], ",", 
       RowBox[{"907", "\[Rule]", "908"}], ",", 
       RowBox[{"919", "\[Rule]", "488"}], ",", 
       RowBox[{"919", "\[Rule]", "488"}], ",", 
       RowBox[{"919", "\[Rule]", "1352"}], ",", 
       RowBox[{"919", "\[Rule]", "920"}], ",", 
       RowBox[{"69", "\[Rule]", "502"}], ",", 
       RowBox[{"69", "\[Rule]", "502"}], ",", 
       RowBox[{"69", "\[Rule]", "70"}], ",", 
       RowBox[{"933", "\[Rule]", "502"}], ",", 
       RowBox[{"933", "\[Rule]", "502"}], ",", 
       RowBox[{"933", "\[Rule]", "1366"}], ",", 
       RowBox[{"933", "\[Rule]", "934"}], ",", 
       RowBox[{"749", "\[Rule]", "426"}], ",", 
       RowBox[{"749", "\[Rule]", "426"}], ",", 
       RowBox[{"749", "\[Rule]", "1290"}], ",", 
       RowBox[{"749", "\[Rule]", "1290"}], ",", 
       RowBox[{"749", "\[Rule]", "318"}], ",", 
       RowBox[{"749", "\[Rule]", "318"}], ",", 
       RowBox[{"749", "\[Rule]", "1182"}], ",", 
       RowBox[{"749", "\[Rule]", "1182"}], ",", 
       RowBox[{"749", "\[Rule]", "750"}], ",", 
       RowBox[{"317", "\[Rule]", "750"}], ",", 
       RowBox[{"317", "\[Rule]", "750"}], ",", 
       RowBox[{"317", "\[Rule]", "642"}], ",", 
       RowBox[{"317", "\[Rule]", "642"}], ",", 
       RowBox[{"317", "\[Rule]", "318"}], ",", 
       RowBox[{"1613", "\[Rule]", "1290"}], ",", 
       RowBox[{"1613", "\[Rule]", "1290"}], ",", 
       RowBox[{"1613", "\[Rule]", "2154"}], ",", 
       RowBox[{"1613", "\[Rule]", "2154"}], ",", 
       RowBox[{"1613", "\[Rule]", "1182"}], ",", 
       RowBox[{"1613", "\[Rule]", "1182"}], ",", 
       RowBox[{"1613", "\[Rule]", "2046"}], ",", 
       RowBox[{"1613", "\[Rule]", "2046"}], ",", 
       RowBox[{"1613", "\[Rule]", "1614"}], ",", 
       RowBox[{"1181", "\[Rule]", "750"}], ",", 
       RowBox[{"1181", "\[Rule]", "750"}], ",", 
       RowBox[{"1181", "\[Rule]", "1614"}], ",", 
       RowBox[{"1181", "\[Rule]", "1614"}], ",", 
       RowBox[{"1181", "\[Rule]", "642"}], ",", 
       RowBox[{"1181", "\[Rule]", "642"}], ",", 
       RowBox[{"1181", "\[Rule]", "1506"}], ",", 
       RowBox[{"1181", "\[Rule]", "1506"}], ",", 
       RowBox[{"1181", "\[Rule]", "1182"}], ",", 
       RowBox[{"731", "\[Rule]", "408"}], ",", 
       RowBox[{"731", "\[Rule]", "408"}], ",", 
       RowBox[{"731", "\[Rule]", "1272"}], ",", 
       RowBox[{"731", "\[Rule]", "1272"}], ",", 
       RowBox[{"731", "\[Rule]", "300"}], ",", 
       RowBox[{"731", "\[Rule]", "300"}], ",", 
       RowBox[{"731", "\[Rule]", "1164"}], ",", 
       RowBox[{"731", "\[Rule]", "1164"}], ",", 
       RowBox[{"731", "\[Rule]", "732"}], ",", 
       RowBox[{"623", "\[Rule]", "300"}], ",", 
       RowBox[{"623", "\[Rule]", "300"}], ",", 
       RowBox[{"623", "\[Rule]", "1164"}], ",", 
       RowBox[{"623", "\[Rule]", "1164"}], ",", 
       RowBox[{"623", "\[Rule]", "192"}], ",", 
       RowBox[{"623", "\[Rule]", "1056"}], ",", 
       RowBox[{"623", "\[Rule]", "624"}], ",", 
       RowBox[{"299", "\[Rule]", "732"}], ",", 
       RowBox[{"299", "\[Rule]", "732"}], ",", 
       RowBox[{"299", "\[Rule]", "624"}], ",", 
       RowBox[{"299", "\[Rule]", "624"}], ",", 
       RowBox[{"299", "\[Rule]", "300"}], ",", 
       RowBox[{"1595", "\[Rule]", "1272"}], ",", 
       RowBox[{"1595", "\[Rule]", "1272"}], ",", 
       RowBox[{"1595", "\[Rule]", "2136"}], ",", 
       RowBox[{"1595", "\[Rule]", "2136"}], ",", 
       RowBox[{"1595", "\[Rule]", "1164"}], ",", 
       RowBox[{"1595", "\[Rule]", "1164"}], ",", 
       RowBox[{"1595", "\[Rule]", "2028"}], ",", 
       RowBox[{"1595", "\[Rule]", "2028"}], ",", 
       RowBox[{"1595", "\[Rule]", "1596"}], ",", 
       RowBox[{"1487", "\[Rule]", "1164"}], ",", 
       RowBox[{"1487", "\[Rule]", "1164"}], ",", 
       RowBox[{"1487", "\[Rule]", "2028"}], ",", 
       RowBox[{"1487", "\[Rule]", "2028"}], ",", 
       RowBox[{"1487", "\[Rule]", "1056"}], ",", 
       RowBox[{"1487", "\[Rule]", "1056"}], ",", 
       RowBox[{"1487", "\[Rule]", "1920"}], ",", 
       RowBox[{"1487", "\[Rule]", "1920"}], ",", 
       RowBox[{"1487", "\[Rule]", "1488"}], ",", 
       RowBox[{"1163", "\[Rule]", "732"}], ",", 
       RowBox[{"1163", "\[Rule]", "732"}], ",", 
       RowBox[{"1163", "\[Rule]", "1596"}], ",", 
       RowBox[{"1163", "\[Rule]", "1596"}], ",", 
       RowBox[{"1163", "\[Rule]", "624"}], ",", 
       RowBox[{"1163", "\[Rule]", "624"}], ",", 
       RowBox[{"1163", "\[Rule]", "1488"}], ",", 
       RowBox[{"1163", "\[Rule]", "1488"}], ",", 
       RowBox[{"1163", "\[Rule]", "1164"}], ",", 
       RowBox[{"515", "\[Rule]", "192"}], ",", 
       RowBox[{"515", "\[Rule]", "1056"}], ",", 
       RowBox[{"515", "\[Rule]", "84"}], ",", 
       RowBox[{"515", "\[Rule]", "84"}], ",", 
       RowBox[{"515", "\[Rule]", "948"}], ",", 
       RowBox[{"515", "\[Rule]", "948"}], ",", 
       RowBox[{"515", "\[Rule]", "516"}], ",", 
       RowBox[{"191", "\[Rule]", "624"}], ",", 
       RowBox[{"191", "\[Rule]", "516"}], ",", 
       RowBox[{"191", "\[Rule]", "192"}], ",", 
       RowBox[{"1379", "\[Rule]", "1056"}], ",", 
       RowBox[{"1379", "\[Rule]", "1056"}], ",", 
       RowBox[{"1379", "\[Rule]", "1920"}], ",", 
       RowBox[{"1379", "\[Rule]", "1920"}], ",", 
       RowBox[{"1379", "\[Rule]", "948"}], ",", 
       RowBox[{"1379", "\[Rule]", "1812"}], ",", 
       RowBox[{"1379", "\[Rule]", "1380"}], ",", 
       RowBox[{"1055", "\[Rule]", "624"}], ",", 
       RowBox[{"1055", "\[Rule]", "1488"}], ",", 
       RowBox[{"1055", "\[Rule]", "1488"}], ",", 
       RowBox[{"1055", "\[Rule]", "516"}], ",", 
       RowBox[{"1055", "\[Rule]", "1380"}], ",", 
       RowBox[{"1055", "\[Rule]", "1380"}], ",", 
       RowBox[{"1055", "\[Rule]", "1056"}], ",", 
       RowBox[{"83", "\[Rule]", "516"}], ",", 
       RowBox[{"83", "\[Rule]", "516"}], ",", 
       RowBox[{"83", "\[Rule]", "84"}], ",", 
       RowBox[{"947", "\[Rule]", "516"}], ",", 
       RowBox[{"947", "\[Rule]", "516"}], ",", 
       RowBox[{"947", "\[Rule]", "1380"}], ",", 
       RowBox[{"947", "\[Rule]", "948"}], ",", 
       RowBox[{"2405", "\[Rule]", "2082"}], ",", 
       RowBox[{"2405", "\[Rule]", "2082"}], ",", 
       RowBox[{"2405", "\[Rule]", "2946"}], ",", 
       RowBox[{"2405", "\[Rule]", "2946"}], ",", 
       RowBox[{"2405", "\[Rule]", "1974"}], ",", 
       RowBox[{"2405", "\[Rule]", "1974"}], ",", 
       RowBox[{"2405", "\[Rule]", "2838"}], ",", 
       RowBox[{"2405", "\[Rule]", "2838"}], ",", 
       RowBox[{"2405", "\[Rule]", "2406"}], ",", 
       RowBox[{"2435", "\[Rule]", "2112"}], ",", 
       RowBox[{"2435", "\[Rule]", "2112"}], ",", 
       RowBox[{"2435", "\[Rule]", "2976"}], ",", 
       RowBox[{"2435", "\[Rule]", "2976"}], ",", 
       RowBox[{"2435", "\[Rule]", "2004"}], ",", 
       RowBox[{"2435", "\[Rule]", "2004"}], ",", 
       RowBox[{"2435", "\[Rule]", "2868"}], ",", 
       RowBox[{"2435", "\[Rule]", "2868"}], ",", 
       RowBox[{"2435", "\[Rule]", "2436"}], ",", 
       RowBox[{"2419", "\[Rule]", "2096"}], ",", 
       RowBox[{"2419", "\[Rule]", "2096"}], ",", 
       RowBox[{"2419", "\[Rule]", "2960"}], ",", 
       RowBox[{"2419", "\[Rule]", "2960"}], ",", 
       RowBox[{"2419", "\[Rule]", "1988"}], ",", 
       RowBox[{"2419", "\[Rule]", "1988"}], ",", 
       RowBox[{"2419", "\[Rule]", "2852"}], ",", 
       RowBox[{"2419", "\[Rule]", "2852"}], ",", 
       RowBox[{"2419", "\[Rule]", "2420"}], ",", 
       RowBox[{"2297", "\[Rule]", "1974"}], ",", 
       RowBox[{"2297", "\[Rule]", "1974"}], ",", 
       RowBox[{"2297", "\[Rule]", "2838"}], ",", 
       RowBox[{"2297", "\[Rule]", "2838"}], ",", 
       RowBox[{"2297", "\[Rule]", "1866"}], ",", 
       RowBox[{"2297", "\[Rule]", "1866"}], ",", 
       RowBox[{"2297", "\[Rule]", "2730"}], ",", 
       RowBox[{"2297", "\[Rule]", "2730"}], ",", 
       RowBox[{"2297", "\[Rule]", "2298"}], ",", 
       RowBox[{"2327", "\[Rule]", "2004"}], ",", 
       RowBox[{"2327", "\[Rule]", "2004"}], ",", 
       RowBox[{"2327", "\[Rule]", "2868"}], ",", 
       RowBox[{"2327", "\[Rule]", "2868"}], ",", 
       RowBox[{"2327", "\[Rule]", "1896"}], ",", 
       RowBox[{"2327", "\[Rule]", "1896"}], ",", 
       RowBox[{"2327", "\[Rule]", "2760"}], ",", 
       RowBox[{"2327", "\[Rule]", "2760"}], ",", 
       RowBox[{"2327", "\[Rule]", "2328"}], ",", 
       RowBox[{"2311", "\[Rule]", "1988"}], ",", 
       RowBox[{"2311", "\[Rule]", "1988"}], ",", 
       RowBox[{"2311", "\[Rule]", "2852"}], ",", 
       RowBox[{"2311", "\[Rule]", "2852"}], ",", 
       RowBox[{"2311", "\[Rule]", "1880"}], ",", 
       RowBox[{"2311", "\[Rule]", "1880"}], ",", 
       RowBox[{"2311", "\[Rule]", "2744"}], ",", 
       RowBox[{"2311", "\[Rule]", "2744"}], ",", 
       RowBox[{"2311", "\[Rule]", "2312"}], ",", 
       RowBox[{"1973", "\[Rule]", "1542"}], ",", 
       RowBox[{"1973", "\[Rule]", "1542"}], ",", 
       RowBox[{"1973", "\[Rule]", "2406"}], ",", 
       RowBox[{"1973", "\[Rule]", "2406"}], ",", 
       RowBox[{"1973", "\[Rule]", "1434"}], ",", 
       RowBox[{"1973", "\[Rule]", "1434"}], ",", 
       RowBox[{"1973", "\[Rule]", "2298"}], ",", 
       RowBox[{"1973", "\[Rule]", "2298"}], ",", 
       RowBox[{"1973", "\[Rule]", "1974"}], ",", 
       RowBox[{"2003", "\[Rule]", "1572"}], ",", 
       RowBox[{"2003", "\[Rule]", "1572"}], ",", 
       RowBox[{"2003", "\[Rule]", "2436"}], ",", 
       RowBox[{"2003", "\[Rule]", "2436"}], ",", 
       RowBox[{"2003", "\[Rule]", "1464"}], ",", 
       RowBox[{"2003", "\[Rule]", "1464"}], ",", 
       RowBox[{"2003", "\[Rule]", "2328"}], ",", 
       RowBox[{"2003", "\[Rule]", "2328"}], ",", 
       RowBox[{"2003", "\[Rule]", "2004"}], ",", 
       RowBox[{"1987", "\[Rule]", "1556"}], ",", 
       RowBox[{"1987", "\[Rule]", "1556"}], ",", 
       RowBox[{"1987", "\[Rule]", "2420"}], ",", 
       RowBox[{"1987", "\[Rule]", "2420"}], ",", 
       RowBox[{"1987", "\[Rule]", "1448"}], ",", 
       RowBox[{"1987", "\[Rule]", "1448"}], ",", 
       RowBox[{"1987", "\[Rule]", "2312"}], ",", 
       RowBox[{"1987", "\[Rule]", "2312"}], ",", 
       RowBox[{"1987", "\[Rule]", "1988"}], ",", 
       RowBox[{"2467", "\[Rule]", "2144"}], ",", 
       RowBox[{"2467", "\[Rule]", "2144"}], ",", 
       RowBox[{"2467", "\[Rule]", "3008"}], ",", 
       RowBox[{"2467", "\[Rule]", "3008"}], ",", 
       RowBox[{"2467", "\[Rule]", "2036"}], ",", 
       RowBox[{"2467", "\[Rule]", "2036"}], ",", 
       RowBox[{"2467", "\[Rule]", "2900"}], ",", 
       RowBox[{"2467", "\[Rule]", "2900"}], ",", 
       RowBox[{"2467", "\[Rule]", "2468"}], ",", 
       RowBox[{"2449", "\[Rule]", "2126"}], ",", 
       RowBox[{"2449", "\[Rule]", "2126"}], ",", 
       RowBox[{"2449", "\[Rule]", "2990"}], ",", 
       RowBox[{"2449", "\[Rule]", "2990"}], ",", 
       RowBox[{"2449", "\[Rule]", "2018"}], ",", 
       RowBox[{"2449", "\[Rule]", "2018"}], ",", 
       RowBox[{"2449", "\[Rule]", "2882"}], ",", 
       RowBox[{"2449", "\[Rule]", "2882"}], ",", 
       RowBox[{"2449", "\[Rule]", "2450"}], ",", 
       RowBox[{"2359", "\[Rule]", "2036"}], ",", 
       RowBox[{"2359", "\[Rule]", "2036"}], ",", 
       RowBox[{"2359", "\[Rule]", "2900"}], ",", 
       RowBox[{"2359", "\[Rule]", "2900"}], ",", 
       RowBox[{"2359", "\[Rule]", "1928"}], ",", 
       RowBox[{"2359", "\[Rule]", "1928"}], ",", 
       RowBox[{"2359", "\[Rule]", "2792"}], ",", 
       RowBox[{"2359", "\[Rule]", "2792"}], ",", 
       RowBox[{"2359", "\[Rule]", "2360"}], ",", 
       RowBox[{"2341", "\[Rule]", "2018"}], ",", 
       RowBox[{"2341", "\[Rule]", "2018"}], ",", 
       RowBox[{"2341", "\[Rule]", "2882"}], ",", 
       RowBox[{"2341", "\[Rule]", "2882"}], ",", 
       RowBox[{"2341", "\[Rule]", "1910"}], ",", 
       RowBox[{"2341", "\[Rule]", "1910"}], ",", 
       RowBox[{"2341", "\[Rule]", "2774"}], ",", 
       RowBox[{"2341", "\[Rule]", "2774"}], ",", 
       RowBox[{"2341", "\[Rule]", "2342"}], ",", 
       RowBox[{"2035", "\[Rule]", "1604"}], ",", 
       RowBox[{"2035", "\[Rule]", "1604"}], ",", 
       RowBox[{"2035", "\[Rule]", "2468"}], ",", 
       RowBox[{"2035", "\[Rule]", "2468"}], ",", 
       RowBox[{"2035", "\[Rule]", "1496"}], ",", 
       RowBox[{"2035", "\[Rule]", "1496"}], ",", 
       RowBox[{"2035", "\[Rule]", "2360"}], ",", 
       RowBox[{"2035", "\[Rule]", "2360"}], ",", 
       RowBox[{"2035", "\[Rule]", "2036"}], ",", 
       RowBox[{"2017", "\[Rule]", "1586"}], ",", 
       RowBox[{"2017", "\[Rule]", "1586"}], ",", 
       RowBox[{"2017", "\[Rule]", "2450"}], ",", 
       RowBox[{"2017", "\[Rule]", "2450"}], ",", 
       RowBox[{"2017", "\[Rule]", "1478"}], ",", 
       RowBox[{"2017", "\[Rule]", "1478"}], ",", 
       RowBox[{"2017", "\[Rule]", "2342"}], ",", 
       RowBox[{"2017", "\[Rule]", "2342"}], ",", 
       RowBox[{"2017", "\[Rule]", "2018"}], ",", 
       RowBox[{"2431", "\[Rule]", "2108"}], ",", 
       RowBox[{"2431", "\[Rule]", "2108"}], ",", 
       RowBox[{"2431", "\[Rule]", "2972"}], ",", 
       RowBox[{"2431", "\[Rule]", "2972"}], ",", 
       RowBox[{"2431", "\[Rule]", "2000"}], ",", 
       RowBox[{"2431", "\[Rule]", "2000"}], ",", 
       RowBox[{"2431", "\[Rule]", "2864"}], ",", 
       RowBox[{"2431", "\[Rule]", "2864"}], ",", 
       RowBox[{"2431", "\[Rule]", "2432"}], ",", 
       RowBox[{"2323", "\[Rule]", "2000"}], ",", 
       RowBox[{"2323", "\[Rule]", "2000"}], ",", 
       RowBox[{"2323", "\[Rule]", "2864"}], ",", 
       RowBox[{"2323", "\[Rule]", "2864"}], ",", 
       RowBox[{"2323", "\[Rule]", "1892"}], ",", 
       RowBox[{"2323", "\[Rule]", "1892"}], ",", 
       RowBox[{"2323", "\[Rule]", "2756"}], ",", 
       RowBox[{"2323", "\[Rule]", "2756"}], ",", 
       RowBox[{"2323", "\[Rule]", "2324"}], ",", 
       RowBox[{"1999", "\[Rule]", "1568"}], ",", 
       RowBox[{"1999", "\[Rule]", "1568"}], ",", 
       RowBox[{"1999", "\[Rule]", "2432"}], ",", 
       RowBox[{"1999", "\[Rule]", "2432"}], ",", 
       RowBox[{"1999", "\[Rule]", "1460"}], ",", 
       RowBox[{"1999", "\[Rule]", "1460"}], ",", 
       RowBox[{"1999", "\[Rule]", "2324"}], ",", 
       RowBox[{"1999", "\[Rule]", "2324"}], ",", 
       RowBox[{"1999", "\[Rule]", "2000"}], ",", 
       RowBox[{"2189", "\[Rule]", "1866"}], ",", 
       RowBox[{"2189", "\[Rule]", "1866"}], ",", 
       RowBox[{"2189", "\[Rule]", "2730"}], ",", 
       RowBox[{"2189", "\[Rule]", "2730"}], ",", 
       RowBox[{"2189", "\[Rule]", "1758"}], ",", 
       RowBox[{"2189", "\[Rule]", "1758"}], ",", 
       RowBox[{"2189", "\[Rule]", "2622"}], ",", 
       RowBox[{"2189", "\[Rule]", "2622"}], ",", 
       RowBox[{"2189", "\[Rule]", "2190"}], ",", 
       RowBox[{"2219", "\[Rule]", "1896"}], ",", 
       RowBox[{"2219", "\[Rule]", "1896"}], ",", 
       RowBox[{"2219", "\[Rule]", "2760"}], ",", 
       RowBox[{"2219", "\[Rule]", "2760"}], ",", 
       RowBox[{"2219", "\[Rule]", "1788"}], ",", 
       RowBox[{"2219", "\[Rule]", "1788"}], ",", 
       RowBox[{"2219", "\[Rule]", "2652"}], ",", 
       RowBox[{"2219", "\[Rule]", "2652"}], ",", 
       RowBox[{"2219", "\[Rule]", "2220"}], ",", 
       RowBox[{"2203", "\[Rule]", "1880"}], ",", 
       RowBox[{"2203", "\[Rule]", "1880"}], ",", 
       RowBox[{"2203", "\[Rule]", "2744"}], ",", 
       RowBox[{"2203", "\[Rule]", "2744"}], ",", 
       RowBox[{"2203", "\[Rule]", "1772"}], ",", 
       RowBox[{"2203", "\[Rule]", "1772"}], ",", 
       RowBox[{"2203", "\[Rule]", "2636"}], ",", 
       RowBox[{"2203", "\[Rule]", "2636"}], ",", 
       RowBox[{"2203", "\[Rule]", "2204"}], ",", 
       RowBox[{"1865", "\[Rule]", "1434"}], ",", 
       RowBox[{"1865", "\[Rule]", "1434"}], ",", 
       RowBox[{"1865", "\[Rule]", "2298"}], ",", 
       RowBox[{"1865", "\[Rule]", "2298"}], ",", 
       RowBox[{"1865", "\[Rule]", "1326"}], ",", 
       RowBox[{"1865", "\[Rule]", "1326"}], ",", 
       RowBox[{"1865", "\[Rule]", "2190"}], ",", 
       RowBox[{"1865", "\[Rule]", "2190"}], ",", 
       RowBox[{"1865", "\[Rule]", "1866"}], ",", 
       RowBox[{"1895", "\[Rule]", "1464"}], ",", 
       RowBox[{"1895", "\[Rule]", "1464"}], ",", 
       RowBox[{"1895", "\[Rule]", "2328"}], ",", 
       RowBox[{"1895", "\[Rule]", "2328"}], ",", 
       RowBox[{"1895", "\[Rule]", "1356"}], ",", 
       RowBox[{"1895", "\[Rule]", "1356"}], ",", 
       RowBox[{"1895", "\[Rule]", "2220"}], ",", 
       RowBox[{"1895", "\[Rule]", "2220"}], ",", 
       RowBox[{"1895", "\[Rule]", "1896"}], ",", 
       RowBox[{"1879", "\[Rule]", "1448"}], ",", 
       RowBox[{"1879", "\[Rule]", "1448"}], ",", 
       RowBox[{"1879", "\[Rule]", "2312"}], ",", 
       RowBox[{"1879", "\[Rule]", "2312"}], ",", 
       RowBox[{"1879", "\[Rule]", "1340"}], ",", 
       RowBox[{"1879", "\[Rule]", "1340"}], ",", 
       RowBox[{"1879", "\[Rule]", "2204"}], ",", 
       RowBox[{"1879", "\[Rule]", "2204"}], ",", 
       RowBox[{"1879", "\[Rule]", "1880"}], ",", 
       RowBox[{"2251", "\[Rule]", "1928"}], ",", 
       RowBox[{"2251", "\[Rule]", "1928"}], ",", 
       RowBox[{"2251", "\[Rule]", "2792"}], ",", 
       RowBox[{"2251", "\[Rule]", "2792"}], ",", 
       RowBox[{"2251", "\[Rule]", "1820"}], ",", 
       RowBox[{"2251", "\[Rule]", "1820"}], ",", 
       RowBox[{"2251", "\[Rule]", "2684"}], ",", 
       RowBox[{"2251", "\[Rule]", "2684"}], ",", 
       RowBox[{"2251", "\[Rule]", "2252"}], ",", 
       RowBox[{"2233", "\[Rule]", "1910"}], ",", 
       RowBox[{"2233", "\[Rule]", "1910"}], ",", 
       RowBox[{"2233", "\[Rule]", "2774"}], ",", 
       RowBox[{"2233", "\[Rule]", "2774"}], ",", 
       RowBox[{"2233", "\[Rule]", "1802"}], ",", 
       RowBox[{"2233", "\[Rule]", "1802"}], ",", 
       RowBox[{"2233", "\[Rule]", "2666"}], ",", 
       RowBox[{"2233", "\[Rule]", "2666"}], ",", 
       RowBox[{"2233", "\[Rule]", "2234"}], ",", 
       RowBox[{"1927", "\[Rule]", "1496"}], ",", 
       RowBox[{"1927", "\[Rule]", "1496"}], ",", 
       RowBox[{"1927", "\[Rule]", "2360"}], ",", 
       RowBox[{"1927", "\[Rule]", "2360"}], ",", 
       RowBox[{"1927", "\[Rule]", "1388"}], ",", 
       RowBox[{"1927", "\[Rule]", "1388"}], ",", 
       RowBox[{"1927", "\[Rule]", "2252"}], ",", 
       RowBox[{"1927", "\[Rule]", "2252"}], ",", 
       RowBox[{"1927", "\[Rule]", "1928"}], ",", 
       RowBox[{"1909", "\[Rule]", "1478"}], ",", 
       RowBox[{"1909", "\[Rule]", "1478"}], ",", 
       RowBox[{"1909", "\[Rule]", "2342"}], ",", 
       RowBox[{"1909", "\[Rule]", "2342"}], ",", 
       RowBox[{"1909", "\[Rule]", "1370"}], ",", 
       RowBox[{"1909", "\[Rule]", "1370"}], ",", 
       RowBox[{"1909", "\[Rule]", "2234"}], ",", 
       RowBox[{"1909", "\[Rule]", "2234"}], ",", 
       RowBox[{"1909", "\[Rule]", "1910"}], ",", 
       RowBox[{"2215", "\[Rule]", "1892"}], ",", 
       RowBox[{"2215", "\[Rule]", "1892"}], ",", 
       RowBox[{"2215", "\[Rule]", "2756"}], ",", 
       RowBox[{"2215", "\[Rule]", "2756"}], ",", 
       RowBox[{"2215", "\[Rule]", "1784"}], ",", 
       RowBox[{"2215", "\[Rule]", "1784"}], ",", 
       RowBox[{"2215", "\[Rule]", "2648"}], ",", 
       RowBox[{"2215", "\[Rule]", "2648"}], ",", 
       RowBox[{"2215", "\[Rule]", "2216"}], ",", 
       RowBox[{"1891", "\[Rule]", "1460"}], ",", 
       RowBox[{"1891", "\[Rule]", "1460"}], ",", 
       RowBox[{"1891", "\[Rule]", "2324"}], ",", 
       RowBox[{"1891", "\[Rule]", "2324"}], ",", 
       RowBox[{"1891", "\[Rule]", "1352"}], ",", 
       RowBox[{"1891", "\[Rule]", "1352"}], ",", 
       RowBox[{"1891", "\[Rule]", "2216"}], ",", 
       RowBox[{"1891", "\[Rule]", "2216"}], ",", 
       RowBox[{"1891", "\[Rule]", "1892"}], ",", 
       RowBox[{"2481", "\[Rule]", "2158"}], ",", 
       RowBox[{"2481", "\[Rule]", "2158"}], ",", 
       RowBox[{"2481", "\[Rule]", "3022"}], ",", 
       RowBox[{"2481", "\[Rule]", "3022"}], ",", 
       RowBox[{"2481", "\[Rule]", "2050"}], ",", 
       RowBox[{"2481", "\[Rule]", "2050"}], ",", 
       RowBox[{"2481", "\[Rule]", "2914"}], ",", 
       RowBox[{"2481", "\[Rule]", "2914"}], ",", 
       RowBox[{"2481", "\[Rule]", "2482"}], ",", 
       RowBox[{"2373", "\[Rule]", "2050"}], ",", 
       RowBox[{"2373", "\[Rule]", "2050"}], ",", 
       RowBox[{"2373", "\[Rule]", "2914"}], ",", 
       RowBox[{"2373", "\[Rule]", "2914"}], ",", 
       RowBox[{"2373", "\[Rule]", "1942"}], ",", 
       RowBox[{"2373", "\[Rule]", "1942"}], ",", 
       RowBox[{"2373", "\[Rule]", "2806"}], ",", 
       RowBox[{"2373", "\[Rule]", "2806"}], ",", 
       RowBox[{"2373", "\[Rule]", "2374"}], ",", 
       RowBox[{"2049", "\[Rule]", "1618"}], ",", 
       RowBox[{"2049", "\[Rule]", "1618"}], ",", 
       RowBox[{"2049", "\[Rule]", "2482"}], ",", 
       RowBox[{"2049", "\[Rule]", "2482"}], ",", 
       RowBox[{"2049", "\[Rule]", "1510"}], ",", 
       RowBox[{"2049", "\[Rule]", "1510"}], ",", 
       RowBox[{"2049", "\[Rule]", "2374"}], ",", 
       RowBox[{"2049", "\[Rule]", "2374"}], ",", 
       RowBox[{"2049", "\[Rule]", "2050"}], ",", 
       RowBox[{"2463", "\[Rule]", "2140"}], ",", 
       RowBox[{"2463", "\[Rule]", "2140"}], ",", 
       RowBox[{"2463", "\[Rule]", "3004"}], ",", 
       RowBox[{"2463", "\[Rule]", "3004"}], ",", 
       RowBox[{"2463", "\[Rule]", "2032"}], ",", 
       RowBox[{"2463", "\[Rule]", "2032"}], ",", 
       RowBox[{"2463", "\[Rule]", "2896"}], ",", 
       RowBox[{"2463", "\[Rule]", "2896"}], ",", 
       RowBox[{"2463", "\[Rule]", "2464"}], ",", 
       RowBox[{"2355", "\[Rule]", "2032"}], ",", 
       RowBox[{"2355", "\[Rule]", "2032"}], ",", 
       RowBox[{"2355", "\[Rule]", "2896"}], ",", 
       RowBox[{"2355", "\[Rule]", "2896"}], ",", 
       RowBox[{"2355", "\[Rule]", "1924"}], ",", 
       RowBox[{"2355", "\[Rule]", "1924"}], ",", 
       RowBox[{"2355", "\[Rule]", "2788"}], ",", 
       RowBox[{"2355", "\[Rule]", "2788"}], ",", 
       RowBox[{"2355", "\[Rule]", "2356"}], ",", 
       RowBox[{"2031", "\[Rule]", "1600"}], ",", 
       RowBox[{"2031", "\[Rule]", "1600"}], ",", 
       RowBox[{"2031", "\[Rule]", "2464"}], ",", 
       RowBox[{"2031", "\[Rule]", "2464"}], ",", 
       RowBox[{"2031", "\[Rule]", "1492"}], ",", 
       RowBox[{"2031", "\[Rule]", "1492"}], ",", 
       RowBox[{"2031", "\[Rule]", "2356"}], ",", 
       RowBox[{"2031", "\[Rule]", "2356"}], ",", 
       RowBox[{"2031", "\[Rule]", "2032"}], ",", 
       RowBox[{"2265", "\[Rule]", "1942"}], ",", 
       RowBox[{"2265", "\[Rule]", "1942"}], ",", 
       RowBox[{"2265", "\[Rule]", "2806"}], ",", 
       RowBox[{"2265", "\[Rule]", "2806"}], ",", 
       RowBox[{"2265", "\[Rule]", "1834"}], ",", 
       RowBox[{"2265", "\[Rule]", "1834"}], ",", 
       RowBox[{"2265", "\[Rule]", "2698"}], ",", 
       RowBox[{"2265", "\[Rule]", "2698"}], ",", 
       RowBox[{"2265", "\[Rule]", "2266"}], ",", 
       RowBox[{"1941", "\[Rule]", "1510"}], ",", 
       RowBox[{"1941", "\[Rule]", "1510"}], ",", 
       RowBox[{"1941", "\[Rule]", "2374"}], ",", 
       RowBox[{"1941", "\[Rule]", "2374"}], ",", 
       RowBox[{"1941", "\[Rule]", "1402"}], ",", 
       RowBox[{"1941", "\[Rule]", "1402"}], ",", 
       RowBox[{"1941", "\[Rule]", "2266"}], ",", 
       RowBox[{"1941", "\[Rule]", "2266"}], ",", 
       RowBox[{"1941", "\[Rule]", "1942"}], ",", 
       RowBox[{"2247", "\[Rule]", "1924"}], ",", 
       RowBox[{"2247", "\[Rule]", "1924"}], ",", 
       RowBox[{"2247", "\[Rule]", "2788"}], ",", 
       RowBox[{"2247", "\[Rule]", "2788"}], ",", 
       RowBox[{"2247", "\[Rule]", "1816"}], ",", 
       RowBox[{"2247", "\[Rule]", "1816"}], ",", 
       RowBox[{"2247", "\[Rule]", "2680"}], ",", 
       RowBox[{"2247", "\[Rule]", "2680"}], ",", 
       RowBox[{"2247", "\[Rule]", "2248"}], ",", 
       RowBox[{"1923", "\[Rule]", "1492"}], ",", 
       RowBox[{"1923", "\[Rule]", "1492"}], ",", 
       RowBox[{"1923", "\[Rule]", "2356"}], ",", 
       RowBox[{"1923", "\[Rule]", "2356"}], ",", 
       RowBox[{"1923", "\[Rule]", "1384"}], ",", 
       RowBox[{"1923", "\[Rule]", "1384"}], ",", 
       RowBox[{"1923", "\[Rule]", "2248"}], ",", 
       RowBox[{"1923", "\[Rule]", "2248"}], ",", 
       RowBox[{"1923", "\[Rule]", "1924"}], ",", 
       RowBox[{"2445", "\[Rule]", "2122"}], ",", 
       RowBox[{"2445", "\[Rule]", "2122"}], ",", 
       RowBox[{"2445", "\[Rule]", "2986"}], ",", 
       RowBox[{"2445", "\[Rule]", "2986"}], ",", 
       RowBox[{"2445", "\[Rule]", "2014"}], ",", 
       RowBox[{"2445", "\[Rule]", "2014"}], ",", 
       RowBox[{"2445", "\[Rule]", "2878"}], ",", 
       RowBox[{"2445", "\[Rule]", "2878"}], ",", 
       RowBox[{"2445", "\[Rule]", "2446"}], ",", 
       RowBox[{"2337", "\[Rule]", "2014"}], ",", 
       RowBox[{"2337", "\[Rule]", "2014"}], ",", 
       RowBox[{"2337", "\[Rule]", "2878"}], ",", 
       RowBox[{"2337", "\[Rule]", "2878"}], ",", 
       RowBox[{"2337", "\[Rule]", "1906"}], ",", 
       RowBox[{"2337", "\[Rule]", "1906"}], ",", 
       RowBox[{"2337", "\[Rule]", "2770"}], ",", 
       RowBox[{"2337", "\[Rule]", "2770"}], ",", 
       RowBox[{"2337", "\[Rule]", "2338"}], ",", 
       RowBox[{"2013", "\[Rule]", "1582"}], ",", 
       RowBox[{"2013", "\[Rule]", "1582"}], ",", 
       RowBox[{"2013", "\[Rule]", "2446"}], ",", 
       RowBox[{"2013", "\[Rule]", "2446"}], ",", 
       RowBox[{"2013", "\[Rule]", "1474"}], ",", 
       RowBox[{"2013", "\[Rule]", "1474"}], ",", 
       RowBox[{"2013", "\[Rule]", "2338"}], ",", 
       RowBox[{"2013", "\[Rule]", "2338"}], ",", 
       RowBox[{"2013", "\[Rule]", "2014"}], ",", 
       RowBox[{"2229", "\[Rule]", "1906"}], ",", 
       RowBox[{"2229", "\[Rule]", "1906"}], ",", 
       RowBox[{"2229", "\[Rule]", "2770"}], ",", 
       RowBox[{"2229", "\[Rule]", "2770"}], ",", 
       RowBox[{"2229", "\[Rule]", "1798"}], ",", 
       RowBox[{"2229", "\[Rule]", "1798"}], ",", 
       RowBox[{"2229", "\[Rule]", "2662"}], ",", 
       RowBox[{"2229", "\[Rule]", "2662"}], ",", 
       RowBox[{"2229", "\[Rule]", "2230"}], ",", 
       RowBox[{"1905", "\[Rule]", "1474"}], ",", 
       RowBox[{"1905", "\[Rule]", "1474"}], ",", 
       RowBox[{"1905", "\[Rule]", "2338"}], ",", 
       RowBox[{"1905", "\[Rule]", "2338"}], ",", 
       RowBox[{"1905", "\[Rule]", "1366"}], ",", 
       RowBox[{"1905", "\[Rule]", "1366"}], ",", 
       RowBox[{"1905", "\[Rule]", "2230"}], ",", 
       RowBox[{"1905", "\[Rule]", "2230"}], ",", 
       RowBox[{"1905", "\[Rule]", "1906"}], ",", 
       RowBox[{"1757", "\[Rule]", "1326"}], ",", 
       RowBox[{"1757", "\[Rule]", "2190"}], ",", 
       RowBox[{"1757", "\[Rule]", "2190"}], ",", 
       RowBox[{"1757", "\[Rule]", "1758"}], ",", 
       RowBox[{"1787", "\[Rule]", "1356"}], ",", 
       RowBox[{"1787", "\[Rule]", "2220"}], ",", 
       RowBox[{"1787", "\[Rule]", "2220"}], ",", 
       RowBox[{"1787", "\[Rule]", "1788"}], ",", 
       RowBox[{"1771", "\[Rule]", "1340"}], ",", 
       RowBox[{"1771", "\[Rule]", "2204"}], ",", 
       RowBox[{"1771", "\[Rule]", "2204"}], ",", 
       RowBox[{"1771", "\[Rule]", "1772"}], ",", 
       RowBox[{"1819", "\[Rule]", "1388"}], ",", 
       RowBox[{"1819", "\[Rule]", "2252"}], ",", 
       RowBox[{"1819", "\[Rule]", "2252"}], ",", 
       RowBox[{"1819", "\[Rule]", "1820"}], ",", 
       RowBox[{"1801", "\[Rule]", "1370"}], ",", 
       RowBox[{"1801", "\[Rule]", "2234"}], ",", 
       RowBox[{"1801", "\[Rule]", "2234"}], ",", 
       RowBox[{"1801", "\[Rule]", "1802"}], ",", 
       RowBox[{"1783", "\[Rule]", "1352"}], ",", 
       RowBox[{"1783", "\[Rule]", "2216"}], ",", 
       RowBox[{"1783", "\[Rule]", "2216"}], ",", 
       RowBox[{"1783", "\[Rule]", "1784"}], ",", 
       RowBox[{"1833", "\[Rule]", "1402"}], ",", 
       RowBox[{"1833", "\[Rule]", "2266"}], ",", 
       RowBox[{"1833", "\[Rule]", "2266"}], ",", 
       RowBox[{"1833", "\[Rule]", "1834"}], ",", 
       RowBox[{"1815", "\[Rule]", "1384"}], ",", 
       RowBox[{"1815", "\[Rule]", "2248"}], ",", 
       RowBox[{"1815", "\[Rule]", "2248"}], ",", 
       RowBox[{"1815", "\[Rule]", "1816"}], ",", 
       RowBox[{"1797", "\[Rule]", "1366"}], ",", 
       RowBox[{"1797", "\[Rule]", "2230"}], ",", 
       RowBox[{"1797", "\[Rule]", "2230"}], ",", 
       RowBox[{"1797", "\[Rule]", "1798"}], ",", 
       RowBox[{"2477", "\[Rule]", "2154"}], ",", 
       RowBox[{"2477", "\[Rule]", "2154"}], ",", 
       RowBox[{"2477", "\[Rule]", "3018"}], ",", 
       RowBox[{"2477", "\[Rule]", "3018"}], ",", 
       RowBox[{"2477", "\[Rule]", "2046"}], ",", 
       RowBox[{"2477", "\[Rule]", "2046"}], ",", 
       RowBox[{"2477", "\[Rule]", "2910"}], ",", 
       RowBox[{"2477", "\[Rule]", "2910"}], ",", 
       RowBox[{"2477", "\[Rule]", "2478"}], ",", 
       RowBox[{"2369", "\[Rule]", "2046"}], ",", 
       RowBox[{"2369", "\[Rule]", "2046"}], ",", 
       RowBox[{"2369", "\[Rule]", "2910"}], ",", 
       RowBox[{"2369", "\[Rule]", "2910"}], ",", 
       RowBox[{"2369", "\[Rule]", "1938"}], ",", 
       RowBox[{"2369", "\[Rule]", "1938"}], ",", 
       RowBox[{"2369", "\[Rule]", "2802"}], ",", 
       RowBox[{"2369", "\[Rule]", "2802"}], ",", 
       RowBox[{"2369", "\[Rule]", "2370"}], ",", 
       RowBox[{"2045", "\[Rule]", "1614"}], ",", 
       RowBox[{"2045", "\[Rule]", "1614"}], ",", 
       RowBox[{"2045", "\[Rule]", "2478"}], ",", 
       RowBox[{"2045", "\[Rule]", "2478"}], ",", 
       RowBox[{"2045", "\[Rule]", "1506"}], ",", 
       RowBox[{"2045", "\[Rule]", "1506"}], ",", 
       RowBox[{"2045", "\[Rule]", "2370"}], ",", 
       RowBox[{"2045", "\[Rule]", "2370"}], ",", 
       RowBox[{"2045", "\[Rule]", "2046"}], ",", 
       RowBox[{"2261", "\[Rule]", "1938"}], ",", 
       RowBox[{"2261", "\[Rule]", "1938"}], ",", 
       RowBox[{"2261", "\[Rule]", "2802"}], ",", 
       RowBox[{"2261", "\[Rule]", "2802"}], ",", 
       RowBox[{"2261", "\[Rule]", "1830"}], ",", 
       RowBox[{"2261", "\[Rule]", "1830"}], ",", 
       RowBox[{"2261", "\[Rule]", "2694"}], ",", 
       RowBox[{"2261", "\[Rule]", "2694"}], ",", 
       RowBox[{"2261", "\[Rule]", "2262"}], ",", 
       RowBox[{"1937", "\[Rule]", "1506"}], ",", 
       RowBox[{"1937", "\[Rule]", "1506"}], ",", 
       RowBox[{"1937", "\[Rule]", "2370"}], ",", 
       RowBox[{"1937", "\[Rule]", "2370"}], ",", 
       RowBox[{"1937", "\[Rule]", "1398"}], ",", 
       RowBox[{"1937", "\[Rule]", "1398"}], ",", 
       RowBox[{"1937", "\[Rule]", "2262"}], ",", 
       RowBox[{"1937", "\[Rule]", "2262"}], ",", 
       RowBox[{"1937", "\[Rule]", "1938"}], ",", 
       RowBox[{"1829", "\[Rule]", "1398"}], ",", 
       RowBox[{"1829", "\[Rule]", "2262"}], ",", 
       RowBox[{"1829", "\[Rule]", "2262"}], ",", 
       RowBox[{"1829", "\[Rule]", "1830"}], ",", 
       RowBox[{"2459", "\[Rule]", "2136"}], ",", 
       RowBox[{"2459", "\[Rule]", "2136"}], ",", 
       RowBox[{"2459", "\[Rule]", "3000"}], ",", 
       RowBox[{"2459", "\[Rule]", "3000"}], ",", 
       RowBox[{"2459", "\[Rule]", "2028"}], ",", 
       RowBox[{"2459", "\[Rule]", "2028"}], ",", 
       RowBox[{"2459", "\[Rule]", "2892"}], ",", 
       RowBox[{"2459", "\[Rule]", "2892"}], ",", 
       RowBox[{"2459", "\[Rule]", "2460"}], ",", 
       RowBox[{"2351", "\[Rule]", "2028"}], ",", 
       RowBox[{"2351", "\[Rule]", "2028"}], ",", 
       RowBox[{"2351", "\[Rule]", "2892"}], ",", 
       RowBox[{"2351", "\[Rule]", "2892"}], ",", 
       RowBox[{"2351", "\[Rule]", "1920"}], ",", 
       RowBox[{"2351", "\[Rule]", "1920"}], ",", 
       RowBox[{"2351", "\[Rule]", "2784"}], ",", 
       RowBox[{"2351", "\[Rule]", "2784"}], ",", 
       RowBox[{"2351", "\[Rule]", "2352"}], ",", 
       RowBox[{"2027", "\[Rule]", "1596"}], ",", 
       RowBox[{"2027", "\[Rule]", "1596"}], ",", 
       RowBox[{"2027", "\[Rule]", "2460"}], ",", 
       RowBox[{"2027", "\[Rule]", "2460"}], ",", 
       RowBox[{"2027", "\[Rule]", "1488"}], ",", 
       RowBox[{"2027", "\[Rule]", "1488"}], ",", 
       RowBox[{"2027", "\[Rule]", "2352"}], ",", 
       RowBox[{"2027", "\[Rule]", "2352"}], ",", 
       RowBox[{"2027", "\[Rule]", "2028"}], ",", 
       RowBox[{"2243", "\[Rule]", "1920"}], ",", 
       RowBox[{"2243", "\[Rule]", "1920"}], ",", 
       RowBox[{"2243", "\[Rule]", "2784"}], ",", 
       RowBox[{"2243", "\[Rule]", "2784"}], ",", 
       RowBox[{"2243", "\[Rule]", "1812"}], ",", 
       RowBox[{"2243", "\[Rule]", "1812"}], ",", 
       RowBox[{"2243", "\[Rule]", "2676"}], ",", 
       RowBox[{"2243", "\[Rule]", "2676"}], ",", 
       RowBox[{"2243", "\[Rule]", "2244"}], ",", 
       RowBox[{"1919", "\[Rule]", "1488"}], ",", 
       RowBox[{"1919", "\[Rule]", "1488"}], ",", 
       RowBox[{"1919", "\[Rule]", "2352"}], ",", 
       RowBox[{"1919", "\[Rule]", "2352"}], ",", 
       RowBox[{"1919", "\[Rule]", "1380"}], ",", 
       RowBox[{"1919", "\[Rule]", "1380"}], ",", 
       RowBox[{"1919", "\[Rule]", "2244"}], ",", 
       RowBox[{"1919", "\[Rule]", "2244"}], ",", 
       RowBox[{"1919", "\[Rule]", "1920"}], ",", 
       RowBox[{"1811", "\[Rule]", "1380"}], ",", 
       RowBox[{"1811", "\[Rule]", "2244"}], ",", 
       RowBox[{"1811", "\[Rule]", "2244"}], ",", 
       RowBox[{"1811", "\[Rule]", "1812"}], ",", 
       RowBox[{"745", "\[Rule]", "422"}], ",", 
       RowBox[{"745", "\[Rule]", "422"}], ",", 
       RowBox[{"745", "\[Rule]", "1286"}], ",", 
       RowBox[{"745", "\[Rule]", "1286"}], ",", 
       RowBox[{"745", "\[Rule]", "314"}], ",", 
       RowBox[{"745", "\[Rule]", "314"}], ",", 
       RowBox[{"745", "\[Rule]", "1178"}], ",", 
       RowBox[{"745", "\[Rule]", "1178"}], ",", 
       RowBox[{"745", "\[Rule]", "746"}], ",", 
       RowBox[{"637", "\[Rule]", "314"}], ",", 
       RowBox[{"637", "\[Rule]", "314"}], ",", 
       RowBox[{"637", "\[Rule]", "1178"}], ",", 
       RowBox[{"637", "\[Rule]", "1178"}], ",", 
       RowBox[{"637", "\[Rule]", "206"}], ",", 
       RowBox[{"637", "\[Rule]", "1070"}], ",", 
       RowBox[{"637", "\[Rule]", "638"}], ",", 
       RowBox[{"313", "\[Rule]", "746"}], ",", 
       RowBox[{"313", "\[Rule]", "746"}], ",", 
       RowBox[{"313", "\[Rule]", "638"}], ",", 
       RowBox[{"313", "\[Rule]", "638"}], ",", 
       RowBox[{"313", "\[Rule]", "314"}], ",", 
       RowBox[{"1609", "\[Rule]", "1286"}], ",", 
       RowBox[{"1609", "\[Rule]", "1286"}], ",", 
       RowBox[{"1609", "\[Rule]", "2150"}], ",", 
       RowBox[{"1609", "\[Rule]", "2150"}], ",", 
       RowBox[{"1609", "\[Rule]", "1178"}], ",", 
       RowBox[{"1609", "\[Rule]", "1178"}], ",", 
       RowBox[{"1609", "\[Rule]", "2042"}], ",", 
       RowBox[{"1609", "\[Rule]", "2042"}], ",", 
       RowBox[{"1609", "\[Rule]", "1610"}], ",", 
       RowBox[{"1501", "\[Rule]", "1178"}], ",", 
       RowBox[{"1501", "\[Rule]", "1178"}], ",", 
       RowBox[{"1501", "\[Rule]", "2042"}], ",", 
       RowBox[{"1501", "\[Rule]", "2042"}], ",", 
       RowBox[{"1501", "\[Rule]", "1070"}], ",", 
       RowBox[{"1501", "\[Rule]", "1070"}], ",", 
       RowBox[{"1501", "\[Rule]", "1934"}], ",", 
       RowBox[{"1501", "\[Rule]", "1934"}], ",", 
       RowBox[{"1501", "\[Rule]", "1502"}], ",", 
       RowBox[{"1177", "\[Rule]", "746"}], ",", 
       RowBox[{"1177", "\[Rule]", "746"}], ",", 
       RowBox[{"1177", "\[Rule]", "1610"}], ",", 
       RowBox[{"1177", "\[Rule]", "1610"}], ",", 
       RowBox[{"1177", "\[Rule]", "638"}], ",", 
       RowBox[{"1177", "\[Rule]", "638"}], ",", 
       RowBox[{"1177", "\[Rule]", "1502"}], ",", 
       RowBox[{"1177", "\[Rule]", "1502"}], ",", 
       RowBox[{"1177", "\[Rule]", "1178"}], ",", 
       RowBox[{"529", "\[Rule]", "206"}], ",", 
       RowBox[{"529", "\[Rule]", "1070"}], ",", 
       RowBox[{"529", "\[Rule]", "98"}], ",", 
       RowBox[{"529", "\[Rule]", "98"}], ",", 
       RowBox[{"529", "\[Rule]", "962"}], ",", 
       RowBox[{"529", "\[Rule]", "962"}], ",", 
       RowBox[{"529", "\[Rule]", "530"}], ",", 
       RowBox[{"205", "\[Rule]", "638"}], ",", 
       RowBox[{"205", "\[Rule]", "530"}], ",", 
       RowBox[{"205", "\[Rule]", "206"}], ",", 
       RowBox[{"1393", "\[Rule]", "1070"}], ",", 
       RowBox[{"1393", "\[Rule]", "1070"}], ",", 
       RowBox[{"1393", "\[Rule]", "1934"}], ",", 
       RowBox[{"1393", "\[Rule]", "1934"}], ",", 
       RowBox[{"1393", "\[Rule]", "962"}], ",", 
       RowBox[{"1393", "\[Rule]", "1826"}], ",", 
       RowBox[{"1393", "\[Rule]", "1394"}], ",", 
       RowBox[{"1069", "\[Rule]", "638"}], ",", 
       RowBox[{"1069", "\[Rule]", "1502"}], ",", 
       RowBox[{"1069", "\[Rule]", "1502"}], ",", 
       RowBox[{"1069", "\[Rule]", "530"}], ",", 
       RowBox[{"1069", "\[Rule]", "1394"}], ",", 
       RowBox[{"1069", "\[Rule]", "1394"}], ",", 
       RowBox[{"1069", "\[Rule]", "1070"}], ",", 
       RowBox[{"97", "\[Rule]", "530"}], ",", 
       RowBox[{"97", "\[Rule]", "530"}], ",", 
       RowBox[{"97", "\[Rule]", "98"}], ",", 
       RowBox[{"961", "\[Rule]", "530"}], ",", 
       RowBox[{"961", "\[Rule]", "530"}], ",", 
       RowBox[{"961", "\[Rule]", "1394"}], ",", 
       RowBox[{"961", "\[Rule]", "962"}], ",", 
       RowBox[{"2473", "\[Rule]", "2150"}], ",", 
       RowBox[{"2473", "\[Rule]", "2150"}], ",", 
       RowBox[{"2473", "\[Rule]", "3014"}], ",", 
       RowBox[{"2473", "\[Rule]", "3014"}], ",", 
       RowBox[{"2473", "\[Rule]", "2042"}], ",", 
       RowBox[{"2473", "\[Rule]", "2042"}], ",", 
       RowBox[{"2473", "\[Rule]", "2906"}], ",", 
       RowBox[{"2473", "\[Rule]", "2906"}], ",", 
       RowBox[{"2473", "\[Rule]", "2474"}], ",", 
       RowBox[{"2365", "\[Rule]", "2042"}], ",", 
       RowBox[{"2365", "\[Rule]", "2042"}], ",", 
       RowBox[{"2365", "\[Rule]", "2906"}], ",", 
       RowBox[{"2365", "\[Rule]", "2906"}], ",", 
       RowBox[{"2365", "\[Rule]", "1934"}], ",", 
       RowBox[{"2365", "\[Rule]", "1934"}], ",", 
       RowBox[{"2365", "\[Rule]", "2798"}], ",", 
       RowBox[{"2365", "\[Rule]", "2798"}], ",", 
       RowBox[{"2365", "\[Rule]", "2366"}], ",", 
       RowBox[{"2041", "\[Rule]", "1610"}], ",", 
       RowBox[{"2041", "\[Rule]", "1610"}], ",", 
       RowBox[{"2041", "\[Rule]", "2474"}], ",", 
       RowBox[{"2041", "\[Rule]", "2474"}], ",", 
       RowBox[{"2041", "\[Rule]", "1502"}], ",", 
       RowBox[{"2041", "\[Rule]", "1502"}], ",", 
       RowBox[{"2041", "\[Rule]", "2366"}], ",", 
       RowBox[{"2041", "\[Rule]", "2366"}], ",", 
       RowBox[{"2041", "\[Rule]", "2042"}], ",", 
       RowBox[{"2257", "\[Rule]", "1934"}], ",", 
       RowBox[{"2257", "\[Rule]", "1934"}], ",", 
       RowBox[{"2257", "\[Rule]", "2798"}], ",", 
       RowBox[{"2257", "\[Rule]", "2798"}], ",", 
       RowBox[{"2257", "\[Rule]", "1826"}], ",", 
       RowBox[{"2257", "\[Rule]", "1826"}], ",", 
       RowBox[{"2257", "\[Rule]", "2690"}], ",", 
       RowBox[{"2257", "\[Rule]", "2690"}], ",", 
       RowBox[{"2257", "\[Rule]", "2258"}], ",", 
       RowBox[{"1933", "\[Rule]", "1502"}], ",", 
       RowBox[{"1933", "\[Rule]", "1502"}], ",", 
       RowBox[{"1933", "\[Rule]", "2366"}], ",", 
       RowBox[{"1933", "\[Rule]", "2366"}], ",", 
       RowBox[{"1933", "\[Rule]", "1394"}], ",", 
       RowBox[{"1933", "\[Rule]", "1394"}], ",", 
       RowBox[{"1933", "\[Rule]", "2258"}], ",", 
       RowBox[{"1933", "\[Rule]", "2258"}], ",", 
       RowBox[{"1933", "\[Rule]", "1934"}], ",", 
       RowBox[{"1825", "\[Rule]", "1394"}], ",", 
       RowBox[{"1825", "\[Rule]", "2258"}], ",", 
       RowBox[{"1825", "\[Rule]", "2258"}], ",", 
       RowBox[{"1825", "\[Rule]", "1826"}], ",", 
       RowBox[{"354", "\[Rule]", "339"}], ",", 
       RowBox[{"354", "\[Rule]", "369"}], ",", 
       RowBox[{"354", "\[Rule]", "351"}], ",", 
       RowBox[{"1218", "\[Rule]", "1203"}], ",", 
       RowBox[{"1218", "\[Rule]", "1233"}], ",", 
       RowBox[{"1218", "\[Rule]", "1215"}], ",", 
       RowBox[{"246", "\[Rule]", "231"}], ",", 
       RowBox[{"246", "\[Rule]", "261"}], ",", 
       RowBox[{"246", "\[Rule]", "243"}], ",", 
       RowBox[{"1110", "\[Rule]", "1095"}], ",", 
       RowBox[{"1110", "\[Rule]", "1125"}], ",", 
       RowBox[{"1110", "\[Rule]", "1107"}], ",", 
       RowBox[{"678", "\[Rule]", "663"}], ",", 
       RowBox[{"678", "\[Rule]", "693"}], ",", 
       RowBox[{"678", "\[Rule]", "675"}], ",", 
       RowBox[{"384", "\[Rule]", "369"}], ",", 
       RowBox[{"384", "\[Rule]", "399"}], ",", 
       RowBox[{"384", "\[Rule]", "381"}], ",", 
       RowBox[{"1248", "\[Rule]", "1233"}], ",", 
       RowBox[{"1248", "\[Rule]", "1263"}], ",", 
       RowBox[{"1248", "\[Rule]", "1245"}], ",", 
       RowBox[{"708", "\[Rule]", "693"}], ",", 
       RowBox[{"708", "\[Rule]", "723"}], ",", 
       RowBox[{"708", "\[Rule]", "705"}], ",", 
       RowBox[{"368", "\[Rule]", "351"}], ",", 
       RowBox[{"368", "\[Rule]", "381"}], ",", 
       RowBox[{"368", "\[Rule]", "369"}], ",", 
       RowBox[{"368", "\[Rule]", "365"}], ",", 
       RowBox[{"1232", "\[Rule]", "1215"}], ",", 
       RowBox[{"1232", "\[Rule]", "1245"}], ",", 
       RowBox[{"1232", "\[Rule]", "1233"}], ",", 
       RowBox[{"1232", "\[Rule]", "1229"}], ",", 
       RowBox[{"260", "\[Rule]", "243"}], ",", 
       RowBox[{"260", "\[Rule]", "273"}], ",", 
       RowBox[{"260", "\[Rule]", "261"}], ",", 
       RowBox[{"260", "\[Rule]", "257"}], ",", 
       RowBox[{"1124", "\[Rule]", "1107"}], ",", 
       RowBox[{"1124", "\[Rule]", "1137"}], ",", 
       RowBox[{"1124", "\[Rule]", "1125"}], ",", 
       RowBox[{"1124", "\[Rule]", "1121"}], ",", 
       RowBox[{"692", "\[Rule]", "675"}], ",", 
       RowBox[{"692", "\[Rule]", "705"}], ",", 
       RowBox[{"692", "\[Rule]", "693"}], ",", 
       RowBox[{"692", "\[Rule]", "689"}], ",", 
       RowBox[{"138", "\[Rule]", "123"}], ",", 
       RowBox[{"138", "\[Rule]", "153"}], ",", 
       RowBox[{"138", "\[Rule]", "135"}], ",", 
       RowBox[{"1002", "\[Rule]", "987"}], ",", 
       RowBox[{"1002", "\[Rule]", "1017"}], ",", 
       RowBox[{"1002", "\[Rule]", "999"}], ",", 
       RowBox[{"570", "\[Rule]", "555"}], ",", 
       RowBox[{"570", "\[Rule]", "585"}], ",", 
       RowBox[{"570", "\[Rule]", "567"}], ",", 
       RowBox[{"152", "\[Rule]", "135"}], ",", 
       RowBox[{"152", "\[Rule]", "165"}], ",", 
       RowBox[{"152", "\[Rule]", "153"}], ",", 
       RowBox[{"152", "\[Rule]", "149"}], ",", 
       RowBox[{"1016", "\[Rule]", "999"}], ",", 
       RowBox[{"1016", "\[Rule]", "1029"}], ",", 
       RowBox[{"1016", "\[Rule]", "1017"}], ",", 
       RowBox[{"1016", "\[Rule]", "1013"}], ",", 
       RowBox[{"584", "\[Rule]", "567"}], ",", 
       RowBox[{"584", "\[Rule]", "597"}], ",", 
       RowBox[{"584", "\[Rule]", "585"}], ",", 
       RowBox[{"584", "\[Rule]", "581"}], ",", 
       RowBox[{"416", "\[Rule]", "399"}], ",", 
       RowBox[{"416", "\[Rule]", "431"}], ",", 
       RowBox[{"416", "\[Rule]", "413"}], ",", 
       RowBox[{"1280", "\[Rule]", "1263"}], ",", 
       RowBox[{"1280", "\[Rule]", "1295"}], ",", 
       RowBox[{"1280", "\[Rule]", "1277"}], ",", 
       RowBox[{"740", "\[Rule]", "723"}], ",", 
       RowBox[{"740", "\[Rule]", "755"}], ",", 
       RowBox[{"740", "\[Rule]", "737"}], ",", 
       RowBox[{"398", "\[Rule]", "381"}], ",", 
       RowBox[{"398", "\[Rule]", "413"}], ",", 
       RowBox[{"398", "\[Rule]", "399"}], ",", 
       RowBox[{"398", "\[Rule]", "395"}], ",", 
       RowBox[{"1262", "\[Rule]", "1245"}], ",", 
       RowBox[{"1262", "\[Rule]", "1277"}], ",", 
       RowBox[{"1262", "\[Rule]", "1263"}], ",", 
       RowBox[{"1262", "\[Rule]", "1259"}], ",", 
       RowBox[{"722", "\[Rule]", "705"}], ",", 
       RowBox[{"722", "\[Rule]", "737"}], ",", 
       RowBox[{"722", "\[Rule]", "723"}], ",", 
       RowBox[{"722", "\[Rule]", "719"}], ",", 
       RowBox[{"380", "\[Rule]", "365"}], ",", 
       RowBox[{"380", "\[Rule]", "395"}], ",", 
       RowBox[{"380", "\[Rule]", "381"}], ",", 
       RowBox[{"380", "\[Rule]", "377"}], ",", 
       RowBox[{"1244", "\[Rule]", "1229"}], ",", 
       RowBox[{"1244", "\[Rule]", "1259"}], ",", 
       RowBox[{"1244", "\[Rule]", "1245"}], ",", 
       RowBox[{"1244", "\[Rule]", "1241"}], ",", 
       RowBox[{"272", "\[Rule]", "257"}], ",", 
       RowBox[{"272", "\[Rule]", "287"}], ",", 
       RowBox[{"272", "\[Rule]", "273"}], ",", 
       RowBox[{"272", "\[Rule]", "269"}], ",", 
       RowBox[{"1136", "\[Rule]", "1121"}], ",", 
       RowBox[{"1136", "\[Rule]", "1151"}], ",", 
       RowBox[{"1136", "\[Rule]", "1137"}], ",", 
       RowBox[{"1136", "\[Rule]", "1133"}], ",", 
       RowBox[{"704", "\[Rule]", "689"}], ",", 
       RowBox[{"704", "\[Rule]", "719"}], ",", 
       RowBox[{"704", "\[Rule]", "705"}], ",", 
       RowBox[{"704", "\[Rule]", "701"}], ",", 
       RowBox[{"164", "\[Rule]", "149"}], ",", 
       RowBox[{"164", "\[Rule]", "179"}], ",", 
       RowBox[{"164", "\[Rule]", "165"}], ",", 
       RowBox[{"164", "\[Rule]", "161"}], ",", 
       RowBox[{"1028", "\[Rule]", "1013"}], ",", 
       RowBox[{"1028", "\[Rule]", "1043"}], ",", 
       RowBox[{"1028", "\[Rule]", "1029"}], ",", 
       RowBox[{"1028", "\[Rule]", "1025"}], ",", 
       RowBox[{"596", "\[Rule]", "581"}], ",", 
       RowBox[{"596", "\[Rule]", "611"}], ",", 
       RowBox[{"596", "\[Rule]", "597"}], ",", 
       RowBox[{"596", "\[Rule]", "593"}], ",", 
       RowBox[{"2082", "\[Rule]", "2067"}], ",", 
       RowBox[{"2082", "\[Rule]", "2097"}], ",", 
       RowBox[{"2082", "\[Rule]", "2079"}], ",", 
       RowBox[{"1974", "\[Rule]", "1959"}], ",", 
       RowBox[{"1974", "\[Rule]", "1989"}], ",", 
       RowBox[{"1974", "\[Rule]", "1971"}], ",", 
       RowBox[{"1542", "\[Rule]", "1527"}], ",", 
       RowBox[{"1542", "\[Rule]", "1557"}], ",", 
       RowBox[{"1542", "\[Rule]", "1539"}], ",", 
       RowBox[{"2112", "\[Rule]", "2097"}], ",", 
       RowBox[{"2112", "\[Rule]", "2127"}], ",", 
       RowBox[{"2112", "\[Rule]", "2109"}], ",", 
       RowBox[{"1572", "\[Rule]", "1557"}], ",", 
       RowBox[{"1572", "\[Rule]", "1587"}], ",", 
       RowBox[{"1572", "\[Rule]", "1569"}], ",", 
       RowBox[{"2096", "\[Rule]", "2079"}], ",", 
       RowBox[{"2096", "\[Rule]", "2109"}], ",", 
       RowBox[{"2096", "\[Rule]", "2097"}], ",", 
       RowBox[{"2096", "\[Rule]", "2093"}], ",", 
       RowBox[{"1988", "\[Rule]", "1971"}], ",", 
       RowBox[{"1988", "\[Rule]", "2001"}], ",", 
       RowBox[{"1988", "\[Rule]", "1989"}], ",", 
       RowBox[{"1988", "\[Rule]", "1985"}], ",", 
       RowBox[{"1556", "\[Rule]", "1539"}], ",", 
       RowBox[{"1556", "\[Rule]", "1569"}], ",", 
       RowBox[{"1556", "\[Rule]", "1557"}], ",", 
       RowBox[{"1556", "\[Rule]", "1553"}], ",", 
       RowBox[{"1866", "\[Rule]", "1851"}], ",", 
       RowBox[{"1866", "\[Rule]", "1881"}], ",", 
       RowBox[{"1866", "\[Rule]", "1863"}], ",", 
       RowBox[{"1434", "\[Rule]", "1419"}], ",", 
       RowBox[{"1434", "\[Rule]", "1449"}], ",", 
       RowBox[{"1434", "\[Rule]", "1431"}], ",", 
       RowBox[{"1880", "\[Rule]", "1863"}], ",", 
       RowBox[{"1880", "\[Rule]", "1893"}], ",", 
       RowBox[{"1880", "\[Rule]", "1881"}], ",", 
       RowBox[{"1880", "\[Rule]", "1877"}], ",", 
       RowBox[{"1448", "\[Rule]", "1431"}], ",", 
       RowBox[{"1448", "\[Rule]", "1461"}], ",", 
       RowBox[{"1448", "\[Rule]", "1449"}], ",", 
       RowBox[{"1448", "\[Rule]", "1445"}], ",", 
       RowBox[{"2144", "\[Rule]", "2127"}], ",", 
       RowBox[{"2144", "\[Rule]", "2159"}], ",", 
       RowBox[{"2144", "\[Rule]", "2141"}], ",", 
       RowBox[{"1604", "\[Rule]", "1587"}], ",", 
       RowBox[{"1604", "\[Rule]", "1619"}], ",", 
       RowBox[{"1604", "\[Rule]", "1601"}], ",", 
       RowBox[{"2126", "\[Rule]", "2109"}], ",", 
       RowBox[{"2126", "\[Rule]", "2141"}], ",", 
       RowBox[{"2126", "\[Rule]", "2127"}], ",", 
       RowBox[{"2126", "\[Rule]", "2123"}], ",", 
       RowBox[{"1586", "\[Rule]", "1569"}], ",", 
       RowBox[{"1586", "\[Rule]", "1601"}], ",", 
       RowBox[{"1586", "\[Rule]", "1587"}], ",", 
       RowBox[{"1586", "\[Rule]", "1583"}], ",", 
       RowBox[{"2108", "\[Rule]", "2093"}], ",", 
       RowBox[{"2108", "\[Rule]", "2123"}], ",", 
       RowBox[{"2108", "\[Rule]", "2109"}], ",", 
       RowBox[{"2108", "\[Rule]", "2105"}], ",", 
       RowBox[{"2000", "\[Rule]", "1985"}], ",", 
       RowBox[{"2000", "\[Rule]", "2015"}], ",", 
       RowBox[{"2000", "\[Rule]", "2001"}], ",", 
       RowBox[{"2000", "\[Rule]", "1997"}], ",", 
       RowBox[{"1568", "\[Rule]", "1553"}], ",", 
       RowBox[{"1568", "\[Rule]", "1583"}], ",", 
       RowBox[{"1568", "\[Rule]", "1569"}], ",", 
       RowBox[{"1568", "\[Rule]", "1565"}], ",", 
       RowBox[{"1892", "\[Rule]", "1877"}], ",", 
       RowBox[{"1892", "\[Rule]", "1907"}], ",", 
       RowBox[{"1892", "\[Rule]", "1893"}], ",", 
       RowBox[{"1892", "\[Rule]", "1889"}], ",", 
       RowBox[{"1460", "\[Rule]", "1445"}], ",", 
       RowBox[{"1460", "\[Rule]", "1475"}], ",", 
       RowBox[{"1460", "\[Rule]", "1461"}], ",", 
       RowBox[{"1460", "\[Rule]", "1457"}], ",", 
       RowBox[{"30", "\[Rule]", "15"}], ",", 
       RowBox[{"30", "\[Rule]", "45"}], ",", 
       RowBox[{"30", "\[Rule]", "27"}], ",", 
       RowBox[{"894", "\[Rule]", "879"}], ",", 
       RowBox[{"894", "\[Rule]", "909"}], ",", 
       RowBox[{"894", "\[Rule]", "891"}], ",", 
       RowBox[{"462", "\[Rule]", "447"}], ",", 
       RowBox[{"462", "\[Rule]", "477"}], ",", 
       RowBox[{"462", "\[Rule]", "459"}], ",", 
       RowBox[{"44", "\[Rule]", "27"}], ",", 
       RowBox[{"44", "\[Rule]", "57"}], ",", 
       RowBox[{"44", "\[Rule]", "45"}], ",", 
       RowBox[{"44", "\[Rule]", "41"}], ",", 
       RowBox[{"908", "\[Rule]", "891"}], ",", 
       RowBox[{"908", "\[Rule]", "921"}], ",", 
       RowBox[{"908", "\[Rule]", "909"}], ",", 
       RowBox[{"908", "\[Rule]", "905"}], ",", 
       RowBox[{"476", "\[Rule]", "459"}], ",", 
       RowBox[{"476", "\[Rule]", "489"}], ",", 
       RowBox[{"476", "\[Rule]", "477"}], ",", 
       RowBox[{"476", "\[Rule]", "473"}], ",", 
       RowBox[{"56", "\[Rule]", "41"}], ",", 
       RowBox[{"56", "\[Rule]", "71"}], ",", 
       RowBox[{"56", "\[Rule]", "57"}], ",", 
       RowBox[{"56", "\[Rule]", "53"}], ",", 
       RowBox[{"920", "\[Rule]", "905"}], ",", 
       RowBox[{"920", "\[Rule]", "935"}], ",", 
       RowBox[{"920", "\[Rule]", "921"}], ",", 
       RowBox[{"920", "\[Rule]", "917"}], ",", 
       RowBox[{"488", "\[Rule]", "473"}], ",", 
       RowBox[{"488", "\[Rule]", "503"}], ",", 
       RowBox[{"488", "\[Rule]", "489"}], ",", 
       RowBox[{"488", "\[Rule]", "485"}], ",", 
       RowBox[{"1758", "\[Rule]", "1743"}], ",", 
       RowBox[{"1758", "\[Rule]", "1773"}], ",", 
       RowBox[{"1758", "\[Rule]", "1755"}], ",", 
       RowBox[{"1326", "\[Rule]", "1311"}], ",", 
       RowBox[{"1326", "\[Rule]", "1341"}], ",", 
       RowBox[{"1326", "\[Rule]", "1323"}], ",", 
       RowBox[{"1772", "\[Rule]", "1755"}], ",", 
       RowBox[{"1772", "\[Rule]", "1785"}], ",", 
       RowBox[{"1772", "\[Rule]", "1773"}], ",", 
       RowBox[{"1772", "\[Rule]", "1769"}], ",", 
       RowBox[{"1340", "\[Rule]", "1323"}], ",", 
       RowBox[{"1340", "\[Rule]", "1353"}], ",", 
       RowBox[{"1340", "\[Rule]", "1341"}], ",", 
       RowBox[{"1340", "\[Rule]", "1337"}], ",", 
       RowBox[{"1784", "\[Rule]", "1769"}], ",", 
       RowBox[{"1784", "\[Rule]", "1799"}], ",", 
       RowBox[{"1784", "\[Rule]", "1785"}], ",", 
       RowBox[{"1784", "\[Rule]", "1781"}], ",", 
       RowBox[{"1352", "\[Rule]", "1337"}], ",", 
       RowBox[{"1352", "\[Rule]", "1367"}], ",", 
       RowBox[{"1352", "\[Rule]", "1353"}], ",", 
       RowBox[{"1352", "\[Rule]", "1349"}], ",", 
       RowBox[{"430", "\[Rule]", "413"}], ",", 
       RowBox[{"430", "\[Rule]", "431"}], ",", 
       RowBox[{"430", "\[Rule]", "427"}], ",", 
       RowBox[{"1294", "\[Rule]", "1277"}], ",", 
       RowBox[{"1294", "\[Rule]", "1295"}], ",", 
       RowBox[{"1294", "\[Rule]", "1291"}], ",", 
       RowBox[{"754", "\[Rule]", "737"}], ",", 
       RowBox[{"754", "\[Rule]", "755"}], ",", 
       RowBox[{"754", "\[Rule]", "751"}], ",", 
       RowBox[{"412", "\[Rule]", "395"}], ",", 
       RowBox[{"412", "\[Rule]", "427"}], ",", 
       RowBox[{"412", "\[Rule]", "413"}], ",", 
       RowBox[{"412", "\[Rule]", "409"}], ",", 
       RowBox[{"1276", "\[Rule]", "1259"}], ",", 
       RowBox[{"1276", "\[Rule]", "1291"}], ",", 
       RowBox[{"1276", "\[Rule]", "1277"}], ",", 
       RowBox[{"1276", "\[Rule]", "1273"}], ",", 
       RowBox[{"736", "\[Rule]", "719"}], ",", 
       RowBox[{"736", "\[Rule]", "751"}], ",", 
       RowBox[{"736", "\[Rule]", "737"}], ",", 
       RowBox[{"736", "\[Rule]", "733"}], ",", 
       RowBox[{"2158", "\[Rule]", "2141"}], ",", 
       RowBox[{"2158", "\[Rule]", "2159"}], ",", 
       RowBox[{"2158", "\[Rule]", "2155"}], ",", 
       RowBox[{"1618", "\[Rule]", "1601"}], ",", 
       RowBox[{"1618", "\[Rule]", "1619"}], ",", 
       RowBox[{"1618", "\[Rule]", "1615"}], ",", 
       RowBox[{"2140", "\[Rule]", "2123"}], ",", 
       RowBox[{"2140", "\[Rule]", "2155"}], ",", 
       RowBox[{"2140", "\[Rule]", "2141"}], ",", 
       RowBox[{"2140", "\[Rule]", "2137"}], ",", 
       RowBox[{"1600", "\[Rule]", "1583"}], ",", 
       RowBox[{"1600", "\[Rule]", "1615"}], ",", 
       RowBox[{"1600", "\[Rule]", "1601"}], ",", 
       RowBox[{"1600", "\[Rule]", "1597"}], ",", 
       RowBox[{"394", "\[Rule]", "377"}], ",", 
       RowBox[{"394", "\[Rule]", "409"}], ",", 
       RowBox[{"394", "\[Rule]", "395"}], ",", 
       RowBox[{"394", "\[Rule]", "391"}], ",", 
       RowBox[{"1258", "\[Rule]", "1241"}], ",", 
       RowBox[{"1258", "\[Rule]", "1273"}], ",", 
       RowBox[{"1258", "\[Rule]", "1259"}], ",", 
       RowBox[{"1258", "\[Rule]", "1255"}], ",", 
       RowBox[{"286", "\[Rule]", "269"}], ",", 
       RowBox[{"286", "\[Rule]", "301"}], ",", 
       RowBox[{"286", "\[Rule]", "287"}], ",", 
       RowBox[{"286", "\[Rule]", "283"}], ",", 
       RowBox[{"1150", "\[Rule]", "1133"}], ",", 
       RowBox[{"1150", "\[Rule]", "1165"}], ",", 
       RowBox[{"1150", "\[Rule]", "1151"}], ",", 
       RowBox[{"1150", "\[Rule]", "1147"}], ",", 
       RowBox[{"718", "\[Rule]", "701"}], ",", 
       RowBox[{"718", "\[Rule]", "733"}], ",", 
       RowBox[{"718", "\[Rule]", "719"}], ",", 
       RowBox[{"718", "\[Rule]", "715"}], ",", 
       RowBox[{"178", "\[Rule]", "161"}], ",", 
       RowBox[{"178", "\[Rule]", "193"}], ",", 
       RowBox[{"178", "\[Rule]", "179"}], ",", 
       RowBox[{"178", "\[Rule]", "175"}], ",", 
       RowBox[{"1042", "\[Rule]", "1025"}], ",", 
       RowBox[{"1042", "\[Rule]", "1057"}], ",", 
       RowBox[{"1042", "\[Rule]", "1043"}], ",", 
       RowBox[{"1042", "\[Rule]", "1039"}], ",", 
       RowBox[{"610", "\[Rule]", "593"}], ",", 
       RowBox[{"610", "\[Rule]", "625"}], ",", 
       RowBox[{"610", "\[Rule]", "611"}], ",", 
       RowBox[{"610", "\[Rule]", "607"}], ",", 
       RowBox[{"2122", "\[Rule]", "2105"}], ",", 
       RowBox[{"2122", "\[Rule]", "2137"}], ",", 
       RowBox[{"2122", "\[Rule]", "2123"}], ",", 
       RowBox[{"2122", "\[Rule]", "2119"}], ",", 
       RowBox[{"2014", "\[Rule]", "1997"}], ",", 
       RowBox[{"2014", "\[Rule]", "2029"}], ",", 
       RowBox[{"2014", "\[Rule]", "2015"}], ",", 
       RowBox[{"2014", "\[Rule]", "2011"}], ",", 
       RowBox[{"1582", "\[Rule]", "1565"}], ",", 
       RowBox[{"1582", "\[Rule]", "1597"}], ",", 
       RowBox[{"1582", "\[Rule]", "1583"}], ",", 
       RowBox[{"1582", "\[Rule]", "1579"}], ",", 
       RowBox[{"1906", "\[Rule]", "1889"}], ",", 
       RowBox[{"1906", "\[Rule]", "1921"}], ",", 
       RowBox[{"1906", "\[Rule]", "1907"}], ",", 
       RowBox[{"1906", "\[Rule]", "1903"}], ",", 
       RowBox[{"1474", "\[Rule]", "1457"}], ",", 
       RowBox[{"1474", "\[Rule]", "1489"}], ",", 
       RowBox[{"1474", "\[Rule]", "1475"}], ",", 
       RowBox[{"1474", "\[Rule]", "1471"}], ",", 
       RowBox[{"70", "\[Rule]", "53"}], ",", 
       RowBox[{"70", "\[Rule]", "85"}], ",", 
       RowBox[{"70", "\[Rule]", "71"}], ",", 
       RowBox[{"70", "\[Rule]", "67"}], ",", 
       RowBox[{"934", "\[Rule]", "917"}], ",", 
       RowBox[{"934", "\[Rule]", "949"}], ",", 
       RowBox[{"934", "\[Rule]", "935"}], ",", 
       RowBox[{"934", "\[Rule]", "931"}], ",", 
       RowBox[{"502", "\[Rule]", "485"}], ",", 
       RowBox[{"502", "\[Rule]", "517"}], ",", 
       RowBox[{"502", "\[Rule]", "503"}], ",", 
       RowBox[{"502", "\[Rule]", "499"}], ",", 
       RowBox[{"1798", "\[Rule]", "1781"}], ",", 
       RowBox[{"1798", "\[Rule]", "1813"}], ",", 
       RowBox[{"1798", "\[Rule]", "1799"}], ",", 
       RowBox[{"1798", "\[Rule]", "1795"}], ",", 
       RowBox[{"1366", "\[Rule]", "1349"}], ",", 
       RowBox[{"1366", "\[Rule]", "1381"}], ",", 
       RowBox[{"1366", "\[Rule]", "1367"}], ",", 
       RowBox[{"1366", "\[Rule]", "1363"}], ",", 
       RowBox[{"426", "\[Rule]", "409"}], ",", 
       RowBox[{"426", "\[Rule]", "427"}], ",", 
       RowBox[{"426", "\[Rule]", "423"}], ",", 
       RowBox[{"1290", "\[Rule]", "1273"}], ",", 
       RowBox[{"1290", "\[Rule]", "1291"}], ",", 
       RowBox[{"1290", "\[Rule]", "1287"}], ",", 
       RowBox[{"750", "\[Rule]", "733"}], ",", 
       RowBox[{"750", "\[Rule]", "751"}], ",", 
       RowBox[{"750", "\[Rule]", "747"}], ",", 
       RowBox[{"2154", "\[Rule]", "2137"}], ",", 
       RowBox[{"2154", "\[Rule]", "2155"}], ",", 
       RowBox[{"2154", "\[Rule]", "2151"}], ",", 
       RowBox[{"1614", "\[Rule]", "1597"}], ",", 
       RowBox[{"1614", "\[Rule]", "1615"}], ",", 
       RowBox[{"1614", "\[Rule]", "1611"}], ",", 
       RowBox[{"408", "\[Rule]", "391"}], ",", 
       RowBox[{"408", "\[Rule]", "423"}], ",", 
       RowBox[{"408", "\[Rule]", "409"}], ",", 
       RowBox[{"408", "\[Rule]", "405"}], ",", 
       RowBox[{"1272", "\[Rule]", "1255"}], ",", 
       RowBox[{"1272", "\[Rule]", "1287"}], ",", 
       RowBox[{"1272", "\[Rule]", "1273"}], ",", 
       RowBox[{"1272", "\[Rule]", "1269"}], ",", 
       RowBox[{"300", "\[Rule]", "283"}], ",", 
       RowBox[{"300", "\[Rule]", "315"}], ",", 
       RowBox[{"300", "\[Rule]", "301"}], ",", 
       RowBox[{"300", "\[Rule]", "297"}], ",", 
       RowBox[{"1164", "\[Rule]", "1147"}], ",", 
       RowBox[{"1164", "\[Rule]", "1179"}], ",", 
       RowBox[{"1164", "\[Rule]", "1165"}], ",", 
       RowBox[{"1164", "\[Rule]", "1161"}], ",", 
       RowBox[{"732", "\[Rule]", "715"}], ",", 
       RowBox[{"732", "\[Rule]", "747"}], ",", 
       RowBox[{"732", "\[Rule]", "733"}], ",", 
       RowBox[{"732", "\[Rule]", "729"}], ",", 
       RowBox[{"192", "\[Rule]", "175"}], ",", 
       RowBox[{"192", "\[Rule]", "207"}], ",", 
       RowBox[{"192", "\[Rule]", "193"}], ",", 
       RowBox[{"192", "\[Rule]", "189"}], ",", 
       RowBox[{"1056", "\[Rule]", "1039"}], ",", 
       RowBox[{"1056", "\[Rule]", "1071"}], ",", 
       RowBox[{"1056", "\[Rule]", "1057"}], ",", 
       RowBox[{"1056", "\[Rule]", "1053"}], ",", 
       RowBox[{"624", "\[Rule]", "607"}], ",", 
       RowBox[{"624", "\[Rule]", "639"}], ",", 
       RowBox[{"624", "\[Rule]", "625"}], ",", 
       RowBox[{"624", "\[Rule]", "621"}], ",", 
       RowBox[{"2136", "\[Rule]", "2119"}], ",", 
       RowBox[{"2136", "\[Rule]", "2151"}], ",", 
       RowBox[{"2136", "\[Rule]", "2137"}], ",", 
       RowBox[{"2136", "\[Rule]", "2133"}], ",", 
       RowBox[{"2028", "\[Rule]", "2011"}], ",", 
       RowBox[{"2028", "\[Rule]", "2043"}], ",", 
       RowBox[{"2028", "\[Rule]", "2029"}], ",", 
       RowBox[{"2028", "\[Rule]", "2025"}], ",", 
       RowBox[{"1596", "\[Rule]", "1579"}], ",", 
       RowBox[{"1596", "\[Rule]", "1611"}], ",", 
       RowBox[{"1596", "\[Rule]", "1597"}], ",", 
       RowBox[{"1596", "\[Rule]", "1593"}], ",", 
       RowBox[{"1920", "\[Rule]", "1903"}], ",", 
       RowBox[{"1920", "\[Rule]", "1935"}], ",", 
       RowBox[{"1920", "\[Rule]", "1921"}], ",", 
       RowBox[{"1920", "\[Rule]", "1917"}], ",", 
       RowBox[{"1488", "\[Rule]", "1471"}], ",", 
       RowBox[{"1488", "\[Rule]", "1503"}], ",", 
       RowBox[{"1488", "\[Rule]", "1489"}], ",", 
       RowBox[{"1488", "\[Rule]", "1485"}], ",", 
       RowBox[{"84", "\[Rule]", "67"}], ",", 
       RowBox[{"84", "\[Rule]", "99"}], ",", 
       RowBox[{"84", "\[Rule]", "85"}], ",", 
       RowBox[{"84", "\[Rule]", "81"}], ",", 
       RowBox[{"948", "\[Rule]", "931"}], ",", 
       RowBox[{"948", "\[Rule]", "963"}], ",", 
       RowBox[{"948", "\[Rule]", "949"}], ",", 
       RowBox[{"948", "\[Rule]", "945"}], ",", 
       RowBox[{"516", "\[Rule]", "499"}], ",", 
       RowBox[{"516", "\[Rule]", "531"}], ",", 
       RowBox[{"516", "\[Rule]", "517"}], ",", 
       RowBox[{"516", "\[Rule]", "513"}], ",", 
       RowBox[{"1812", "\[Rule]", "1795"}], ",", 
       RowBox[{"1812", "\[Rule]", "1827"}], ",", 
       RowBox[{"1812", "\[Rule]", "1813"}], ",", 
       RowBox[{"1812", "\[Rule]", "1809"}], ",", 
       RowBox[{"1380", "\[Rule]", "1363"}], ",", 
       RowBox[{"1380", "\[Rule]", "1395"}], ",", 
       RowBox[{"1380", "\[Rule]", "1381"}], ",", 
       RowBox[{"1380", "\[Rule]", "1377"}], ",", 
       RowBox[{"2946", "\[Rule]", "2931"}], ",", 
       RowBox[{"2946", "\[Rule]", "2961"}], ",", 
       RowBox[{"2946", "\[Rule]", "2943"}], ",", 
       RowBox[{"2838", "\[Rule]", "2823"}], ",", 
       RowBox[{"2838", "\[Rule]", "2853"}], ",", 
       RowBox[{"2838", "\[Rule]", "2835"}], ",", 
       RowBox[{"2406", "\[Rule]", "2391"}], ",", 
       RowBox[{"2406", "\[Rule]", "2421"}], ",", 
       RowBox[{"2406", "\[Rule]", "2403"}], ",", 
       RowBox[{"2976", "\[Rule]", "2961"}], ",", 
       RowBox[{"2976", "\[Rule]", "2991"}], ",", 
       RowBox[{"2976", "\[Rule]", "2973"}], ",", 
       RowBox[{"2868", "\[Rule]", "2853"}], ",", 
       RowBox[{"2868", "\[Rule]", "2883"}], ",", 
       RowBox[{"2868", "\[Rule]", "2865"}], ",", 
       RowBox[{"2436", "\[Rule]", "2421"}], ",", 
       RowBox[{"2436", "\[Rule]", "2451"}], ",", 
       RowBox[{"2436", "\[Rule]", "2433"}], ",", 
       RowBox[{"2960", "\[Rule]", "2943"}], ",", 
       RowBox[{"2960", "\[Rule]", "2973"}], ",", 
       RowBox[{"2960", "\[Rule]", "2961"}], ",", 
       RowBox[{"2960", "\[Rule]", "2957"}], ",", 
       RowBox[{"2852", "\[Rule]", "2835"}], ",", 
       RowBox[{"2852", "\[Rule]", "2865"}], ",", 
       RowBox[{"2852", "\[Rule]", "2853"}], ",", 
       RowBox[{"2852", "\[Rule]", "2849"}], ",", 
       RowBox[{"2420", "\[Rule]", "2403"}], ",", 
       RowBox[{"2420", "\[Rule]", "2433"}], ",", 
       RowBox[{"2420", "\[Rule]", "2421"}], ",", 
       RowBox[{"2420", "\[Rule]", "2417"}], ",", 
       RowBox[{"2730", "\[Rule]", "2715"}], ",", 
       RowBox[{"2730", "\[Rule]", "2745"}], ",", 
       RowBox[{"2730", "\[Rule]", "2727"}], ",", 
       RowBox[{"2298", "\[Rule]", "2283"}], ",", 
       RowBox[{"2298", "\[Rule]", "2313"}], ",", 
       RowBox[{"2298", "\[Rule]", "2295"}], ",", 
       RowBox[{"2760", "\[Rule]", "2745"}], ",", 
       RowBox[{"2760", "\[Rule]", "2775"}], ",", 
       RowBox[{"2760", "\[Rule]", "2757"}], ",", 
       RowBox[{"2328", "\[Rule]", "2313"}], ",", 
       RowBox[{"2328", "\[Rule]", "2343"}], ",", 
       RowBox[{"2328", "\[Rule]", "2325"}], ",", 
       RowBox[{"2744", "\[Rule]", "2727"}], ",", 
       RowBox[{"2744", "\[Rule]", "2757"}], ",", 
       RowBox[{"2744", "\[Rule]", "2745"}], ",", 
       RowBox[{"2744", "\[Rule]", "2741"}], ",", 
       RowBox[{"2312", "\[Rule]", "2295"}], ",", 
       RowBox[{"2312", "\[Rule]", "2325"}], ",", 
       RowBox[{"2312", "\[Rule]", "2313"}], ",", 
       RowBox[{"2312", "\[Rule]", "2309"}], ",", 
       RowBox[{"3008", "\[Rule]", "2991"}], ",", 
       RowBox[{"3008", "\[Rule]", "3023"}], ",", 
       RowBox[{"3008", "\[Rule]", "3005"}], ",", 
       RowBox[{"2900", "\[Rule]", "2883"}], ",", 
       RowBox[{"2900", "\[Rule]", "2915"}], ",", 
       RowBox[{"2900", "\[Rule]", "2897"}], ",", 
       RowBox[{"2468", "\[Rule]", "2451"}], ",", 
       RowBox[{"2468", "\[Rule]", "2483"}], ",", 
       RowBox[{"2468", "\[Rule]", "2465"}], ",", 
       RowBox[{"2990", "\[Rule]", "2973"}], ",", 
       RowBox[{"2990", "\[Rule]", "3005"}], ",", 
       RowBox[{"2990", "\[Rule]", "2991"}], ",", 
       RowBox[{"2990", "\[Rule]", "2987"}], ",", 
       RowBox[{"2882", "\[Rule]", "2865"}], ",", 
       RowBox[{"2882", "\[Rule]", "2897"}], ",", 
       RowBox[{"2882", "\[Rule]", "2883"}], ",", 
       RowBox[{"2882", "\[Rule]", "2879"}], ",", 
       RowBox[{"2450", "\[Rule]", "2433"}], ",", 
       RowBox[{"2450", "\[Rule]", "2465"}], ",", 
       RowBox[{"2450", "\[Rule]", "2451"}], ",", 
       RowBox[{"2450", "\[Rule]", "2447"}], ",", 
       RowBox[{"2792", "\[Rule]", "2775"}], ",", 
       RowBox[{"2792", "\[Rule]", "2807"}], ",", 
       RowBox[{"2792", "\[Rule]", "2789"}], ",", 
       RowBox[{"2360", "\[Rule]", "2343"}], ",", 
       RowBox[{"2360", "\[Rule]", "2375"}], ",", 
       RowBox[{"2360", "\[Rule]", "2357"}], ",", 
       RowBox[{"2774", "\[Rule]", "2757"}], ",", 
       RowBox[{"2774", "\[Rule]", "2789"}], ",", 
       RowBox[{"2774", "\[Rule]", "2775"}], ",", 
       RowBox[{"2774", "\[Rule]", "2771"}], ",", 
       RowBox[{"2342", "\[Rule]", "2325"}], ",", 
       RowBox[{"2342", "\[Rule]", "2357"}], ",", 
       RowBox[{"2342", "\[Rule]", "2343"}], ",", 
       RowBox[{"2342", "\[Rule]", "2339"}], ",", 
       RowBox[{"2972", "\[Rule]", "2957"}], ",", 
       RowBox[{"2972", "\[Rule]", "2987"}], ",", 
       RowBox[{"2972", "\[Rule]", "2973"}], ",", 
       RowBox[{"2972", "\[Rule]", "2969"}], ",", 
       RowBox[{"2864", "\[Rule]", "2849"}], ",", 
       RowBox[{"2864", "\[Rule]", "2879"}], ",", 
       RowBox[{"2864", "\[Rule]", "2865"}], ",", 
       RowBox[{"2864", "\[Rule]", "2861"}], ",", 
       RowBox[{"2432", "\[Rule]", "2417"}], ",", 
       RowBox[{"2432", "\[Rule]", "2447"}], ",", 
       RowBox[{"2432", "\[Rule]", "2433"}], ",", 
       RowBox[{"2432", "\[Rule]", "2429"}], ",", 
       RowBox[{"2756", "\[Rule]", "2741"}], ",", 
       RowBox[{"2756", "\[Rule]", "2771"}], ",", 
       RowBox[{"2756", "\[Rule]", "2757"}], ",", 
       RowBox[{"2756", "\[Rule]", "2753"}], ",", 
       RowBox[{"2324", "\[Rule]", "2309"}], ",", 
       RowBox[{"2324", "\[Rule]", "2339"}], ",", 
       RowBox[{"2324", "\[Rule]", "2325"}], ",", 
       RowBox[{"2324", "\[Rule]", "2321"}], ",", 
       RowBox[{"2622", "\[Rule]", "2607"}], ",", 
       RowBox[{"2622", "\[Rule]", "2637"}], ",", 
       RowBox[{"2622", "\[Rule]", "2619"}], ",", 
       RowBox[{"2190", "\[Rule]", "2175"}], ",", 
       RowBox[{"2190", "\[Rule]", "2205"}], ",", 
       RowBox[{"2190", "\[Rule]", "2187"}], ",", 
       RowBox[{"2652", "\[Rule]", "2637"}], ",", 
       RowBox[{"2652", "\[Rule]", "2667"}], ",", 
       RowBox[{"2652", "\[Rule]", "2649"}], ",", 
       RowBox[{"2220", "\[Rule]", "2205"}], ",", 
       RowBox[{"2220", "\[Rule]", "2235"}], ",", 
       RowBox[{"2220", "\[Rule]", "2217"}], ",", 
       RowBox[{"2636", "\[Rule]", "2619"}], ",", 
       RowBox[{"2636", "\[Rule]", "2649"}], ",", 
       RowBox[{"2636", "\[Rule]", "2637"}], ",", 
       RowBox[{"2636", "\[Rule]", "2633"}], ",", 
       RowBox[{"2204", "\[Rule]", "2187"}], ",", 
       RowBox[{"2204", "\[Rule]", "2217"}], ",", 
       RowBox[{"2204", "\[Rule]", "2205"}], ",", 
       RowBox[{"2204", "\[Rule]", "2201"}], ",", 
       RowBox[{"2684", "\[Rule]", "2667"}], ",", 
       RowBox[{"2684", "\[Rule]", "2699"}], ",", 
       RowBox[{"2684", "\[Rule]", "2681"}], ",", 
       RowBox[{"2252", "\[Rule]", "2235"}], ",", 
       RowBox[{"2252", "\[Rule]", "2267"}], ",", 
       RowBox[{"2252", "\[Rule]", "2249"}], ",", 
       RowBox[{"2666", "\[Rule]", "2649"}], ",", 
       RowBox[{"2666", "\[Rule]", "2681"}], ",", 
       RowBox[{"2666", "\[Rule]", "2667"}], ",", 
       RowBox[{"2666", "\[Rule]", "2663"}], ",", 
       RowBox[{"2234", "\[Rule]", "2217"}], ",", 
       RowBox[{"2234", "\[Rule]", "2249"}], ",", 
       RowBox[{"2234", "\[Rule]", "2235"}], ",", 
       RowBox[{"2234", "\[Rule]", "2231"}], ",", 
       RowBox[{"2648", "\[Rule]", "2633"}], ",", 
       RowBox[{"2648", "\[Rule]", "2663"}], ",", 
       RowBox[{"2648", "\[Rule]", "2649"}], ",", 
       RowBox[{"2648", "\[Rule]", "2645"}], ",", 
       RowBox[{"2216", "\[Rule]", "2201"}], ",", 
       RowBox[{"2216", "\[Rule]", "2231"}], ",", 
       RowBox[{"2216", "\[Rule]", "2217"}], ",", 
       RowBox[{"2216", "\[Rule]", "2213"}], ",", 
       RowBox[{"3022", "\[Rule]", "3005"}], ",", 
       RowBox[{"3022", "\[Rule]", "3023"}], ",", 
       RowBox[{"3022", "\[Rule]", "3019"}], ",", 
       RowBox[{"2914", "\[Rule]", "2897"}], ",", 
       RowBox[{"2914", "\[Rule]", "2915"}], ",", 
       RowBox[{"2914", "\[Rule]", "2911"}], ",", 
       RowBox[{"2482", "\[Rule]", "2465"}], ",", 
       RowBox[{"2482", "\[Rule]", "2483"}], ",", 
       RowBox[{"2482", "\[Rule]", "2479"}], ",", 
       RowBox[{"2806", "\[Rule]", "2789"}], ",", 
       RowBox[{"2806", "\[Rule]", "2807"}], ",", 
       RowBox[{"2806", "\[Rule]", "2803"}], ",", 
       RowBox[{"2374", "\[Rule]", "2357"}], ",", 
       RowBox[{"2374", "\[Rule]", "2375"}], ",", 
       RowBox[{"2374", "\[Rule]", "2371"}], ",", 
       RowBox[{"3004", "\[Rule]", "2987"}], ",", 
       RowBox[{"3004", "\[Rule]", "3019"}], ",", 
       RowBox[{"3004", "\[Rule]", "3005"}], ",", 
       RowBox[{"3004", "\[Rule]", "3001"}], ",", 
       RowBox[{"2896", "\[Rule]", "2879"}], ",", 
       RowBox[{"2896", "\[Rule]", "2911"}], ",", 
       RowBox[{"2896", "\[Rule]", "2897"}], ",", 
       RowBox[{"2896", "\[Rule]", "2893"}], ",", 
       RowBox[{"2464", "\[Rule]", "2447"}], ",", 
       RowBox[{"2464", "\[Rule]", "2479"}], ",", 
       RowBox[{"2464", "\[Rule]", "2465"}], ",", 
       RowBox[{"2464", "\[Rule]", "2461"}], ",", 
       RowBox[{"2788", "\[Rule]", "2771"}], ",", 
       RowBox[{"2788", "\[Rule]", "2803"}], ",", 
       RowBox[{"2788", "\[Rule]", "2789"}], ",", 
       RowBox[{"2788", "\[Rule]", "2785"}], ",", 
       RowBox[{"2356", "\[Rule]", "2339"}], ",", 
       RowBox[{"2356", "\[Rule]", "2371"}], ",", 
       RowBox[{"2356", "\[Rule]", "2357"}], ",", 
       RowBox[{"2356", "\[Rule]", "2353"}], ",", 
       RowBox[{"2698", "\[Rule]", "2681"}], ",", 
       RowBox[{"2698", "\[Rule]", "2699"}], ",", 
       RowBox[{"2698", "\[Rule]", "2695"}], ",", 
       RowBox[{"2266", "\[Rule]", "2249"}], ",", 
       RowBox[{"2266", "\[Rule]", "2267"}], ",", 
       RowBox[{"2266", "\[Rule]", "2263"}], ",", 
       RowBox[{"2680", "\[Rule]", "2663"}], ",", 
       RowBox[{"2680", "\[Rule]", "2695"}], ",", 
       RowBox[{"2680", "\[Rule]", "2681"}], ",", 
       RowBox[{"2680", "\[Rule]", "2677"}], ",", 
       RowBox[{"2248", "\[Rule]", "2231"}], ",", 
       RowBox[{"2248", "\[Rule]", "2263"}], ",", 
       RowBox[{"2248", "\[Rule]", "2249"}], ",", 
       RowBox[{"2248", "\[Rule]", "2245"}], ",", 
       RowBox[{"2986", "\[Rule]", "2969"}], ",", 
       RowBox[{"2986", "\[Rule]", "3001"}], ",", 
       RowBox[{"2986", "\[Rule]", "2987"}], ",", 
       RowBox[{"2986", "\[Rule]", "2983"}], ",", 
       RowBox[{"2878", "\[Rule]", "2861"}], ",", 
       RowBox[{"2878", "\[Rule]", "2893"}], ",", 
       RowBox[{"2878", "\[Rule]", "2879"}], ",", 
       RowBox[{"2878", "\[Rule]", "2875"}], ",", 
       RowBox[{"2446", "\[Rule]", "2429"}], ",", 
       RowBox[{"2446", "\[Rule]", "2461"}], ",", 
       RowBox[{"2446", "\[Rule]", "2447"}], ",", 
       RowBox[{"2446", "\[Rule]", "2443"}], ",", 
       RowBox[{"2770", "\[Rule]", "2753"}], ",", 
       RowBox[{"2770", "\[Rule]", "2785"}], ",", 
       RowBox[{"2770", "\[Rule]", "2771"}], ",", 
       RowBox[{"2770", "\[Rule]", "2767"}], ",", 
       RowBox[{"2338", "\[Rule]", "2321"}], ",", 
       RowBox[{"2338", "\[Rule]", "2353"}], ",", 
       RowBox[{"2338", "\[Rule]", "2339"}], ",", 
       RowBox[{"2338", "\[Rule]", "2335"}], ",", 
       RowBox[{"2662", "\[Rule]", "2645"}], ",", 
       RowBox[{"2662", "\[Rule]", "2677"}], ",", 
       RowBox[{"2662", "\[Rule]", "2663"}], ",", 
       RowBox[{"2662", "\[Rule]", "2659"}], ",", 
       RowBox[{"2230", "\[Rule]", "2213"}], ",", 
       RowBox[{"2230", "\[Rule]", "2245"}], ",", 
       RowBox[{"2230", "\[Rule]", "2231"}], ",", 
       RowBox[{"2230", "\[Rule]", "2227"}], ",", 
       RowBox[{"3018", "\[Rule]", "3001"}], ",", 
       RowBox[{"3018", "\[Rule]", "3019"}], ",", 
       RowBox[{"3018", "\[Rule]", "3015"}], ",", 
       RowBox[{"2910", "\[Rule]", "2893"}], ",", 
       RowBox[{"2910", "\[Rule]", "2911"}], ",", 
       RowBox[{"2910", "\[Rule]", "2907"}], ",", 
       RowBox[{"2478", "\[Rule]", "2461"}], ",", 
       RowBox[{"2478", "\[Rule]", "2479"}], ",", 
       RowBox[{"2478", "\[Rule]", "2475"}], ",", 
       RowBox[{"2802", "\[Rule]", "2785"}], ",", 
       RowBox[{"2802", "\[Rule]", "2803"}], ",", 
       RowBox[{"2802", "\[Rule]", "2799"}], ",", 
       RowBox[{"2370", "\[Rule]", "2353"}], ",", 
       RowBox[{"2370", "\[Rule]", "2371"}], ",", 
       RowBox[{"2370", "\[Rule]", "2367"}], ",", 
       RowBox[{"2694", "\[Rule]", "2677"}], ",", 
       RowBox[{"2694", "\[Rule]", "2695"}], ",", 
       RowBox[{"2694", "\[Rule]", "2691"}], ",", 
       RowBox[{"2262", "\[Rule]", "2245"}], ",", 
       RowBox[{"2262", "\[Rule]", "2263"}], ",", 
       RowBox[{"2262", "\[Rule]", "2259"}], ",", 
       RowBox[{"3000", "\[Rule]", "2983"}], ",", 
       RowBox[{"3000", "\[Rule]", "3015"}], ",", 
       RowBox[{"3000", "\[Rule]", "3001"}], ",", 
       RowBox[{"3000", "\[Rule]", "2997"}], ",", 
       RowBox[{"2892", "\[Rule]", "2875"}], ",", 
       RowBox[{"2892", "\[Rule]", "2907"}], ",", 
       RowBox[{"2892", "\[Rule]", "2893"}], ",", 
       RowBox[{"2892", "\[Rule]", "2889"}], ",", 
       RowBox[{"2460", "\[Rule]", "2443"}], ",", 
       RowBox[{"2460", "\[Rule]", "2475"}], ",", 
       RowBox[{"2460", "\[Rule]", "2461"}], ",", 
       RowBox[{"2460", "\[Rule]", "2457"}], ",", 
       RowBox[{"2784", "\[Rule]", "2767"}], ",", 
       RowBox[{"2784", "\[Rule]", "2799"}], ",", 
       RowBox[{"2784", "\[Rule]", "2785"}], ",", 
       RowBox[{"2784", "\[Rule]", "2781"}], ",", 
       RowBox[{"2352", "\[Rule]", "2335"}], ",", 
       RowBox[{"2352", "\[Rule]", "2367"}], ",", 
       RowBox[{"2352", "\[Rule]", "2353"}], ",", 
       RowBox[{"2352", "\[Rule]", "2349"}], ",", 
       RowBox[{"2676", "\[Rule]", "2659"}], ",", 
       RowBox[{"2676", "\[Rule]", "2691"}], ",", 
       RowBox[{"2676", "\[Rule]", "2677"}], ",", 
       RowBox[{"2676", "\[Rule]", "2673"}], ",", 
       RowBox[{"2244", "\[Rule]", "2227"}], ",", 
       RowBox[{"2244", "\[Rule]", "2259"}], ",", 
       RowBox[{"2244", "\[Rule]", "2245"}], ",", 
       RowBox[{"2244", "\[Rule]", "2241"}], ",", 
       RowBox[{"422", "\[Rule]", "405"}], ",", 
       RowBox[{"422", "\[Rule]", "423"}], ",", 
       RowBox[{"422", "\[Rule]", "419"}], ",", 
       RowBox[{"1286", "\[Rule]", "1269"}], ",", 
       RowBox[{"1286", "\[Rule]", "1287"}], ",", 
       RowBox[{"1286", "\[Rule]", "1283"}], ",", 
       RowBox[{"314", "\[Rule]", "297"}], ",", 
       RowBox[{"314", "\[Rule]", "315"}], ",", 
       RowBox[{"314", "\[Rule]", "311"}], ",", 
       RowBox[{"1178", "\[Rule]", "1161"}], ",", 
       RowBox[{"1178", "\[Rule]", "1179"}], ",", 
       RowBox[{"1178", "\[Rule]", "1175"}], ",", 
       RowBox[{"746", "\[Rule]", "729"}], ",", 
       RowBox[{"746", "\[Rule]", "747"}], ",", 
       RowBox[{"746", "\[Rule]", "743"}], ",", 
       RowBox[{"206", "\[Rule]", "189"}], ",", 
       RowBox[{"206", "\[Rule]", "207"}], ",", 
       RowBox[{"206", "\[Rule]", "203"}], ",", 
       RowBox[{"1070", "\[Rule]", "1053"}], ",", 
       RowBox[{"1070", "\[Rule]", "1071"}], ",", 
       RowBox[{"1070", "\[Rule]", "1067"}], ",", 
       RowBox[{"638", "\[Rule]", "621"}], ",", 
       RowBox[{"638", "\[Rule]", "639"}], ",", 
       RowBox[{"638", "\[Rule]", "635"}], ",", 
       RowBox[{"2150", "\[Rule]", "2133"}], ",", 
       RowBox[{"2150", "\[Rule]", "2151"}], ",", 
       RowBox[{"2150", "\[Rule]", "2147"}], ",", 
       RowBox[{"2042", "\[Rule]", "2025"}], ",", 
       RowBox[{"2042", "\[Rule]", "2043"}], ",", 
       RowBox[{"2042", "\[Rule]", "2039"}], ",", 
       RowBox[{"1610", "\[Rule]", "1593"}], ",", 
       RowBox[{"1610", "\[Rule]", "1611"}], ",", 
       RowBox[{"1610", "\[Rule]", "1607"}], ",", 
       RowBox[{"1934", "\[Rule]", "1917"}], ",", 
       RowBox[{"1934", "\[Rule]", "1935"}], ",", 
       RowBox[{"1934", "\[Rule]", "1931"}], ",", 
       RowBox[{"1502", "\[Rule]", "1485"}], ",", 
       RowBox[{"1502", "\[Rule]", "1503"}], ",", 
       RowBox[{"1502", "\[Rule]", "1499"}], ",", 
       RowBox[{"98", "\[Rule]", "81"}], ",", 
       RowBox[{"98", "\[Rule]", "99"}], ",", 
       RowBox[{"98", "\[Rule]", "95"}], ",", 
       RowBox[{"962", "\[Rule]", "945"}], ",", 
       RowBox[{"962", "\[Rule]", "963"}], ",", 
       RowBox[{"962", "\[Rule]", "959"}], ",", 
       RowBox[{"530", "\[Rule]", "513"}], ",", 
       RowBox[{"530", "\[Rule]", "531"}], ",", 
       RowBox[{"530", "\[Rule]", "527"}], ",", 
       RowBox[{"1826", "\[Rule]", "1809"}], ",", 
       RowBox[{"1826", "\[Rule]", "1827"}], ",", 
       RowBox[{"1826", "\[Rule]", "1823"}], ",", 
       RowBox[{"1394", "\[Rule]", "1377"}], ",", 
       RowBox[{"1394", "\[Rule]", "1395"}], ",", 
       RowBox[{"1394", "\[Rule]", "1391"}], ",", 
       RowBox[{"3014", "\[Rule]", "2997"}], ",", 
       RowBox[{"3014", "\[Rule]", "3015"}], ",", 
       RowBox[{"3014", "\[Rule]", "3011"}], ",", 
       RowBox[{"2906", "\[Rule]", "2889"}], ",", 
       RowBox[{"2906", "\[Rule]", "2907"}], ",", 
       RowBox[{"2906", "\[Rule]", "2903"}], ",", 
       RowBox[{"2474", "\[Rule]", "2457"}], ",", 
       RowBox[{"2474", "\[Rule]", "2475"}], ",", 
       RowBox[{"2474", "\[Rule]", "2471"}], ",", 
       RowBox[{"2798", "\[Rule]", "2781"}], ",", 
       RowBox[{"2798", "\[Rule]", "2799"}], ",", 
       RowBox[{"2798", "\[Rule]", "2795"}], ",", 
       RowBox[{"2366", "\[Rule]", "2349"}], ",", 
       RowBox[{"2366", "\[Rule]", "2367"}], ",", 
       RowBox[{"2366", "\[Rule]", "2363"}], ",", 
       RowBox[{"2690", "\[Rule]", "2673"}], ",", 
       RowBox[{"2690", "\[Rule]", "2691"}], ",", 
       RowBox[{"2690", "\[Rule]", "2687"}], ",", 
       RowBox[{"2258", "\[Rule]", "2241"}], ",", 
       RowBox[{"2258", "\[Rule]", "2259"}], ",", 
       RowBox[{"2258", "\[Rule]", "2255"}], ",", 
       RowBox[{"339", "\[Rule]", "772"}], ",", 
       RowBox[{"339", "\[Rule]", "664"}], ",", 
       RowBox[{"339", "\[Rule]", "664"}], ",", 
       RowBox[{"339", "\[Rule]", "340"}], ",", 
       RowBox[{"369", "\[Rule]", "802"}], ",", 
       RowBox[{"369", "\[Rule]", "802"}], ",", 
       RowBox[{"369", "\[Rule]", "694"}], ",", 
       RowBox[{"369", "\[Rule]", "694"}], ",", 
       RowBox[{"369", "\[Rule]", "370"}], ",", 
       RowBox[{"351", "\[Rule]", "784"}], ",", 
       RowBox[{"351", "\[Rule]", "676"}], ",", 
       RowBox[{"351", "\[Rule]", "352"}], ",", 
       RowBox[{"1203", "\[Rule]", "772"}], ",", 
       RowBox[{"1203", "\[Rule]", "772"}], ",", 
       RowBox[{"1203", "\[Rule]", "1636"}], ",", 
       RowBox[{"1203", "\[Rule]", "1636"}], ",", 
       RowBox[{"1203", "\[Rule]", "664"}], ",", 
       RowBox[{"1203", "\[Rule]", "664"}], ",", 
       RowBox[{"1203", "\[Rule]", "1528"}], ",", 
       RowBox[{"1203", "\[Rule]", "1528"}], ",", 
       RowBox[{"1203", "\[Rule]", "1204"}], ",", 
       RowBox[{"1233", "\[Rule]", "802"}], ",", 
       RowBox[{"1233", "\[Rule]", "1666"}], ",", 
       RowBox[{"1233", "\[Rule]", "694"}], ",", 
       RowBox[{"1233", "\[Rule]", "694"}], ",", 
       RowBox[{"1233", "\[Rule]", "1558"}], ",", 
       RowBox[{"1233", "\[Rule]", "1558"}], ",", 
       RowBox[{"1233", "\[Rule]", "1234"}], ",", 
       RowBox[{"1215", "\[Rule]", "784"}], ",", 
       RowBox[{"1215", "\[Rule]", "1648"}], ",", 
       RowBox[{"1215", "\[Rule]", "1648"}], ",", 
       RowBox[{"1215", "\[Rule]", "676"}], ",", 
       RowBox[{"1215", "\[Rule]", "1540"}], ",", 
       RowBox[{"1215", "\[Rule]", "1540"}], ",", 
       RowBox[{"1215", "\[Rule]", "1216"}], ",", 
       RowBox[{"231", "\[Rule]", "664"}], ",", 
       RowBox[{"231", "\[Rule]", "664"}], ",", 
       RowBox[{"231", "\[Rule]", "556"}], ",", 
       RowBox[{"231", "\[Rule]", "556"}], ",", 
       RowBox[{"231", "\[Rule]", "232"}], ",", 
       RowBox[{"243", "\[Rule]", "676"}], ",", 
       RowBox[{"243", "\[Rule]", "676"}], ",", 
       RowBox[{"243", "\[Rule]", "568"}], ",", 
       RowBox[{"243", "\[Rule]", "568"}], ",", 
       RowBox[{"243", "\[Rule]", "244"}], ",", 
       RowBox[{"1095", "\[Rule]", "664"}], ",", 
       RowBox[{"1095", "\[Rule]", "664"}], ",", 
       RowBox[{"1095", "\[Rule]", "1528"}], ",", 
       RowBox[{"1095", "\[Rule]", "1528"}], ",", 
       RowBox[{"1095", "\[Rule]", "556"}], ",", 
       RowBox[{"1095", "\[Rule]", "556"}], ",", 
       RowBox[{"1095", "\[Rule]", "1420"}], ",", 
       RowBox[{"1095", "\[Rule]", "1420"}], ",", 
       RowBox[{"1095", "\[Rule]", "1096"}], ",", 
       RowBox[{"1107", "\[Rule]", "676"}], ",", 
       RowBox[{"1107", "\[Rule]", "676"}], ",", 
       RowBox[{"1107", "\[Rule]", "1540"}], ",", 
       RowBox[{"1107", "\[Rule]", "1540"}], ",", 
       RowBox[{"1107", "\[Rule]", "568"}], ",", 
       RowBox[{"1107", "\[Rule]", "568"}], ",", 
       RowBox[{"1107", "\[Rule]", "1432"}], ",", 
       RowBox[{"1107", "\[Rule]", "1432"}], ",", 
       RowBox[{"1107", "\[Rule]", "1108"}], ",", 
       RowBox[{"663", "\[Rule]", "340"}], ",", 
       RowBox[{"663", "\[Rule]", "340"}], ",", 
       RowBox[{"663", "\[Rule]", "1204"}], ",", 
       RowBox[{"663", "\[Rule]", "1204"}], ",", 
       RowBox[{"663", "\[Rule]", "232"}], ",", 
       RowBox[{"663", "\[Rule]", "232"}], ",", 
       RowBox[{"663", "\[Rule]", "1096"}], ",", 
       RowBox[{"663", "\[Rule]", "1096"}], ",", 
       RowBox[{"663", "\[Rule]", "664"}], ",", 
       RowBox[{"693", "\[Rule]", "370"}], ",", 
       RowBox[{"693", "\[Rule]", "370"}], ",", 
       RowBox[{"693", "\[Rule]", "1234"}], ",", 
       RowBox[{"693", "\[Rule]", "1234"}], ",", 
       RowBox[{"693", "\[Rule]", "262"}], ",", 
       RowBox[{"693", "\[Rule]", "262"}], ",", 
       RowBox[{"693", "\[Rule]", "1126"}], ",", 
       RowBox[{"693", "\[Rule]", "1126"}], ",", 
       RowBox[{"693", "\[Rule]", "694"}], ",", 
       RowBox[{"675", "\[Rule]", "352"}], ",", 
       RowBox[{"675", "\[Rule]", "1216"}], ",", 
       RowBox[{"675", "\[Rule]", "244"}], ",", 
       RowBox[{"675", "\[Rule]", "244"}], ",", 
       RowBox[{"675", "\[Rule]", "1108"}], ",", 
       RowBox[{"675", "\[Rule]", "1108"}], ",", 
       RowBox[{"675", "\[Rule]", "676"}], ",", 
       RowBox[{"399", "\[Rule]", "832"}], ",", 
       RowBox[{"399", "\[Rule]", "832"}], ",", 
       RowBox[{"399", "\[Rule]", "724"}], ",", 
       RowBox[{"399", "\[Rule]", "724"}], ",", 
       RowBox[{"399", "\[Rule]", "400"}], ",", 
       RowBox[{"381", "\[Rule]", "814"}], ",", 
       RowBox[{"381", "\[Rule]", "814"}], ",", 
       RowBox[{"381", "\[Rule]", "706"}], ",", 
       RowBox[{"381", "\[Rule]", "706"}], ",", 
       RowBox[{"381", "\[Rule]", "382"}], ",", 
       RowBox[{"1263", "\[Rule]", "832"}], ",", 
       RowBox[{"1263", "\[Rule]", "832"}], ",", 
       RowBox[{"1263", "\[Rule]", "1696"}], ",", 
       RowBox[{"1263", "\[Rule]", "1696"}], ",", 
       RowBox[{"1263", "\[Rule]", "724"}], ",", 
       RowBox[{"1263", "\[Rule]", "724"}], ",", 
       RowBox[{"1263", "\[Rule]", "1588"}], ",", 
       RowBox[{"1263", "\[Rule]", "1588"}], ",", 
       RowBox[{"1263", "\[Rule]", "1264"}], ",", 
       RowBox[{"1245", "\[Rule]", "814"}], ",", 
       RowBox[{"1245", "\[Rule]", "814"}], ",", 
       RowBox[{"1245", "\[Rule]", "1678"}], ",", 
       RowBox[{"1245", "\[Rule]", "706"}], ",", 
       RowBox[{"1245", "\[Rule]", "706"}], ",", 
       RowBox[{"1245", "\[Rule]", "1570"}], ",", 
       RowBox[{"1245", "\[Rule]", "1246"}], ",", 
       RowBox[{"723", "\[Rule]", "400"}], ",", 
       RowBox[{"723", "\[Rule]", "400"}], ",", 
       RowBox[{"723", "\[Rule]", "1264"}], ",", 
       RowBox[{"723", "\[Rule]", "1264"}], ",", 
       RowBox[{"723", "\[Rule]", "292"}], ",", 
       RowBox[{"723", "\[Rule]", "292"}], ",", 
       RowBox[{"723", "\[Rule]", "1156"}], ",", 
       RowBox[{"723", "\[Rule]", "1156"}], ",", 
       RowBox[{"723", "\[Rule]", "724"}], ",", 
       RowBox[{"705", "\[Rule]", "382"}], ",", 
       RowBox[{"705", "\[Rule]", "382"}], ",", 
       RowBox[{"705", "\[Rule]", "1246"}], ",", 
       RowBox[{"705", "\[Rule]", "1246"}], ",", 
       RowBox[{"705", "\[Rule]", "274"}], ",", 
       RowBox[{"705", "\[Rule]", "274"}], ",", 
       RowBox[{"705", "\[Rule]", "1138"}], ",", 
       RowBox[{"705", "\[Rule]", "1138"}], ",", 
       RowBox[{"705", "\[Rule]", "706"}], ",", 
       RowBox[{"365", "\[Rule]", "798"}], ",", 
       RowBox[{"365", "\[Rule]", "798"}], ",", 
       RowBox[{"365", "\[Rule]", "690"}], ",", 
       RowBox[{"365", "\[Rule]", "690"}], ",", 
       RowBox[{"365", "\[Rule]", "366"}], ",", 
       RowBox[{"1229", "\[Rule]", "798"}], ",", 
       RowBox[{"1229", "\[Rule]", "798"}], ",", 
       RowBox[{"1229", "\[Rule]", "1662"}], ",", 
       RowBox[{"1229", "\[Rule]", "1662"}], ",", 
       RowBox[{"1229", "\[Rule]", "690"}], ",", 
       RowBox[{"1229", "\[Rule]", "1554"}], ",", 
       RowBox[{"1229", "\[Rule]", "1230"}], ",", 
       RowBox[{"257", "\[Rule]", "690"}], ",", 
       RowBox[{"257", "\[Rule]", "690"}], ",", 
       RowBox[{"257", "\[Rule]", "582"}], ",", 
       RowBox[{"257", "\[Rule]", "582"}], ",", 
       RowBox[{"257", "\[Rule]", "258"}], ",", 
       RowBox[{"1121", "\[Rule]", "690"}], ",", 
       RowBox[{"1121", "\[Rule]", "1554"}], ",", 
       RowBox[{"1121", "\[Rule]", "582"}], ",", 
       RowBox[{"1121", "\[Rule]", "582"}], ",", 
       RowBox[{"1121", "\[Rule]", "1446"}], ",", 
       RowBox[{"1121", "\[Rule]", "1446"}], ",", 
       RowBox[{"1121", "\[Rule]", "1122"}], ",", 
       RowBox[{"689", "\[Rule]", "366"}], ",", 
       RowBox[{"689", "\[Rule]", "366"}], ",", 
       RowBox[{"689", "\[Rule]", "1230"}], ",", 
       RowBox[{"689", "\[Rule]", "258"}], ",", 
       RowBox[{"689", "\[Rule]", "258"}], ",", 
       RowBox[{"689", "\[Rule]", "1122"}], ",", 
       RowBox[{"689", "\[Rule]", "690"}], ",", 
       RowBox[{"123", "\[Rule]", "556"}], ",", 
       RowBox[{"123", "\[Rule]", "448"}], ",", 
       RowBox[{"123", "\[Rule]", "124"}], ",", 
       RowBox[{"135", "\[Rule]", "568"}], ",", 
       RowBox[{"135", "\[Rule]", "460"}], ",", 
       RowBox[{"135", "\[Rule]", "136"}], ",", 
       RowBox[{"987", "\[Rule]", "556"}], ",", 
       RowBox[{"987", "\[Rule]", "1420"}], ",", 
       RowBox[{"987", "\[Rule]", "1420"}], ",", 
       RowBox[{"987", "\[Rule]", "448"}], ",", 
       RowBox[{"987", "\[Rule]", "1312"}], ",", 
       RowBox[{"987", "\[Rule]", "1312"}], ",", 
       RowBox[{"987", "\[Rule]", "988"}], ",", 
       RowBox[{"999", "\[Rule]", "568"}], ",", 
       RowBox[{"999", "\[Rule]", "1432"}], ",", 
       RowBox[{"999", "\[Rule]", "1432"}], ",", 
       RowBox[{"999", "\[Rule]", "460"}], ",", 
       RowBox[{"999", "\[Rule]", "1324"}], ",", 
       RowBox[{"999", "\[Rule]", "1324"}], ",", 
       RowBox[{"999", "\[Rule]", "1000"}], ",", 
       RowBox[{"555", "\[Rule]", "232"}], ",", 
       RowBox[{"555", "\[Rule]", "232"}], ",", 
       RowBox[{"555", "\[Rule]", "1096"}], ",", 
       RowBox[{"555", "\[Rule]", "1096"}], ",", 
       RowBox[{"555", "\[Rule]", "124"}], ",", 
       RowBox[{"555", "\[Rule]", "988"}], ",", 
       RowBox[{"555", "\[Rule]", "556"}], ",", 
       RowBox[{"567", "\[Rule]", "244"}], ",", 
       RowBox[{"567", "\[Rule]", "244"}], ",", 
       RowBox[{"567", "\[Rule]", "1108"}], ",", 
       RowBox[{"567", "\[Rule]", "1108"}], ",", 
       RowBox[{"567", "\[Rule]", "136"}], ",", 
       RowBox[{"567", "\[Rule]", "1000"}], ",", 
       RowBox[{"567", "\[Rule]", "568"}], ",", 
       RowBox[{"149", "\[Rule]", "582"}], ",", 
       RowBox[{"149", "\[Rule]", "474"}], ",", 
       RowBox[{"149", "\[Rule]", "150"}], ",", 
       RowBox[{"1013", "\[Rule]", "582"}], ",", 
       RowBox[{"1013", "\[Rule]", "1446"}], ",", 
       RowBox[{"1013", "\[Rule]", "1446"}], ",", 
       RowBox[{"1013", "\[Rule]", "474"}], ",", 
       RowBox[{"1013", "\[Rule]", "1338"}], ",", 
       RowBox[{"1013", "\[Rule]", "1338"}], ",", 
       RowBox[{"1013", "\[Rule]", "1014"}], ",", 
       RowBox[{"581", "\[Rule]", "258"}], ",", 
       RowBox[{"581", "\[Rule]", "258"}], ",", 
       RowBox[{"581", "\[Rule]", "1122"}], ",", 
       RowBox[{"581", "\[Rule]", "1122"}], ",", 
       RowBox[{"581", "\[Rule]", "150"}], ",", 
       RowBox[{"581", "\[Rule]", "1014"}], ",", 
       RowBox[{"581", "\[Rule]", "582"}], ",", 
       RowBox[{"431", "\[Rule]", "864"}], ",", 
       RowBox[{"431", "\[Rule]", "864"}], ",", 
       RowBox[{"431", "\[Rule]", "756"}], ",", 
       RowBox[{"431", "\[Rule]", "756"}], ",", 
       RowBox[{"431", "\[Rule]", "432"}], ",", 
       RowBox[{"413", "\[Rule]", "846"}], ",", 
       RowBox[{"413", "\[Rule]", "846"}], ",", 
       RowBox[{"413", "\[Rule]", "738"}], ",", 
       RowBox[{"413", "\[Rule]", "738"}], ",", 
       RowBox[{"413", "\[Rule]", "414"}], ",", 
       RowBox[{"1295", "\[Rule]", "864"}], ",", 
       RowBox[{"1295", "\[Rule]", "864"}], ",", 
       RowBox[{"1295", "\[Rule]", "1728"}], ",", 
       RowBox[{"1295", "\[Rule]", "1728"}], ",", 
       RowBox[{"1295", "\[Rule]", "756"}], ",", 
       RowBox[{"1295", "\[Rule]", "756"}], ",", 
       RowBox[{"1295", "\[Rule]", "1620"}], ",", 
       RowBox[{"1295", "\[Rule]", "1620"}], ",", 
       RowBox[{"1295", "\[Rule]", "1296"}], ",", 
       RowBox[{"1277", "\[Rule]", "846"}], ",", 
       RowBox[{"1277", "\[Rule]", "846"}], ",", 
       RowBox[{"1277", "\[Rule]", "1710"}], ",", 
       RowBox[{"1277", "\[Rule]", "1710"}], ",", 
       RowBox[{"1277", "\[Rule]", "738"}], ",", 
       RowBox[{"1277", "\[Rule]", "738"}], ",", 
       RowBox[{"1277", "\[Rule]", "1602"}], ",", 
       RowBox[{"1277", "\[Rule]", "1602"}], ",", 
       RowBox[{"1277", "\[Rule]", "1278"}], ",", 
       RowBox[{"755", "\[Rule]", "432"}], ",", 
       RowBox[{"755", "\[Rule]", "432"}], ",", 
       RowBox[{"755", "\[Rule]", "1296"}], ",", 
       RowBox[{"755", "\[Rule]", "1296"}], ",", 
       RowBox[{"755", "\[Rule]", "324"}], ",", 
       RowBox[{"755", "\[Rule]", "324"}], ",", 
       RowBox[{"755", "\[Rule]", "1188"}], ",", 
       RowBox[{"755", "\[Rule]", "1188"}], ",", 
       RowBox[{"755", "\[Rule]", "756"}], ",", 
       RowBox[{"737", "\[Rule]", "414"}], ",", 
       RowBox[{"737", "\[Rule]", "414"}], ",", 
       RowBox[{"737", "\[Rule]", "1278"}], ",", 
       RowBox[{"737", "\[Rule]", "1278"}], ",", 
       RowBox[{"737", "\[Rule]", "306"}], ",", 
       RowBox[{"737", "\[Rule]", "306"}], ",", 
       RowBox[{"737", "\[Rule]", "1170"}], ",", 
       RowBox[{"737", "\[Rule]", "1170"}], ",", 
       RowBox[{"737", "\[Rule]", "738"}], ",", 
       RowBox[{"395", "\[Rule]", "828"}], ",", 
       RowBox[{"395", "\[Rule]", "828"}], ",", 
       RowBox[{"395", "\[Rule]", "720"}], ",", 
       RowBox[{"395", "\[Rule]", "720"}], ",", 
       RowBox[{"395", "\[Rule]", "396"}], ",", 
       RowBox[{"1259", "\[Rule]", "828"}], ",", 
       RowBox[{"1259", "\[Rule]", "828"}], ",", 
       RowBox[{"1259", "\[Rule]", "1692"}], ",", 
       RowBox[{"1259", "\[Rule]", "1692"}], ",", 
       RowBox[{"1259", "\[Rule]", "720"}], ",", 
       RowBox[{"1259", "\[Rule]", "720"}], ",", 
       RowBox[{"1259", "\[Rule]", "1584"}], ",", 
       RowBox[{"1259", "\[Rule]", "1584"}], ",", 
       RowBox[{"1259", "\[Rule]", "1260"}], ",", 
       RowBox[{"719", "\[Rule]", "396"}], ",", 
       RowBox[{"719", "\[Rule]", "396"}], ",", 
       RowBox[{"719", "\[Rule]", "1260"}], ",", 
       RowBox[{"719", "\[Rule]", "1260"}], ",", 
       RowBox[{"719", "\[Rule]", "288"}], ",", 
       RowBox[{"719", "\[Rule]", "288"}], ",", 
       RowBox[{"719", "\[Rule]", "1152"}], ",", 
       RowBox[{"719", "\[Rule]", "1152"}], ",", 
       RowBox[{"719", "\[Rule]", "720"}], ",", 
       RowBox[{"377", "\[Rule]", "810"}], ",", 
       RowBox[{"377", "\[Rule]", "810"}], ",", 
       RowBox[{"377", "\[Rule]", "702"}], ",", 
       RowBox[{"377", "\[Rule]", "702"}], ",", 
       RowBox[{"377", "\[Rule]", "378"}], ",", 
       RowBox[{"1241", "\[Rule]", "810"}], ",", 
       RowBox[{"1241", "\[Rule]", "810"}], ",", 
       RowBox[{"1241", "\[Rule]", "1674"}], ",", 
       RowBox[{"1241", "\[Rule]", "1674"}], ",", 
       RowBox[{"1241", "\[Rule]", "702"}], ",", 
       RowBox[{"1241", "\[Rule]", "702"}], ",", 
       RowBox[{"1241", "\[Rule]", "1566"}], ",", 
       RowBox[{"1241", "\[Rule]", "1566"}], ",", 
       RowBox[{"1241", "\[Rule]", "1242"}], ",", 
       RowBox[{"269", "\[Rule]", "702"}], ",", 
       RowBox[{"269", "\[Rule]", "702"}], ",", 
       RowBox[{"269", "\[Rule]", "594"}], ",", 
       RowBox[{"269", "\[Rule]", "594"}], ",", 
       RowBox[{"269", "\[Rule]", "270"}], ",", 
       RowBox[{"1133", "\[Rule]", "702"}], ",", 
       RowBox[{"1133", "\[Rule]", "702"}], ",", 
       RowBox[{"1133", "\[Rule]", "1566"}], ",", 
       RowBox[{"1133", "\[Rule]", "594"}], ",", 
       RowBox[{"1133", "\[Rule]", "594"}], ",", 
       RowBox[{"1133", "\[Rule]", "1458"}], ",", 
       RowBox[{"1133", "\[Rule]", "1134"}], ",", 
       RowBox[{"701", "\[Rule]", "378"}], ",", 
       RowBox[{"701", "\[Rule]", "378"}], ",", 
       RowBox[{"701", "\[Rule]", "1242"}], ",", 
       RowBox[{"701", "\[Rule]", "1242"}], ",", 
       RowBox[{"701", "\[Rule]", "270"}], ",", 
       RowBox[{"701", "\[Rule]", "270"}], ",", 
       RowBox[{"701", "\[Rule]", "1134"}], ",", 
       RowBox[{"701", "\[Rule]", "1134"}], ",", 
       RowBox[{"701", "\[Rule]", "702"}], ",", 
       RowBox[{"161", "\[Rule]", "594"}], ",", 
       RowBox[{"161", "\[Rule]", "486"}], ",", 
       RowBox[{"161", "\[Rule]", "162"}], ",", 
       RowBox[{"1025", "\[Rule]", "594"}], ",", 
       RowBox[{"1025", "\[Rule]", "1458"}], ",", 
       RowBox[{"1025", "\[Rule]", "1458"}], ",", 
       RowBox[{"1025", "\[Rule]", "486"}], ",", 
       RowBox[{"1025", "\[Rule]", "1350"}], ",", 
       RowBox[{"1025", "\[Rule]", "1350"}], ",", 
       RowBox[{"1025", "\[Rule]", "1026"}], ",", 
       RowBox[{"593", "\[Rule]", "270"}], ",", 
       RowBox[{"593", "\[Rule]", "270"}], ",", 
       RowBox[{"593", "\[Rule]", "1134"}], ",", 
       RowBox[{"593", "\[Rule]", "1134"}], ",", 
       RowBox[{"593", "\[Rule]", "162"}], ",", 
       RowBox[{"593", "\[Rule]", "1026"}], ",", 
       RowBox[{"593", "\[Rule]", "594"}], ",", 
       RowBox[{"2067", "\[Rule]", "1636"}], ",", 
       RowBox[{"2067", "\[Rule]", "1636"}], ",", 
       RowBox[{"2067", "\[Rule]", "2500"}], ",", 
       RowBox[{"2067", "\[Rule]", "2500"}], ",", 
       RowBox[{"2067", "\[Rule]", "1528"}], ",", 
       RowBox[{"2067", "\[Rule]", "1528"}], ",", 
       RowBox[{"2067", "\[Rule]", "2392"}], ",", 
       RowBox[{"2067", "\[Rule]", "2392"}], ",", 
       RowBox[{"2067", "\[Rule]", "2068"}], ",", 
       RowBox[{"2097", "\[Rule]", "1666"}], ",", 
       RowBox[{"2097", "\[Rule]", "1666"}], ",", 
       RowBox[{"2097", "\[Rule]", "2530"}], ",", 
       RowBox[{"2097", "\[Rule]", "2530"}], ",", 
       RowBox[{"2097", "\[Rule]", "1558"}], ",", 
       RowBox[{"2097", "\[Rule]", "1558"}], ",", 
       RowBox[{"2097", "\[Rule]", "2422"}], ",", 
       RowBox[{"2097", "\[Rule]", "2422"}], ",", 
       RowBox[{"2097", "\[Rule]", "2098"}], ",", 
       RowBox[{"2079", "\[Rule]", "1648"}], ",", 
       RowBox[{"2079", "\[Rule]", "1648"}], ",", 
       RowBox[{"2079", "\[Rule]", "2512"}], ",", 
       RowBox[{"2079", "\[Rule]", "2512"}], ",", 
       RowBox[{"2079", "\[Rule]", "1540"}], ",", 
       RowBox[{"2079", "\[Rule]", "1540"}], ",", 
       RowBox[{"2079", "\[Rule]", "2404"}], ",", 
       RowBox[{"2079", "\[Rule]", "2404"}], ",", 
       RowBox[{"2079", "\[Rule]", "2080"}], ",", 
       RowBox[{"1959", "\[Rule]", "1528"}], ",", 
       RowBox[{"1959", "\[Rule]", "1528"}], ",", 
       RowBox[{"1959", "\[Rule]", "2392"}], ",", 
       RowBox[{"1959", "\[Rule]", "2392"}], ",", 
       RowBox[{"1959", "\[Rule]", "1420"}], ",", 
       RowBox[{"1959", "\[Rule]", "1420"}], ",", 
       RowBox[{"1959", "\[Rule]", "2284"}], ",", 
       RowBox[{"1959", "\[Rule]", "2284"}], ",", 
       RowBox[{"1959", "\[Rule]", "1960"}], ",", 
       RowBox[{"1971", "\[Rule]", "1540"}], ",", 
       RowBox[{"1971", "\[Rule]", "1540"}], ",", 
       RowBox[{"1971", "\[Rule]", "2404"}], ",", 
       RowBox[{"1971", "\[Rule]", "2404"}], ",", 
       RowBox[{"1971", "\[Rule]", "1432"}], ",", 
       RowBox[{"1971", "\[Rule]", "1432"}], ",", 
       RowBox[{"1971", "\[Rule]", "2296"}], ",", 
       RowBox[{"1971", "\[Rule]", "2296"}], ",", 
       RowBox[{"1971", "\[Rule]", "1972"}], ",", 
       RowBox[{"1527", "\[Rule]", "1204"}], ",", 
       RowBox[{"1527", "\[Rule]", "1204"}], ",", 
       RowBox[{"1527", "\[Rule]", "2068"}], ",", 
       RowBox[{"1527", "\[Rule]", "2068"}], ",", 
       RowBox[{"1527", "\[Rule]", "1096"}], ",", 
       RowBox[{"1527", "\[Rule]", "1096"}], ",", 
       RowBox[{"1527", "\[Rule]", "1960"}], ",", 
       RowBox[{"1527", "\[Rule]", "1960"}], ",", 
       RowBox[{"1527", "\[Rule]", "1528"}], ",", 
       RowBox[{"1557", "\[Rule]", "1234"}], ",", 
       RowBox[{"1557", "\[Rule]", "1234"}], ",", 
       RowBox[{"1557", "\[Rule]", "2098"}], ",", 
       RowBox[{"1557", "\[Rule]", "2098"}], ",", 
       RowBox[{"1557", "\[Rule]", "1126"}], ",", 
       RowBox[{"1557", "\[Rule]", "1126"}], ",", 
       RowBox[{"1557", "\[Rule]", "1990"}], ",", 
       RowBox[{"1557", "\[Rule]", "1990"}], ",", 
       RowBox[{"1557", "\[Rule]", "1558"}], ",", 
       RowBox[{"1539", "\[Rule]", "1216"}], ",", 
       RowBox[{"1539", "\[Rule]", "1216"}], ",", 
       RowBox[{"1539", "\[Rule]", "2080"}], ",", 
       RowBox[{"1539", "\[Rule]", "2080"}], ",", 
       RowBox[{"1539", "\[Rule]", "1108"}], ",", 
       RowBox[{"1539", "\[Rule]", "1108"}], ",", 
       RowBox[{"1539", "\[Rule]", "1972"}], ",", 
       RowBox[{"1539", "\[Rule]", "1972"}], ",", 
       RowBox[{"1539", "\[Rule]", "1540"}], ",", 
       RowBox[{"2127", "\[Rule]", "1696"}], ",", 
       RowBox[{"2127", "\[Rule]", "2560"}], ",", 
       RowBox[{"2127", "\[Rule]", "1588"}], ",", 
       RowBox[{"2127", "\[Rule]", "1588"}], ",", 
       RowBox[{"2127", "\[Rule]", "2452"}], ",", 
       RowBox[{"2127", "\[Rule]", "2452"}], ",", 
       RowBox[{"2127", "\[Rule]", "2128"}], ",", 
       RowBox[{"2109", "\[Rule]", "1678"}], ",", 
       RowBox[{"2109", "\[Rule]", "2542"}], ",", 
       RowBox[{"2109", "\[Rule]", "2542"}], ",", 
       RowBox[{"2109", "\[Rule]", "1570"}], ",", 
       RowBox[{"2109", "\[Rule]", "2434"}], ",", 
       RowBox[{"2109", "\[Rule]", "2434"}], ",", 
       RowBox[{"2109", "\[Rule]", "2110"}], ",", 
       RowBox[{"1587", "\[Rule]", "1264"}], ",", 
       RowBox[{"1587", "\[Rule]", "1264"}], ",", 
       RowBox[{"1587", "\[Rule]", "2128"}], ",", 
       RowBox[{"1587", "\[Rule]", "2128"}], ",", 
       RowBox[{"1587", "\[Rule]", "1156"}], ",", 
       RowBox[{"1587", "\[Rule]", "1156"}], ",", 
       RowBox[{"1587", "\[Rule]", "2020"}], ",", 
       RowBox[{"1587", "\[Rule]", "2020"}], ",", 
       RowBox[{"1587", "\[Rule]", "1588"}], ",", 
       RowBox[{"1569", "\[Rule]", "1246"}], ",", 
       RowBox[{"1569", "\[Rule]", "2110"}], ",", 
       RowBox[{"1569", "\[Rule]", "1138"}], ",", 
       RowBox[{"1569", "\[Rule]", "1138"}], ",", 
       RowBox[{"1569", "\[Rule]", "2002"}], ",", 
       RowBox[{"1569", "\[Rule]", "2002"}], ",", 
       RowBox[{"1569", "\[Rule]", "1570"}], ",", 
       RowBox[{"2093", "\[Rule]", "1662"}], ",", 
       RowBox[{"2093", "\[Rule]", "1662"}], ",", 
       RowBox[{"2093", "\[Rule]", "2526"}], ",", 
       RowBox[{"2093", "\[Rule]", "2526"}], ",", 
       RowBox[{"2093", "\[Rule]", "1554"}], ",", 
       RowBox[{"2093", "\[Rule]", "1554"}], ",", 
       RowBox[{"2093", "\[Rule]", "2418"}], ",", 
       RowBox[{"2093", "\[Rule]", "2418"}], ",", 
       RowBox[{"2093", "\[Rule]", "2094"}], ",", 
       RowBox[{"1985", "\[Rule]", "1554"}], ",", 
       RowBox[{"1985", "\[Rule]", "1554"}], ",", 
       RowBox[{"1985", "\[Rule]", "2418"}], ",", 
       RowBox[{"1985", "\[Rule]", "2418"}], ",", 
       RowBox[{"1985", "\[Rule]", "1446"}], ",", 
       RowBox[{"1985", "\[Rule]", "1446"}], ",", 
       RowBox[{"1985", "\[Rule]", "2310"}], ",", 
       RowBox[{"1985", "\[Rule]", "2310"}], ",", 
       RowBox[{"1985", "\[Rule]", "1986"}], ",", 
       RowBox[{"1553", "\[Rule]", "1230"}], ",", 
       RowBox[{"1553", "\[Rule]", "2094"}], ",", 
       RowBox[{"1553", "\[Rule]", "2094"}], ",", 
       RowBox[{"1553", "\[Rule]", "1122"}], ",", 
       RowBox[{"1553", "\[Rule]", "1986"}], ",", 
       RowBox[{"1553", "\[Rule]", "1986"}], ",", 
       RowBox[{"1553", "\[Rule]", "1554"}], ",", 
       RowBox[{"1851", "\[Rule]", "1420"}], ",", 
       RowBox[{"1851", "\[Rule]", "1420"}], ",", 
       RowBox[{"1851", "\[Rule]", "2284"}], ",", 
       RowBox[{"1851", "\[Rule]", "2284"}], ",", 
       RowBox[{"1851", "\[Rule]", "1312"}], ",", 
       RowBox[{"1851", "\[Rule]", "1312"}], ",", 
       RowBox[{"1851", "\[Rule]", "2176"}], ",", 
       RowBox[{"1851", "\[Rule]", "2176"}], ",", 
       RowBox[{"1851", "\[Rule]", "1852"}], ",", 
       RowBox[{"1863", "\[Rule]", "1432"}], ",", 
       RowBox[{"1863", "\[Rule]", "1432"}], ",", 
       RowBox[{"1863", "\[Rule]", "2296"}], ",", 
       RowBox[{"1863", "\[Rule]", "2296"}], ",", 
       RowBox[{"1863", "\[Rule]", "1324"}], ",", 
       RowBox[{"1863", "\[Rule]", "1324"}], ",", 
       RowBox[{"1863", "\[Rule]", "2188"}], ",", 
       RowBox[{"1863", "\[Rule]", "2188"}], ",", 
       RowBox[{"1863", "\[Rule]", "1864"}], ",", 
       RowBox[{"1419", "\[Rule]", "1096"}], ",", 
       RowBox[{"1419", "\[Rule]", "1096"}], ",", 
       RowBox[{"1419", "\[Rule]", "1960"}], ",", 
       RowBox[{"1419", "\[Rule]", "1960"}], ",", 
       RowBox[{"1419", "\[Rule]", "988"}], ",", 
       RowBox[{"1419", "\[Rule]", "988"}], ",", 
       RowBox[{"1419", "\[Rule]", "1852"}], ",", 
       RowBox[{"1419", "\[Rule]", "1852"}], ",", 
       RowBox[{"1419", "\[Rule]", "1420"}], ",", 
       RowBox[{"1431", "\[Rule]", "1108"}], ",", 
       RowBox[{"1431", "\[Rule]", "1108"}], ",", 
       RowBox[{"1431", "\[Rule]", "1972"}], ",", 
       RowBox[{"1431", "\[Rule]", "1972"}], ",", 
       RowBox[{"1431", "\[Rule]", "1000"}], ",", 
       RowBox[{"1431", "\[Rule]", "1000"}], ",", 
       RowBox[{"1431", "\[Rule]", "1864"}], ",", 
       RowBox[{"1431", "\[Rule]", "1864"}], ",", 
       RowBox[{"1431", "\[Rule]", "1432"}], ",", 
       RowBox[{"1877", "\[Rule]", "1446"}], ",", 
       RowBox[{"1877", "\[Rule]", "1446"}], ",", 
       RowBox[{"1877", "\[Rule]", "2310"}], ",", 
       RowBox[{"1877", "\[Rule]", "2310"}], ",", 
       RowBox[{"1877", "\[Rule]", "1338"}], ",", 
       RowBox[{"1877", "\[Rule]", "1338"}], ",", 
       RowBox[{"1877", "\[Rule]", "2202"}], ",", 
       RowBox[{"1877", "\[Rule]", "2202"}], ",", 
       RowBox[{"1877", "\[Rule]", "1878"}], ",", 
       RowBox[{"1445", "\[Rule]", "1122"}], ",", 
       RowBox[{"1445", "\[Rule]", "1122"}], ",", 
       RowBox[{"1445", "\[Rule]", "1986"}], ",", 
       RowBox[{"1445", "\[Rule]", "1986"}], ",", 
       RowBox[{"1445", "\[Rule]", "1014"}], ",", 
       RowBox[{"1445", "\[Rule]", "1014"}], ",", 
       RowBox[{"1445", "\[Rule]", "1878"}], ",", 
       RowBox[{"1445", "\[Rule]", "1878"}], ",", 
       RowBox[{"1445", "\[Rule]", "1446"}], ",", 
       RowBox[{"2159", "\[Rule]", "1728"}], ",", 
       RowBox[{"2159", "\[Rule]", "1728"}], ",", 
       RowBox[{"2159", "\[Rule]", "2592"}], ",", 
       RowBox[{"2159", "\[Rule]", "2592"}], ",", 
       RowBox[{"2159", "\[Rule]", "1620"}], ",", 
       RowBox[{"2159", "\[Rule]", "1620"}], ",", 
       RowBox[{"2159", "\[Rule]", "2484"}], ",", 
       RowBox[{"2159", "\[Rule]", "2484"}], ",", 
       RowBox[{"2159", "\[Rule]", "2160"}], ",", 
       RowBox[{"2141", "\[Rule]", "1710"}], ",", 
       RowBox[{"2141", "\[Rule]", "1710"}], ",", 
       RowBox[{"2141", "\[Rule]", "2574"}], ",", 
       RowBox[{"2141", "\[Rule]", "1602"}], ",", 
       RowBox[{"2141", "\[Rule]", "1602"}], ",", 
       RowBox[{"2141", "\[Rule]", "2466"}], ",", 
       RowBox[{"2141", "\[Rule]", "2142"}], ",", 
       RowBox[{"1619", "\[Rule]", "1296"}], ",", 
       RowBox[{"1619", "\[Rule]", "1296"}], ",", 
       RowBox[{"1619", "\[Rule]", "2160"}], ",", 
       RowBox[{"1619", "\[Rule]", "2160"}], ",", 
       RowBox[{"1619", "\[Rule]", "1188"}], ",", 
       RowBox[{"1619", "\[Rule]", "1188"}], ",", 
       RowBox[{"1619", "\[Rule]", "2052"}], ",", 
       RowBox[{"1619", "\[Rule]", "2052"}], ",", 
       RowBox[{"1619", "\[Rule]", "1620"}], ",", 
       RowBox[{"1601", "\[Rule]", "1278"}], ",", 
       RowBox[{"1601", "\[Rule]", "1278"}], ",", 
       RowBox[{"1601", "\[Rule]", "2142"}], ",", 
       RowBox[{"1601", "\[Rule]", "2142"}], ",", 
       RowBox[{"1601", "\[Rule]", "1170"}], ",", 
       RowBox[{"1601", "\[Rule]", "1170"}], ",", 
       RowBox[{"1601", "\[Rule]", "2034"}], ",", 
       RowBox[{"1601", "\[Rule]", "2034"}], ",", 
       RowBox[{"1601", "\[Rule]", "1602"}], ",", 
       RowBox[{"2123", "\[Rule]", "1692"}], ",", 
       RowBox[{"2123", "\[Rule]", "1692"}], ",", 
       RowBox[{"2123", "\[Rule]", "2556"}], ",", 
       RowBox[{"2123", "\[Rule]", "2556"}], ",", 
       RowBox[{"2123", "\[Rule]", "1584"}], ",", 
       RowBox[{"2123", "\[Rule]", "2448"}], ",", 
       RowBox[{"2123", "\[Rule]", "2124"}], ",", 
       RowBox[{"1583", "\[Rule]", "1260"}], ",", 
       RowBox[{"1583", "\[Rule]", "1260"}], ",", 
       RowBox[{"1583", "\[Rule]", "2124"}], ",", 
       RowBox[{"1583", "\[Rule]", "1152"}], ",", 
       RowBox[{"1583", "\[Rule]", "1152"}], ",", 
       RowBox[{"1583", "\[Rule]", "2016"}], ",", 
       RowBox[{"1583", "\[Rule]", "1584"}], ",", 
       RowBox[{"2105", "\[Rule]", "1674"}], ",", 
       RowBox[{"2105", "\[Rule]", "1674"}], ",", 
       RowBox[{"2105", "\[Rule]", "2538"}], ",", 
       RowBox[{"2105", "\[Rule]", "2538"}], ",", 
       RowBox[{"2105", "\[Rule]", "1566"}], ",", 
       RowBox[{"2105", "\[Rule]", "1566"}], ",", 
       RowBox[{"2105", "\[Rule]", "2430"}], ",", 
       RowBox[{"2105", "\[Rule]", "2430"}], ",", 
       RowBox[{"2105", "\[Rule]", "2106"}], ",", 
       RowBox[{"1997", "\[Rule]", "1566"}], ",", 
       RowBox[{"1997", "\[Rule]", "2430"}], ",", 
       RowBox[{"1997", "\[Rule]", "2430"}], ",", 
       RowBox[{"1997", "\[Rule]", "1458"}], ",", 
       RowBox[{"1997", "\[Rule]", "2322"}], ",", 
       RowBox[{"1997", "\[Rule]", "2322"}], ",", 
       RowBox[{"1997", "\[Rule]", "1998"}], ",", 
       RowBox[{"1565", "\[Rule]", "1242"}], ",", 
       RowBox[{"1565", "\[Rule]", "1242"}], ",", 
       RowBox[{"1565", "\[Rule]", "2106"}], ",", 
       RowBox[{"1565", "\[Rule]", "2106"}], ",", 
       RowBox[{"1565", "\[Rule]", "1134"}], ",", 
       RowBox[{"1565", "\[Rule]", "1998"}], ",", 
       RowBox[{"1565", "\[Rule]", "1566"}], ",", 
       RowBox[{"1889", "\[Rule]", "1458"}], ",", 
       RowBox[{"1889", "\[Rule]", "1458"}], ",", 
       RowBox[{"1889", "\[Rule]", "2322"}], ",", 
       RowBox[{"1889", "\[Rule]", "2322"}], ",", 
       RowBox[{"1889", "\[Rule]", "1350"}], ",", 
       RowBox[{"1889", "\[Rule]", "1350"}], ",", 
       RowBox[{"1889", "\[Rule]", "2214"}], ",", 
       RowBox[{"1889", "\[Rule]", "2214"}], ",", 
       RowBox[{"1889", "\[Rule]", "1890"}], ",", 
       RowBox[{"1457", "\[Rule]", "1134"}], ",", 
       RowBox[{"1457", "\[Rule]", "1998"}], ",", 
       RowBox[{"1457", "\[Rule]", "1026"}], ",", 
       RowBox[{"1457", "\[Rule]", "1026"}], ",", 
       RowBox[{"1457", "\[Rule]", "1890"}], ",", 
       RowBox[{"1457", "\[Rule]", "1890"}], ",", 
       RowBox[{"1457", "\[Rule]", "1458"}], ",", 
       RowBox[{"15", "\[Rule]", "448"}], ",", 
       RowBox[{"15", "\[Rule]", "448"}], ",", 
       RowBox[{"15", "\[Rule]", "16"}], ",", 
       RowBox[{"27", "\[Rule]", "460"}], ",", 
       RowBox[{"27", "\[Rule]", "460"}], ",", 
       RowBox[{"27", "\[Rule]", "28"}], ",", 
       RowBox[{"879", "\[Rule]", "448"}], ",", 
       RowBox[{"879", "\[Rule]", "448"}], ",", 
       RowBox[{"879", "\[Rule]", "1312"}], ",", 
       RowBox[{"879", "\[Rule]", "880"}], ",", 
       RowBox[{"891", "\[Rule]", "460"}], ",", 
       RowBox[{"891", "\[Rule]", "460"}], ",", 
       RowBox[{"891", "\[Rule]", "1324"}], ",", 
       RowBox[{"891", "\[Rule]", "892"}], ",", 
       RowBox[{"447", "\[Rule]", "124"}], ",", 
       RowBox[{"447", "\[Rule]", "988"}], ",", 
       RowBox[{"447", "\[Rule]", "16"}], ",", 
       RowBox[{"447", "\[Rule]", "16"}], ",", 
       RowBox[{"447", "\[Rule]", "880"}], ",", 
       RowBox[{"447", "\[Rule]", "880"}], ",", 
       RowBox[{"447", "\[Rule]", "448"}], ",", 
       RowBox[{"459", "\[Rule]", "136"}], ",", 
       RowBox[{"459", "\[Rule]", "1000"}], ",", 
       RowBox[{"459", "\[Rule]", "28"}], ",", 
       RowBox[{"459", "\[Rule]", "28"}], ",", 
       RowBox[{"459", "\[Rule]", "892"}], ",", 
       RowBox[{"459", "\[Rule]", "892"}], ",", 
       RowBox[{"459", "\[Rule]", "460"}], ",", 
       RowBox[{"41", "\[Rule]", "474"}], ",", 
       RowBox[{"41", "\[Rule]", "474"}], ",", 
       RowBox[{"41", "\[Rule]", "42"}], ",", 
       RowBox[{"905", "\[Rule]", "474"}], ",", 
       RowBox[{"905", "\[Rule]", "474"}], ",", 
       RowBox[{"905", "\[Rule]", "1338"}], ",", 
       RowBox[{"905", "\[Rule]", "906"}], ",", 
       RowBox[{"473", "\[Rule]", "150"}], ",", 
       RowBox[{"473", "\[Rule]", "1014"}], ",", 
       RowBox[{"473", "\[Rule]", "42"}], ",", 
       RowBox[{"473", "\[Rule]", "42"}], ",", 
       RowBox[{"473", "\[Rule]", "906"}], ",", 
       RowBox[{"473", "\[Rule]", "906"}], ",", 
       RowBox[{"473", "\[Rule]", "474"}], ",", 
       RowBox[{"53", "\[Rule]", "486"}], ",", 
       RowBox[{"53", "\[Rule]", "486"}], ",", 
       RowBox[{"53", "\[Rule]", "54"}], ",", 
       RowBox[{"917", "\[Rule]", "486"}], ",", 
       RowBox[{"917", "\[Rule]", "486"}], ",", 
       RowBox[{"917", "\[Rule]", "1350"}], ",", 
       RowBox[{"917", "\[Rule]", "918"}], ",", 
       RowBox[{"485", "\[Rule]", "162"}], ",", 
       RowBox[{"485", "\[Rule]", "1026"}], ",", 
       RowBox[{"485", "\[Rule]", "54"}], ",", 
       RowBox[{"485", "\[Rule]", "54"}], ",", 
       RowBox[{"485", "\[Rule]", "918"}], ",", 
       RowBox[{"485", "\[Rule]", "918"}], ",", 
       RowBox[{"485", "\[Rule]", "486"}], ",", 
       RowBox[{"1743", "\[Rule]", "1312"}], ",", 
       RowBox[{"1743", "\[Rule]", "2176"}], ",", 
       RowBox[{"1743", "\[Rule]", "2176"}], ",", 
       RowBox[{"1743", "\[Rule]", "1744"}], ",", 
       RowBox[{"1755", "\[Rule]", "1324"}], ",", 
       RowBox[{"1755", "\[Rule]", "2188"}], ",", 
       RowBox[{"1755", "\[Rule]", "2188"}], ",", 
       RowBox[{"1755", "\[Rule]", "1756"}], ",", 
       RowBox[{"1311", "\[Rule]", "988"}], ",", 
       RowBox[{"1311", "\[Rule]", "988"}], ",", 
       RowBox[{"1311", "\[Rule]", "1852"}], ",", 
       RowBox[{"1311", "\[Rule]", "1852"}], ",", 
       RowBox[{"1311", "\[Rule]", "880"}], ",", 
       RowBox[{"1311", "\[Rule]", "1744"}], ",", 
       RowBox[{"1311", "\[Rule]", "1312"}], ",", 
       RowBox[{"1323", "\[Rule]", "1000"}], ",", 
       RowBox[{"1323", "\[Rule]", "1000"}], ",", 
       RowBox[{"1323", "\[Rule]", "1864"}], ",", 
       RowBox[{"1323", "\[Rule]", "1864"}], ",", 
       RowBox[{"1323", "\[Rule]", "892"}], ",", 
       RowBox[{"1323", "\[Rule]", "1756"}], ",", 
       RowBox[{"1323", "\[Rule]", "1324"}], ",", 
       RowBox[{"1769", "\[Rule]", "1338"}], ",", 
       RowBox[{"1769", "\[Rule]", "2202"}], ",", 
       RowBox[{"1769", "\[Rule]", "2202"}], ",", 
       RowBox[{"1769", "\[Rule]", "1770"}], ",", 
       RowBox[{"1337", "\[Rule]", "1014"}], ",", 
       RowBox[{"1337", "\[Rule]", "1014"}], ",", 
       RowBox[{"1337", "\[Rule]", "1878"}], ",", 
       RowBox[{"1337", "\[Rule]", "1878"}], ",", 
       RowBox[{"1337", "\[Rule]", "906"}], ",", 
       RowBox[{"1337", "\[Rule]", "1770"}], ",", 
       RowBox[{"1337", "\[Rule]", "1338"}], ",", 
       RowBox[{"1781", "\[Rule]", "1350"}], ",", 
       RowBox[{"1781", "\[Rule]", "2214"}], ",", 
       RowBox[{"1781", "\[Rule]", "2214"}], ",", 
       RowBox[{"1781", "\[Rule]", "1782"}], ",", 
       RowBox[{"1349", "\[Rule]", "1026"}], ",", 
       RowBox[{"1349", "\[Rule]", "1026"}], ",", 
       RowBox[{"1349", "\[Rule]", "1890"}], ",", 
       RowBox[{"1349", "\[Rule]", "1890"}], ",", 
       RowBox[{"1349", "\[Rule]", "918"}], ",", 
       RowBox[{"1349", "\[Rule]", "1782"}], ",", 
       RowBox[{"1349", "\[Rule]", "1350"}], ",", 
       RowBox[{"427", "\[Rule]", "860"}], ",", 
       RowBox[{"427", "\[Rule]", "860"}], ",", 
       RowBox[{"427", "\[Rule]", "752"}], ",", 
       RowBox[{"427", "\[Rule]", "752"}], ",", 
       RowBox[{"427", "\[Rule]", "428"}], ",", 
       RowBox[{"1291", "\[Rule]", "860"}], ",", 
       RowBox[{"1291", "\[Rule]", "860"}], ",", 
       RowBox[{"1291", "\[Rule]", "1724"}], ",", 
       RowBox[{"1291", "\[Rule]", "1724"}], ",", 
       RowBox[{"1291", "\[Rule]", "752"}], ",", 
       RowBox[{"1291", "\[Rule]", "752"}], ",", 
       RowBox[{"1291", "\[Rule]", "1616"}], ",", 
       RowBox[{"1291", "\[Rule]", "1616"}], ",", 
       RowBox[{"1291", "\[Rule]", "1292"}], ",", 
       RowBox[{"751", "\[Rule]", "428"}], ",", 
       RowBox[{"751", "\[Rule]", "428"}], ",", 
       RowBox[{"751", "\[Rule]", "1292"}], ",", 
       RowBox[{"751", "\[Rule]", "1292"}], ",", 
       RowBox[{"751", "\[Rule]", "320"}], ",", 
       RowBox[{"751", "\[Rule]", "320"}], ",", 
       RowBox[{"751", "\[Rule]", "1184"}], ",", 
       RowBox[{"751", "\[Rule]", "1184"}], ",", 
       RowBox[{"751", "\[Rule]", "752"}], ",", 
       RowBox[{"409", "\[Rule]", "842"}], ",", 
       RowBox[{"409", "\[Rule]", "842"}], ",", 
       RowBox[{"409", "\[Rule]", "734"}], ",", 
       RowBox[{"409", "\[Rule]", "734"}], ",", 
       RowBox[{"409", "\[Rule]", "410"}], ",", 
       RowBox[{"1273", "\[Rule]", "842"}], ",", 
       RowBox[{"1273", "\[Rule]", "842"}], ",", 
       RowBox[{"1273", "\[Rule]", "1706"}], ",", 
       RowBox[{"1273", "\[Rule]", "1706"}], ",", 
       RowBox[{"1273", "\[Rule]", "734"}], ",", 
       RowBox[{"1273", "\[Rule]", "734"}], ",", 
       RowBox[{"1273", "\[Rule]", "1598"}], ",", 
       RowBox[{"1273", "\[Rule]", "1598"}], ",", 
       RowBox[{"1273", "\[Rule]", "1274"}], ",", 
       RowBox[{"733", "\[Rule]", "410"}], ",", 
       RowBox[{"733", "\[Rule]", "410"}], ",", 
       RowBox[{"733", "\[Rule]", "1274"}], ",", 
       RowBox[{"733", "\[Rule]", "1274"}], ",", 
       RowBox[{"733", "\[Rule]", "302"}], ",", 
       RowBox[{"733", "\[Rule]", "302"}], ",", 
       RowBox[{"733", "\[Rule]", "1166"}], ",", 
       RowBox[{"733", "\[Rule]", "1166"}], ",", 
       RowBox[{"733", "\[Rule]", "734"}], ",", 
       RowBox[{"2155", "\[Rule]", "1724"}], ",", 
       RowBox[{"2155", "\[Rule]", "1724"}], ",", 
       RowBox[{"2155", "\[Rule]", "2588"}], ",", 
       RowBox[{"2155", "\[Rule]", "2588"}], ",", 
       RowBox[{"2155", "\[Rule]", "1616"}], ",", 
       RowBox[{"2155", "\[Rule]", "1616"}], ",", 
       RowBox[{"2155", "\[Rule]", "2480"}], ",", 
       RowBox[{"2155", "\[Rule]", "2480"}], ",", 
       RowBox[{"2155", "\[Rule]", "2156"}], ",", 
       RowBox[{"1615", "\[Rule]", "1292"}], ",", 
       RowBox[{"1615", "\[Rule]", "1292"}], ",", 
       RowBox[{"1615", "\[Rule]", "2156"}], ",", 
       RowBox[{"1615", "\[Rule]", "2156"}], ",", 
       RowBox[{"1615", "\[Rule]", "1184"}], ",", 
       RowBox[{"1615", "\[Rule]", "1184"}], ",", 
       RowBox[{"1615", "\[Rule]", "2048"}], ",", 
       RowBox[{"1615", "\[Rule]", "2048"}], ",", 
       RowBox[{"1615", "\[Rule]", "1616"}], ",", 
       RowBox[{"2137", "\[Rule]", "1706"}], ",", 
       RowBox[{"2137", "\[Rule]", "1706"}], ",", 
       RowBox[{"2137", "\[Rule]", "2570"}], ",", 
       RowBox[{"2137", "\[Rule]", "2570"}], ",", 
       RowBox[{"2137", "\[Rule]", "1598"}], ",", 
       RowBox[{"2137", "\[Rule]", "1598"}], ",", 
       RowBox[{"2137", "\[Rule]", "2462"}], ",", 
       RowBox[{"2137", "\[Rule]", "2462"}], ",", 
       RowBox[{"2137", "\[Rule]", "2138"}], ",", 
       RowBox[{"1597", "\[Rule]", "1274"}], ",", 
       RowBox[{"1597", "\[Rule]", "1274"}], ",", 
       RowBox[{"1597", "\[Rule]", "2138"}], ",", 
       RowBox[{"1597", "\[Rule]", "2138"}], ",", 
       RowBox[{"1597", "\[Rule]", "1166"}], ",", 
       RowBox[{"1597", "\[Rule]", "1166"}], ",", 
       RowBox[{"1597", "\[Rule]", "2030"}], ",", 
       RowBox[{"1597", "\[Rule]", "2030"}], ",", 
       RowBox[{"1597", "\[Rule]", "1598"}], ",", 
       RowBox[{"391", "\[Rule]", "824"}], ",", 
       RowBox[{"391", "\[Rule]", "824"}], ",", 
       RowBox[{"391", "\[Rule]", "716"}], ",", 
       RowBox[{"391", "\[Rule]", "716"}], ",", 
       RowBox[{"391", "\[Rule]", "392"}], ",", 
       RowBox[{"1255", "\[Rule]", "824"}], ",", 
       RowBox[{"1255", "\[Rule]", "824"}], ",", 
       RowBox[{"1255", "\[Rule]", "1688"}], ",", 
       RowBox[{"1255", "\[Rule]", "1688"}], ",", 
       RowBox[{"1255", "\[Rule]", "716"}], ",", 
       RowBox[{"1255", "\[Rule]", "716"}], ",", 
       RowBox[{"1255", "\[Rule]", "1580"}], ",", 
       RowBox[{"1255", "\[Rule]", "1580"}], ",", 
       RowBox[{"1255", "\[Rule]", "1256"}], ",", 
       RowBox[{"283", "\[Rule]", "716"}], ",", 
       RowBox[{"283", "\[Rule]", "716"}], ",", 
       RowBox[{"283", "\[Rule]", "608"}], ",", 
       RowBox[{"283", "\[Rule]", "608"}], ",", 
       RowBox[{"283", "\[Rule]", "284"}], ",", 
       RowBox[{"1147", "\[Rule]", "716"}], ",", 
       RowBox[{"1147", "\[Rule]", "716"}], ",", 
       RowBox[{"1147", "\[Rule]", "1580"}], ",", 
       RowBox[{"1147", "\[Rule]", "1580"}], ",", 
       RowBox[{"1147", "\[Rule]", "608"}], ",", 
       RowBox[{"1147", "\[Rule]", "608"}], ",", 
       RowBox[{"1147", "\[Rule]", "1472"}], ",", 
       RowBox[{"1147", "\[Rule]", "1472"}], ",", 
       RowBox[{"1147", "\[Rule]", "1148"}], ",", 
       RowBox[{"715", "\[Rule]", "392"}], ",", 
       RowBox[{"715", "\[Rule]", "392"}], ",", 
       RowBox[{"715", "\[Rule]", "1256"}], ",", 
       RowBox[{"715", "\[Rule]", "1256"}], ",", 
       RowBox[{"715", "\[Rule]", "284"}], ",", 
       RowBox[{"715", "\[Rule]", "284"}], ",", 
       RowBox[{"715", "\[Rule]", "1148"}], ",", 
       RowBox[{"715", "\[Rule]", "1148"}], ",", 
       RowBox[{"715", "\[Rule]", "716"}], ",", 
       RowBox[{"175", "\[Rule]", "608"}], ",", 
       RowBox[{"175", "\[Rule]", "500"}], ",", 
       RowBox[{"175", "\[Rule]", "176"}], ",", 
       RowBox[{"1039", "\[Rule]", "608"}], ",", 
       RowBox[{"1039", "\[Rule]", "1472"}], ",", 
       RowBox[{"1039", "\[Rule]", "1472"}], ",", 
       RowBox[{"1039", "\[Rule]", "500"}], ",", 
       RowBox[{"1039", "\[Rule]", "1364"}], ",", 
       RowBox[{"1039", "\[Rule]", "1364"}], ",", 
       RowBox[{"1039", "\[Rule]", "1040"}], ",", 
       RowBox[{"607", "\[Rule]", "284"}], ",", 
       RowBox[{"607", "\[Rule]", "284"}], ",", 
       RowBox[{"607", "\[Rule]", "1148"}], ",", 
       RowBox[{"607", "\[Rule]", "1148"}], ",", 
       RowBox[{"607", "\[Rule]", "176"}], ",", 
       RowBox[{"607", "\[Rule]", "1040"}], ",", 
       RowBox[{"607", "\[Rule]", "608"}], ",", 
       RowBox[{"2119", "\[Rule]", "1688"}], ",", 
       RowBox[{"2119", "\[Rule]", "1688"}], ",", 
       RowBox[{"2119", "\[Rule]", "2552"}], ",", 
       RowBox[{"2119", "\[Rule]", "2552"}], ",", 
       RowBox[{"2119", "\[Rule]", "1580"}], ",", 
       RowBox[{"2119", "\[Rule]", "1580"}], ",", 
       RowBox[{"2119", "\[Rule]", "2444"}], ",", 
       RowBox[{"2119", "\[Rule]", "2444"}], ",", 
       RowBox[{"2119", "\[Rule]", "2120"}], ",", 
       RowBox[{"2011", "\[Rule]", "1580"}], ",", 
       RowBox[{"2011", "\[Rule]", "1580"}], ",", 
       RowBox[{"2011", "\[Rule]", "2444"}], ",", 
       RowBox[{"2011", "\[Rule]", "2444"}], ",", 
       RowBox[{"2011", "\[Rule]", "1472"}], ",", 
       RowBox[{"2011", "\[Rule]", "2336"}], ",", 
       RowBox[{"2011", "\[Rule]", "2012"}], ",", 
       RowBox[{"1579", "\[Rule]", "1256"}], ",", 
       RowBox[{"1579", "\[Rule]", "1256"}], ",", 
       RowBox[{"1579", "\[Rule]", "2120"}], ",", 
       RowBox[{"1579", "\[Rule]", "2120"}], ",", 
       RowBox[{"1579", "\[Rule]", "1148"}], ",", 
       RowBox[{"1579", "\[Rule]", "1148"}], ",", 
       RowBox[{"1579", "\[Rule]", "2012"}], ",", 
       RowBox[{"1579", "\[Rule]", "2012"}], ",", 
       RowBox[{"1579", "\[Rule]", "1580"}], ",", 
       RowBox[{"1903", "\[Rule]", "1472"}], ",", 
       RowBox[{"1903", "\[Rule]", "2336"}], ",", 
       RowBox[{"1903", "\[Rule]", "1364"}], ",", 
       RowBox[{"1903", "\[Rule]", "1364"}], ",", 
       RowBox[{"1903", "\[Rule]", "2228"}], ",", 
       RowBox[{"1903", "\[Rule]", "2228"}], ",", 
       RowBox[{"1903", "\[Rule]", "1904"}], ",", 
       RowBox[{"1471", "\[Rule]", "1148"}], ",", 
       RowBox[{"1471", "\[Rule]", "1148"}], ",", 
       RowBox[{"1471", "\[Rule]", "2012"}], ",", 
       RowBox[{"1471", "\[Rule]", "1040"}], ",", 
       RowBox[{"1471", "\[Rule]", "1040"}], ",", 
       RowBox[{"1471", "\[Rule]", "1904"}], ",", 
       RowBox[{"1471", "\[Rule]", "1472"}], ",", 
       RowBox[{"67", "\[Rule]", "500"}], ",", 
       RowBox[{"67", "\[Rule]", "500"}], ",", 
       RowBox[{"67", "\[Rule]", "68"}], ",", 
       RowBox[{"931", "\[Rule]", "500"}], ",", 
       RowBox[{"931", "\[Rule]", "500"}], ",", 
       RowBox[{"931", "\[Rule]", "1364"}], ",", 
       RowBox[{"931", "\[Rule]", "932"}], ",", 
       RowBox[{"499", "\[Rule]", "176"}], ",", 
       RowBox[{"499", "\[Rule]", "1040"}], ",", 
       RowBox[{"499", "\[Rule]", "68"}], ",", 
       RowBox[{"499", "\[Rule]", "68"}], ",", 
       RowBox[{"499", "\[Rule]", "932"}], ",", 
       RowBox[{"499", "\[Rule]", "932"}], ",", 
       RowBox[{"499", "\[Rule]", "500"}], ",", 
       RowBox[{"1795", "\[Rule]", "1364"}], ",", 
       RowBox[{"1795", "\[Rule]", "2228"}], ",", 
       RowBox[{"1795", "\[Rule]", "2228"}], ",", 
       RowBox[{"1795", "\[Rule]", "1796"}], ",", 
       RowBox[{"1363", "\[Rule]", "1040"}], ",", 
       RowBox[{"1363", "\[Rule]", "1040"}], ",", 
       RowBox[{"1363", "\[Rule]", "1904"}], ",", 
       RowBox[{"1363", "\[Rule]", "1904"}], ",", 
       RowBox[{"1363", "\[Rule]", "932"}], ",", 
       RowBox[{"1363", "\[Rule]", "1796"}], ",", 
       RowBox[{"1363", "\[Rule]", "1364"}], ",", 
       RowBox[{"423", "\[Rule]", "856"}], ",", 
       RowBox[{"423", "\[Rule]", "856"}], ",", 
       RowBox[{"423", "\[Rule]", "748"}], ",", 
       RowBox[{"423", "\[Rule]", "748"}], ",", 
       RowBox[{"423", "\[Rule]", "424"}], ",", 
       RowBox[{"1287", "\[Rule]", "856"}], ",", 
       RowBox[{"1287", "\[Rule]", "856"}], ",", 
       RowBox[{"1287", "\[Rule]", "1720"}], ",", 
       RowBox[{"1287", "\[Rule]", "1720"}], ",", 
       RowBox[{"1287", "\[Rule]", "748"}], ",", 
       RowBox[{"1287", "\[Rule]", "748"}], ",", 
       RowBox[{"1287", "\[Rule]", "1612"}], ",", 
       RowBox[{"1287", "\[Rule]", "1612"}], ",", 
       RowBox[{"1287", "\[Rule]", "1288"}], ",", 
       RowBox[{"747", "\[Rule]", "424"}], ",", 
       RowBox[{"747", "\[Rule]", "424"}], ",", 
       RowBox[{"747", "\[Rule]", "1288"}], ",", 
       RowBox[{"747", "\[Rule]", "1288"}], ",", 
       RowBox[{"747", "\[Rule]", "316"}], ",", 
       RowBox[{"747", "\[Rule]", "316"}], ",", 
       RowBox[{"747", "\[Rule]", "1180"}], ",", 
       RowBox[{"747", "\[Rule]", "1180"}], ",", 
       RowBox[{"747", "\[Rule]", "748"}], ",", 
       RowBox[{"2151", "\[Rule]", "1720"}], ",", 
       RowBox[{"2151", "\[Rule]", "1720"}], ",", 
       RowBox[{"2151", "\[Rule]", "2584"}], ",", 
       RowBox[{"2151", "\[Rule]", "2584"}], ",", 
       RowBox[{"2151", "\[Rule]", "1612"}], ",", 
       RowBox[{"2151", "\[Rule]", "1612"}], ",", 
       RowBox[{"2151", "\[Rule]", "2476"}], ",", 
       RowBox[{"2151", "\[Rule]", "2476"}], ",", 
       RowBox[{"2151", "\[Rule]", "2152"}], ",", 
       RowBox[{"1611", "\[Rule]", "1288"}], ",", 
       RowBox[{"1611", "\[Rule]", "1288"}], ",", 
       RowBox[{"1611", "\[Rule]", "2152"}], ",", 
       RowBox[{"1611", "\[Rule]", "2152"}], ",", 
       RowBox[{"1611", "\[Rule]", "1180"}], ",", 
       RowBox[{"1611", "\[Rule]", "1180"}], ",", 
       RowBox[{"1611", "\[Rule]", "2044"}], ",", 
       RowBox[{"1611", "\[Rule]", "2044"}], ",", 
       RowBox[{"1611", "\[Rule]", "1612"}], ",", 
       RowBox[{"405", "\[Rule]", "838"}], ",", 
       RowBox[{"405", "\[Rule]", "838"}], ",", 
       RowBox[{"405", "\[Rule]", "730"}], ",", 
       RowBox[{"405", "\[Rule]", "730"}], ",", 
       RowBox[{"405", "\[Rule]", "406"}], ",", 
       RowBox[{"1269", "\[Rule]", "838"}], ",", 
       RowBox[{"1269", "\[Rule]", "838"}], ",", 
       RowBox[{"1269", "\[Rule]", "1702"}], ",", 
       RowBox[{"1269", "\[Rule]", "1702"}], ",", 
       RowBox[{"1269", "\[Rule]", "730"}], ",", 
       RowBox[{"1269", "\[Rule]", "730"}], ",", 
       RowBox[{"1269", "\[Rule]", "1594"}], ",", 
       RowBox[{"1269", "\[Rule]", "1594"}], ",", 
       RowBox[{"1269", "\[Rule]", "1270"}], ",", 
       RowBox[{"297", "\[Rule]", "730"}], ",", 
       RowBox[{"297", "\[Rule]", "730"}], ",", 
       RowBox[{"297", "\[Rule]", "622"}], ",", 
       RowBox[{"297", "\[Rule]", "622"}], ",", 
       RowBox[{"297", "\[Rule]", "298"}], ",", 
       RowBox[{"1161", "\[Rule]", "730"}], ",", 
       RowBox[{"1161", "\[Rule]", "730"}], ",", 
       RowBox[{"1161", "\[Rule]", "1594"}], ",", 
       RowBox[{"1161", "\[Rule]", "1594"}], ",", 
       RowBox[{"1161", "\[Rule]", "622"}], ",", 
       RowBox[{"1161", "\[Rule]", "622"}], ",", 
       RowBox[{"1161", "\[Rule]", "1486"}], ",", 
       RowBox[{"1161", "\[Rule]", "1486"}], ",", 
       RowBox[{"1161", "\[Rule]", "1162"}], ",", 
       RowBox[{"729", "\[Rule]", "406"}], ",", 
       RowBox[{"729", "\[Rule]", "406"}], ",", 
       RowBox[{"729", "\[Rule]", "1270"}], ",", 
       RowBox[{"729", "\[Rule]", "1270"}], ",", 
       RowBox[{"729", "\[Rule]", "298"}], ",", 
       RowBox[{"729", "\[Rule]", "298"}], ",", 
       RowBox[{"729", "\[Rule]", "1162"}], ",", 
       RowBox[{"729", "\[Rule]", "1162"}], ",", 
       RowBox[{"729", "\[Rule]", "730"}], ",", 
       RowBox[{"189", "\[Rule]", "622"}], ",", 
       RowBox[{"189", "\[Rule]", "514"}], ",", 
       RowBox[{"189", "\[Rule]", "190"}], ",", 
       RowBox[{"1053", "\[Rule]", "622"}], ",", 
       RowBox[{"1053", "\[Rule]", "1486"}], ",", 
       RowBox[{"1053", "\[Rule]", "1486"}], ",", 
       RowBox[{"1053", "\[Rule]", "514"}], ",", 
       RowBox[{"1053", "\[Rule]", "1378"}], ",", 
       RowBox[{"1053", "\[Rule]", "1378"}], ",", 
       RowBox[{"1053", "\[Rule]", "1054"}], ",", 
       RowBox[{"621", "\[Rule]", "298"}], ",", 
       RowBox[{"621", "\[Rule]", "298"}], ",", 
       RowBox[{"621", "\[Rule]", "1162"}], ",", 
       RowBox[{"621", "\[Rule]", "1162"}], ",", 
       RowBox[{"621", "\[Rule]", "190"}], ",", 
       RowBox[{"621", "\[Rule]", "1054"}], ",", 
       RowBox[{"621", "\[Rule]", "622"}], ",", 
       RowBox[{"2133", "\[Rule]", "1702"}], ",", 
       RowBox[{"2133", "\[Rule]", "1702"}], ",", 
       RowBox[{"2133", "\[Rule]", "2566"}], ",", 
       RowBox[{"2133", "\[Rule]", "2566"}], ",", 
       RowBox[{"2133", "\[Rule]", "1594"}], ",", 
       RowBox[{"2133", "\[Rule]", "1594"}], ",", 
       RowBox[{"2133", "\[Rule]", "2458"}], ",", 
       RowBox[{"2133", "\[Rule]", "2458"}], ",", 
       RowBox[{"2133", "\[Rule]", "2134"}], ",", 
       RowBox[{"2025", "\[Rule]", "1594"}], ",", 
       RowBox[{"2025", "\[Rule]", "1594"}], ",", 
       RowBox[{"2025", "\[Rule]", "2458"}], ",", 
       RowBox[{"2025", "\[Rule]", "2458"}], ",", 
       RowBox[{"2025", "\[Rule]", "1486"}], ",", 
       RowBox[{"2025", "\[Rule]", "1486"}], ",", 
       RowBox[{"2025", "\[Rule]", "2350"}], ",", 
       RowBox[{"2025", "\[Rule]", "2350"}], ",", 
       RowBox[{"2025", "\[Rule]", "2026"}], ",", 
       RowBox[{"1593", "\[Rule]", "1270"}], ",", 
       RowBox[{"1593", "\[Rule]", "1270"}], ",", 
       RowBox[{"1593", "\[Rule]", "2134"}], ",", 
       RowBox[{"1593", "\[Rule]", "2134"}], ",", 
       RowBox[{"1593", "\[Rule]", "1162"}], ",", 
       RowBox[{"1593", "\[Rule]", "1162"}], ",", 
       RowBox[{"1593", "\[Rule]", "2026"}], ",", 
       RowBox[{"1593", "\[Rule]", "2026"}], ",", 
       RowBox[{"1593", "\[Rule]", "1594"}], ",", 
       RowBox[{"1917", "\[Rule]", "1486"}], ",", 
       RowBox[{"1917", "\[Rule]", "1486"}], ",", 
       RowBox[{"1917", "\[Rule]", "2350"}], ",", 
       RowBox[{"1917", "\[Rule]", "1378"}], ",", 
       RowBox[{"1917", "\[Rule]", "1378"}], ",", 
       RowBox[{"1917", "\[Rule]", "2242"}], ",", 
       RowBox[{"1917", "\[Rule]", "1918"}], ",", 
       RowBox[{"1485", "\[Rule]", "1162"}], ",", 
       RowBox[{"1485", "\[Rule]", "1162"}], ",", 
       RowBox[{"1485", "\[Rule]", "2026"}], ",", 
       RowBox[{"1485", "\[Rule]", "2026"}], ",", 
       RowBox[{"1485", "\[Rule]", "1054"}], ",", 
       RowBox[{"1485", "\[Rule]", "1054"}], ",", 
       RowBox[{"1485", "\[Rule]", "1918"}], ",", 
       RowBox[{"1485", "\[Rule]", "1918"}], ",", 
       RowBox[{"1485", "\[Rule]", "1486"}], ",", 
       RowBox[{"81", "\[Rule]", "514"}], ",", 
       RowBox[{"81", "\[Rule]", "514"}], ",", 
       RowBox[{"81", "\[Rule]", "82"}], ",", 
       RowBox[{"945", "\[Rule]", "514"}], ",", 
       RowBox[{"945", "\[Rule]", "514"}], ",", 
       RowBox[{"945", "\[Rule]", "1378"}], ",", 
       RowBox[{"945", "\[Rule]", "946"}], ",", 
       RowBox[{"513", "\[Rule]", "190"}], ",", 
       RowBox[{"513", "\[Rule]", "1054"}], ",", 
       RowBox[{"513", "\[Rule]", "82"}], ",", 
       RowBox[{"513", "\[Rule]", "82"}], ",", 
       RowBox[{"513", "\[Rule]", "946"}], ",", 
       RowBox[{"513", "\[Rule]", "946"}], ",", 
       RowBox[{"513", "\[Rule]", "514"}], ",", 
       RowBox[{"1809", "\[Rule]", "1378"}], ",", 
       RowBox[{"1809", "\[Rule]", "2242"}], ",", 
       RowBox[{"1809", "\[Rule]", "2242"}], ",", 
       RowBox[{"1809", "\[Rule]", "1810"}], ",", 
       RowBox[{"1377", "\[Rule]", "1054"}], ",", 
       RowBox[{"1377", "\[Rule]", "1054"}], ",", 
       RowBox[{"1377", "\[Rule]", "1918"}], ",", 
       RowBox[{"1377", "\[Rule]", "1918"}], ",", 
       RowBox[{"1377", "\[Rule]", "946"}], ",", 
       RowBox[{"1377", "\[Rule]", "1810"}], ",", 
       RowBox[{"1377", "\[Rule]", "1378"}], ",", 
       RowBox[{"2931", "\[Rule]", "2500"}], ",", 
       RowBox[{"2931", "\[Rule]", "2500"}], ",", 
       RowBox[{"2931", "\[Rule]", "2392"}], ",", 
       RowBox[{"2931", "\[Rule]", "2392"}], ",", 
       RowBox[{"2931", "\[Rule]", "2932"}], ",", 
       RowBox[{"2961", "\[Rule]", "2530"}], ",", 
       RowBox[{"2961", "\[Rule]", "2530"}], ",", 
       RowBox[{"2961", "\[Rule]", "2422"}], ",", 
       RowBox[{"2961", "\[Rule]", "2422"}], ",", 
       RowBox[{"2961", "\[Rule]", "2962"}], ",", 
       RowBox[{"2943", "\[Rule]", "2512"}], ",", 
       RowBox[{"2943", "\[Rule]", "2512"}], ",", 
       RowBox[{"2943", "\[Rule]", "2404"}], ",", 
       RowBox[{"2943", "\[Rule]", "2404"}], ",", 
       RowBox[{"2943", "\[Rule]", "2944"}], ",", 
       RowBox[{"2823", "\[Rule]", "2392"}], ",", 
       RowBox[{"2823", "\[Rule]", "2392"}], ",", 
       RowBox[{"2823", "\[Rule]", "2284"}], ",", 
       RowBox[{"2823", "\[Rule]", "2284"}], ",", 
       RowBox[{"2823", "\[Rule]", "2824"}], ",", 
       RowBox[{"2853", "\[Rule]", "2422"}], ",", 
       RowBox[{"2853", "\[Rule]", "2422"}], ",", 
       RowBox[{"2853", "\[Rule]", "2314"}], ",", 
       RowBox[{"2853", "\[Rule]", "2314"}], ",", 
       RowBox[{"2853", "\[Rule]", "2854"}], ",", 
       RowBox[{"2835", "\[Rule]", "2404"}], ",", 
       RowBox[{"2835", "\[Rule]", "2404"}], ",", 
       RowBox[{"2835", "\[Rule]", "2296"}], ",", 
       RowBox[{"2835", "\[Rule]", "2296"}], ",", 
       RowBox[{"2835", "\[Rule]", "2836"}], ",", 
       RowBox[{"2391", "\[Rule]", "2068"}], ",", 
       RowBox[{"2391", "\[Rule]", "2068"}], ",", 
       RowBox[{"2391", "\[Rule]", "2932"}], ",", 
       RowBox[{"2391", "\[Rule]", "2932"}], ",", 
       RowBox[{"2391", "\[Rule]", "1960"}], ",", 
       RowBox[{"2391", "\[Rule]", "1960"}], ",", 
       RowBox[{"2391", "\[Rule]", "2824"}], ",", 
       RowBox[{"2391", "\[Rule]", "2824"}], ",", 
       RowBox[{"2391", "\[Rule]", "2392"}], ",", 
       RowBox[{"2421", "\[Rule]", "2098"}], ",", 
       RowBox[{"2421", "\[Rule]", "2098"}], ",", 
       RowBox[{"2421", "\[Rule]", "2962"}], ",", 
       RowBox[{"2421", "\[Rule]", "2962"}], ",", 
       RowBox[{"2421", "\[Rule]", "1990"}], ",", 
       RowBox[{"2421", "\[Rule]", "1990"}], ",", 
       RowBox[{"2421", "\[Rule]", "2854"}], ",", 
       RowBox[{"2421", "\[Rule]", "2854"}], ",", 
       RowBox[{"2421", "\[Rule]", "2422"}], ",", 
       RowBox[{"2403", "\[Rule]", "2080"}], ",", 
       RowBox[{"2403", "\[Rule]", "2080"}], ",", 
       RowBox[{"2403", "\[Rule]", "2944"}], ",", 
       RowBox[{"2403", "\[Rule]", "2944"}], ",", 
       RowBox[{"2403", "\[Rule]", "1972"}], ",", 
       RowBox[{"2403", "\[Rule]", "1972"}], ",", 
       RowBox[{"2403", "\[Rule]", "2836"}], ",", 
       RowBox[{"2403", "\[Rule]", "2836"}], ",", 
       RowBox[{"2403", "\[Rule]", "2404"}], ",", 
       RowBox[{"2991", "\[Rule]", "2560"}], ",", 
       RowBox[{"2991", "\[Rule]", "2560"}], ",", 
       RowBox[{"2991", "\[Rule]", "2452"}], ",", 
       RowBox[{"2991", "\[Rule]", "2452"}], ",", 
       RowBox[{"2991", "\[Rule]", "2992"}], ",", 
       RowBox[{"2973", "\[Rule]", "2542"}], ",", 
       RowBox[{"2973", "\[Rule]", "2542"}], ",", 
       RowBox[{"2973", "\[Rule]", "2434"}], ",", 
       RowBox[{"2973", "\[Rule]", "2434"}], ",", 
       RowBox[{"2973", "\[Rule]", "2974"}], ",", 
       RowBox[{"2883", "\[Rule]", "2452"}], ",", 
       RowBox[{"2883", "\[Rule]", "2452"}], ",", 
       RowBox[{"2883", "\[Rule]", "2344"}], ",", 
       RowBox[{"2883", "\[Rule]", "2344"}], ",", 
       RowBox[{"2883", "\[Rule]", "2884"}], ",", 
       RowBox[{"2865", "\[Rule]", "2434"}], ",", 
       RowBox[{"2865", "\[Rule]", "2434"}], ",", 
       RowBox[{"2865", "\[Rule]", "2326"}], ",", 
       RowBox[{"2865", "\[Rule]", "2326"}], ",", 
       RowBox[{"2865", "\[Rule]", "2866"}], ",", 
       RowBox[{"2451", "\[Rule]", "2128"}], ",", 
       RowBox[{"2451", "\[Rule]", "2128"}], ",", 
       RowBox[{"2451", "\[Rule]", "2992"}], ",", 
       RowBox[{"2451", "\[Rule]", "2992"}], ",", 
       RowBox[{"2451", "\[Rule]", "2020"}], ",", 
       RowBox[{"2451", "\[Rule]", "2020"}], ",", 
       RowBox[{"2451", "\[Rule]", "2884"}], ",", 
       RowBox[{"2451", "\[Rule]", "2884"}], ",", 
       RowBox[{"2451", "\[Rule]", "2452"}], ",", 
       RowBox[{"2433", "\[Rule]", "2110"}], ",", 
       RowBox[{"2433", "\[Rule]", "2110"}], ",", 
       RowBox[{"2433", "\[Rule]", "2974"}], ",", 
       RowBox[{"2433", "\[Rule]", "2974"}], ",", 
       RowBox[{"2433", "\[Rule]", "2002"}], ",", 
       RowBox[{"2433", "\[Rule]", "2002"}], ",", 
       RowBox[{"2433", "\[Rule]", "2866"}], ",", 
       RowBox[{"2433", "\[Rule]", "2866"}], ",", 
       RowBox[{"2433", "\[Rule]", "2434"}], ",", 
       RowBox[{"2957", "\[Rule]", "2526"}], ",", 
       RowBox[{"2957", "\[Rule]", "2526"}], ",", 
       RowBox[{"2957", "\[Rule]", "2418"}], ",", 
       RowBox[{"2957", "\[Rule]", "2418"}], ",", 
       RowBox[{"2957", "\[Rule]", "2958"}], ",", 
       RowBox[{"2849", "\[Rule]", "2418"}], ",", 
       RowBox[{"2849", "\[Rule]", "2418"}], ",", 
       RowBox[{"2849", "\[Rule]", "2310"}], ",", 
       RowBox[{"2849", "\[Rule]", "2310"}], ",", 
       RowBox[{"2849", "\[Rule]", "2850"}], ",", 
       RowBox[{"2417", "\[Rule]", "2094"}], ",", 
       RowBox[{"2417", "\[Rule]", "2094"}], ",", 
       RowBox[{"2417", "\[Rule]", "2958"}], ",", 
       RowBox[{"2417", "\[Rule]", "2958"}], ",", 
       RowBox[{"2417", "\[Rule]", "1986"}], ",", 
       RowBox[{"2417", "\[Rule]", "1986"}], ",", 
       RowBox[{"2417", "\[Rule]", "2850"}], ",", 
       RowBox[{"2417", "\[Rule]", "2850"}], ",", 
       RowBox[{"2417", "\[Rule]", "2418"}], ",", 
       RowBox[{"2715", "\[Rule]", "2284"}], ",", 
       RowBox[{"2715", "\[Rule]", "2284"}], ",", 
       RowBox[{"2715", "\[Rule]", "2176"}], ",", 
       RowBox[{"2715", "\[Rule]", "2176"}], ",", 
       RowBox[{"2715", "\[Rule]", "2716"}], ",", 
       RowBox[{"2745", "\[Rule]", "2314"}], ",", 
       RowBox[{"2745", "\[Rule]", "2314"}], ",", 
       RowBox[{"2745", "\[Rule]", "2206"}], ",", 
       RowBox[{"2745", "\[Rule]", "2206"}], ",", 
       RowBox[{"2745", "\[Rule]", "2746"}], ",", 
       RowBox[{"2727", "\[Rule]", "2296"}], ",", 
       RowBox[{"2727", "\[Rule]", "2296"}], ",", 
       RowBox[{"2727", "\[Rule]", "2188"}], ",", 
       RowBox[{"2727", "\[Rule]", "2188"}], ",", 
       RowBox[{"2727", "\[Rule]", "2728"}], ",", 
       RowBox[{"2283", "\[Rule]", "1960"}], ",", 
       RowBox[{"2283", "\[Rule]", "1960"}], ",", 
       RowBox[{"2283", "\[Rule]", "2824"}], ",", 
       RowBox[{"2283", "\[Rule]", "2824"}], ",", 
       RowBox[{"2283", "\[Rule]", "1852"}], ",", 
       RowBox[{"2283", "\[Rule]", "1852"}], ",", 
       RowBox[{"2283", "\[Rule]", "2716"}], ",", 
       RowBox[{"2283", "\[Rule]", "2716"}], ",", 
       RowBox[{"2283", "\[Rule]", "2284"}], ",", 
       RowBox[{"2313", "\[Rule]", "1990"}], ",", 
       RowBox[{"2313", "\[Rule]", "1990"}], ",", 
       RowBox[{"2313", "\[Rule]", "2854"}], ",", 
       RowBox[{"2313", "\[Rule]", "2854"}], ",", 
       RowBox[{"2313", "\[Rule]", "1882"}], ",", 
       RowBox[{"2313", "\[Rule]", "1882"}], ",", 
       RowBox[{"2313", "\[Rule]", "2746"}], ",", 
       RowBox[{"2313", "\[Rule]", "2746"}], ",", 
       RowBox[{"2313", "\[Rule]", "2314"}], ",", 
       RowBox[{"2295", "\[Rule]", "1972"}], ",", 
       RowBox[{"2295", "\[Rule]", "1972"}], ",", 
       RowBox[{"2295", "\[Rule]", "2836"}], ",", 
       RowBox[{"2295", "\[Rule]", "2836"}], ",", 
       RowBox[{"2295", "\[Rule]", "1864"}], ",", 
       RowBox[{"2295", "\[Rule]", "1864"}], ",", 
       RowBox[{"2295", "\[Rule]", "2728"}], ",", 
       RowBox[{"2295", "\[Rule]", "2728"}], ",", 
       RowBox[{"2295", "\[Rule]", "2296"}], ",", 
       RowBox[{"2775", "\[Rule]", "2344"}], ",", 
       RowBox[{"2775", "\[Rule]", "2344"}], ",", 
       RowBox[{"2775", "\[Rule]", "2236"}], ",", 
       RowBox[{"2775", "\[Rule]", "2236"}], ",", 
       RowBox[{"2775", "\[Rule]", "2776"}], ",", 
       RowBox[{"2757", "\[Rule]", "2326"}], ",", 
       RowBox[{"2757", "\[Rule]", "2326"}], ",", 
       RowBox[{"2757", "\[Rule]", "2218"}], ",", 
       RowBox[{"2757", "\[Rule]", "2218"}], ",", 
       RowBox[{"2757", "\[Rule]", "2758"}], ",", 
       RowBox[{"2343", "\[Rule]", "2020"}], ",", 
       RowBox[{"2343", "\[Rule]", "2020"}], ",", 
       RowBox[{"2343", "\[Rule]", "2884"}], ",", 
       RowBox[{"2343", "\[Rule]", "2884"}], ",", 
       RowBox[{"2343", "\[Rule]", "1912"}], ",", 
       RowBox[{"2343", "\[Rule]", "1912"}], ",", 
       RowBox[{"2343", "\[Rule]", "2776"}], ",", 
       RowBox[{"2343", "\[Rule]", "2776"}], ",", 
       RowBox[{"2343", "\[Rule]", "2344"}], ",", 
       RowBox[{"2325", "\[Rule]", "2002"}], ",", 
       RowBox[{"2325", "\[Rule]", "2002"}], ",", 
       RowBox[{"2325", "\[Rule]", "2866"}], ",", 
       RowBox[{"2325", "\[Rule]", "2866"}], ",", 
       RowBox[{"2325", "\[Rule]", "1894"}], ",", 
       RowBox[{"2325", "\[Rule]", "1894"}], ",", 
       RowBox[{"2325", "\[Rule]", "2758"}], ",", 
       RowBox[{"2325", "\[Rule]", "2758"}], ",", 
       RowBox[{"2325", "\[Rule]", "2326"}], ",", 
       RowBox[{"2741", "\[Rule]", "2310"}], ",", 
       RowBox[{"2741", "\[Rule]", "2310"}], ",", 
       RowBox[{"2741", "\[Rule]", "2202"}], ",", 
       RowBox[{"2741", "\[Rule]", "2202"}], ",", 
       RowBox[{"2741", "\[Rule]", "2742"}], ",", 
       RowBox[{"2309", "\[Rule]", "1986"}], ",", 
       RowBox[{"2309", "\[Rule]", "1986"}], ",", 
       RowBox[{"2309", "\[Rule]", "2850"}], ",", 
       RowBox[{"2309", "\[Rule]", "2850"}], ",", 
       RowBox[{"2309", "\[Rule]", "1878"}], ",", 
       RowBox[{"2309", "\[Rule]", "1878"}], ",", 
       RowBox[{"2309", "\[Rule]", "2742"}], ",", 
       RowBox[{"2309", "\[Rule]", "2742"}], ",", 
       RowBox[{"2309", "\[Rule]", "2310"}], ",", 
       RowBox[{"3023", "\[Rule]", "2592"}], ",", 
       RowBox[{"3023", "\[Rule]", "2484"}], ",", 
       RowBox[{"3023", "\[Rule]", "2484"}], ",", 
       RowBox[{"3023", "\[Rule]", "3024"}], ",", 
       RowBox[{"3005", "\[Rule]", "2574"}], ",", 
       RowBox[{"3005", "\[Rule]", "2466"}], ",", 
       RowBox[{"3005", "\[Rule]", "3006"}], ",", 
       RowBox[{"2915", "\[Rule]", "2484"}], ",", 
       RowBox[{"2915", "\[Rule]", "2484"}], ",", 
       RowBox[{"2915", "\[Rule]", "2376"}], ",", 
       RowBox[{"2915", "\[Rule]", "2376"}], ",", 
       RowBox[{"2915", "\[Rule]", "2916"}], ",", 
       RowBox[{"2897", "\[Rule]", "2466"}], ",", 
       RowBox[{"2897", "\[Rule]", "2466"}], ",", 
       RowBox[{"2897", "\[Rule]", "2358"}], ",", 
       RowBox[{"2897", "\[Rule]", "2358"}], ",", 
       RowBox[{"2897", "\[Rule]", "2898"}], ",", 
       RowBox[{"2483", "\[Rule]", "2160"}], ",", 
       RowBox[{"2483", "\[Rule]", "2160"}], ",", 
       RowBox[{"2483", "\[Rule]", "3024"}], ",", 
       RowBox[{"2483", "\[Rule]", "3024"}], ",", 
       RowBox[{"2483", "\[Rule]", "2052"}], ",", 
       RowBox[{"2483", "\[Rule]", "2052"}], ",", 
       RowBox[{"2483", "\[Rule]", "2916"}], ",", 
       RowBox[{"2483", "\[Rule]", "2916"}], ",", 
       RowBox[{"2483", "\[Rule]", "2484"}], ",", 
       RowBox[{"2465", "\[Rule]", "2142"}], ",", 
       RowBox[{"2465", "\[Rule]", "3006"}], ",", 
       RowBox[{"2465", "\[Rule]", "2034"}], ",", 
       RowBox[{"2465", "\[Rule]", "2034"}], ",", 
       RowBox[{"2465", "\[Rule]", "2898"}], ",", 
       RowBox[{"2465", "\[Rule]", "2898"}], ",", 
       RowBox[{"2465", "\[Rule]", "2466"}], ",", 
       RowBox[{"2987", "\[Rule]", "2556"}], ",", 
       RowBox[{"2987", "\[Rule]", "2556"}], ",", 
       RowBox[{"2987", "\[Rule]", "2448"}], ",", 
       RowBox[{"2987", "\[Rule]", "2448"}], ",", 
       RowBox[{"2987", "\[Rule]", "2988"}], ",", 
       RowBox[{"2879", "\[Rule]", "2448"}], ",", 
       RowBox[{"2879", "\[Rule]", "2448"}], ",", 
       RowBox[{"2879", "\[Rule]", "2340"}], ",", 
       RowBox[{"2879", "\[Rule]", "2340"}], ",", 
       RowBox[{"2879", "\[Rule]", "2880"}], ",", 
       RowBox[{"2447", "\[Rule]", "2124"}], ",", 
       RowBox[{"2447", "\[Rule]", "2988"}], ",", 
       RowBox[{"2447", "\[Rule]", "2988"}], ",", 
       RowBox[{"2447", "\[Rule]", "2016"}], ",", 
       RowBox[{"2447", "\[Rule]", "2880"}], ",", 
       RowBox[{"2447", "\[Rule]", "2880"}], ",", 
       RowBox[{"2447", "\[Rule]", "2448"}], ",", 
       RowBox[{"2807", "\[Rule]", "2376"}], ",", 
       RowBox[{"2807", "\[Rule]", "2376"}], ",", 
       RowBox[{"2807", "\[Rule]", "2268"}], ",", 
       RowBox[{"2807", "\[Rule]", "2268"}], ",", 
       RowBox[{"2807", "\[Rule]", "2808"}], ",", 
       RowBox[{"2789", "\[Rule]", "2358"}], ",", 
       RowBox[{"2789", "\[Rule]", "2358"}], ",", 
       RowBox[{"2789", "\[Rule]", "2250"}], ",", 
       RowBox[{"2789", "\[Rule]", "2250"}], ",", 
       RowBox[{"2789", "\[Rule]", "2790"}], ",", 
       RowBox[{"2375", "\[Rule]", "2052"}], ",", 
       RowBox[{"2375", "\[Rule]", "2052"}], ",", 
       RowBox[{"2375", "\[Rule]", "2916"}], ",", 
       RowBox[{"2375", "\[Rule]", "2916"}], ",", 
       RowBox[{"2375", "\[Rule]", "1944"}], ",", 
       RowBox[{"2375", "\[Rule]", "1944"}], ",", 
       RowBox[{"2375", "\[Rule]", "2808"}], ",", 
       RowBox[{"2375", "\[Rule]", "2808"}], ",", 
       RowBox[{"2375", "\[Rule]", "2376"}], ",", 
       RowBox[{"2357", "\[Rule]", "2034"}], ",", 
       RowBox[{"2357", "\[Rule]", "2034"}], ",", 
       RowBox[{"2357", "\[Rule]", "2898"}], ",", 
       RowBox[{"2357", "\[Rule]", "2898"}], ",", 
       RowBox[{"2357", "\[Rule]", "1926"}], ",", 
       RowBox[{"2357", "\[Rule]", "1926"}], ",", 
       RowBox[{"2357", "\[Rule]", "2790"}], ",", 
       RowBox[{"2357", "\[Rule]", "2790"}], ",", 
       RowBox[{"2357", "\[Rule]", "2358"}], ",", 
       RowBox[{"2771", "\[Rule]", "2340"}], ",", 
       RowBox[{"2771", "\[Rule]", "2340"}], ",", 
       RowBox[{"2771", "\[Rule]", "2232"}], ",", 
       RowBox[{"2771", "\[Rule]", "2232"}], ",", 
       RowBox[{"2771", "\[Rule]", "2772"}], ",", 
       RowBox[{"2339", "\[Rule]", "2016"}], ",", 
       RowBox[{"2339", "\[Rule]", "2016"}], ",", 
       RowBox[{"2339", "\[Rule]", "2880"}], ",", 
       RowBox[{"2339", "\[Rule]", "2880"}], ",", 
       RowBox[{"2339", "\[Rule]", "1908"}], ",", 
       RowBox[{"2339", "\[Rule]", "1908"}], ",", 
       RowBox[{"2339", "\[Rule]", "2772"}], ",", 
       RowBox[{"2339", "\[Rule]", "2772"}], ",", 
       RowBox[{"2339", "\[Rule]", "2340"}], ",", 
       RowBox[{"2969", "\[Rule]", "2538"}], ",", 
       RowBox[{"2969", "\[Rule]", "2538"}], ",", 
       RowBox[{"2969", "\[Rule]", "2430"}], ",", 
       RowBox[{"2969", "\[Rule]", "2430"}], ",", 
       RowBox[{"2969", "\[Rule]", "2970"}], ",", 
       RowBox[{"2861", "\[Rule]", "2430"}], ",", 
       RowBox[{"2861", "\[Rule]", "2430"}], ",", 
       RowBox[{"2861", "\[Rule]", "2322"}], ",", 
       RowBox[{"2861", "\[Rule]", "2322"}], ",", 
       RowBox[{"2861", "\[Rule]", "2862"}], ",", 
       RowBox[{"2429", "\[Rule]", "2106"}], ",", 
       RowBox[{"2429", "\[Rule]", "2106"}], ",", 
       RowBox[{"2429", "\[Rule]", "2970"}], ",", 
       RowBox[{"2429", "\[Rule]", "2970"}], ",", 
       RowBox[{"2429", "\[Rule]", "1998"}], ",", 
       RowBox[{"2429", "\[Rule]", "1998"}], ",", 
       RowBox[{"2429", "\[Rule]", "2862"}], ",", 
       RowBox[{"2429", "\[Rule]", "2862"}], ",", 
       RowBox[{"2429", "\[Rule]", "2430"}], ",", 
       RowBox[{"2753", "\[Rule]", "2322"}], ",", 
       RowBox[{"2753", "\[Rule]", "2322"}], ",", 
       RowBox[{"2753", "\[Rule]", "2214"}], ",", 
       RowBox[{"2753", "\[Rule]", "2214"}], ",", 
       RowBox[{"2753", "\[Rule]", "2754"}], ",", 
       RowBox[{"2321", "\[Rule]", "1998"}], ",", 
       RowBox[{"2321", "\[Rule]", "1998"}], ",", 
       RowBox[{"2321", "\[Rule]", "2862"}], ",", 
       RowBox[{"2321", "\[Rule]", "2862"}], ",", 
       RowBox[{"2321", "\[Rule]", "1890"}], ",", 
       RowBox[{"2321", "\[Rule]", "1890"}], ",", 
       RowBox[{"2321", "\[Rule]", "2754"}], ",", 
       RowBox[{"2321", "\[Rule]", "2754"}], ",", 
       RowBox[{"2321", "\[Rule]", "2322"}], ",", 
       RowBox[{"2607", "\[Rule]", "2176"}], ",", 
       RowBox[{"2607", "\[Rule]", "2176"}], ",", 
       RowBox[{"2607", "\[Rule]", "2608"}], ",", 
       RowBox[{"2637", "\[Rule]", "2206"}], ",", 
       RowBox[{"2637", "\[Rule]", "2206"}], ",", 
       RowBox[{"2637", "\[Rule]", "2638"}], ",", 
       RowBox[{"2619", "\[Rule]", "2188"}], ",", 
       RowBox[{"2619", "\[Rule]", "2188"}], ",", 
       RowBox[{"2619", "\[Rule]", "2620"}], ",", 
       RowBox[{"2175", "\[Rule]", "1852"}], ",", 
       RowBox[{"2175", "\[Rule]", "1852"}], ",", 
       RowBox[{"2175", "\[Rule]", "2716"}], ",", 
       RowBox[{"2175", "\[Rule]", "2716"}], ",", 
       RowBox[{"2175", "\[Rule]", "1744"}], ",", 
       RowBox[{"2175", "\[Rule]", "1744"}], ",", 
       RowBox[{"2175", "\[Rule]", "2608"}], ",", 
       RowBox[{"2175", "\[Rule]", "2608"}], ",", 
       RowBox[{"2175", "\[Rule]", "2176"}], ",", 
       RowBox[{"2205", "\[Rule]", "1882"}], ",", 
       RowBox[{"2205", "\[Rule]", "1882"}], ",", 
       RowBox[{"2205", "\[Rule]", "2746"}], ",", 
       RowBox[{"2205", "\[Rule]", "2746"}], ",", 
       RowBox[{"2205", "\[Rule]", "1774"}], ",", 
       RowBox[{"2205", "\[Rule]", "1774"}], ",", 
       RowBox[{"2205", "\[Rule]", "2638"}], ",", 
       RowBox[{"2205", "\[Rule]", "2638"}], ",", 
       RowBox[{"2205", "\[Rule]", "2206"}], ",", 
       RowBox[{"2187", "\[Rule]", "1864"}], ",", 
       RowBox[{"2187", "\[Rule]", "1864"}], ",", 
       RowBox[{"2187", "\[Rule]", "2728"}], ",", 
       RowBox[{"2187", "\[Rule]", "2728"}], ",", 
       RowBox[{"2187", "\[Rule]", "1756"}], ",", 
       RowBox[{"2187", "\[Rule]", "1756"}], ",", 
       RowBox[{"2187", "\[Rule]", "2620"}], ",", 
       RowBox[{"2187", "\[Rule]", "2620"}], ",", 
       RowBox[{"2187", "\[Rule]", "2188"}], ",", 
       RowBox[{"2667", "\[Rule]", "2236"}], ",", 
       RowBox[{"2667", "\[Rule]", "2236"}], ",", 
       RowBox[{"2667", "\[Rule]", "2668"}], ",", 
       RowBox[{"2649", "\[Rule]", "2218"}], ",", 
       RowBox[{"2649", "\[Rule]", "2218"}], ",", 
       RowBox[{"2649", "\[Rule]", "2650"}], ",", 
       RowBox[{"2235", "\[Rule]", "1912"}], ",", 
       RowBox[{"2235", "\[Rule]", "1912"}], ",", 
       RowBox[{"2235", "\[Rule]", "2776"}], ",", 
       RowBox[{"2235", "\[Rule]", "2776"}], ",", 
       RowBox[{"2235", "\[Rule]", "1804"}], ",", 
       RowBox[{"2235", "\[Rule]", "1804"}], ",", 
       RowBox[{"2235", "\[Rule]", "2668"}], ",", 
       RowBox[{"2235", "\[Rule]", "2668"}], ",", 
       RowBox[{"2235", "\[Rule]", "2236"}], ",", 
       RowBox[{"2217", "\[Rule]", "1894"}], ",", 
       RowBox[{"2217", "\[Rule]", "1894"}], ",", 
       RowBox[{"2217", "\[Rule]", "2758"}], ",", 
       RowBox[{"2217", "\[Rule]", "2758"}], ",", 
       RowBox[{"2217", "\[Rule]", "1786"}], ",", 
       RowBox[{"2217", "\[Rule]", "1786"}], ",", 
       RowBox[{"2217", "\[Rule]", "2650"}], ",", 
       RowBox[{"2217", "\[Rule]", "2650"}], ",", 
       RowBox[{"2217", "\[Rule]", "2218"}], ",", 
       RowBox[{"2633", "\[Rule]", "2202"}], ",", 
       RowBox[{"2633", "\[Rule]", "2202"}], ",", 
       RowBox[{"2633", "\[Rule]", "2634"}], ",", 
       RowBox[{"2201", "\[Rule]", "1878"}], ",", 
       RowBox[{"2201", "\[Rule]", "1878"}], ",", 
       RowBox[{"2201", "\[Rule]", "2742"}], ",", 
       RowBox[{"2201", "\[Rule]", "2742"}], ",", 
       RowBox[{"2201", "\[Rule]", "1770"}], ",", 
       RowBox[{"2201", "\[Rule]", "1770"}], ",", 
       RowBox[{"2201", "\[Rule]", "2634"}], ",", 
       RowBox[{"2201", "\[Rule]", "2634"}], ",", 
       RowBox[{"2201", "\[Rule]", "2202"}], ",", 
       RowBox[{"2699", "\[Rule]", "2268"}], ",", 
       RowBox[{"2699", "\[Rule]", "2268"}], ",", 
       RowBox[{"2699", "\[Rule]", "2700"}], ",", 
       RowBox[{"2681", "\[Rule]", "2250"}], ",", 
       RowBox[{"2681", "\[Rule]", "2250"}], ",", 
       RowBox[{"2681", "\[Rule]", "2682"}], ",", 
       RowBox[{"2267", "\[Rule]", "1944"}], ",", 
       RowBox[{"2267", "\[Rule]", "1944"}], ",", 
       RowBox[{"2267", "\[Rule]", "2808"}], ",", 
       RowBox[{"2267", "\[Rule]", "2808"}], ",", 
       RowBox[{"2267", "\[Rule]", "1836"}], ",", 
       RowBox[{"2267", "\[Rule]", "1836"}], ",", 
       RowBox[{"2267", "\[Rule]", "2700"}], ",", 
       RowBox[{"2267", "\[Rule]", "2700"}], ",", 
       RowBox[{"2267", "\[Rule]", "2268"}], ",", 
       RowBox[{"2249", "\[Rule]", "1926"}], ",", 
       RowBox[{"2249", "\[Rule]", "1926"}], ",", 
       RowBox[{"2249", "\[Rule]", "2790"}], ",", 
       RowBox[{"2249", "\[Rule]", "2790"}], ",", 
       RowBox[{"2249", "\[Rule]", "1818"}], ",", 
       RowBox[{"2249", "\[Rule]", "1818"}], ",", 
       RowBox[{"2249", "\[Rule]", "2682"}], ",", 
       RowBox[{"2249", "\[Rule]", "2682"}], ",", 
       RowBox[{"2249", "\[Rule]", "2250"}], ",", 
       RowBox[{"2663", "\[Rule]", "2232"}], ",", 
       RowBox[{"2663", "\[Rule]", "2232"}], ",", 
       RowBox[{"2663", "\[Rule]", "2664"}], ",", 
       RowBox[{"2231", "\[Rule]", "1908"}], ",", 
       RowBox[{"2231", "\[Rule]", "1908"}], ",", 
       RowBox[{"2231", "\[Rule]", "2772"}], ",", 
       RowBox[{"2231", "\[Rule]", "2772"}], ",", 
       RowBox[{"2231", "\[Rule]", "1800"}], ",", 
       RowBox[{"2231", "\[Rule]", "1800"}], ",", 
       RowBox[{"2231", "\[Rule]", "2664"}], ",", 
       RowBox[{"2231", "\[Rule]", "2664"}], ",", 
       RowBox[{"2231", "\[Rule]", "2232"}], ",", 
       RowBox[{"2645", "\[Rule]", "2214"}], ",", 
       RowBox[{"2645", "\[Rule]", "2214"}], ",", 
       RowBox[{"2645", "\[Rule]", "2646"}], ",", 
       RowBox[{"2213", "\[Rule]", "1890"}], ",", 
       RowBox[{"2213", "\[Rule]", "1890"}], ",", 
       RowBox[{"2213", "\[Rule]", "2754"}], ",", 
       RowBox[{"2213", "\[Rule]", "2754"}], ",", 
       RowBox[{"2213", "\[Rule]", "1782"}], ",", 
       RowBox[{"2213", "\[Rule]", "1782"}], ",", 
       RowBox[{"2213", "\[Rule]", "2646"}], ",", 
       RowBox[{"2213", "\[Rule]", "2646"}], ",", 
       RowBox[{"2213", "\[Rule]", "2214"}], ",", 
       RowBox[{"3019", "\[Rule]", "2588"}], ",", 
       RowBox[{"3019", "\[Rule]", "2588"}], ",", 
       RowBox[{"3019", "\[Rule]", "2480"}], ",", 
       RowBox[{"3019", "\[Rule]", "3020"}], ",", 
       RowBox[{"2911", "\[Rule]", "2480"}], ",", 
       RowBox[{"2911", "\[Rule]", "2372"}], ",", 
       RowBox[{"2911", "\[Rule]", "2372"}], ",", 
       RowBox[{"2911", "\[Rule]", "2912"}], ",", 
       RowBox[{"2479", "\[Rule]", "2156"}], ",", 
       RowBox[{"2479", "\[Rule]", "2156"}], ",", 
       RowBox[{"2479", "\[Rule]", "3020"}], ",", 
       RowBox[{"2479", "\[Rule]", "2048"}], ",", 
       RowBox[{"2479", "\[Rule]", "2048"}], ",", 
       RowBox[{"2479", "\[Rule]", "2912"}], ",", 
       RowBox[{"2479", "\[Rule]", "2480"}], ",", 
       RowBox[{"2803", "\[Rule]", "2372"}], ",", 
       RowBox[{"2803", "\[Rule]", "2372"}], ",", 
       RowBox[{"2803", "\[Rule]", "2264"}], ",", 
       RowBox[{"2803", "\[Rule]", "2264"}], ",", 
       RowBox[{"2803", "\[Rule]", "2804"}], ",", 
       RowBox[{"2371", "\[Rule]", "2048"}], ",", 
       RowBox[{"2371", "\[Rule]", "2048"}], ",", 
       RowBox[{"2371", "\[Rule]", "2912"}], ",", 
       RowBox[{"2371", "\[Rule]", "2912"}], ",", 
       RowBox[{"2371", "\[Rule]", "1940"}], ",", 
       RowBox[{"2371", "\[Rule]", "1940"}], ",", 
       RowBox[{"2371", "\[Rule]", "2804"}], ",", 
       RowBox[{"2371", "\[Rule]", "2804"}], ",", 
       RowBox[{"2371", "\[Rule]", "2372"}], ",", 
       RowBox[{"3001", "\[Rule]", "2570"}], ",", 
       RowBox[{"3001", "\[Rule]", "2570"}], ",", 
       RowBox[{"3001", "\[Rule]", "2462"}], ",", 
       RowBox[{"3001", "\[Rule]", "2462"}], ",", 
       RowBox[{"3001", "\[Rule]", "3002"}], ",", 
       RowBox[{"2893", "\[Rule]", "2462"}], ",", 
       RowBox[{"2893", "\[Rule]", "2354"}], ",", 
       RowBox[{"2893", "\[Rule]", "2894"}], ",", 
       RowBox[{"2461", "\[Rule]", "2138"}], ",", 
       RowBox[{"2461", "\[Rule]", "2138"}], ",", 
       RowBox[{"2461", "\[Rule]", "3002"}], ",", 
       RowBox[{"2461", "\[Rule]", "3002"}], ",", 
       RowBox[{"2461", "\[Rule]", "2030"}], ",", 
       RowBox[{"2461", "\[Rule]", "2894"}], ",", 
       RowBox[{"2461", "\[Rule]", "2462"}], ",", 
       RowBox[{"2785", "\[Rule]", "2354"}], ",", 
       RowBox[{"2785", "\[Rule]", "2354"}], ",", 
       RowBox[{"2785", "\[Rule]", "2246"}], ",", 
       RowBox[{"2785", "\[Rule]", "2246"}], ",", 
       RowBox[{"2785", "\[Rule]", "2786"}], ",", 
       RowBox[{"2353", "\[Rule]", "2030"}], ",", 
       RowBox[{"2353", "\[Rule]", "2894"}], ",", 
       RowBox[{"2353", "\[Rule]", "1922"}], ",", 
       RowBox[{"2353", "\[Rule]", "1922"}], ",", 
       RowBox[{"2353", "\[Rule]", "2786"}], ",", 
       RowBox[{"2353", "\[Rule]", "2786"}], ",", 
       RowBox[{"2353", "\[Rule]", "2354"}], ",", 
       RowBox[{"2695", "\[Rule]", "2264"}], ",", 
       RowBox[{"2695", "\[Rule]", "2264"}], ",", 
       RowBox[{"2695", "\[Rule]", "2696"}], ",", 
       RowBox[{"2263", "\[Rule]", "1940"}], ",", 
       RowBox[{"2263", "\[Rule]", "1940"}], ",", 
       RowBox[{"2263", "\[Rule]", "2804"}], ",", 
       RowBox[{"2263", "\[Rule]", "2804"}], ",", 
       RowBox[{"2263", "\[Rule]", "1832"}], ",", 
       RowBox[{"2263", "\[Rule]", "1832"}], ",", 
       RowBox[{"2263", "\[Rule]", "2696"}], ",", 
       RowBox[{"2263", "\[Rule]", "2696"}], ",", 
       RowBox[{"2263", "\[Rule]", "2264"}], ",", 
       RowBox[{"2677", "\[Rule]", "2246"}], ",", 
       RowBox[{"2677", "\[Rule]", "2246"}], ",", 
       RowBox[{"2677", "\[Rule]", "2678"}], ",", 
       RowBox[{"2245", "\[Rule]", "1922"}], ",", 
       RowBox[{"2245", "\[Rule]", "1922"}], ",", 
       RowBox[{"2245", "\[Rule]", "2786"}], ",", 
       RowBox[{"2245", "\[Rule]", "2786"}], ",", 
       RowBox[{"2245", "\[Rule]", "1814"}], ",", 
       RowBox[{"2245", "\[Rule]", "1814"}], ",", 
       RowBox[{"2245", "\[Rule]", "2678"}], ",", 
       RowBox[{"2245", "\[Rule]", "2678"}], ",", 
       RowBox[{"2245", "\[Rule]", "2246"}], ",", 
       RowBox[{"2983", "\[Rule]", "2552"}], ",", 
       RowBox[{"2983", "\[Rule]", "2552"}], ",", 
       RowBox[{"2983", "\[Rule]", "2444"}], ",", 
       RowBox[{"2983", "\[Rule]", "2444"}], ",", 
       RowBox[{"2983", "\[Rule]", "2984"}], ",", 
       RowBox[{"2875", "\[Rule]", "2444"}], ",", 
       RowBox[{"2875", "\[Rule]", "2444"}], ",", 
       RowBox[{"2875", "\[Rule]", "2336"}], ",", 
       RowBox[{"2875", "\[Rule]", "2336"}], ",", 
       RowBox[{"2875", "\[Rule]", "2876"}], ",", 
       RowBox[{"2443", "\[Rule]", "2120"}], ",", 
       RowBox[{"2443", "\[Rule]", "2120"}], ",", 
       RowBox[{"2443", "\[Rule]", "2984"}], ",", 
       RowBox[{"2443", "\[Rule]", "2984"}], ",", 
       RowBox[{"2443", "\[Rule]", "2012"}], ",", 
       RowBox[{"2443", "\[Rule]", "2012"}], ",", 
       RowBox[{"2443", "\[Rule]", "2876"}], ",", 
       RowBox[{"2443", "\[Rule]", "2876"}], ",", 
       RowBox[{"2443", "\[Rule]", "2444"}], ",", 
       RowBox[{"2767", "\[Rule]", "2336"}], ",", 
       RowBox[{"2767", "\[Rule]", "2336"}], ",", 
       RowBox[{"2767", "\[Rule]", "2228"}], ",", 
       RowBox[{"2767", "\[Rule]", "2228"}], ",", 
       RowBox[{"2767", "\[Rule]", "2768"}], ",", 
       RowBox[{"2335", "\[Rule]", "2012"}], ",", 
       RowBox[{"2335", "\[Rule]", "2876"}], ",", 
       RowBox[{"2335", "\[Rule]", "2876"}], ",", 
       RowBox[{"2335", "\[Rule]", "1904"}], ",", 
       RowBox[{"2335", "\[Rule]", "2768"}], ",", 
       RowBox[{"2335", "\[Rule]", "2768"}], ",", 
       RowBox[{"2335", "\[Rule]", "2336"}], ",", 
       RowBox[{"2659", "\[Rule]", "2228"}], ",", 
       RowBox[{"2659", "\[Rule]", "2228"}], ",", 
       RowBox[{"2659", "\[Rule]", "2660"}], ",", 
       RowBox[{"2227", "\[Rule]", "1904"}], ",", 
       RowBox[{"2227", "\[Rule]", "1904"}], ",", 
       RowBox[{"2227", "\[Rule]", "2768"}], ",", 
       RowBox[{"2227", "\[Rule]", "2768"}], ",", 
       RowBox[{"2227", "\[Rule]", "1796"}], ",", 
       RowBox[{"2227", "\[Rule]", "1796"}], ",", 
       RowBox[{"2227", "\[Rule]", "2660"}], ",", 
       RowBox[{"2227", "\[Rule]", "2660"}], ",", 
       RowBox[{"2227", "\[Rule]", "2228"}], ",", 
       RowBox[{"3015", "\[Rule]", "2584"}], ",", 
       RowBox[{"3015", "\[Rule]", "2584"}], ",", 
       RowBox[{"3015", "\[Rule]", "2476"}], ",", 
       RowBox[{"3015", "\[Rule]", "2476"}], ",", 
       RowBox[{"3015", "\[Rule]", "3016"}], ",", 
       RowBox[{"2907", "\[Rule]", "2476"}], ",", 
       RowBox[{"2907", "\[Rule]", "2476"}], ",", 
       RowBox[{"2907", "\[Rule]", "2368"}], ",", 
       RowBox[{"2907", "\[Rule]", "2908"}], ",", 
       RowBox[{"2475", "\[Rule]", "2152"}], ",", 
       RowBox[{"2475", "\[Rule]", "2152"}], ",", 
       RowBox[{"2475", "\[Rule]", "3016"}], ",", 
       RowBox[{"2475", "\[Rule]", "3016"}], ",", 
       RowBox[{"2475", "\[Rule]", "2044"}], ",", 
       RowBox[{"2475", "\[Rule]", "2044"}], ",", 
       RowBox[{"2475", "\[Rule]", "2908"}], ",", 
       RowBox[{"2475", "\[Rule]", "2908"}], ",", 
       RowBox[{"2475", "\[Rule]", "2476"}], ",", 
       RowBox[{"2799", "\[Rule]", "2368"}], ",", 
       RowBox[{"2799", "\[Rule]", "2260"}], ",", 
       RowBox[{"2799", "\[Rule]", "2260"}], ",", 
       RowBox[{"2799", "\[Rule]", "2800"}], ",", 
       RowBox[{"2367", "\[Rule]", "2044"}], ",", 
       RowBox[{"2367", "\[Rule]", "2044"}], ",", 
       RowBox[{"2367", "\[Rule]", "2908"}], ",", 
       RowBox[{"2367", "\[Rule]", "1936"}], ",", 
       RowBox[{"2367", "\[Rule]", "1936"}], ",", 
       RowBox[{"2367", "\[Rule]", "2800"}], ",", 
       RowBox[{"2367", "\[Rule]", "2368"}], ",", 
       RowBox[{"2691", "\[Rule]", "2260"}], ",", 
       RowBox[{"2691", "\[Rule]", "2260"}], ",", 
       RowBox[{"2691", "\[Rule]", "2692"}], ",", 
       RowBox[{"2259", "\[Rule]", "1936"}], ",", 
       RowBox[{"2259", "\[Rule]", "1936"}], ",", 
       RowBox[{"2259", "\[Rule]", "2800"}], ",", 
       RowBox[{"2259", "\[Rule]", "2800"}], ",", 
       RowBox[{"2259", "\[Rule]", "1828"}], ",", 
       RowBox[{"2259", "\[Rule]", "1828"}], ",", 
       RowBox[{"2259", "\[Rule]", "2692"}], ",", 
       RowBox[{"2259", "\[Rule]", "2692"}], ",", 
       RowBox[{"2259", "\[Rule]", "2260"}], ",", 
       RowBox[{"2997", "\[Rule]", "2566"}], ",", 
       RowBox[{"2997", "\[Rule]", "2566"}], ",", 
       RowBox[{"2997", "\[Rule]", "2458"}], ",", 
       RowBox[{"2997", "\[Rule]", "2458"}], ",", 
       RowBox[{"2997", "\[Rule]", "2998"}], ",", 
       RowBox[{"2889", "\[Rule]", "2458"}], ",", 
       RowBox[{"2889", "\[Rule]", "2458"}], ",", 
       RowBox[{"2889", "\[Rule]", "2350"}], ",", 
       RowBox[{"2889", "\[Rule]", "2350"}], ",", 
       RowBox[{"2889", "\[Rule]", "2890"}], ",", 
       RowBox[{"2457", "\[Rule]", "2134"}], ",", 
       RowBox[{"2457", "\[Rule]", "2134"}], ",", 
       RowBox[{"2457", "\[Rule]", "2998"}], ",", 
       RowBox[{"2457", "\[Rule]", "2998"}], ",", 
       RowBox[{"2457", "\[Rule]", "2026"}], ",", 
       RowBox[{"2457", "\[Rule]", "2026"}], ",", 
       RowBox[{"2457", "\[Rule]", "2890"}], ",", 
       RowBox[{"2457", "\[Rule]", "2890"}], ",", 
       RowBox[{"2457", "\[Rule]", "2458"}], ",", 
       RowBox[{"2781", "\[Rule]", "2350"}], ",", 
       RowBox[{"2781", "\[Rule]", "2242"}], ",", 
       RowBox[{"2781", "\[Rule]", "2782"}], ",", 
       RowBox[{"2349", "\[Rule]", "2026"}], ",", 
       RowBox[{"2349", "\[Rule]", "2026"}], ",", 
       RowBox[{"2349", "\[Rule]", "2890"}], ",", 
       RowBox[{"2349", "\[Rule]", "2890"}], ",", 
       RowBox[{"2349", "\[Rule]", "1918"}], ",", 
       RowBox[{"2349", "\[Rule]", "2782"}], ",", 
       RowBox[{"2349", "\[Rule]", "2350"}], ",", 
       RowBox[{"2673", "\[Rule]", "2242"}], ",", 
       RowBox[{"2673", "\[Rule]", "2242"}], ",", 
       RowBox[{"2673", "\[Rule]", "2674"}], ",", 
       RowBox[{"2241", "\[Rule]", "1918"}], ",", 
       RowBox[{"2241", "\[Rule]", "2782"}], ",", 
       RowBox[{"2241", "\[Rule]", "1810"}], ",", 
       RowBox[{"2241", "\[Rule]", "1810"}], ",", 
       RowBox[{"2241", "\[Rule]", "2674"}], ",", 
       RowBox[{"2241", "\[Rule]", "2674"}], ",", 
       RowBox[{"2241", "\[Rule]", "2242"}], ",", 
       RowBox[{"419", "\[Rule]", "852"}], ",", 
       RowBox[{"419", "\[Rule]", "852"}], ",", 
       RowBox[{"419", "\[Rule]", "744"}], ",", 
       RowBox[{"419", "\[Rule]", "744"}], ",", 
       RowBox[{"419", "\[Rule]", "420"}], ",", 
       RowBox[{"1283", "\[Rule]", "852"}], ",", 
       RowBox[{"1283", "\[Rule]", "852"}], ",", 
       RowBox[{"1283", "\[Rule]", "1716"}], ",", 
       RowBox[{"1283", "\[Rule]", "1716"}], ",", 
       RowBox[{"1283", "\[Rule]", "744"}], ",", 
       RowBox[{"1283", "\[Rule]", "744"}], ",", 
       RowBox[{"1283", "\[Rule]", "1608"}], ",", 
       RowBox[{"1283", "\[Rule]", "1608"}], ",", 
       RowBox[{"1283", "\[Rule]", "1284"}], ",", 
       RowBox[{"311", "\[Rule]", "744"}], ",", 
       RowBox[{"311", "\[Rule]", "744"}], ",", 
       RowBox[{"311", "\[Rule]", "636"}], ",", 
       RowBox[{"311", "\[Rule]", "636"}], ",", 
       RowBox[{"311", "\[Rule]", "312"}], ",", 
       RowBox[{"1175", "\[Rule]", "744"}], ",", 
       RowBox[{"1175", "\[Rule]", "744"}], ",", 
       RowBox[{"1175", "\[Rule]", "1608"}], ",", 
       RowBox[{"1175", "\[Rule]", "1608"}], ",", 
       RowBox[{"1175", "\[Rule]", "636"}], ",", 
       RowBox[{"1175", "\[Rule]", "636"}], ",", 
       RowBox[{"1175", "\[Rule]", "1500"}], ",", 
       RowBox[{"1175", "\[Rule]", "1500"}], ",", 
       RowBox[{"1175", "\[Rule]", "1176"}], ",", 
       RowBox[{"743", "\[Rule]", "420"}], ",", 
       RowBox[{"743", "\[Rule]", "420"}], ",", 
       RowBox[{"743", "\[Rule]", "1284"}], ",", 
       RowBox[{"743", "\[Rule]", "1284"}], ",", 
       RowBox[{"743", "\[Rule]", "312"}], ",", 
       RowBox[{"743", "\[Rule]", "312"}], ",", 
       RowBox[{"743", "\[Rule]", "1176"}], ",", 
       RowBox[{"743", "\[Rule]", "1176"}], ",", 
       RowBox[{"743", "\[Rule]", "744"}], ",", 
       RowBox[{"203", "\[Rule]", "636"}], ",", 
       RowBox[{"203", "\[Rule]", "528"}], ",", 
       RowBox[{"203", "\[Rule]", "204"}], ",", 
       RowBox[{"1067", "\[Rule]", "636"}], ",", 
       RowBox[{"1067", "\[Rule]", "1500"}], ",", 
       RowBox[{"1067", "\[Rule]", "1500"}], ",", 
       RowBox[{"1067", "\[Rule]", "528"}], ",", 
       RowBox[{"1067", "\[Rule]", "1392"}], ",", 
       RowBox[{"1067", "\[Rule]", "1392"}], ",", 
       RowBox[{"1067", "\[Rule]", "1068"}], ",", 
       RowBox[{"635", "\[Rule]", "312"}], ",", 
       RowBox[{"635", "\[Rule]", "312"}], ",", 
       RowBox[{"635", "\[Rule]", "1176"}], ",", 
       RowBox[{"635", "\[Rule]", "1176"}], ",", 
       RowBox[{"635", "\[Rule]", "204"}], ",", 
       RowBox[{"635", "\[Rule]", "1068"}], ",", 
       RowBox[{"635", "\[Rule]", "636"}], ",", 
       RowBox[{"2147", "\[Rule]", "1716"}], ",", 
       RowBox[{"2147", "\[Rule]", "1716"}], ",", 
       RowBox[{"2147", "\[Rule]", "2580"}], ",", 
       RowBox[{"2147", "\[Rule]", "2580"}], ",", 
       RowBox[{"2147", "\[Rule]", "1608"}], ",", 
       RowBox[{"2147", "\[Rule]", "1608"}], ",", 
       RowBox[{"2147", "\[Rule]", "2472"}], ",", 
       RowBox[{"2147", "\[Rule]", "2472"}], ",", 
       RowBox[{"2147", "\[Rule]", "2148"}], ",", 
       RowBox[{"2039", "\[Rule]", "1608"}], ",", 
       RowBox[{"2039", "\[Rule]", "1608"}], ",", 
       RowBox[{"2039", "\[Rule]", "2472"}], ",", 
       RowBox[{"2039", "\[Rule]", "2472"}], ",", 
       RowBox[{"2039", "\[Rule]", "1500"}], ",", 
       RowBox[{"2039", "\[Rule]", "1500"}], ",", 
       RowBox[{"2039", "\[Rule]", "2364"}], ",", 
       RowBox[{"2039", "\[Rule]", "2364"}], ",", 
       RowBox[{"2039", "\[Rule]", "2040"}], ",", 
       RowBox[{"1607", "\[Rule]", "1284"}], ",", 
       RowBox[{"1607", "\[Rule]", "1284"}], ",", 
       RowBox[{"1607", "\[Rule]", "2148"}], ",", 
       RowBox[{"1607", "\[Rule]", "2148"}], ",", 
       RowBox[{"1607", "\[Rule]", "1176"}], ",", 
       RowBox[{"1607", "\[Rule]", "1176"}], ",", 
       RowBox[{"1607", "\[Rule]", "2040"}], ",", 
       RowBox[{"1607", "\[Rule]", "2040"}], ",", 
       RowBox[{"1607", "\[Rule]", "1608"}], ",", 
       RowBox[{"1931", "\[Rule]", "1500"}], ",", 
       RowBox[{"1931", "\[Rule]", "1500"}], ",", 
       RowBox[{"1931", "\[Rule]", "2364"}], ",", 
       RowBox[{"1931", "\[Rule]", "2364"}], ",", 
       RowBox[{"1931", "\[Rule]", "1392"}], ",", 
       RowBox[{"1931", "\[Rule]", "1392"}], ",", 
       RowBox[{"1931", "\[Rule]", "2256"}], ",", 
       RowBox[{"1931", "\[Rule]", "2256"}], ",", 
       RowBox[{"1931", "\[Rule]", "1932"}], ",", 
       RowBox[{"1499", "\[Rule]", "1176"}], ",", 
       RowBox[{"1499", "\[Rule]", "1176"}], ",", 
       RowBox[{"1499", "\[Rule]", "2040"}], ",", 
       RowBox[{"1499", "\[Rule]", "2040"}], ",", 
       RowBox[{"1499", "\[Rule]", "1068"}], ",", 
       RowBox[{"1499", "\[Rule]", "1068"}], ",", 
       RowBox[{"1499", "\[Rule]", "1932"}], ",", 
       RowBox[{"1499", "\[Rule]", "1932"}], ",", 
       RowBox[{"1499", "\[Rule]", "1500"}], ",", 
       RowBox[{"95", "\[Rule]", "528"}], ",", 
       RowBox[{"95", "\[Rule]", "528"}], ",", 
       RowBox[{"95", "\[Rule]", "96"}], ",", 
       RowBox[{"959", "\[Rule]", "528"}], ",", 
       RowBox[{"959", "\[Rule]", "528"}], ",", 
       RowBox[{"959", "\[Rule]", "1392"}], ",", 
       RowBox[{"959", "\[Rule]", "960"}], ",", 
       RowBox[{"527", "\[Rule]", "204"}], ",", 
       RowBox[{"527", "\[Rule]", "1068"}], ",", 
       RowBox[{"527", "\[Rule]", "96"}], ",", 
       RowBox[{"527", "\[Rule]", "96"}], ",", 
       RowBox[{"527", "\[Rule]", "960"}], ",", 
       RowBox[{"527", "\[Rule]", "960"}], ",", 
       RowBox[{"527", "\[Rule]", "528"}], ",", 
       RowBox[{"1823", "\[Rule]", "1392"}], ",", 
       RowBox[{"1823", "\[Rule]", "2256"}], ",", 
       RowBox[{"1823", "\[Rule]", "2256"}], ",", 
       RowBox[{"1823", "\[Rule]", "1824"}], ",", 
       RowBox[{"1391", "\[Rule]", "1068"}], ",", 
       RowBox[{"1391", "\[Rule]", "1068"}], ",", 
       RowBox[{"1391", "\[Rule]", "1932"}], ",", 
       RowBox[{"1391", "\[Rule]", "1932"}], ",", 
       RowBox[{"1391", "\[Rule]", "960"}], ",", 
       RowBox[{"1391", "\[Rule]", "1824"}], ",", 
       RowBox[{"1391", "\[Rule]", "1392"}], ",", 
       RowBox[{"3011", "\[Rule]", "2580"}], ",", 
       RowBox[{"3011", "\[Rule]", "2580"}], ",", 
       RowBox[{"3011", "\[Rule]", "2472"}], ",", 
       RowBox[{"3011", "\[Rule]", "2472"}], ",", 
       RowBox[{"3011", "\[Rule]", "3012"}], ",", 
       RowBox[{"2903", "\[Rule]", "2472"}], ",", 
       RowBox[{"2903", "\[Rule]", "2472"}], ",", 
       RowBox[{"2903", "\[Rule]", "2364"}], ",", 
       RowBox[{"2903", "\[Rule]", "2364"}], ",", 
       RowBox[{"2903", "\[Rule]", "2904"}], ",", 
       RowBox[{"2471", "\[Rule]", "2148"}], ",", 
       RowBox[{"2471", "\[Rule]", "2148"}], ",", 
       RowBox[{"2471", "\[Rule]", "3012"}], ",", 
       RowBox[{"2471", "\[Rule]", "3012"}], ",", 
       RowBox[{"2471", "\[Rule]", "2040"}], ",", 
       RowBox[{"2471", "\[Rule]", "2040"}], ",", 
       RowBox[{"2471", "\[Rule]", "2904"}], ",", 
       RowBox[{"2471", "\[Rule]", "2904"}], ",", 
       RowBox[{"2471", "\[Rule]", "2472"}], ",", 
       RowBox[{"2795", "\[Rule]", "2364"}], ",", 
       RowBox[{"2795", "\[Rule]", "2364"}], ",", 
       RowBox[{"2795", "\[Rule]", "2256"}], ",", 
       RowBox[{"2795", "\[Rule]", "2796"}], ",", 
       RowBox[{"2363", "\[Rule]", "2040"}], ",", 
       RowBox[{"2363", "\[Rule]", "2040"}], ",", 
       RowBox[{"2363", "\[Rule]", "2904"}], ",", 
       RowBox[{"2363", "\[Rule]", "2904"}], ",", 
       RowBox[{"2363", "\[Rule]", "1932"}], ",", 
       RowBox[{"2363", "\[Rule]", "1932"}], ",", 
       RowBox[{"2363", "\[Rule]", "2796"}], ",", 
       RowBox[{"2363", "\[Rule]", "2796"}], ",", 
       RowBox[{"2363", "\[Rule]", "2364"}], ",", 
       RowBox[{"2687", "\[Rule]", "2256"}], ",", 
       RowBox[{"2687", "\[Rule]", "2688"}], ",", 
       RowBox[{"2255", "\[Rule]", "1932"}], ",", 
       RowBox[{"2255", "\[Rule]", "1932"}], ",", 
       RowBox[{"2255", "\[Rule]", "2796"}], ",", 
       RowBox[{"2255", "\[Rule]", "1824"}], ",", 
       RowBox[{"2255", "\[Rule]", "1824"}], ",", 
       RowBox[{"2255", "\[Rule]", "2688"}], ",", 
       RowBox[{"2255", "\[Rule]", "2256"}], ",", 
       RowBox[{"772", "\[Rule]", "785"}], ",", 
       RowBox[{"772", "\[Rule]", "769"}], ",", 
       RowBox[{"664", "\[Rule]", "677"}], ",", 
       RowBox[{"664", "\[Rule]", "661"}], ",", 
       RowBox[{"340", "\[Rule]", "353"}], ",", 
       RowBox[{"340", "\[Rule]", "337"}], ",", 
       RowBox[{"802", "\[Rule]", "785"}], ",", 
       RowBox[{"802", "\[Rule]", "815"}], ",", 
       RowBox[{"802", "\[Rule]", "799"}], ",", 
       RowBox[{"370", "\[Rule]", "353"}], ",", 
       RowBox[{"370", "\[Rule]", "383"}], ",", 
       RowBox[{"370", "\[Rule]", "367"}], ",", 
       RowBox[{"784", "\[Rule]", "769"}], ",", 
       RowBox[{"784", "\[Rule]", "799"}], ",", 
       RowBox[{"784", "\[Rule]", "785"}], ",", 
       RowBox[{"784", "\[Rule]", "781"}], ",", 
       RowBox[{"676", "\[Rule]", "661"}], ",", 
       RowBox[{"676", "\[Rule]", "691"}], ",", 
       RowBox[{"676", "\[Rule]", "677"}], ",", 
       RowBox[{"676", "\[Rule]", "673"}], ",", 
       RowBox[{"352", "\[Rule]", "337"}], ",", 
       RowBox[{"352", "\[Rule]", "367"}], ",", 
       RowBox[{"352", "\[Rule]", "353"}], ",", 
       RowBox[{"352", "\[Rule]", "349"}], ",", 
       RowBox[{"1636", "\[Rule]", "1649"}], ",", 
       RowBox[{"1636", "\[Rule]", "1633"}], ",", 
       RowBox[{"1528", "\[Rule]", "1541"}], ",", 
       RowBox[{"1528", "\[Rule]", "1525"}], ",", 
       RowBox[{"1204", "\[Rule]", "1217"}], ",", 
       RowBox[{"1204", "\[Rule]", "1201"}], ",", 
       RowBox[{"1666", "\[Rule]", "1649"}], ",", 
       RowBox[{"1666", "\[Rule]", "1679"}], ",", 
       RowBox[{"1666", "\[Rule]", "1663"}], ",", 
       RowBox[{"1234", "\[Rule]", "1217"}], ",", 
       RowBox[{"1234", "\[Rule]", "1247"}], ",", 
       RowBox[{"1234", "\[Rule]", "1231"}], ",", 
       RowBox[{"1648", "\[Rule]", "1633"}], ",", 
       RowBox[{"1648", "\[Rule]", "1663"}], ",", 
       RowBox[{"1648", "\[Rule]", "1649"}], ",", 
       RowBox[{"1648", "\[Rule]", "1645"}], ",", 
       RowBox[{"1540", "\[Rule]", "1525"}], ",", 
       RowBox[{"1540", "\[Rule]", "1555"}], ",", 
       RowBox[{"1540", "\[Rule]", "1541"}], ",", 
       RowBox[{"1540", "\[Rule]", "1537"}], ",", 
       RowBox[{"1216", "\[Rule]", "1201"}], ",", 
       RowBox[{"1216", "\[Rule]", "1231"}], ",", 
       RowBox[{"1216", "\[Rule]", "1217"}], ",", 
       RowBox[{"1216", "\[Rule]", "1213"}], ",", 
       RowBox[{"556", "\[Rule]", "569"}], ",", 
       RowBox[{"556", "\[Rule]", "553"}], ",", 
       RowBox[{"232", "\[Rule]", "245"}], ",", 
       RowBox[{"232", "\[Rule]", "229"}], ",", 
       RowBox[{"568", "\[Rule]", "553"}], ",", 
       RowBox[{"568", "\[Rule]", "583"}], ",", 
       RowBox[{"568", "\[Rule]", "569"}], ",", 
       RowBox[{"568", "\[Rule]", "565"}], ",", 
       RowBox[{"244", "\[Rule]", "229"}], ",", 
       RowBox[{"244", "\[Rule]", "259"}], ",", 
       RowBox[{"244", "\[Rule]", "245"}], ",", 
       RowBox[{"244", "\[Rule]", "241"}], ",", 
       RowBox[{"1420", "\[Rule]", "1433"}], ",", 
       RowBox[{"1420", "\[Rule]", "1417"}], ",", 
       RowBox[{"1096", "\[Rule]", "1109"}], ",", 
       RowBox[{"1096", "\[Rule]", "1093"}], ",", 
       RowBox[{"1432", "\[Rule]", "1417"}], ",", 
       RowBox[{"1432", "\[Rule]", "1447"}], ",", 
       RowBox[{"1432", "\[Rule]", "1433"}], ",", 
       RowBox[{"1432", "\[Rule]", "1429"}], ",", 
       RowBox[{"1108", "\[Rule]", "1093"}], ",", 
       RowBox[{"1108", "\[Rule]", "1123"}], ",", 
       RowBox[{"1108", "\[Rule]", "1109"}], ",", 
       RowBox[{"1108", "\[Rule]", "1105"}], ",", 
       RowBox[{"832", "\[Rule]", "815"}], ",", 
       RowBox[{"832", "\[Rule]", "847"}], ",", 
       RowBox[{"832", "\[Rule]", "829"}], ",", 
       RowBox[{"400", "\[Rule]", "383"}], ",", 
       RowBox[{"400", "\[Rule]", "415"}], ",", 
       RowBox[{"400", "\[Rule]", "397"}], ",", 
       RowBox[{"814", "\[Rule]", "799"}], ",", 
       RowBox[{"814", "\[Rule]", "829"}], ",", 
       RowBox[{"814", "\[Rule]", "815"}], ",", 
       RowBox[{"814", "\[Rule]", "811"}], ",", 
       RowBox[{"382", "\[Rule]", "367"}], ",", 
       RowBox[{"382", "\[Rule]", "397"}], ",", 
       RowBox[{"382", "\[Rule]", "383"}], ",", 
       RowBox[{"382", "\[Rule]", "379"}], ",", 
       RowBox[{"1696", "\[Rule]", "1679"}], ",", 
       RowBox[{"1696", "\[Rule]", "1711"}], ",", 
       RowBox[{"1696", "\[Rule]", "1693"}], ",", 
       RowBox[{"1264", "\[Rule]", "1247"}], ",", 
       RowBox[{"1264", "\[Rule]", "1279"}], ",", 
       RowBox[{"1264", "\[Rule]", "1261"}], ",", 
       RowBox[{"1678", "\[Rule]", "1663"}], ",", 
       RowBox[{"1678", "\[Rule]", "1693"}], ",", 
       RowBox[{"1678", "\[Rule]", "1679"}], ",", 
       RowBox[{"1678", "\[Rule]", "1675"}], ",", 
       RowBox[{"1246", "\[Rule]", "1231"}], ",", 
       RowBox[{"1246", "\[Rule]", "1261"}], ",", 
       RowBox[{"1246", "\[Rule]", "1247"}], ",", 
       RowBox[{"1246", "\[Rule]", "1243"}], ",", 
       RowBox[{"798", "\[Rule]", "781"}], ",", 
       RowBox[{"798", "\[Rule]", "811"}], ",", 
       RowBox[{"798", "\[Rule]", "799"}], ",", 
       RowBox[{"798", "\[Rule]", "795"}], ",", 
       RowBox[{"690", "\[Rule]", "673"}], ",", 
       RowBox[{"690", "\[Rule]", "703"}], ",", 
       RowBox[{"690", "\[Rule]", "691"}], ",", 
       RowBox[{"690", "\[Rule]", "687"}], ",", 
       RowBox[{"366", "\[Rule]", "349"}], ",", 
       RowBox[{"366", "\[Rule]", "379"}], ",", 
       RowBox[{"366", "\[Rule]", "367"}], ",", 
       RowBox[{"366", "\[Rule]", "363"}], ",", 
       RowBox[{"1662", "\[Rule]", "1645"}], ",", 
       RowBox[{"1662", "\[Rule]", "1675"}], ",", 
       RowBox[{"1662", "\[Rule]", "1663"}], ",", 
       RowBox[{"1662", "\[Rule]", "1659"}], ",", 
       RowBox[{"1554", "\[Rule]", "1537"}], ",", 
       RowBox[{"1554", "\[Rule]", "1567"}], ",", 
       RowBox[{"1554", "\[Rule]", "1555"}], ",", 
       RowBox[{"1554", "\[Rule]", "1551"}], ",", 
       RowBox[{"1230", "\[Rule]", "1213"}], ",", 
       RowBox[{"1230", "\[Rule]", "1243"}], ",", 
       RowBox[{"1230", "\[Rule]", "1231"}], ",", 
       RowBox[{"1230", "\[Rule]", "1227"}], ",", 
       RowBox[{"582", "\[Rule]", "565"}], ",", 
       RowBox[{"582", "\[Rule]", "595"}], ",", 
       RowBox[{"582", "\[Rule]", "583"}], ",", 
       RowBox[{"582", "\[Rule]", "579"}], ",", 
       RowBox[{"258", "\[Rule]", "241"}], ",", 
       RowBox[{"258", "\[Rule]", "271"}], ",", 
       RowBox[{"258", "\[Rule]", "259"}], ",", 
       RowBox[{"258", "\[Rule]", "255"}], ",", 
       RowBox[{"1446", "\[Rule]", "1429"}], ",", 
       RowBox[{"1446", "\[Rule]", "1459"}], ",", 
       RowBox[{"1446", "\[Rule]", "1447"}], ",", 
       RowBox[{"1446", "\[Rule]", "1443"}], ",", 
       RowBox[{"1122", "\[Rule]", "1105"}], ",", 
       RowBox[{"1122", "\[Rule]", "1135"}], ",", 
       RowBox[{"1122", "\[Rule]", "1123"}], ",", 
       RowBox[{"1122", "\[Rule]", "1119"}], ",", 
       RowBox[{"448", "\[Rule]", "461"}], ",", 
       RowBox[{"448", "\[Rule]", "445"}], ",", 
       RowBox[{"124", "\[Rule]", "137"}], ",", 
       RowBox[{"124", "\[Rule]", "121"}], ",", 
       RowBox[{"460", "\[Rule]", "445"}], ",", 
       RowBox[{"460", "\[Rule]", "475"}], ",", 
       RowBox[{"460", "\[Rule]", "461"}], ",", 
       RowBox[{"460", "\[Rule]", "457"}], ",", 
       RowBox[{"136", "\[Rule]", "121"}], ",", 
       RowBox[{"136", "\[Rule]", "151"}], ",", 
       RowBox[{"136", "\[Rule]", "137"}], ",", 
       RowBox[{"136", "\[Rule]", "133"}], ",", 
       RowBox[{"1312", "\[Rule]", "1325"}], ",", 
       RowBox[{"1312", "\[Rule]", "1309"}], ",", 
       RowBox[{"988", "\[Rule]", "1001"}], ",", 
       RowBox[{"988", "\[Rule]", "985"}], ",", 
       RowBox[{"1324", "\[Rule]", "1309"}], ",", 
       RowBox[{"1324", "\[Rule]", "1339"}], ",", 
       RowBox[{"1324", "\[Rule]", "1325"}], ",", 
       RowBox[{"1324", "\[Rule]", "1321"}], ",", 
       RowBox[{"1000", "\[Rule]", "985"}], ",", 
       RowBox[{"1000", "\[Rule]", "1015"}], ",", 
       RowBox[{"1000", "\[Rule]", "1001"}], ",", 
       RowBox[{"1000", "\[Rule]", "997"}], ",", 
       RowBox[{"474", "\[Rule]", "457"}], ",", 
       RowBox[{"474", "\[Rule]", "487"}], ",", 
       RowBox[{"474", "\[Rule]", "475"}], ",", 
       RowBox[{"474", "\[Rule]", "471"}], ",", 
       RowBox[{"150", "\[Rule]", "133"}], ",", 
       RowBox[{"150", "\[Rule]", "163"}], ",", 
       RowBox[{"150", "\[Rule]", "151"}], ",", 
       RowBox[{"150", "\[Rule]", "147"}], ",", 
       RowBox[{"1338", "\[Rule]", "1321"}], ",", 
       RowBox[{"1338", "\[Rule]", "1351"}], ",", 
       RowBox[{"1338", "\[Rule]", "1339"}], ",", 
       RowBox[{"1338", "\[Rule]", "1335"}], ",", 
       RowBox[{"1014", "\[Rule]", "997"}], ",", 
       RowBox[{"1014", "\[Rule]", "1027"}], ",", 
       RowBox[{"1014", "\[Rule]", "1015"}], ",", 
       RowBox[{"1014", "\[Rule]", "1011"}], ",", 
       RowBox[{"864", "\[Rule]", "847"}], ",", 
       RowBox[{"864", "\[Rule]", "861"}], ",", 
       RowBox[{"432", "\[Rule]", "415"}], ",", 
       RowBox[{"432", "\[Rule]", "429"}], ",", 
       RowBox[{"846", "\[Rule]", "829"}], ",", 
       RowBox[{"846", "\[Rule]", "861"}], ",", 
       RowBox[{"846", "\[Rule]", "847"}], ",", 
       RowBox[{"846", "\[Rule]", "843"}], ",", 
       RowBox[{"414", "\[Rule]", "397"}], ",", 
       RowBox[{"414", "\[Rule]", "429"}], ",", 
       RowBox[{"414", "\[Rule]", "415"}], ",", 
       RowBox[{"414", "\[Rule]", "411"}], ",", 
       RowBox[{"1728", "\[Rule]", "1711"}], ",", 
       RowBox[{"1728", "\[Rule]", "1725"}], ",", 
       RowBox[{"1296", "\[Rule]", "1279"}], ",", 
       RowBox[{"1296", "\[Rule]", "1293"}], ",", 
       RowBox[{"1710", "\[Rule]", "1693"}], ",", 
       RowBox[{"1710", "\[Rule]", "1725"}], ",", 
       RowBox[{"1710", "\[Rule]", "1711"}], ",", 
       RowBox[{"1710", "\[Rule]", "1707"}], ",", 
       RowBox[{"1278", "\[Rule]", "1261"}], ",", 
       RowBox[{"1278", "\[Rule]", "1293"}], ",", 
       RowBox[{"1278", "\[Rule]", "1279"}], ",", 
       RowBox[{"1278", "\[Rule]", "1275"}], ",", 
       RowBox[{"828", "\[Rule]", "811"}], ",", 
       RowBox[{"828", "\[Rule]", "843"}], ",", 
       RowBox[{"828", "\[Rule]", "829"}], ",", 
       RowBox[{"828", "\[Rule]", "825"}], ",", 
       RowBox[{"396", "\[Rule]", "379"}], ",", 
       RowBox[{"396", "\[Rule]", "411"}], ",", 
       RowBox[{"396", "\[Rule]", "397"}], ",", 
       RowBox[{"396", "\[Rule]", "393"}], ",", 
       RowBox[{"1692", "\[Rule]", "1675"}], ",", 
       RowBox[{"1692", "\[Rule]", "1707"}], ",", 
       RowBox[{"1692", "\[Rule]", "1693"}], ",", 
       RowBox[{"1692", "\[Rule]", "1689"}], ",", 
       RowBox[{"1260", "\[Rule]", "1243"}], ",", 
       RowBox[{"1260", "\[Rule]", "1275"}], ",", 
       RowBox[{"1260", "\[Rule]", "1261"}], ",", 
       RowBox[{"1260", "\[Rule]", "1257"}], ",", 
       RowBox[{"810", "\[Rule]", "795"}], ",", 
       RowBox[{"810", "\[Rule]", "825"}], ",", 
       RowBox[{"810", "\[Rule]", "811"}], ",", 
       RowBox[{"810", "\[Rule]", "807"}], ",", 
       RowBox[{"702", "\[Rule]", "687"}], ",", 
       RowBox[{"702", "\[Rule]", "717"}], ",", 
       RowBox[{"702", "\[Rule]", "703"}], ",", 
       RowBox[{"702", "\[Rule]", "699"}], ",", 
       RowBox[{"378", "\[Rule]", "363"}], ",", 
       RowBox[{"378", "\[Rule]", "393"}], ",", 
       RowBox[{"378", "\[Rule]", "379"}], ",", 
       RowBox[{"378", "\[Rule]", "375"}], ",", 
       RowBox[{"1674", "\[Rule]", "1659"}], ",", 
       RowBox[{"1674", "\[Rule]", "1689"}], ",", 
       RowBox[{"1674", "\[Rule]", "1675"}], ",", 
       RowBox[{"1674", "\[Rule]", "1671"}], ",", 
       RowBox[{"1566", "\[Rule]", "1551"}], ",", 
       RowBox[{"1566", "\[Rule]", "1581"}], ",", 
       RowBox[{"1566", "\[Rule]", "1567"}], ",", 
       RowBox[{"1566", "\[Rule]", "1563"}], ",", 
       RowBox[{"1242", "\[Rule]", "1227"}], ",", 
       RowBox[{"1242", "\[Rule]", "1257"}], ",", 
       RowBox[{"1242", "\[Rule]", "1243"}], ",", 
       RowBox[{"1242", "\[Rule]", "1239"}], ",", 
       RowBox[{"594", "\[Rule]", "579"}], ",", 
       RowBox[{"594", "\[Rule]", "609"}], ",", 
       RowBox[{"594", "\[Rule]", "595"}], ",", 
       RowBox[{"594", "\[Rule]", "591"}], ",", 
       RowBox[{"270", "\[Rule]", "255"}], ",", 
       RowBox[{"270", "\[Rule]", "285"}], ",", 
       RowBox[{"270", "\[Rule]", "271"}], ",", 
       RowBox[{"270", "\[Rule]", "267"}], ",", 
       RowBox[{"1458", "\[Rule]", "1443"}], ",", 
       RowBox[{"1458", "\[Rule]", "1473"}], ",", 
       RowBox[{"1458", "\[Rule]", "1459"}], ",", 
       RowBox[{"1458", "\[Rule]", "1455"}], ",", 
       RowBox[{"1134", "\[Rule]", "1119"}], ",", 
       RowBox[{"1134", "\[Rule]", "1149"}], ",", 
       RowBox[{"1134", "\[Rule]", "1135"}], ",", 
       RowBox[{"1134", "\[Rule]", "1131"}], ",", 
       RowBox[{"486", "\[Rule]", "471"}], ",", 
       RowBox[{"486", "\[Rule]", "501"}], ",", 
       RowBox[{"486", "\[Rule]", "487"}], ",", 
       RowBox[{"486", "\[Rule]", "483"}], ",", 
       RowBox[{"162", "\[Rule]", "147"}], ",", 
       RowBox[{"162", "\[Rule]", "177"}], ",", 
       RowBox[{"162", "\[Rule]", "163"}], ",", 
       RowBox[{"162", "\[Rule]", "159"}], ",", 
       RowBox[{"1350", "\[Rule]", "1335"}], ",", 
       RowBox[{"1350", "\[Rule]", "1365"}], ",", 
       RowBox[{"1350", "\[Rule]", "1351"}], ",", 
       RowBox[{"1350", "\[Rule]", "1347"}], ",", 
       RowBox[{"1026", "\[Rule]", "1011"}], ",", 
       RowBox[{"1026", "\[Rule]", "1041"}], ",", 
       RowBox[{"1026", "\[Rule]", "1027"}], ",", 
       RowBox[{"1026", "\[Rule]", "1023"}], ",", 
       RowBox[{"2500", "\[Rule]", "2513"}], ",", 
       RowBox[{"2500", "\[Rule]", "2497"}], ",", 
       RowBox[{"2392", "\[Rule]", "2405"}], ",", 
       RowBox[{"2392", "\[Rule]", "2389"}], ",", 
       RowBox[{"2068", "\[Rule]", "2081"}], ",", 
       RowBox[{"2068", "\[Rule]", "2065"}], ",", 
       RowBox[{"2530", "\[Rule]", "2513"}], ",", 
       RowBox[{"2530", "\[Rule]", "2543"}], ",", 
       RowBox[{"2530", "\[Rule]", "2527"}], ",", 
       RowBox[{"2098", "\[Rule]", "2081"}], ",", 
       RowBox[{"2098", "\[Rule]", "2111"}], ",", 
       RowBox[{"2098", "\[Rule]", "2095"}], ",", 
       RowBox[{"2512", "\[Rule]", "2497"}], ",", 
       RowBox[{"2512", "\[Rule]", "2527"}], ",", 
       RowBox[{"2512", "\[Rule]", "2513"}], ",", 
       RowBox[{"2512", "\[Rule]", "2509"}], ",", 
       RowBox[{"2404", "\[Rule]", "2389"}], ",", 
       RowBox[{"2404", "\[Rule]", "2419"}], ",", 
       RowBox[{"2404", "\[Rule]", "2405"}], ",", 
       RowBox[{"2404", "\[Rule]", "2401"}], ",", 
       RowBox[{"2080", "\[Rule]", "2065"}], ",", 
       RowBox[{"2080", "\[Rule]", "2095"}], ",", 
       RowBox[{"2080", "\[Rule]", "2081"}], ",", 
       RowBox[{"2080", "\[Rule]", "2077"}], ",", 
       RowBox[{"2284", "\[Rule]", "2297"}], ",", 
       RowBox[{"2284", "\[Rule]", "2281"}], ",", 
       RowBox[{"1960", "\[Rule]", "1973"}], ",", 
       RowBox[{"1960", "\[Rule]", "1957"}], ",", 
       RowBox[{"2296", "\[Rule]", "2281"}], ",", 
       RowBox[{"2296", "\[Rule]", "2311"}], ",", 
       RowBox[{"2296", "\[Rule]", "2297"}], ",", 
       RowBox[{"2296", "\[Rule]", "2293"}], ",", 
       RowBox[{"1972", "\[Rule]", "1957"}], ",", 
       RowBox[{"1972", "\[Rule]", "1987"}], ",", 
       RowBox[{"1972", "\[Rule]", "1973"}], ",", 
       RowBox[{"1972", "\[Rule]", "1969"}], ",", 
       RowBox[{"2560", "\[Rule]", "2543"}], ",", 
       RowBox[{"2560", "\[Rule]", "2575"}], ",", 
       RowBox[{"2560", "\[Rule]", "2557"}], ",", 
       RowBox[{"2128", "\[Rule]", "2111"}], ",", 
       RowBox[{"2128", "\[Rule]", "2143"}], ",", 
       RowBox[{"2128", "\[Rule]", "2125"}], ",", 
       RowBox[{"2542", "\[Rule]", "2527"}], ",", 
       RowBox[{"2542", "\[Rule]", "2557"}], ",", 
       RowBox[{"2542", "\[Rule]", "2543"}], ",", 
       RowBox[{"2542", "\[Rule]", "2539"}], ",", 
       RowBox[{"2110", "\[Rule]", "2095"}], ",", 
       RowBox[{"2110", "\[Rule]", "2125"}], ",", 
       RowBox[{"2110", "\[Rule]", "2111"}], ",", 
       RowBox[{"2110", "\[Rule]", "2107"}], ",", 
       RowBox[{"2526", "\[Rule]", "2509"}], ",", 
       RowBox[{"2526", "\[Rule]", "2539"}], ",", 
       RowBox[{"2526", "\[Rule]", "2527"}], ",", 
       RowBox[{"2526", "\[Rule]", "2523"}], ",", 
       RowBox[{"2418", "\[Rule]", "2401"}], ",", 
       RowBox[{"2418", "\[Rule]", "2431"}], ",", 
       RowBox[{"2418", "\[Rule]", "2419"}], ",", 
       RowBox[{"2418", "\[Rule]", "2415"}], ",", 
       RowBox[{"2094", "\[Rule]", "2077"}], ",", 
       RowBox[{"2094", "\[Rule]", "2107"}], ",", 
       RowBox[{"2094", "\[Rule]", "2095"}], ",", 
       RowBox[{"2094", "\[Rule]", "2091"}], ",", 
       RowBox[{"2310", "\[Rule]", "2293"}], ",", 
       RowBox[{"2310", "\[Rule]", "2323"}], ",", 
       RowBox[{"2310", "\[Rule]", "2311"}], ",", 
       RowBox[{"2310", "\[Rule]", "2307"}], ",", 
       RowBox[{"1986", "\[Rule]", "1969"}], ",", 
       RowBox[{"1986", "\[Rule]", "1999"}], ",", 
       RowBox[{"1986", "\[Rule]", "1987"}], ",", 
       RowBox[{"1986", "\[Rule]", "1983"}], ",", 
       RowBox[{"2176", "\[Rule]", "2189"}], ",", 
       RowBox[{"2176", "\[Rule]", "2173"}], ",", 
       RowBox[{"1852", "\[Rule]", "1865"}], ",", 
       RowBox[{"1852", "\[Rule]", "1849"}], ",", 
       RowBox[{"2188", "\[Rule]", "2173"}], ",", 
       RowBox[{"2188", "\[Rule]", "2203"}], ",", 
       RowBox[{"2188", "\[Rule]", "2189"}], ",", 
       RowBox[{"2188", "\[Rule]", "2185"}], ",", 
       RowBox[{"1864", "\[Rule]", "1849"}], ",", 
       RowBox[{"1864", "\[Rule]", "1879"}], ",", 
       RowBox[{"1864", "\[Rule]", "1865"}], ",", 
       RowBox[{"1864", "\[Rule]", "1861"}], ",", 
       RowBox[{"2202", "\[Rule]", "2185"}], ",", 
       RowBox[{"2202", "\[Rule]", "2215"}], ",", 
       RowBox[{"2202", "\[Rule]", "2203"}], ",", 
       RowBox[{"2202", "\[Rule]", "2199"}], ",", 
       RowBox[{"1878", "\[Rule]", "1861"}], ",", 
       RowBox[{"1878", "\[Rule]", "1891"}], ",", 
       RowBox[{"1878", "\[Rule]", "1879"}], ",", 
       RowBox[{"1878", "\[Rule]", "1875"}], ",", 
       RowBox[{"2592", "\[Rule]", "2575"}], ",", 
       RowBox[{"2592", "\[Rule]", "2589"}], ",", 
       RowBox[{"2160", "\[Rule]", "2143"}], ",", 
       RowBox[{"2160", "\[Rule]", "2157"}], ",", 
       RowBox[{"2574", "\[Rule]", "2557"}], ",", 
       RowBox[{"2574", "\[Rule]", "2589"}], ",", 
       RowBox[{"2574", "\[Rule]", "2575"}], ",", 
       RowBox[{"2574", "\[Rule]", "2571"}], ",", 
       RowBox[{"2142", "\[Rule]", "2125"}], ",", 
       RowBox[{"2142", "\[Rule]", "2157"}], ",", 
       RowBox[{"2142", "\[Rule]", "2143"}], ",", 
       RowBox[{"2142", "\[Rule]", "2139"}], ",", 
       RowBox[{"2556", "\[Rule]", "2539"}], ",", 
       RowBox[{"2556", "\[Rule]", "2571"}], ",", 
       RowBox[{"2556", "\[Rule]", "2557"}], ",", 
       RowBox[{"2556", "\[Rule]", "2553"}], ",", 
       RowBox[{"2124", "\[Rule]", "2107"}], ",", 
       RowBox[{"2124", "\[Rule]", "2139"}], ",", 
       RowBox[{"2124", "\[Rule]", "2125"}], ",", 
       RowBox[{"2124", "\[Rule]", "2121"}], ",", 
       RowBox[{"2538", "\[Rule]", "2523"}], ",", 
       RowBox[{"2538", "\[Rule]", "2553"}], ",", 
       RowBox[{"2538", "\[Rule]", "2539"}], ",", 
       RowBox[{"2538", "\[Rule]", "2535"}], ",", 
       RowBox[{"2430", "\[Rule]", "2415"}], ",", 
       RowBox[{"2430", "\[Rule]", "2445"}], ",", 
       RowBox[{"2430", "\[Rule]", "2431"}], ",", 
       RowBox[{"2430", "\[Rule]", "2427"}], ",", 
       RowBox[{"2106", "\[Rule]", "2091"}], ",", 
       RowBox[{"2106", "\[Rule]", "2121"}], ",", 
       RowBox[{"2106", "\[Rule]", "2107"}], ",", 
       RowBox[{"2106", "\[Rule]", "2103"}], ",", 
       RowBox[{"2322", "\[Rule]", "2307"}], ",", 
       RowBox[{"2322", "\[Rule]", "2337"}], ",", 
       RowBox[{"2322", "\[Rule]", "2323"}], ",", 
       RowBox[{"2322", "\[Rule]", "2319"}], ",", 
       RowBox[{"1998", "\[Rule]", "1983"}], ",", 
       RowBox[{"1998", "\[Rule]", "2013"}], ",", 
       RowBox[{"1998", "\[Rule]", "1999"}], ",", 
       RowBox[{"1998", "\[Rule]", "1995"}], ",", 
       RowBox[{"2214", "\[Rule]", "2199"}], ",", 
       RowBox[{"2214", "\[Rule]", "2229"}], ",", 
       RowBox[{"2214", "\[Rule]", "2215"}], ",", 
       RowBox[{"2214", "\[Rule]", "2211"}], ",", 
       RowBox[{"1890", "\[Rule]", "1875"}], ",", 
       RowBox[{"1890", "\[Rule]", "1905"}], ",", 
       RowBox[{"1890", "\[Rule]", "1891"}], ",", 
       RowBox[{"1890", "\[Rule]", "1887"}], ",", 
       RowBox[{"16", "\[Rule]", "29"}], ",", 
       RowBox[{"16", "\[Rule]", "13"}], ",", 
       RowBox[{"28", "\[Rule]", "13"}], ",", 
       RowBox[{"28", "\[Rule]", "43"}], ",", 
       RowBox[{"28", "\[Rule]", "29"}], ",", 
       RowBox[{"28", "\[Rule]", "25"}], ",", 
       RowBox[{"880", "\[Rule]", "893"}], ",", 
       RowBox[{"880", "\[Rule]", "877"}], ",", 
       RowBox[{"892", "\[Rule]", "877"}], ",", 
       RowBox[{"892", "\[Rule]", "907"}], ",", 
       RowBox[{"892", "\[Rule]", "893"}], ",", 
       RowBox[{"892", "\[Rule]", "889"}], ",", 
       RowBox[{"42", "\[Rule]", "25"}], ",", 
       RowBox[{"42", "\[Rule]", "55"}], ",", 
       RowBox[{"42", "\[Rule]", "43"}], ",", 
       RowBox[{"42", "\[Rule]", "39"}], ",", 
       RowBox[{"906", "\[Rule]", "889"}], ",", 
       RowBox[{"906", "\[Rule]", "919"}], ",", 
       RowBox[{"906", "\[Rule]", "907"}], ",", 
       RowBox[{"906", "\[Rule]", "903"}], ",", 
       RowBox[{"54", "\[Rule]", "39"}], ",", 
       RowBox[{"54", "\[Rule]", "69"}], ",", 
       RowBox[{"54", "\[Rule]", "55"}], ",", 
       RowBox[{"54", "\[Rule]", "51"}], ",", 
       RowBox[{"918", "\[Rule]", "903"}], ",", 
       RowBox[{"918", "\[Rule]", "933"}], ",", 
       RowBox[{"918", "\[Rule]", "919"}], ",", 
       RowBox[{"918", "\[Rule]", "915"}], ",", 
       RowBox[{"1744", "\[Rule]", "1757"}], ",", 
       RowBox[{"1744", "\[Rule]", "1741"}], ",", 
       RowBox[{"1756", "\[Rule]", "1741"}], ",", 
       RowBox[{"1756", "\[Rule]", "1771"}], ",", 
       RowBox[{"1756", "\[Rule]", "1757"}], ",", 
       RowBox[{"1756", "\[Rule]", "1753"}], ",", 
       RowBox[{"1770", "\[Rule]", "1753"}], ",", 
       RowBox[{"1770", "\[Rule]", "1783"}], ",", 
       RowBox[{"1770", "\[Rule]", "1771"}], ",", 
       RowBox[{"1770", "\[Rule]", "1767"}], ",", 
       RowBox[{"1782", "\[Rule]", "1767"}], ",", 
       RowBox[{"1782", "\[Rule]", "1797"}], ",", 
       RowBox[{"1782", "\[Rule]", "1783"}], ",", 
       RowBox[{"1782", "\[Rule]", "1779"}], ",", 
       RowBox[{"860", "\[Rule]", "843"}], ",", 
       RowBox[{"860", "\[Rule]", "861"}], ",", 
       RowBox[{"860", "\[Rule]", "857"}], ",", 
       RowBox[{"428", "\[Rule]", "411"}], ",", 
       RowBox[{"428", "\[Rule]", "429"}], ",", 
       RowBox[{"428", "\[Rule]", "425"}], ",", 
       RowBox[{"1724", "\[Rule]", "1707"}], ",", 
       RowBox[{"1724", "\[Rule]", "1725"}], ",", 
       RowBox[{"1724", "\[Rule]", "1721"}], ",", 
       RowBox[{"1292", "\[Rule]", "1275"}], ",", 
       RowBox[{"1292", "\[Rule]", "1293"}], ",", 
       RowBox[{"1292", "\[Rule]", "1289"}], ",", 
       RowBox[{"842", "\[Rule]", "825"}], ",", 
       RowBox[{"842", "\[Rule]", "857"}], ",", 
       RowBox[{"842", "\[Rule]", "843"}], ",", 
       RowBox[{"842", "\[Rule]", "839"}], ",", 
       RowBox[{"410", "\[Rule]", "393"}], ",", 
       RowBox[{"410", "\[Rule]", "425"}], ",", 
       RowBox[{"410", "\[Rule]", "411"}], ",", 
       RowBox[{"410", "\[Rule]", "407"}], ",", 
       RowBox[{"1706", "\[Rule]", "1689"}], ",", 
       RowBox[{"1706", "\[Rule]", "1721"}], ",", 
       RowBox[{"1706", "\[Rule]", "1707"}], ",", 
       RowBox[{"1706", "\[Rule]", "1703"}], ",", 
       RowBox[{"1274", "\[Rule]", "1257"}], ",", 
       RowBox[{"1274", "\[Rule]", "1289"}], ",", 
       RowBox[{"1274", "\[Rule]", "1275"}], ",", 
       RowBox[{"1274", "\[Rule]", "1271"}], ",", 
       RowBox[{"2588", "\[Rule]", "2571"}], ",", 
       RowBox[{"2588", "\[Rule]", "2589"}], ",", 
       RowBox[{"2588", "\[Rule]", "2585"}], ",", 
       RowBox[{"2156", "\[Rule]", "2139"}], ",", 
       RowBox[{"2156", "\[Rule]", "2157"}], ",", 
       RowBox[{"2156", "\[Rule]", "2153"}], ",", 
       RowBox[{"2570", "\[Rule]", "2553"}], ",", 
       RowBox[{"2570", "\[Rule]", "2585"}], ",", 
       RowBox[{"2570", "\[Rule]", "2571"}], ",", 
       RowBox[{"2570", "\[Rule]", "2567"}], ",", 
       RowBox[{"2138", "\[Rule]", "2121"}], ",", 
       RowBox[{"2138", "\[Rule]", "2153"}], ",", 
       RowBox[{"2138", "\[Rule]", "2139"}], ",", 
       RowBox[{"2138", "\[Rule]", "2135"}], ",", 
       RowBox[{"824", "\[Rule]", "807"}], ",", 
       RowBox[{"824", "\[Rule]", "839"}], ",", 
       RowBox[{"824", "\[Rule]", "825"}], ",", 
       RowBox[{"824", "\[Rule]", "821"}], ",", 
       RowBox[{"716", "\[Rule]", "699"}], ",", 
       RowBox[{"716", "\[Rule]", "731"}], ",", 
       RowBox[{"716", "\[Rule]", "717"}], ",", 
       RowBox[{"716", "\[Rule]", "713"}], ",", 
       RowBox[{"392", "\[Rule]", "375"}], ",", 
       RowBox[{"392", "\[Rule]", "407"}], ",", 
       RowBox[{"392", "\[Rule]", "393"}], ",", 
       RowBox[{"392", "\[Rule]", "389"}], ",", 
       RowBox[{"1688", "\[Rule]", "1671"}], ",", 
       RowBox[{"1688", "\[Rule]", "1703"}], ",", 
       RowBox[{"1688", "\[Rule]", "1689"}], ",", 
       RowBox[{"1688", "\[Rule]", "1685"}], ",", 
       RowBox[{"1580", "\[Rule]", "1563"}], ",", 
       RowBox[{"1580", "\[Rule]", "1595"}], ",", 
       RowBox[{"1580", "\[Rule]", "1581"}], ",", 
       RowBox[{"1580", "\[Rule]", "1577"}], ",", 
       RowBox[{"1256", "\[Rule]", "1239"}], ",", 
       RowBox[{"1256", "\[Rule]", "1271"}], ",", 
       RowBox[{"1256", "\[Rule]", "1257"}], ",", 
       RowBox[{"1256", "\[Rule]", "1253"}], ",", 
       RowBox[{"608", "\[Rule]", "591"}], ",", 
       RowBox[{"608", "\[Rule]", "623"}], ",", 
       RowBox[{"608", "\[Rule]", "609"}], ",", 
       RowBox[{"608", "\[Rule]", "605"}], ",", 
       RowBox[{"284", "\[Rule]", "267"}], ",", 
       RowBox[{"284", "\[Rule]", "299"}], ",", 
       RowBox[{"284", "\[Rule]", "285"}], ",", 
       RowBox[{"284", "\[Rule]", "281"}], ",", 
       RowBox[{"1472", "\[Rule]", "1455"}], ",", 
       RowBox[{"1472", "\[Rule]", "1487"}], ",", 
       RowBox[{"1472", "\[Rule]", "1473"}], ",", 
       RowBox[{"1472", "\[Rule]", "1469"}], ",", 
       RowBox[{"1148", "\[Rule]", "1131"}], ",", 
       RowBox[{"1148", "\[Rule]", "1163"}], ",", 
       RowBox[{"1148", "\[Rule]", "1149"}], ",", 
       RowBox[{"1148", "\[Rule]", "1145"}], ",", 
       RowBox[{"500", "\[Rule]", "483"}], ",", 
       RowBox[{"500", "\[Rule]", "515"}], ",", 
       RowBox[{"500", "\[Rule]", "501"}], ",", 
       RowBox[{"500", "\[Rule]", "497"}], ",", 
       RowBox[{"176", "\[Rule]", "159"}], ",", 
       RowBox[{"176", "\[Rule]", "191"}], ",", 
       RowBox[{"176", "\[Rule]", "177"}], ",", 
       RowBox[{"176", "\[Rule]", "173"}], ",", 
       RowBox[{"1364", "\[Rule]", "1347"}], ",", 
       RowBox[{"1364", "\[Rule]", "1379"}], ",", 
       RowBox[{"1364", "\[Rule]", "1365"}], ",", 
       RowBox[{"1364", "\[Rule]", "1361"}], ",", 
       RowBox[{"1040", "\[Rule]", "1023"}], ",", 
       RowBox[{"1040", "\[Rule]", "1055"}], ",", 
       RowBox[{"1040", "\[Rule]", "1041"}], ",", 
       RowBox[{"1040", "\[Rule]", "1037"}], ",", 
       RowBox[{"2552", "\[Rule]", "2535"}], ",", 
       RowBox[{"2552", "\[Rule]", "2567"}], ",", 
       RowBox[{"2552", "\[Rule]", "2553"}], ",", 
       RowBox[{"2552", "\[Rule]", "2549"}], ",", 
       RowBox[{"2444", "\[Rule]", "2427"}], ",", 
       RowBox[{"2444", "\[Rule]", "2459"}], ",", 
       RowBox[{"2444", "\[Rule]", "2445"}], ",", 
       RowBox[{"2444", "\[Rule]", "2441"}], ",", 
       RowBox[{"2120", "\[Rule]", "2103"}], ",", 
       RowBox[{"2120", "\[Rule]", "2135"}], ",", 
       RowBox[{"2120", "\[Rule]", "2121"}], ",", 
       RowBox[{"2120", "\[Rule]", "2117"}], ",", 
       RowBox[{"2336", "\[Rule]", "2319"}], ",", 
       RowBox[{"2336", "\[Rule]", "2351"}], ",", 
       RowBox[{"2336", "\[Rule]", "2337"}], ",", 
       RowBox[{"2336", "\[Rule]", "2333"}], ",", 
       RowBox[{"2012", "\[Rule]", "1995"}], ",", 
       RowBox[{"2012", "\[Rule]", "2027"}], ",", 
       RowBox[{"2012", "\[Rule]", "2013"}], ",", 
       RowBox[{"2012", "\[Rule]", "2009"}], ",", 
       RowBox[{"2228", "\[Rule]", "2211"}], ",", 
       RowBox[{"2228", "\[Rule]", "2243"}], ",", 
       RowBox[{"2228", "\[Rule]", "2229"}], ",", 
       RowBox[{"2228", "\[Rule]", "2225"}], ",", 
       RowBox[{"1904", "\[Rule]", "1887"}], ",", 
       RowBox[{"1904", "\[Rule]", "1919"}], ",", 
       RowBox[{"1904", "\[Rule]", "1905"}], ",", 
       RowBox[{"1904", "\[Rule]", "1901"}], ",", 
       RowBox[{"68", "\[Rule]", "51"}], ",", 
       RowBox[{"68", "\[Rule]", "83"}], ",", 
       RowBox[{"68", "\[Rule]", "69"}], ",", 
       RowBox[{"68", "\[Rule]", "65"}], ",", 
       RowBox[{"932", "\[Rule]", "915"}], ",", 
       RowBox[{"932", "\[Rule]", "947"}], ",", 
       RowBox[{"932", "\[Rule]", "933"}], ",", 
       RowBox[{"932", "\[Rule]", "929"}], ",", 
       RowBox[{"1796", "\[Rule]", "1779"}], ",", 
       RowBox[{"1796", "\[Rule]", "1811"}], ",", 
       RowBox[{"1796", "\[Rule]", "1797"}], ",", 
       RowBox[{"1796", "\[Rule]", "1793"}], ",", 
       RowBox[{"856", "\[Rule]", "839"}], ",", 
       RowBox[{"856", "\[Rule]", "857"}], ",", 
       RowBox[{"856", "\[Rule]", "853"}], ",", 
       RowBox[{"424", "\[Rule]", "407"}], ",", 
       RowBox[{"424", "\[Rule]", "425"}], ",", 
       RowBox[{"424", "\[Rule]", "421"}], ",", 
       RowBox[{"1720", "\[Rule]", "1703"}], ",", 
       RowBox[{"1720", "\[Rule]", "1721"}], ",", 
       RowBox[{"1720", "\[Rule]", "1717"}], ",", 
       RowBox[{"1288", "\[Rule]", "1271"}], ",", 
       RowBox[{"1288", "\[Rule]", "1289"}], ",", 
       RowBox[{"1288", "\[Rule]", "1285"}], ",", 
       RowBox[{"2584", "\[Rule]", "2567"}], ",", 
       RowBox[{"2584", "\[Rule]", "2585"}], ",", 
       RowBox[{"2584", "\[Rule]", "2581"}], ",", 
       RowBox[{"2152", "\[Rule]", "2135"}], ",", 
       RowBox[{"2152", "\[Rule]", "2153"}], ",", 
       RowBox[{"2152", "\[Rule]", "2149"}], ",", 
       RowBox[{"838", "\[Rule]", "821"}], ",", 
       RowBox[{"838", "\[Rule]", "853"}], ",", 
       RowBox[{"838", "\[Rule]", "839"}], ",", 
       RowBox[{"838", "\[Rule]", "835"}], ",", 
       RowBox[{"730", "\[Rule]", "713"}], ",", 
       RowBox[{"730", "\[Rule]", "745"}], ",", 
       RowBox[{"730", "\[Rule]", "731"}], ",", 
       RowBox[{"730", "\[Rule]", "727"}], ",", 
       RowBox[{"406", "\[Rule]", "389"}], ",", 
       RowBox[{"406", "\[Rule]", "421"}], ",", 
       RowBox[{"406", "\[Rule]", "407"}], ",", 
       RowBox[{"406", "\[Rule]", "403"}], ",", 
       RowBox[{"1702", "\[Rule]", "1685"}], ",", 
       RowBox[{"1702", "\[Rule]", "1717"}], ",", 
       RowBox[{"1702", "\[Rule]", "1703"}], ",", 
       RowBox[{"1702", "\[Rule]", "1699"}], ",", 
       RowBox[{"1594", "\[Rule]", "1577"}], ",", 
       RowBox[{"1594", "\[Rule]", "1609"}], ",", 
       RowBox[{"1594", "\[Rule]", "1595"}], ",", 
       RowBox[{"1594", "\[Rule]", "1591"}], ",", 
       RowBox[{"1270", "\[Rule]", "1253"}], ",", 
       RowBox[{"1270", "\[Rule]", "1285"}], ",", 
       RowBox[{"1270", "\[Rule]", "1271"}], ",", 
       RowBox[{"1270", "\[Rule]", "1267"}], ",", 
       RowBox[{"622", "\[Rule]", "605"}], ",", 
       RowBox[{"622", "\[Rule]", "637"}], ",", 
       RowBox[{"622", "\[Rule]", "623"}], ",", 
       RowBox[{"622", "\[Rule]", "619"}], ",", 
       RowBox[{"298", "\[Rule]", "281"}], ",", 
       RowBox[{"298", "\[Rule]", "313"}], ",", 
       RowBox[{"298", "\[Rule]", "299"}], ",", 
       RowBox[{"298", "\[Rule]", "295"}], ",", 
       RowBox[{"1486", "\[Rule]", "1469"}], ",", 
       RowBox[{"1486", "\[Rule]", "1501"}], ",", 
       RowBox[{"1486", "\[Rule]", "1487"}], ",", 
       RowBox[{"1486", "\[Rule]", "1483"}], ",", 
       RowBox[{"1162", "\[Rule]", "1145"}], ",", 
       RowBox[{"1162", "\[Rule]", "1177"}], ",", 
       RowBox[{"1162", "\[Rule]", "1163"}], ",", 
       RowBox[{"1162", "\[Rule]", "1159"}], ",", 
       RowBox[{"514", "\[Rule]", "497"}], ",", 
       RowBox[{"514", "\[Rule]", "529"}], ",", 
       RowBox[{"514", "\[Rule]", "515"}], ",", 
       RowBox[{"514", "\[Rule]", "511"}], ",", 
       RowBox[{"190", "\[Rule]", "173"}], ",", 
       RowBox[{"190", "\[Rule]", "205"}], ",", 
       RowBox[{"190", "\[Rule]", "191"}], ",", 
       RowBox[{"190", "\[Rule]", "187"}], ",", 
       RowBox[{"1378", "\[Rule]", "1361"}], ",", 
       RowBox[{"1378", "\[Rule]", "1393"}], ",", 
       RowBox[{"1378", "\[Rule]", "1379"}], ",", 
       RowBox[{"1378", "\[Rule]", "1375"}], ",", 
       RowBox[{"1054", "\[Rule]", "1037"}], ",", 
       RowBox[{"1054", "\[Rule]", "1069"}], ",", 
       RowBox[{"1054", "\[Rule]", "1055"}], ",", 
       RowBox[{"1054", "\[Rule]", "1051"}], ",", 
       RowBox[{"2566", "\[Rule]", "2549"}], ",", 
       RowBox[{"2566", "\[Rule]", "2581"}], ",", 
       RowBox[{"2566", "\[Rule]", "2567"}], ",", 
       RowBox[{"2566", "\[Rule]", "2563"}], ",", 
       RowBox[{"2458", "\[Rule]", "2441"}], ",", 
       RowBox[{"2458", "\[Rule]", "2473"}], ",", 
       RowBox[{"2458", "\[Rule]", "2459"}], ",", 
       RowBox[{"2458", "\[Rule]", "2455"}], ",", 
       RowBox[{"2134", "\[Rule]", "2117"}], ",", 
       RowBox[{"2134", "\[Rule]", "2149"}], ",", 
       RowBox[{"2134", "\[Rule]", "2135"}], ",", 
       RowBox[{"2134", "\[Rule]", "2131"}], ",", 
       RowBox[{"2350", "\[Rule]", "2333"}], ",", 
       RowBox[{"2350", "\[Rule]", "2365"}], ",", 
       RowBox[{"2350", "\[Rule]", "2351"}], ",", 
       RowBox[{"2350", "\[Rule]", "2347"}], ",", 
       RowBox[{"2026", "\[Rule]", "2009"}], ",", 
       RowBox[{"2026", "\[Rule]", "2041"}], ",", 
       RowBox[{"2026", "\[Rule]", "2027"}], ",", 
       RowBox[{"2026", "\[Rule]", "2023"}], ",", 
       RowBox[{"2242", "\[Rule]", "2225"}], ",", 
       RowBox[{"2242", "\[Rule]", "2257"}], ",", 
       RowBox[{"2242", "\[Rule]", "2243"}], ",", 
       RowBox[{"2242", "\[Rule]", "2239"}], ",", 
       RowBox[{"1918", "\[Rule]", "1901"}], ",", 
       RowBox[{"1918", "\[Rule]", "1933"}], ",", 
       RowBox[{"1918", "\[Rule]", "1919"}], ",", 
       RowBox[{"1918", "\[Rule]", "1915"}], ",", 
       RowBox[{"82", "\[Rule]", "65"}], ",", 
       RowBox[{"82", "\[Rule]", "97"}], ",", 
       RowBox[{"82", "\[Rule]", "83"}], ",", 
       RowBox[{"82", "\[Rule]", "79"}], ",", 
       RowBox[{"946", "\[Rule]", "929"}], ",", 
       RowBox[{"946", "\[Rule]", "961"}], ",", 
       RowBox[{"946", "\[Rule]", "947"}], ",", 
       RowBox[{"946", "\[Rule]", "943"}], ",", 
       RowBox[{"1810", "\[Rule]", "1793"}], ",", 
       RowBox[{"1810", "\[Rule]", "1825"}], ",", 
       RowBox[{"1810", "\[Rule]", "1811"}], ",", 
       RowBox[{"1810", "\[Rule]", "1807"}], ",", 
       RowBox[{"2932", "\[Rule]", "2945"}], ",", 
       RowBox[{"2932", "\[Rule]", "2929"}], ",", 
       RowBox[{"2962", "\[Rule]", "2945"}], ",", 
       RowBox[{"2962", "\[Rule]", "2975"}], ",", 
       RowBox[{"2962", "\[Rule]", "2959"}], ",", 
       RowBox[{"2944", "\[Rule]", "2929"}], ",", 
       RowBox[{"2944", "\[Rule]", "2959"}], ",", 
       RowBox[{"2944", "\[Rule]", "2945"}], ",", 
       RowBox[{"2944", "\[Rule]", "2941"}], ",", 
       RowBox[{"2824", "\[Rule]", "2837"}], ",", 
       RowBox[{"2824", "\[Rule]", "2821"}], ",", 
       RowBox[{"2854", "\[Rule]", "2837"}], ",", 
       RowBox[{"2854", "\[Rule]", "2867"}], ",", 
       RowBox[{"2854", "\[Rule]", "2851"}], ",", 
       RowBox[{"2836", "\[Rule]", "2821"}], ",", 
       RowBox[{"2836", "\[Rule]", "2851"}], ",", 
       RowBox[{"2836", "\[Rule]", "2837"}], ",", 
       RowBox[{"2836", "\[Rule]", "2833"}], ",", 
       RowBox[{"2992", "\[Rule]", "2975"}], ",", 
       RowBox[{"2992", "\[Rule]", "3007"}], ",", 
       RowBox[{"2992", "\[Rule]", "2989"}], ",", 
       RowBox[{"2974", "\[Rule]", "2959"}], ",", 
       RowBox[{"2974", "\[Rule]", "2989"}], ",", 
       RowBox[{"2974", "\[Rule]", "2975"}], ",", 
       RowBox[{"2974", "\[Rule]", "2971"}], ",", 
       RowBox[{"2884", "\[Rule]", "2867"}], ",", 
       RowBox[{"2884", "\[Rule]", "2899"}], ",", 
       RowBox[{"2884", "\[Rule]", "2881"}], ",", 
       RowBox[{"2866", "\[Rule]", "2851"}], ",", 
       RowBox[{"2866", "\[Rule]", "2881"}], ",", 
       RowBox[{"2866", "\[Rule]", "2867"}], ",", 
       RowBox[{"2866", "\[Rule]", "2863"}], ",", 
       RowBox[{"2958", "\[Rule]", "2941"}], ",", 
       RowBox[{"2958", "\[Rule]", "2971"}], ",", 
       RowBox[{"2958", "\[Rule]", "2959"}], ",", 
       RowBox[{"2958", "\[Rule]", "2955"}], ",", 
       RowBox[{"2850", "\[Rule]", "2833"}], ",", 
       RowBox[{"2850", "\[Rule]", "2863"}], ",", 
       RowBox[{"2850", "\[Rule]", "2851"}], ",", 
       RowBox[{"2850", "\[Rule]", "2847"}], ",", 
       RowBox[{"2716", "\[Rule]", "2729"}], ",", 
       RowBox[{"2716", "\[Rule]", "2713"}], ",", 
       RowBox[{"2746", "\[Rule]", "2729"}], ",", 
       RowBox[{"2746", "\[Rule]", "2759"}], ",", 
       RowBox[{"2746", "\[Rule]", "2743"}], ",", 
       RowBox[{"2728", "\[Rule]", "2713"}], ",", 
       RowBox[{"2728", "\[Rule]", "2743"}], ",", 
       RowBox[{"2728", "\[Rule]", "2729"}], ",", 
       RowBox[{"2728", "\[Rule]", "2725"}], ",", 
       RowBox[{"2776", "\[Rule]", "2759"}], ",", 
       RowBox[{"2776", "\[Rule]", "2791"}], ",", 
       RowBox[{"2776", "\[Rule]", "2773"}], ",", 
       RowBox[{"2758", "\[Rule]", "2743"}], ",", 
       RowBox[{"2758", "\[Rule]", "2773"}], ",", 
       RowBox[{"2758", "\[Rule]", "2759"}], ",", 
       RowBox[{"2758", "\[Rule]", "2755"}], ",", 
       RowBox[{"2742", "\[Rule]", "2725"}], ",", 
       RowBox[{"2742", "\[Rule]", "2755"}], ",", 
       RowBox[{"2742", "\[Rule]", "2743"}], ",", 
       RowBox[{"2742", "\[Rule]", "2739"}], ",", 
       RowBox[{"3024", "\[Rule]", "3007"}], ",", 
       RowBox[{"3024", "\[Rule]", "3021"}], ",", 
       RowBox[{"3006", "\[Rule]", "2989"}], ",", 
       RowBox[{"3006", "\[Rule]", "3021"}], ",", 
       RowBox[{"3006", "\[Rule]", "3007"}], ",", 
       RowBox[{"3006", "\[Rule]", "3003"}], ",", 
       RowBox[{"2916", "\[Rule]", "2899"}], ",", 
       RowBox[{"2916", "\[Rule]", "2913"}], ",", 
       RowBox[{"2898", "\[Rule]", "2881"}], ",", 
       RowBox[{"2898", "\[Rule]", "2913"}], ",", 
       RowBox[{"2898", "\[Rule]", "2899"}], ",", 
       RowBox[{"2898", "\[Rule]", "2895"}], ",", 
       RowBox[{"2988", "\[Rule]", "2971"}], ",", 
       RowBox[{"2988", "\[Rule]", "3003"}], ",", 
       RowBox[{"2988", "\[Rule]", "2989"}], ",", 
       RowBox[{"2988", "\[Rule]", "2985"}], ",", 
       RowBox[{"2880", "\[Rule]", "2863"}], ",", 
       RowBox[{"2880", "\[Rule]", "2895"}], ",", 
       RowBox[{"2880", "\[Rule]", "2881"}], ",", 
       RowBox[{"2880", "\[Rule]", "2877"}], ",", 
       RowBox[{"2808", "\[Rule]", "2791"}], ",", 
       RowBox[{"2808", "\[Rule]", "2805"}], ",", 
       RowBox[{"2790", "\[Rule]", "2773"}], ",", 
       RowBox[{"2790", "\[Rule]", "2805"}], ",", 
       RowBox[{"2790", "\[Rule]", "2791"}], ",", 
       RowBox[{"2790", "\[Rule]", "2787"}], ",", 
       RowBox[{"2772", "\[Rule]", "2755"}], ",", 
       RowBox[{"2772", "\[Rule]", "2787"}], ",", 
       RowBox[{"2772", "\[Rule]", "2773"}], ",", 
       RowBox[{"2772", "\[Rule]", "2769"}], ",", 
       RowBox[{"2970", "\[Rule]", "2955"}], ",", 
       RowBox[{"2970", "\[Rule]", "2985"}], ",", 
       RowBox[{"2970", "\[Rule]", "2971"}], ",", 
       RowBox[{"2970", "\[Rule]", "2967"}], ",", 
       RowBox[{"2862", "\[Rule]", "2847"}], ",", 
       RowBox[{"2862", "\[Rule]", "2877"}], ",", 
       RowBox[{"2862", "\[Rule]", "2863"}], ",", 
       RowBox[{"2862", "\[Rule]", "2859"}], ",", 
       RowBox[{"2754", "\[Rule]", "2739"}], ",", 
       RowBox[{"2754", "\[Rule]", "2769"}], ",", 
       RowBox[{"2754", "\[Rule]", "2755"}], ",", 
       RowBox[{"2754", "\[Rule]", "2751"}], ",", 
       RowBox[{"2608", "\[Rule]", "2621"}], ",", 
       RowBox[{"2608", "\[Rule]", "2605"}], ",", 
       RowBox[{"2638", "\[Rule]", "2621"}], ",", 
       RowBox[{"2638", "\[Rule]", "2651"}], ",", 
       RowBox[{"2638", "\[Rule]", "2635"}], ",", 
       RowBox[{"2620", "\[Rule]", "2605"}], ",", 
       RowBox[{"2620", "\[Rule]", "2635"}], ",", 
       RowBox[{"2620", "\[Rule]", "2621"}], ",", 
       RowBox[{"2620", "\[Rule]", "2617"}], ",", 
       RowBox[{"2668", "\[Rule]", "2651"}], ",", 
       RowBox[{"2668", "\[Rule]", "2683"}], ",", 
       RowBox[{"2668", "\[Rule]", "2665"}], ",", 
       RowBox[{"2650", "\[Rule]", "2635"}], ",", 
       RowBox[{"2650", "\[Rule]", "2665"}], ",", 
       RowBox[{"2650", "\[Rule]", "2651"}], ",", 
       RowBox[{"2650", "\[Rule]", "2647"}], ",", 
       RowBox[{"2634", "\[Rule]", "2617"}], ",", 
       RowBox[{"2634", "\[Rule]", "2647"}], ",", 
       RowBox[{"2634", "\[Rule]", "2635"}], ",", 
       RowBox[{"2634", "\[Rule]", "2631"}], ",", 
       RowBox[{"2700", "\[Rule]", "2683"}], ",", 
       RowBox[{"2700", "\[Rule]", "2697"}], ",", 
       RowBox[{"2682", "\[Rule]", "2665"}], ",", 
       RowBox[{"2682", "\[Rule]", "2697"}], ",", 
       RowBox[{"2682", "\[Rule]", "2683"}], ",", 
       RowBox[{"2682", "\[Rule]", "2679"}], ",", 
       RowBox[{"2664", "\[Rule]", "2647"}], ",", 
       RowBox[{"2664", "\[Rule]", "2679"}], ",", 
       RowBox[{"2664", "\[Rule]", "2665"}], ",", 
       RowBox[{"2664", "\[Rule]", "2661"}], ",", 
       RowBox[{"2646", "\[Rule]", "2631"}], ",", 
       RowBox[{"2646", "\[Rule]", "2661"}], ",", 
       RowBox[{"2646", "\[Rule]", "2647"}], ",", 
       RowBox[{"2646", "\[Rule]", "2643"}], ",", 
       RowBox[{"3020", "\[Rule]", "3003"}], ",", 
       RowBox[{"3020", "\[Rule]", "3021"}], ",", 
       RowBox[{"3020", "\[Rule]", "3017"}], ",", 
       RowBox[{"2912", "\[Rule]", "2895"}], ",", 
       RowBox[{"2912", "\[Rule]", "2913"}], ",", 
       RowBox[{"2912", "\[Rule]", "2909"}], ",", 
       RowBox[{"2804", "\[Rule]", "2787"}], ",", 
       RowBox[{"2804", "\[Rule]", "2805"}], ",", 
       RowBox[{"2804", "\[Rule]", "2801"}], ",", 
       RowBox[{"3002", "\[Rule]", "2985"}], ",", 
       RowBox[{"3002", "\[Rule]", "3017"}], ",", 
       RowBox[{"3002", "\[Rule]", "3003"}], ",", 
       RowBox[{"3002", "\[Rule]", "2999"}], ",", 
       RowBox[{"2894", "\[Rule]", "2877"}], ",", 
       RowBox[{"2894", "\[Rule]", "2909"}], ",", 
       RowBox[{"2894", "\[Rule]", "2895"}], ",", 
       RowBox[{"2894", "\[Rule]", "2891"}], ",", 
       RowBox[{"2786", "\[Rule]", "2769"}], ",", 
       RowBox[{"2786", "\[Rule]", "2801"}], ",", 
       RowBox[{"2786", "\[Rule]", "2787"}], ",", 
       RowBox[{"2786", "\[Rule]", "2783"}], ",", 
       RowBox[{"2696", "\[Rule]", "2679"}], ",", 
       RowBox[{"2696", "\[Rule]", "2697"}], ",", 
       RowBox[{"2696", "\[Rule]", "2693"}], ",", 
       RowBox[{"2678", "\[Rule]", "2661"}], ",", 
       RowBox[{"2678", "\[Rule]", "2693"}], ",", 
       RowBox[{"2678", "\[Rule]", "2679"}], ",", 
       RowBox[{"2678", "\[Rule]", "2675"}], ",", 
       RowBox[{"2984", "\[Rule]", "2967"}], ",", 
       RowBox[{"2984", "\[Rule]", "2999"}], ",", 
       RowBox[{"2984", "\[Rule]", "2985"}], ",", 
       RowBox[{"2984", "\[Rule]", "2981"}], ",", 
       RowBox[{"2876", "\[Rule]", "2859"}], ",", 
       RowBox[{"2876", "\[Rule]", "2891"}], ",", 
       RowBox[{"2876", "\[Rule]", "2877"}], ",", 
       RowBox[{"2876", "\[Rule]", "2873"}], ",", 
       RowBox[{"2768", "\[Rule]", "2751"}], ",", 
       RowBox[{"2768", "\[Rule]", "2783"}], ",", 
       RowBox[{"2768", "\[Rule]", "2769"}], ",", 
       RowBox[{"2768", "\[Rule]", "2765"}], ",", 
       RowBox[{"2660", "\[Rule]", "2643"}], ",", 
       RowBox[{"2660", "\[Rule]", "2675"}], ",", 
       RowBox[{"2660", "\[Rule]", "2661"}], ",", 
       RowBox[{"2660", "\[Rule]", "2657"}], ",", 
       RowBox[{"3016", "\[Rule]", "2999"}], ",", 
       RowBox[{"3016", "\[Rule]", "3017"}], ",", 
       RowBox[{"3016", "\[Rule]", "3013"}], ",", 
       RowBox[{"2908", "\[Rule]", "2891"}], ",", 
       RowBox[{"2908", "\[Rule]", "2909"}], ",", 
       RowBox[{"2908", "\[Rule]", "2905"}], ",", 
       RowBox[{"2800", "\[Rule]", "2783"}], ",", 
       RowBox[{"2800", "\[Rule]", "2801"}], ",", 
       RowBox[{"2800", "\[Rule]", "2797"}], ",", 
       RowBox[{"2692", "\[Rule]", "2675"}], ",", 
       RowBox[{"2692", "\[Rule]", "2693"}], ",", 
       RowBox[{"2692", "\[Rule]", "2689"}], ",", 
       RowBox[{"2998", "\[Rule]", "2981"}], ",", 
       RowBox[{"2998", "\[Rule]", "3013"}], ",", 
       RowBox[{"2998", "\[Rule]", "2999"}], ",", 
       RowBox[{"2998", "\[Rule]", "2995"}], ",", 
       RowBox[{"2890", "\[Rule]", "2873"}], ",", 
       RowBox[{"2890", "\[Rule]", "2905"}], ",", 
       RowBox[{"2890", "\[Rule]", "2891"}], ",", 
       RowBox[{"2890", "\[Rule]", "2887"}], ",", 
       RowBox[{"2782", "\[Rule]", "2765"}], ",", 
       RowBox[{"2782", "\[Rule]", "2797"}], ",", 
       RowBox[{"2782", "\[Rule]", "2783"}], ",", 
       RowBox[{"2782", "\[Rule]", "2779"}], ",", 
       RowBox[{"2674", "\[Rule]", "2657"}], ",", 
       RowBox[{"2674", "\[Rule]", "2689"}], ",", 
       RowBox[{"2674", "\[Rule]", "2675"}], ",", 
       RowBox[{"2674", "\[Rule]", "2671"}], ",", 
       RowBox[{"852", "\[Rule]", "835"}], ",", 
       RowBox[{"852", "\[Rule]", "853"}], ",", 
       RowBox[{"852", "\[Rule]", "849"}], ",", 
       RowBox[{"744", "\[Rule]", "727"}], ",", 
       RowBox[{"744", "\[Rule]", "745"}], ",", 
       RowBox[{"744", "\[Rule]", "741"}], ",", 
       RowBox[{"420", "\[Rule]", "403"}], ",", 
       RowBox[{"420", "\[Rule]", "421"}], ",", 
       RowBox[{"420", "\[Rule]", "417"}], ",", 
       RowBox[{"1716", "\[Rule]", "1699"}], ",", 
       RowBox[{"1716", "\[Rule]", "1717"}], ",", 
       RowBox[{"1716", "\[Rule]", "1713"}], ",", 
       RowBox[{"1608", "\[Rule]", "1591"}], ",", 
       RowBox[{"1608", "\[Rule]", "1609"}], ",", 
       RowBox[{"1608", "\[Rule]", "1605"}], ",", 
       RowBox[{"1284", "\[Rule]", "1267"}], ",", 
       RowBox[{"1284", "\[Rule]", "1285"}], ",", 
       RowBox[{"1284", "\[Rule]", "1281"}], ",", 
       RowBox[{"636", "\[Rule]", "619"}], ",", 
       RowBox[{"636", "\[Rule]", "637"}], ",", 
       RowBox[{"636", "\[Rule]", "633"}], ",", 
       RowBox[{"312", "\[Rule]", "295"}], ",", 
       RowBox[{"312", "\[Rule]", "313"}], ",", 
       RowBox[{"312", "\[Rule]", "309"}], ",", 
       RowBox[{"1500", "\[Rule]", "1483"}], ",", 
       RowBox[{"1500", "\[Rule]", "1501"}], ",", 
       RowBox[{"1500", "\[Rule]", "1497"}], ",", 
       RowBox[{"1176", "\[Rule]", "1159"}], ",", 
       RowBox[{"1176", "\[Rule]", "1177"}], ",", 
       RowBox[{"1176", "\[Rule]", "1173"}], ",", 
       RowBox[{"528", "\[Rule]", "511"}], ",", 
       RowBox[{"528", "\[Rule]", "529"}], ",", 
       RowBox[{"528", "\[Rule]", "525"}], ",", 
       RowBox[{"204", "\[Rule]", "187"}], ",", 
       RowBox[{"204", "\[Rule]", "205"}], ",", 
       RowBox[{"204", "\[Rule]", "201"}], ",", 
       RowBox[{"1392", "\[Rule]", "1375"}], ",", 
       RowBox[{"1392", "\[Rule]", "1393"}], ",", 
       RowBox[{"1392", "\[Rule]", "1389"}], ",", 
       RowBox[{"1068", "\[Rule]", "1051"}], ",", 
       RowBox[{"1068", "\[Rule]", "1069"}], ",", 
       RowBox[{"1068", "\[Rule]", "1065"}], ",", 
       RowBox[{"2580", "\[Rule]", "2563"}], ",", 
       RowBox[{"2580", "\[Rule]", "2581"}], ",", 
       RowBox[{"2580", "\[Rule]", "2577"}], ",", 
       RowBox[{"2472", "\[Rule]", "2455"}], ",", 
       RowBox[{"2472", "\[Rule]", "2473"}], ",", 
       RowBox[{"2472", "\[Rule]", "2469"}], ",", 
       RowBox[{"2148", "\[Rule]", "2131"}], ",", 
       RowBox[{"2148", "\[Rule]", "2149"}], ",", 
       RowBox[{"2148", "\[Rule]", "2145"}], ",", 
       RowBox[{"2364", "\[Rule]", "2347"}], ",", 
       RowBox[{"2364", "\[Rule]", "2365"}], ",", 
       RowBox[{"2364", "\[Rule]", "2361"}], ",", 
       RowBox[{"2040", "\[Rule]", "2023"}], ",", 
       RowBox[{"2040", "\[Rule]", "2041"}], ",", 
       RowBox[{"2040", "\[Rule]", "2037"}], ",", 
       RowBox[{"2256", "\[Rule]", "2239"}], ",", 
       RowBox[{"2256", "\[Rule]", "2257"}], ",", 
       RowBox[{"2256", "\[Rule]", "2253"}], ",", 
       RowBox[{"1932", "\[Rule]", "1915"}], ",", 
       RowBox[{"1932", "\[Rule]", "1933"}], ",", 
       RowBox[{"1932", "\[Rule]", "1929"}], ",", 
       RowBox[{"96", "\[Rule]", "79"}], ",", 
       RowBox[{"96", "\[Rule]", "97"}], ",", 
       RowBox[{"96", "\[Rule]", "93"}], ",", 
       RowBox[{"960", "\[Rule]", "943"}], ",", 
       RowBox[{"960", "\[Rule]", "961"}], ",", 
       RowBox[{"960", "\[Rule]", "957"}], ",", 
       RowBox[{"1824", "\[Rule]", "1807"}], ",", 
       RowBox[{"1824", "\[Rule]", "1825"}], ",", 
       RowBox[{"1824", "\[Rule]", "1821"}], ",", 
       RowBox[{"3012", "\[Rule]", "2995"}], ",", 
       RowBox[{"3012", "\[Rule]", "3013"}], ",", 
       RowBox[{"3012", "\[Rule]", "3009"}], ",", 
       RowBox[{"2904", "\[Rule]", "2887"}], ",", 
       RowBox[{"2904", "\[Rule]", "2905"}], ",", 
       RowBox[{"2904", "\[Rule]", "2901"}], ",", 
       RowBox[{"2796", "\[Rule]", "2779"}], ",", 
       RowBox[{"2796", "\[Rule]", "2797"}], ",", 
       RowBox[{"2796", "\[Rule]", "2793"}], ",", 
       RowBox[{"2688", "\[Rule]", "2671"}], ",", 
       RowBox[{"2688", "\[Rule]", "2689"}], ",", 
       RowBox[{"2688", "\[Rule]", "2685"}], ",", 
       RowBox[{"785", "\[Rule]", "354"}], ",", 
       RowBox[{"785", "\[Rule]", "354"}], ",", 
       RowBox[{"785", "\[Rule]", "1218"}], ",", 
       RowBox[{"785", "\[Rule]", "1218"}], ",", 
       RowBox[{"785", "\[Rule]", "786"}], ",", 
       RowBox[{"769", "\[Rule]", "338"}], ",", 
       RowBox[{"769", "\[Rule]", "338"}], ",", 
       RowBox[{"769", "\[Rule]", "1202"}], ",", 
       RowBox[{"769", "\[Rule]", "1202"}], ",", 
       RowBox[{"769", "\[Rule]", "770"}], ",", 
       RowBox[{"661", "\[Rule]", "338"}], ",", 
       RowBox[{"661", "\[Rule]", "338"}], ",", 
       RowBox[{"661", "\[Rule]", "1202"}], ",", 
       RowBox[{"661", "\[Rule]", "1202"}], ",", 
       RowBox[{"661", "\[Rule]", "230"}], ",", 
       RowBox[{"661", "\[Rule]", "230"}], ",", 
       RowBox[{"661", "\[Rule]", "1094"}], ",", 
       RowBox[{"661", "\[Rule]", "1094"}], ",", 
       RowBox[{"661", "\[Rule]", "662"}], ",", 
       RowBox[{"353", "\[Rule]", "786"}], ",", 
       RowBox[{"353", "\[Rule]", "786"}], ",", 
       RowBox[{"353", "\[Rule]", "678"}], ",", 
       RowBox[{"353", "\[Rule]", "678"}], ",", 
       RowBox[{"353", "\[Rule]", "354"}], ",", 
       RowBox[{"337", "\[Rule]", "770"}], ",", 
       RowBox[{"337", "\[Rule]", "770"}], ",", 
       RowBox[{"337", "\[Rule]", "662"}], ",", 
       RowBox[{"337", "\[Rule]", "662"}], ",", 
       RowBox[{"337", "\[Rule]", "338"}], ",", 
       RowBox[{"815", "\[Rule]", "384"}], ",", 
       RowBox[{"815", "\[Rule]", "384"}], ",", 
       RowBox[{"815", "\[Rule]", "1248"}], ",", 
       RowBox[{"815", "\[Rule]", "1248"}], ",", 
       RowBox[{"815", "\[Rule]", "816"}], ",", 
       RowBox[{"799", "\[Rule]", "368"}], ",", 
       RowBox[{"799", "\[Rule]", "368"}], ",", 
       RowBox[{"799", "\[Rule]", "1232"}], ",", 
       RowBox[{"799", "\[Rule]", "1232"}], ",", 
       RowBox[{"799", "\[Rule]", "800"}], ",", 
       RowBox[{"383", "\[Rule]", "816"}], ",", 
       RowBox[{"383", "\[Rule]", "816"}], ",", 
       RowBox[{"383", "\[Rule]", "708"}], ",", 
       RowBox[{"383", "\[Rule]", "708"}], ",", 
       RowBox[{"383", "\[Rule]", "384"}], ",", 
       RowBox[{"367", "\[Rule]", "800"}], ",", 
       RowBox[{"367", "\[Rule]", "800"}], ",", 
       RowBox[{"367", "\[Rule]", "692"}], ",", 
       RowBox[{"367", "\[Rule]", "692"}], ",", 
       RowBox[{"367", "\[Rule]", "368"}], ",", 
       RowBox[{"781", "\[Rule]", "350"}], ",", 
       RowBox[{"781", "\[Rule]", "350"}], ",", 
       RowBox[{"781", "\[Rule]", "1214"}], ",", 
       RowBox[{"781", "\[Rule]", "1214"}], ",", 
       RowBox[{"781", "\[Rule]", "782"}], ",", 
       RowBox[{"673", "\[Rule]", "350"}], ",", 
       RowBox[{"673", "\[Rule]", "350"}], ",", 
       RowBox[{"673", "\[Rule]", "1214"}], ",", 
       RowBox[{"673", "\[Rule]", "1214"}], ",", 
       RowBox[{"673", "\[Rule]", "242"}], ",", 
       RowBox[{"673", "\[Rule]", "242"}], ",", 
       RowBox[{"673", "\[Rule]", "1106"}], ",", 
       RowBox[{"673", "\[Rule]", "1106"}], ",", 
       RowBox[{"673", "\[Rule]", "674"}], ",", 
       RowBox[{"349", "\[Rule]", "782"}], ",", 
       RowBox[{"349", "\[Rule]", "782"}], ",", 
       RowBox[{"349", "\[Rule]", "674"}], ",", 
       RowBox[{"349", "\[Rule]", "674"}], ",", 
       RowBox[{"349", "\[Rule]", "350"}], ",", 
       RowBox[{"1649", "\[Rule]", "1218"}], ",", 
       RowBox[{"1649", "\[Rule]", "1218"}], ",", 
       RowBox[{"1649", "\[Rule]", "2082"}], ",", 
       RowBox[{"1649", "\[Rule]", "2082"}], ",", 
       RowBox[{"1649", "\[Rule]", "1650"}], ",", 
       RowBox[{"1633", "\[Rule]", "1202"}], ",", 
       RowBox[{"1633", "\[Rule]", "1202"}], ",", 
       RowBox[{"1633", "\[Rule]", "2066"}], ",", 
       RowBox[{"1633", "\[Rule]", "2066"}], ",", 
       RowBox[{"1633", "\[Rule]", "1634"}], ",", 
       RowBox[{"1525", "\[Rule]", "1202"}], ",", 
       RowBox[{"1525", "\[Rule]", "1202"}], ",", 
       RowBox[{"1525", "\[Rule]", "2066"}], ",", 
       RowBox[{"1525", "\[Rule]", "2066"}], ",", 
       RowBox[{"1525", "\[Rule]", "1094"}], ",", 
       RowBox[{"1525", "\[Rule]", "1094"}], ",", 
       RowBox[{"1525", "\[Rule]", "1958"}], ",", 
       RowBox[{"1525", "\[Rule]", "1958"}], ",", 
       RowBox[{"1525", "\[Rule]", "1526"}], ",", 
       RowBox[{"1217", "\[Rule]", "786"}], ",", 
       RowBox[{"1217", "\[Rule]", "786"}], ",", 
       RowBox[{"1217", "\[Rule]", "1650"}], ",", 
       RowBox[{"1217", "\[Rule]", "1650"}], ",", 
       RowBox[{"1217", "\[Rule]", "678"}], ",", 
       RowBox[{"1217", "\[Rule]", "678"}], ",", 
       RowBox[{"1217", "\[Rule]", "1542"}], ",", 
       RowBox[{"1217", "\[Rule]", "1542"}], ",", 
       RowBox[{"1217", "\[Rule]", "1218"}], ",", 
       RowBox[{"1201", "\[Rule]", "770"}], ",", 
       RowBox[{"1201", "\[Rule]", "770"}], ",", 
       RowBox[{"1201", "\[Rule]", "1634"}], ",", 
       RowBox[{"1201", "\[Rule]", "1634"}], ",", 
       RowBox[{"1201", "\[Rule]", "662"}], ",", 
       RowBox[{"1201", "\[Rule]", "662"}], ",", 
       RowBox[{"1201", "\[Rule]", "1526"}], ",", 
       RowBox[{"1201", "\[Rule]", "1526"}], ",", 
       RowBox[{"1201", "\[Rule]", "1202"}], ",", 
       RowBox[{"1679", "\[Rule]", "1248"}], ",", 
       RowBox[{"1679", "\[Rule]", "1248"}], ",", 
       RowBox[{"1679", "\[Rule]", "2112"}], ",", 
       RowBox[{"1679", "\[Rule]", "2112"}], ",", 
       RowBox[{"1679", "\[Rule]", "1680"}], ",", 
       RowBox[{"1663", "\[Rule]", "1232"}], ",", 
       RowBox[{"1663", "\[Rule]", "1232"}], ",", 
       RowBox[{"1663", "\[Rule]", "2096"}], ",", 
       RowBox[{"1663", "\[Rule]", "2096"}], ",", 
       RowBox[{"1663", "\[Rule]", "1664"}], ",", 
       RowBox[{"1247", "\[Rule]", "816"}], ",", 
       RowBox[{"1247", "\[Rule]", "816"}], ",", 
       RowBox[{"1247", "\[Rule]", "1680"}], ",", 
       RowBox[{"1247", "\[Rule]", "1680"}], ",", 
       RowBox[{"1247", "\[Rule]", "708"}], ",", 
       RowBox[{"1247", "\[Rule]", "708"}], ",", 
       RowBox[{"1247", "\[Rule]", "1572"}], ",", 
       RowBox[{"1247", "\[Rule]", "1572"}], ",", 
       RowBox[{"1247", "\[Rule]", "1248"}], ",", 
       RowBox[{"1231", "\[Rule]", "800"}], ",", 
       RowBox[{"1231", "\[Rule]", "800"}], ",", 
       RowBox[{"1231", "\[Rule]", "1664"}], ",", 
       RowBox[{"1231", "\[Rule]", "1664"}], ",", 
       RowBox[{"1231", "\[Rule]", "692"}], ",", 
       RowBox[{"1231", "\[Rule]", "692"}], ",", 
       RowBox[{"1231", "\[Rule]", "1556"}], ",", 
       RowBox[{"1231", "\[Rule]", "1556"}], ",", 
       RowBox[{"1231", "\[Rule]", "1232"}], ",", 
       RowBox[{"1645", "\[Rule]", "1214"}], ",", 
       RowBox[{"1645", "\[Rule]", "1214"}], ",", 
       RowBox[{"1645", "\[Rule]", "2078"}], ",", 
       RowBox[{"1645", "\[Rule]", "2078"}], ",", 
       RowBox[{"1645", "\[Rule]", "1646"}], ",", 
       RowBox[{"1537", "\[Rule]", "1214"}], ",", 
       RowBox[{"1537", "\[Rule]", "1214"}], ",", 
       RowBox[{"1537", "\[Rule]", "2078"}], ",", 
       RowBox[{"1537", "\[Rule]", "2078"}], ",", 
       RowBox[{"1537", "\[Rule]", "1106"}], ",", 
       RowBox[{"1537", "\[Rule]", "1106"}], ",", 
       RowBox[{"1537", "\[Rule]", "1970"}], ",", 
       RowBox[{"1537", "\[Rule]", "1970"}], ",", 
       RowBox[{"1537", "\[Rule]", "1538"}], ",", 
       RowBox[{"1213", "\[Rule]", "782"}], ",", 
       RowBox[{"1213", "\[Rule]", "782"}], ",", 
       RowBox[{"1213", "\[Rule]", "1646"}], ",", 
       RowBox[{"1213", "\[Rule]", "1646"}], ",", 
       RowBox[{"1213", "\[Rule]", "674"}], ",", 
       RowBox[{"1213", "\[Rule]", "674"}], ",", 
       RowBox[{"1213", "\[Rule]", "1538"}], ",", 
       RowBox[{"1213", "\[Rule]", "1538"}], ",", 
       RowBox[{"1213", "\[Rule]", "1214"}], ",", 
       RowBox[{"553", "\[Rule]", "230"}], ",", 
       RowBox[{"553", "\[Rule]", "230"}], ",", 
       RowBox[{"553", "\[Rule]", "1094"}], ",", 
       RowBox[{"553", "\[Rule]", "1094"}], ",", 
       RowBox[{"553", "\[Rule]", "122"}], ",", 
       RowBox[{"553", "\[Rule]", "986"}], ",", 
       RowBox[{"553", "\[Rule]", "554"}], ",", 
       RowBox[{"229", "\[Rule]", "662"}], ",", 
       RowBox[{"229", "\[Rule]", "662"}], ",", 
       RowBox[{"229", "\[Rule]", "554"}], ",", 
       RowBox[{"229", "\[Rule]", "554"}], ",", 
       RowBox[{"229", "\[Rule]", "230"}], ",", 
       RowBox[{"565", "\[Rule]", "242"}], ",", 
       RowBox[{"565", "\[Rule]", "242"}], ",", 
       RowBox[{"565", "\[Rule]", "1106"}], ",", 
       RowBox[{"565", "\[Rule]", "1106"}], ",", 
       RowBox[{"565", "\[Rule]", "134"}], ",", 
       RowBox[{"565", "\[Rule]", "998"}], ",", 
       RowBox[{"565", "\[Rule]", "566"}], ",", 
       RowBox[{"241", "\[Rule]", "674"}], ",", 
       RowBox[{"241", "\[Rule]", "674"}], ",", 
       RowBox[{"241", "\[Rule]", "566"}], ",", 
       RowBox[{"241", "\[Rule]", "566"}], ",", 
       RowBox[{"241", "\[Rule]", "242"}], ",", 
       RowBox[{"1417", "\[Rule]", "1094"}], ",", 
       RowBox[{"1417", "\[Rule]", "1094"}], ",", 
       RowBox[{"1417", "\[Rule]", "1958"}], ",", 
       RowBox[{"1417", "\[Rule]", "1958"}], ",", 
       RowBox[{"1417", "\[Rule]", "986"}], ",", 
       RowBox[{"1417", "\[Rule]", "986"}], ",", 
       RowBox[{"1417", "\[Rule]", "1850"}], ",", 
       RowBox[{"1417", "\[Rule]", "1850"}], ",", 
       RowBox[{"1417", "\[Rule]", "1418"}], ",", 
       RowBox[{"1093", "\[Rule]", "662"}], ",", 
       RowBox[{"1093", "\[Rule]", "662"}], ",", 
       RowBox[{"1093", "\[Rule]", "1526"}], ",", 
       RowBox[{"1093", "\[Rule]", "1526"}], ",", 
       RowBox[{"1093", "\[Rule]", "554"}], ",", 
       RowBox[{"1093", "\[Rule]", "554"}], ",", 
       RowBox[{"1093", "\[Rule]", "1418"}], ",", 
       RowBox[{"1093", "\[Rule]", "1418"}], ",", 
       RowBox[{"1093", "\[Rule]", "1094"}], ",", 
       RowBox[{"1429", "\[Rule]", "1106"}], ",", 
       RowBox[{"1429", "\[Rule]", "1106"}], ",", 
       RowBox[{"1429", "\[Rule]", "1970"}], ",", 
       RowBox[{"1429", "\[Rule]", "1970"}], ",", 
       RowBox[{"1429", "\[Rule]", "998"}], ",", 
       RowBox[{"1429", "\[Rule]", "998"}], ",", 
       RowBox[{"1429", "\[Rule]", "1862"}], ",", 
       RowBox[{"1429", "\[Rule]", "1862"}], ",", 
       RowBox[{"1429", "\[Rule]", "1430"}], ",", 
       RowBox[{"1105", "\[Rule]", "674"}], ",", 
       RowBox[{"1105", "\[Rule]", "674"}], ",", 
       RowBox[{"1105", "\[Rule]", "1538"}], ",", 
       RowBox[{"1105", "\[Rule]", "1538"}], ",", 
       RowBox[{"1105", "\[Rule]", "566"}], ",", 
       RowBox[{"1105", "\[Rule]", "566"}], ",", 
       RowBox[{"1105", "\[Rule]", "1430"}], ",", 
       RowBox[{"1105", "\[Rule]", "1430"}], ",", 
       RowBox[{"1105", "\[Rule]", "1106"}], ",", 
       RowBox[{"847", "\[Rule]", "416"}], ",", 
       RowBox[{"847", "\[Rule]", "416"}], ",", 
       RowBox[{"847", "\[Rule]", "1280"}], ",", 
       RowBox[{"847", "\[Rule]", "1280"}], ",", 
       RowBox[{"847", "\[Rule]", "848"}], ",", 
       RowBox[{"829", "\[Rule]", "398"}], ",", 
       RowBox[{"829", "\[Rule]", "398"}], ",", 
       RowBox[{"829", "\[Rule]", "1262"}], ",", 
       RowBox[{"829", "\[Rule]", "1262"}], ",", 
       RowBox[{"829", "\[Rule]", "830"}], ",", 
       RowBox[{"415", "\[Rule]", "848"}], ",", 
       RowBox[{"415", "\[Rule]", "848"}], ",", 
       RowBox[{"415", "\[Rule]", "740"}], ",", 
       RowBox[{"415", "\[Rule]", "740"}], ",", 
       RowBox[{"415", "\[Rule]", "416"}], ",", 
       RowBox[{"397", "\[Rule]", "830"}], ",", 
       RowBox[{"397", "\[Rule]", "830"}], ",", 
       RowBox[{"397", "\[Rule]", "722"}], ",", 
       RowBox[{"397", "\[Rule]", "722"}], ",", 
       RowBox[{"397", "\[Rule]", "398"}], ",", 
       RowBox[{"811", "\[Rule]", "380"}], ",", 
       RowBox[{"811", "\[Rule]", "380"}], ",", 
       RowBox[{"811", "\[Rule]", "1244"}], ",", 
       RowBox[{"811", "\[Rule]", "1244"}], ",", 
       RowBox[{"811", "\[Rule]", "812"}], ",", 
       RowBox[{"379", "\[Rule]", "812"}], ",", 
       RowBox[{"379", "\[Rule]", "812"}], ",", 
       RowBox[{"379", "\[Rule]", "704"}], ",", 
       RowBox[{"379", "\[Rule]", "704"}], ",", 
       RowBox[{"379", "\[Rule]", "380"}], ",", 
       RowBox[{"1711", "\[Rule]", "1280"}], ",", 
       RowBox[{"1711", "\[Rule]", "1280"}], ",", 
       RowBox[{"1711", "\[Rule]", "2144"}], ",", 
       RowBox[{"1711", "\[Rule]", "2144"}], ",", 
       RowBox[{"1711", "\[Rule]", "1712"}], ",", 
       RowBox[{"1693", "\[Rule]", "1262"}], ",", 
       RowBox[{"1693", "\[Rule]", "1262"}], ",", 
       RowBox[{"1693", "\[Rule]", "2126"}], ",", 
       RowBox[{"1693", "\[Rule]", "2126"}], ",", 
       RowBox[{"1693", "\[Rule]", "1694"}], ",", 
       RowBox[{"1279", "\[Rule]", "848"}], ",", 
       RowBox[{"1279", "\[Rule]", "848"}], ",", 
       RowBox[{"1279", "\[Rule]", "1712"}], ",", 
       RowBox[{"1279", "\[Rule]", "1712"}], ",", 
       RowBox[{"1279", "\[Rule]", "740"}], ",", 
       RowBox[{"1279", "\[Rule]", "740"}], ",", 
       RowBox[{"1279", "\[Rule]", "1604"}], ",", 
       RowBox[{"1279", "\[Rule]", "1604"}], ",", 
       RowBox[{"1279", "\[Rule]", "1280"}], ",", 
       RowBox[{"1261", "\[Rule]", "830"}], ",", 
       RowBox[{"1261", "\[Rule]", "830"}], ",", 
       RowBox[{"1261", "\[Rule]", "1694"}], ",", 
       RowBox[{"1261", "\[Rule]", "1694"}], ",", 
       RowBox[{"1261", "\[Rule]", "722"}], ",", 
       RowBox[{"1261", "\[Rule]", "722"}], ",", 
       RowBox[{"1261", "\[Rule]", "1586"}], ",", 
       RowBox[{"1261", "\[Rule]", "1586"}], ",", 
       RowBox[{"1261", "\[Rule]", "1262"}], ",", 
       RowBox[{"1675", "\[Rule]", "1244"}], ",", 
       RowBox[{"1675", "\[Rule]", "1244"}], ",", 
       RowBox[{"1675", "\[Rule]", "2108"}], ",", 
       RowBox[{"1675", "\[Rule]", "2108"}], ",", 
       RowBox[{"1675", "\[Rule]", "1676"}], ",", 
       RowBox[{"1243", "\[Rule]", "812"}], ",", 
       RowBox[{"1243", "\[Rule]", "812"}], ",", 
       RowBox[{"1243", "\[Rule]", "1676"}], ",", 
       RowBox[{"1243", "\[Rule]", "1676"}], ",", 
       RowBox[{"1243", "\[Rule]", "704"}], ",", 
       RowBox[{"1243", "\[Rule]", "704"}], ",", 
       RowBox[{"1243", "\[Rule]", "1568"}], ",", 
       RowBox[{"1243", "\[Rule]", "1568"}], ",", 
       RowBox[{"1243", "\[Rule]", "1244"}], ",", 
       RowBox[{"795", "\[Rule]", "364"}], ",", 
       RowBox[{"795", "\[Rule]", "364"}], ",", 
       RowBox[{"795", "\[Rule]", "1228"}], ",", 
       RowBox[{"795", "\[Rule]", "1228"}], ",", 
       RowBox[{"795", "\[Rule]", "796"}], ",", 
       RowBox[{"687", "\[Rule]", "364"}], ",", 
       RowBox[{"687", "\[Rule]", "364"}], ",", 
       RowBox[{"687", "\[Rule]", "1228"}], ",", 
       RowBox[{"687", "\[Rule]", "1228"}], ",", 
       RowBox[{"687", "\[Rule]", "256"}], ",", 
       RowBox[{"687", "\[Rule]", "256"}], ",", 
       RowBox[{"687", "\[Rule]", "1120"}], ",", 
       RowBox[{"687", "\[Rule]", "1120"}], ",", 
       RowBox[{"687", "\[Rule]", "688"}], ",", 
       RowBox[{"363", "\[Rule]", "796"}], ",", 
       RowBox[{"363", "\[Rule]", "796"}], ",", 
       RowBox[{"363", "\[Rule]", "688"}], ",", 
       RowBox[{"363", "\[Rule]", "688"}], ",", 
       RowBox[{"363", "\[Rule]", "364"}], ",", 
       RowBox[{"1659", "\[Rule]", "1228"}], ",", 
       RowBox[{"1659", "\[Rule]", "1228"}], ",", 
       RowBox[{"1659", "\[Rule]", "2092"}], ",", 
       RowBox[{"1659", "\[Rule]", "2092"}], ",", 
       RowBox[{"1659", "\[Rule]", "1660"}], ",", 
       RowBox[{"1551", "\[Rule]", "1228"}], ",", 
       RowBox[{"1551", "\[Rule]", "1228"}], ",", 
       RowBox[{"1551", "\[Rule]", "2092"}], ",", 
       RowBox[{"1551", "\[Rule]", "2092"}], ",", 
       RowBox[{"1551", "\[Rule]", "1120"}], ",", 
       RowBox[{"1551", "\[Rule]", "1120"}], ",", 
       RowBox[{"1551", "\[Rule]", "1984"}], ",", 
       RowBox[{"1551", "\[Rule]", "1984"}], ",", 
       RowBox[{"1551", "\[Rule]", "1552"}], ",", 
       RowBox[{"1227", "\[Rule]", "796"}], ",", 
       RowBox[{"1227", "\[Rule]", "796"}], ",", 
       RowBox[{"1227", "\[Rule]", "1660"}], ",", 
       RowBox[{"1227", "\[Rule]", "1660"}], ",", 
       RowBox[{"1227", "\[Rule]", "688"}], ",", 
       RowBox[{"1227", "\[Rule]", "688"}], ",", 
       RowBox[{"1227", "\[Rule]", "1552"}], ",", 
       RowBox[{"1227", "\[Rule]", "1552"}], ",", 
       RowBox[{"1227", "\[Rule]", "1228"}], ",", 
       RowBox[{"579", "\[Rule]", "256"}], ",", 
       RowBox[{"579", "\[Rule]", "256"}], ",", 
       RowBox[{"579", "\[Rule]", "1120"}], ",", 
       RowBox[{"579", "\[Rule]", "1120"}], ",", 
       RowBox[{"579", "\[Rule]", "148"}], ",", 
       RowBox[{"579", "\[Rule]", "1012"}], ",", 
       RowBox[{"579", "\[Rule]", "580"}], ",", 
       RowBox[{"255", "\[Rule]", "688"}], ",", 
       RowBox[{"255", "\[Rule]", "688"}], ",", 
       RowBox[{"255", "\[Rule]", "580"}], ",", 
       RowBox[{"255", "\[Rule]", "580"}], ",", 
       RowBox[{"255", "\[Rule]", "256"}], ",", 
       RowBox[{"1443", "\[Rule]", "1120"}], ",", 
       RowBox[{"1443", "\[Rule]", "1120"}], ",", 
       RowBox[{"1443", "\[Rule]", "1984"}], ",", 
       RowBox[{"1443", "\[Rule]", "1984"}], ",", 
       RowBox[{"1443", "\[Rule]", "1012"}], ",", 
       RowBox[{"1443", "\[Rule]", "1012"}], ",", 
       RowBox[{"1443", "\[Rule]", "1876"}], ",", 
       RowBox[{"1443", "\[Rule]", "1876"}], ",", 
       RowBox[{"1443", "\[Rule]", "1444"}], ",", 
       RowBox[{"1119", "\[Rule]", "688"}], ",", 
       RowBox[{"1119", "\[Rule]", "688"}], ",", 
       RowBox[{"1119", "\[Rule]", "1552"}], ",", 
       RowBox[{"1119", "\[Rule]", "1552"}], ",", 
       RowBox[{"1119", "\[Rule]", "580"}], ",", 
       RowBox[{"1119", "\[Rule]", "580"}], ",", 
       RowBox[{"1119", "\[Rule]", "1444"}], ",", 
       RowBox[{"1119", "\[Rule]", "1444"}], ",", 
       RowBox[{"1119", "\[Rule]", "1120"}], ",", 
       RowBox[{"445", "\[Rule]", "122"}], ",", 
       RowBox[{"445", "\[Rule]", "986"}], ",", 
       RowBox[{"445", "\[Rule]", "14"}], ",", 
       RowBox[{"445", "\[Rule]", "14"}], ",", 
       RowBox[{"445", "\[Rule]", "878"}], ",", 
       RowBox[{"445", "\[Rule]", "878"}], ",", 
       RowBox[{"445", "\[Rule]", "446"}], ",", 
       RowBox[{"121", "\[Rule]", "554"}], ",", 
       RowBox[{"121", "\[Rule]", "446"}], ",", 
       RowBox[{"121", "\[Rule]", "122"}], ",", 
       RowBox[{"457", "\[Rule]", "134"}], ",", 
       RowBox[{"457", "\[Rule]", "998"}], ",", 
       RowBox[{"457", "\[Rule]", "26"}], ",", 
       RowBox[{"457", "\[Rule]", "26"}], ",", 
       RowBox[{"457", "\[Rule]", "890"}], ",", 
       RowBox[{"457", "\[Rule]", "890"}], ",", 
       RowBox[{"457", "\[Rule]", "458"}], ",", 
       RowBox[{"133", "\[Rule]", "566"}], ",", 
       RowBox[{"133", "\[Rule]", "458"}], ",", 
       RowBox[{"133", "\[Rule]", "134"}], ",", 
       RowBox[{"1309", "\[Rule]", "986"}], ",", 
       RowBox[{"1309", "\[Rule]", "986"}], ",", 
       RowBox[{"1309", "\[Rule]", "1850"}], ",", 
       RowBox[{"1309", "\[Rule]", "1850"}], ",", 
       RowBox[{"1309", "\[Rule]", "878"}], ",", 
       RowBox[{"1309", "\[Rule]", "1742"}], ",", 
       RowBox[{"1309", "\[Rule]", "1310"}], ",", 
       RowBox[{"985", "\[Rule]", "554"}], ",", 
       RowBox[{"985", "\[Rule]", "1418"}], ",", 
       RowBox[{"985", "\[Rule]", "1418"}], ",", 
       RowBox[{"985", "\[Rule]", "446"}], ",", 
       RowBox[{"985", "\[Rule]", "1310"}], ",", 
       RowBox[{"985", "\[Rule]", "1310"}], ",", 
       RowBox[{"985", "\[Rule]", "986"}], ",", 
       RowBox[{"1321", "\[Rule]", "998"}], ",", 
       RowBox[{"1321", "\[Rule]", "998"}], ",", 
       RowBox[{"1321", "\[Rule]", "1862"}], ",", 
       RowBox[{"1321", "\[Rule]", "1862"}], ",", 
       RowBox[{"1321", "\[Rule]", "890"}], ",", 
       RowBox[{"1321", "\[Rule]", "1754"}], ",", 
       RowBox[{"1321", "\[Rule]", "1322"}], ",", 
       RowBox[{"997", "\[Rule]", "566"}], ",", 
       RowBox[{"997", "\[Rule]", "1430"}], ",", 
       RowBox[{"997", "\[Rule]", "1430"}], ",", 
       RowBox[{"997", "\[Rule]", "458"}], ",", 
       RowBox[{"997", "\[Rule]", "1322"}], ",", 
       RowBox[{"997", "\[Rule]", "1322"}], ",", 
       RowBox[{"997", "\[Rule]", "998"}], ",", 
       RowBox[{"471", "\[Rule]", "148"}], ",", 
       RowBox[{"471", "\[Rule]", "1012"}], ",", 
       RowBox[{"471", "\[Rule]", "40"}], ",", 
       RowBox[{"471", "\[Rule]", "40"}], ",", 
       RowBox[{"471", "\[Rule]", "904"}], ",", 
       RowBox[{"471", "\[Rule]", "904"}], ",", 
       RowBox[{"471", "\[Rule]", "472"}], ",", 
       RowBox[{"147", "\[Rule]", "580"}], ",", 
       RowBox[{"147", "\[Rule]", "472"}], ",", 
       RowBox[{"147", "\[Rule]", "148"}], ",", 
       RowBox[{"1335", "\[Rule]", "1012"}], ",", 
       RowBox[{"1335", "\[Rule]", "1012"}], ",", 
       RowBox[{"1335", "\[Rule]", "1876"}], ",", 
       RowBox[{"1335", "\[Rule]", "1876"}], ",", 
       RowBox[{"1335", "\[Rule]", "904"}], ",", 
       RowBox[{"1335", "\[Rule]", "1768"}], ",", 
       RowBox[{"1335", "\[Rule]", "1336"}], ",", 
       RowBox[{"1011", "\[Rule]", "580"}], ",", 
       RowBox[{"1011", "\[Rule]", "1444"}], ",", 
       RowBox[{"1011", "\[Rule]", "1444"}], ",", 
       RowBox[{"1011", "\[Rule]", "472"}], ",", 
       RowBox[{"1011", "\[Rule]", "1336"}], ",", 
       RowBox[{"1011", "\[Rule]", "1336"}], ",", 
       RowBox[{"1011", "\[Rule]", "1012"}], ",", 
       RowBox[{"861", "\[Rule]", "430"}], ",", 
       RowBox[{"861", "\[Rule]", "430"}], ",", 
       RowBox[{"861", "\[Rule]", "1294"}], ",", 
       RowBox[{"861", "\[Rule]", "1294"}], ",", 
       RowBox[{"861", "\[Rule]", "862"}], ",", 
       RowBox[{"429", "\[Rule]", "862"}], ",", 
       RowBox[{"429", "\[Rule]", "862"}], ",", 
       RowBox[{"429", "\[Rule]", "754"}], ",", 
       RowBox[{"429", "\[Rule]", "754"}], ",", 
       RowBox[{"429", "\[Rule]", "430"}], ",", 
       RowBox[{"843", "\[Rule]", "412"}], ",", 
       RowBox[{"843", "\[Rule]", "412"}], ",", 
       RowBox[{"843", "\[Rule]", "1276"}], ",", 
       RowBox[{"843", "\[Rule]", "1276"}], ",", 
       RowBox[{"843", "\[Rule]", "844"}], ",", 
       RowBox[{"411", "\[Rule]", "844"}], ",", 
       RowBox[{"411", "\[Rule]", "844"}], ",", 
       RowBox[{"411", "\[Rule]", "736"}], ",", 
       RowBox[{"411", "\[Rule]", "736"}], ",", 
       RowBox[{"411", "\[Rule]", "412"}], ",", 
       RowBox[{"1725", "\[Rule]", "1294"}], ",", 
       RowBox[{"1725", "\[Rule]", "1294"}], ",", 
       RowBox[{"1725", "\[Rule]", "2158"}], ",", 
       RowBox[{"1725", "\[Rule]", "2158"}], ",", 
       RowBox[{"1725", "\[Rule]", "1726"}], ",", 
       RowBox[{"1293", "\[Rule]", "862"}], ",", 
       RowBox[{"1293", "\[Rule]", "862"}], ",", 
       RowBox[{"1293", "\[Rule]", "1726"}], ",", 
       RowBox[{"1293", "\[Rule]", "1726"}], ",", 
       RowBox[{"1293", "\[Rule]", "754"}], ",", 
       RowBox[{"1293", "\[Rule]", "754"}], ",", 
       RowBox[{"1293", "\[Rule]", "1618"}], ",", 
       RowBox[{"1293", "\[Rule]", "1618"}], ",", 
       RowBox[{"1293", "\[Rule]", "1294"}], ",", 
       RowBox[{"1707", "\[Rule]", "1276"}], ",", 
       RowBox[{"1707", "\[Rule]", "1276"}], ",", 
       RowBox[{"1707", "\[Rule]", "2140"}], ",", 
       RowBox[{"1707", "\[Rule]", "2140"}], ",", 
       RowBox[{"1707", "\[Rule]", "1708"}], ",", 
       RowBox[{"1275", "\[Rule]", "844"}], ",", 
       RowBox[{"1275", "\[Rule]", "844"}], ",", 
       RowBox[{"1275", "\[Rule]", "1708"}], ",", 
       RowBox[{"1275", "\[Rule]", "1708"}], ",", 
       RowBox[{"1275", "\[Rule]", "736"}], ",", 
       RowBox[{"1275", "\[Rule]", "736"}], ",", 
       RowBox[{"1275", "\[Rule]", "1600"}], ",", 
       RowBox[{"1275", "\[Rule]", "1600"}], ",", 
       RowBox[{"1275", "\[Rule]", "1276"}], ",", 
       RowBox[{"825", "\[Rule]", "394"}], ",", 
       RowBox[{"825", "\[Rule]", "394"}], ",", 
       RowBox[{"825", "\[Rule]", "1258"}], ",", 
       RowBox[{"825", "\[Rule]", "1258"}], ",", 
       RowBox[{"825", "\[Rule]", "826"}], ",", 
       RowBox[{"393", "\[Rule]", "826"}], ",", 
       RowBox[{"393", "\[Rule]", "826"}], ",", 
       RowBox[{"393", "\[Rule]", "718"}], ",", 
       RowBox[{"393", "\[Rule]", "718"}], ",", 
       RowBox[{"393", "\[Rule]", "394"}], ",", 
       RowBox[{"1689", "\[Rule]", "1258"}], ",", 
       RowBox[{"1689", "\[Rule]", "1258"}], ",", 
       RowBox[{"1689", "\[Rule]", "2122"}], ",", 
       RowBox[{"1689", "\[Rule]", "2122"}], ",", 
       RowBox[{"1689", "\[Rule]", "1690"}], ",", 
       RowBox[{"1257", "\[Rule]", "826"}], ",", 
       RowBox[{"1257", "\[Rule]", "826"}], ",", 
       RowBox[{"1257", "\[Rule]", "1690"}], ",", 
       RowBox[{"1257", "\[Rule]", "1690"}], ",", 
       RowBox[{"1257", "\[Rule]", "718"}], ",", 
       RowBox[{"1257", "\[Rule]", "718"}], ",", 
       RowBox[{"1257", "\[Rule]", "1582"}], ",", 
       RowBox[{"1257", "\[Rule]", "1582"}], ",", 
       RowBox[{"1257", "\[Rule]", "1258"}], ",", 
       RowBox[{"807", "\[Rule]", "376"}], ",", 
       RowBox[{"807", "\[Rule]", "376"}], ",", 
       RowBox[{"807", "\[Rule]", "1240"}], ",", 
       RowBox[{"807", "\[Rule]", "1240"}], ",", 
       RowBox[{"807", "\[Rule]", "808"}], ",", 
       RowBox[{"699", "\[Rule]", "376"}], ",", 
       RowBox[{"699", "\[Rule]", "376"}], ",", 
       RowBox[{"699", "\[Rule]", "1240"}], ",", 
       RowBox[{"699", "\[Rule]", "1240"}], ",", 
       RowBox[{"699", "\[Rule]", "268"}], ",", 
       RowBox[{"699", "\[Rule]", "268"}], ",", 
       RowBox[{"699", "\[Rule]", "1132"}], ",", 
       RowBox[{"699", "\[Rule]", "1132"}], ",", 
       RowBox[{"699", "\[Rule]", "700"}], ",", 
       RowBox[{"375", "\[Rule]", "808"}], ",", 
       RowBox[{"375", "\[Rule]", "808"}], ",", 
       RowBox[{"375", "\[Rule]", "700"}], ",", 
       RowBox[{"375", "\[Rule]", "700"}], ",", 
       RowBox[{"375", "\[Rule]", "376"}], ",", 
       RowBox[{"1671", "\[Rule]", "1240"}], ",", 
       RowBox[{"1671", "\[Rule]", "1240"}], ",", 
       RowBox[{"1671", "\[Rule]", "2104"}], ",", 
       RowBox[{"1671", "\[Rule]", "2104"}], ",", 
       RowBox[{"1671", "\[Rule]", "1672"}], ",", 
       RowBox[{"1563", "\[Rule]", "1240"}], ",", 
       RowBox[{"1563", "\[Rule]", "1240"}], ",", 
       RowBox[{"1563", "\[Rule]", "2104"}], ",", 
       RowBox[{"1563", "\[Rule]", "2104"}], ",", 
       RowBox[{"1563", "\[Rule]", "1132"}], ",", 
       RowBox[{"1563", "\[Rule]", "1132"}], ",", 
       RowBox[{"1563", "\[Rule]", "1996"}], ",", 
       RowBox[{"1563", "\[Rule]", "1996"}], ",", 
       RowBox[{"1563", "\[Rule]", "1564"}], ",", 
       RowBox[{"1239", "\[Rule]", "808"}], ",", 
       RowBox[{"1239", "\[Rule]", "808"}], ",", 
       RowBox[{"1239", "\[Rule]", "1672"}], ",", 
       RowBox[{"1239", "\[Rule]", "1672"}], ",", 
       RowBox[{"1239", "\[Rule]", "700"}], ",", 
       RowBox[{"1239", "\[Rule]", "700"}], ",", 
       RowBox[{"1239", "\[Rule]", "1564"}], ",", 
       RowBox[{"1239", "\[Rule]", "1564"}], ",", 
       RowBox[{"1239", "\[Rule]", "1240"}], ",", 
       RowBox[{"591", "\[Rule]", "268"}], ",", 
       RowBox[{"591", "\[Rule]", "268"}], ",", 
       RowBox[{"591", "\[Rule]", "1132"}], ",", 
       RowBox[{"591", "\[Rule]", "1132"}], ",", 
       RowBox[{"591", "\[Rule]", "160"}], ",", 
       RowBox[{"591", "\[Rule]", "1024"}], ",", 
       RowBox[{"591", "\[Rule]", "592"}], ",", 
       RowBox[{"267", "\[Rule]", "700"}], ",", 
       RowBox[{"267", "\[Rule]", "700"}], ",", 
       RowBox[{"267", "\[Rule]", "592"}], ",", 
       RowBox[{"267", "\[Rule]", "592"}], ",", 
       RowBox[{"267", "\[Rule]", "268"}], ",", 
       RowBox[{"1455", "\[Rule]", "1132"}], ",", 
       RowBox[{"1455", "\[Rule]", "1132"}], ",", 
       RowBox[{"1455", "\[Rule]", "1996"}], ",", 
       RowBox[{"1455", "\[Rule]", "1996"}], ",", 
       RowBox[{"1455", "\[Rule]", "1024"}], ",", 
       RowBox[{"1455", "\[Rule]", "1024"}], ",", 
       RowBox[{"1455", "\[Rule]", "1888"}], ",", 
       RowBox[{"1455", "\[Rule]", "1888"}], ",", 
       RowBox[{"1455", "\[Rule]", "1456"}], ",", 
       RowBox[{"1131", "\[Rule]", "700"}], ",", 
       RowBox[{"1131", "\[Rule]", "700"}], ",", 
       RowBox[{"1131", "\[Rule]", "1564"}], ",", 
       RowBox[{"1131", "\[Rule]", "1564"}], ",", 
       RowBox[{"1131", "\[Rule]", "592"}], ",", 
       RowBox[{"1131", "\[Rule]", "592"}], ",", 
       RowBox[{"1131", "\[Rule]", "1456"}], ",", 
       RowBox[{"1131", "\[Rule]", "1456"}], ",", 
       RowBox[{"1131", "\[Rule]", "1132"}], ",", 
       RowBox[{"483", "\[Rule]", "160"}], ",", 
       RowBox[{"483", "\[Rule]", "1024"}], ",", 
       RowBox[{"483", "\[Rule]", "52"}], ",", 
       RowBox[{"483", "\[Rule]", "52"}], ",", 
       RowBox[{"483", "\[Rule]", "916"}], ",", 
       RowBox[{"483", "\[Rule]", "916"}], ",", 
       RowBox[{"483", "\[Rule]", "484"}], ",", 
       RowBox[{"159", "\[Rule]", "592"}], ",", 
       RowBox[{"159", "\[Rule]", "484"}], ",", 
       RowBox[{"159", "\[Rule]", "160"}], ",", 
       RowBox[{"1347", "\[Rule]", "1024"}], ",", 
       RowBox[{"1347", "\[Rule]", "1024"}], ",", 
       RowBox[{"1347", "\[Rule]", "1888"}], ",", 
       RowBox[{"1347", "\[Rule]", "1888"}], ",", 
       RowBox[{"1347", "\[Rule]", "916"}], ",", 
       RowBox[{"1347", "\[Rule]", "1780"}], ",", 
       RowBox[{"1347", "\[Rule]", "1348"}], ",", 
       RowBox[{"1023", "\[Rule]", "592"}], ",", 
       RowBox[{"1023", "\[Rule]", "1456"}], ",", 
       RowBox[{"1023", "\[Rule]", "1456"}], ",", 
       RowBox[{"1023", "\[Rule]", "484"}], ",", 
       RowBox[{"1023", "\[Rule]", "1348"}], ",", 
       RowBox[{"1023", "\[Rule]", "1348"}], ",", 
       RowBox[{"1023", "\[Rule]", "1024"}], ",", 
       RowBox[{"2513", "\[Rule]", "2082"}], ",", 
       RowBox[{"2513", "\[Rule]", "2082"}], ",", 
       RowBox[{"2513", "\[Rule]", "2946"}], ",", 
       RowBox[{"2513", "\[Rule]", "2946"}], ",", 
       RowBox[{"2513", "\[Rule]", "2514"}], ",", 
       RowBox[{"2497", "\[Rule]", "2066"}], ",", 
       RowBox[{"2497", "\[Rule]", "2066"}], ",", 
       RowBox[{"2497", "\[Rule]", "2930"}], ",", 
       RowBox[{"2497", "\[Rule]", "2930"}], ",", 
       RowBox[{"2497", "\[Rule]", "2498"}], ",", 
       RowBox[{"2389", "\[Rule]", "2066"}], ",", 
       RowBox[{"2389", "\[Rule]", "2066"}], ",", 
       RowBox[{"2389", "\[Rule]", "2930"}], ",", 
       RowBox[{"2389", "\[Rule]", "2930"}], ",", 
       RowBox[{"2389", "\[Rule]", "1958"}], ",", 
       RowBox[{"2389", "\[Rule]", "1958"}], ",", 
       RowBox[{"2389", "\[Rule]", "2822"}], ",", 
       RowBox[{"2389", "\[Rule]", "2822"}], ",", 
       RowBox[{"2389", "\[Rule]", "2390"}], ",", 
       RowBox[{"2081", "\[Rule]", "1650"}], ",", 
       RowBox[{"2081", "\[Rule]", "1650"}], ",", 
       RowBox[{"2081", "\[Rule]", "2514"}], ",", 
       RowBox[{"2081", "\[Rule]", "2514"}], ",", 
       RowBox[{"2081", "\[Rule]", "1542"}], ",", 
       RowBox[{"2081", "\[Rule]", "1542"}], ",", 
       RowBox[{"2081", "\[Rule]", "2406"}], ",", 
       RowBox[{"2081", "\[Rule]", "2406"}], ",", 
       RowBox[{"2081", "\[Rule]", "2082"}], ",", 
       RowBox[{"2065", "\[Rule]", "1634"}], ",", 
       RowBox[{"2065", "\[Rule]", "1634"}], ",", 
       RowBox[{"2065", "\[Rule]", "2498"}], ",", 
       RowBox[{"2065", "\[Rule]", "2498"}], ",", 
       RowBox[{"2065", "\[Rule]", "1526"}], ",", 
       RowBox[{"2065", "\[Rule]", "1526"}], ",", 
       RowBox[{"2065", "\[Rule]", "2390"}], ",", 
       RowBox[{"2065", "\[Rule]", "2390"}], ",", 
       RowBox[{"2065", "\[Rule]", "2066"}], ",", 
       RowBox[{"2543", "\[Rule]", "2112"}], ",", 
       RowBox[{"2543", "\[Rule]", "2112"}], ",", 
       RowBox[{"2543", "\[Rule]", "2976"}], ",", 
       RowBox[{"2543", "\[Rule]", "2976"}], ",", 
       RowBox[{"2543", "\[Rule]", "2544"}], ",", 
       RowBox[{"2527", "\[Rule]", "2096"}], ",", 
       RowBox[{"2527", "\[Rule]", "2096"}], ",", 
       RowBox[{"2527", "\[Rule]", "2960"}], ",", 
       RowBox[{"2527", "\[Rule]", "2960"}], ",", 
       RowBox[{"2527", "\[Rule]", "2528"}], ",", 
       RowBox[{"2111", "\[Rule]", "1680"}], ",", 
       RowBox[{"2111", "\[Rule]", "1680"}], ",", 
       RowBox[{"2111", "\[Rule]", "2544"}], ",", 
       RowBox[{"2111", "\[Rule]", "2544"}], ",", 
       RowBox[{"2111", "\[Rule]", "1572"}], ",", 
       RowBox[{"2111", "\[Rule]", "1572"}], ",", 
       RowBox[{"2111", "\[Rule]", "2436"}], ",", 
       RowBox[{"2111", "\[Rule]", "2436"}], ",", 
       RowBox[{"2111", "\[Rule]", "2112"}], ",", 
       RowBox[{"2095", "\[Rule]", "1664"}], ",", 
       RowBox[{"2095", "\[Rule]", "1664"}], ",", 
       RowBox[{"2095", "\[Rule]", "2528"}], ",", 
       RowBox[{"2095", "\[Rule]", "2528"}], ",", 
       RowBox[{"2095", "\[Rule]", "1556"}], ",", 
       RowBox[{"2095", "\[Rule]", "1556"}], ",", 
       RowBox[{"2095", "\[Rule]", "2420"}], ",", 
       RowBox[{"2095", "\[Rule]", "2420"}], ",", 
       RowBox[{"2095", "\[Rule]", "2096"}], ",", 
       RowBox[{"2509", "\[Rule]", "2078"}], ",", 
       RowBox[{"2509", "\[Rule]", "2078"}], ",", 
       RowBox[{"2509", "\[Rule]", "2942"}], ",", 
       RowBox[{"2509", "\[Rule]", "2942"}], ",", 
       RowBox[{"2509", "\[Rule]", "2510"}], ",", 
       RowBox[{"2401", "\[Rule]", "2078"}], ",", 
       RowBox[{"2401", "\[Rule]", "2078"}], ",", 
       RowBox[{"2401", "\[Rule]", "2942"}], ",", 
       RowBox[{"2401", "\[Rule]", "2942"}], ",", 
       RowBox[{"2401", "\[Rule]", "1970"}], ",", 
       RowBox[{"2401", "\[Rule]", "1970"}], ",", 
       RowBox[{"2401", "\[Rule]", "2834"}], ",", 
       RowBox[{"2401", "\[Rule]", "2834"}], ",", 
       RowBox[{"2401", "\[Rule]", "2402"}], ",", 
       RowBox[{"2077", "\[Rule]", "1646"}], ",", 
       RowBox[{"2077", "\[Rule]", "1646"}], ",", 
       RowBox[{"2077", "\[Rule]", "2510"}], ",", 
       RowBox[{"2077", "\[Rule]", "2510"}], ",", 
       RowBox[{"2077", "\[Rule]", "1538"}], ",", 
       RowBox[{"2077", "\[Rule]", "1538"}], ",", 
       RowBox[{"2077", "\[Rule]", "2402"}], ",", 
       RowBox[{"2077", "\[Rule]", "2402"}], ",", 
       RowBox[{"2077", "\[Rule]", "2078"}], ",", 
       RowBox[{"2281", "\[Rule]", "1958"}], ",", 
       RowBox[{"2281", "\[Rule]", "1958"}], ",", 
       RowBox[{"2281", "\[Rule]", "2822"}], ",", 
       RowBox[{"2281", "\[Rule]", "2822"}], ",", 
       RowBox[{"2281", "\[Rule]", "1850"}], ",", 
       RowBox[{"2281", "\[Rule]", "1850"}], ",", 
       RowBox[{"2281", "\[Rule]", "2714"}], ",", 
       RowBox[{"2281", "\[Rule]", "2714"}], ",", 
       RowBox[{"2281", "\[Rule]", "2282"}], ",", 
       RowBox[{"1957", "\[Rule]", "1526"}], ",", 
       RowBox[{"1957", "\[Rule]", "1526"}], ",", 
       RowBox[{"1957", "\[Rule]", "2390"}], ",", 
       RowBox[{"1957", "\[Rule]", "2390"}], ",", 
       RowBox[{"1957", "\[Rule]", "1418"}], ",", 
       RowBox[{"1957", "\[Rule]", "1418"}], ",", 
       RowBox[{"1957", "\[Rule]", "2282"}], ",", 
       RowBox[{"1957", "\[Rule]", "2282"}], ",", 
       RowBox[{"1957", "\[Rule]", "1958"}], ",", 
       RowBox[{"2293", "\[Rule]", "1970"}], ",", 
       RowBox[{"2293", "\[Rule]", "1970"}], ",", 
       RowBox[{"2293", "\[Rule]", "2834"}], ",", 
       RowBox[{"2293", "\[Rule]", "2834"}], ",", 
       RowBox[{"2293", "\[Rule]", "1862"}], ",", 
       RowBox[{"2293", "\[Rule]", "1862"}], ",", 
       RowBox[{"2293", "\[Rule]", "2726"}], ",", 
       RowBox[{"2293", "\[Rule]", "2726"}], ",", 
       RowBox[{"2293", "\[Rule]", "2294"}], ",", 
       RowBox[{"1969", "\[Rule]", "1538"}], ",", 
       RowBox[{"1969", "\[Rule]", "1538"}], ",", 
       RowBox[{"1969", "\[Rule]", "2402"}], ",", 
       RowBox[{"1969", "\[Rule]", "2402"}], ",", 
       RowBox[{"1969", "\[Rule]", "1430"}], ",", 
       RowBox[{"1969", "\[Rule]", "1430"}], ",", 
       RowBox[{"1969", "\[Rule]", "2294"}], ",", 
       RowBox[{"1969", "\[Rule]", "2294"}], ",", 
       RowBox[{"1969", "\[Rule]", "1970"}], ",", 
       RowBox[{"2575", "\[Rule]", "2144"}], ",", 
       RowBox[{"2575", "\[Rule]", "2144"}], ",", 
       RowBox[{"2575", "\[Rule]", "3008"}], ",", 
       RowBox[{"2575", "\[Rule]", "3008"}], ",", 
       RowBox[{"2575", "\[Rule]", "2576"}], ",", 
       RowBox[{"2557", "\[Rule]", "2126"}], ",", 
       RowBox[{"2557", "\[Rule]", "2126"}], ",", 
       RowBox[{"2557", "\[Rule]", "2990"}], ",", 
       RowBox[{"2557", "\[Rule]", "2990"}], ",", 
       RowBox[{"2557", "\[Rule]", "2558"}], ",", 
       RowBox[{"2143", "\[Rule]", "1712"}], ",", 
       RowBox[{"2143", "\[Rule]", "1712"}], ",", 
       RowBox[{"2143", "\[Rule]", "2576"}], ",", 
       RowBox[{"2143", "\[Rule]", "2576"}], ",", 
       RowBox[{"2143", "\[Rule]", "1604"}], ",", 
       RowBox[{"2143", "\[Rule]", "1604"}], ",", 
       RowBox[{"2143", "\[Rule]", "2468"}], ",", 
       RowBox[{"2143", "\[Rule]", "2468"}], ",", 
       RowBox[{"2143", "\[Rule]", "2144"}], ",", 
       RowBox[{"2125", "\[Rule]", "1694"}], ",", 
       RowBox[{"2125", "\[Rule]", "1694"}], ",", 
       RowBox[{"2125", "\[Rule]", "2558"}], ",", 
       RowBox[{"2125", "\[Rule]", "2558"}], ",", 
       RowBox[{"2125", "\[Rule]", "1586"}], ",", 
       RowBox[{"2125", "\[Rule]", "1586"}], ",", 
       RowBox[{"2125", "\[Rule]", "2450"}], ",", 
       RowBox[{"2125", "\[Rule]", "2450"}], ",", 
       RowBox[{"2125", "\[Rule]", "2126"}], ",", 
       RowBox[{"2539", "\[Rule]", "2108"}], ",", 
       RowBox[{"2539", "\[Rule]", "2108"}], ",", 
       RowBox[{"2539", "\[Rule]", "2972"}], ",", 
       RowBox[{"2539", "\[Rule]", "2972"}], ",", 
       RowBox[{"2539", "\[Rule]", "2540"}], ",", 
       RowBox[{"2107", "\[Rule]", "1676"}], ",", 
       RowBox[{"2107", "\[Rule]", "1676"}], ",", 
       RowBox[{"2107", "\[Rule]", "2540"}], ",", 
       RowBox[{"2107", "\[Rule]", "2540"}], ",", 
       RowBox[{"2107", "\[Rule]", "1568"}], ",", 
       RowBox[{"2107", "\[Rule]", "1568"}], ",", 
       RowBox[{"2107", "\[Rule]", "2432"}], ",", 
       RowBox[{"2107", "\[Rule]", "2432"}], ",", 
       RowBox[{"2107", "\[Rule]", "2108"}], ",", 
       RowBox[{"2523", "\[Rule]", "2092"}], ",", 
       RowBox[{"2523", "\[Rule]", "2092"}], ",", 
       RowBox[{"2523", "\[Rule]", "2956"}], ",", 
       RowBox[{"2523", "\[Rule]", "2956"}], ",", 
       RowBox[{"2523", "\[Rule]", "2524"}], ",", 
       RowBox[{"2415", "\[Rule]", "2092"}], ",", 
       RowBox[{"2415", "\[Rule]", "2092"}], ",", 
       RowBox[{"2415", "\[Rule]", "2956"}], ",", 
       RowBox[{"2415", "\[Rule]", "2956"}], ",", 
       RowBox[{"2415", "\[Rule]", "1984"}], ",", 
       RowBox[{"2415", "\[Rule]", "1984"}], ",", 
       RowBox[{"2415", "\[Rule]", "2848"}], ",", 
       RowBox[{"2415", "\[Rule]", "2848"}], ",", 
       RowBox[{"2415", "\[Rule]", "2416"}], ",", 
       RowBox[{"2091", "\[Rule]", "1660"}], ",", 
       RowBox[{"2091", "\[Rule]", "1660"}], ",", 
       RowBox[{"2091", "\[Rule]", "2524"}], ",", 
       RowBox[{"2091", "\[Rule]", "2524"}], ",", 
       RowBox[{"2091", "\[Rule]", "1552"}], ",", 
       RowBox[{"2091", "\[Rule]", "1552"}], ",", 
       RowBox[{"2091", "\[Rule]", "2416"}], ",", 
       RowBox[{"2091", "\[Rule]", "2416"}], ",", 
       RowBox[{"2091", "\[Rule]", "2092"}], ",", 
       RowBox[{"2307", "\[Rule]", "1984"}], ",", 
       RowBox[{"2307", "\[Rule]", "1984"}], ",", 
       RowBox[{"2307", "\[Rule]", "2848"}], ",", 
       RowBox[{"2307", "\[Rule]", "2848"}], ",", 
       RowBox[{"2307", "\[Rule]", "1876"}], ",", 
       RowBox[{"2307", "\[Rule]", "1876"}], ",", 
       RowBox[{"2307", "\[Rule]", "2740"}], ",", 
       RowBox[{"2307", "\[Rule]", "2740"}], ",", 
       RowBox[{"2307", "\[Rule]", "2308"}], ",", 
       RowBox[{"1983", "\[Rule]", "1552"}], ",", 
       RowBox[{"1983", "\[Rule]", "1552"}], ",", 
       RowBox[{"1983", "\[Rule]", "2416"}], ",", 
       RowBox[{"1983", "\[Rule]", "2416"}], ",", 
       RowBox[{"1983", "\[Rule]", "1444"}], ",", 
       RowBox[{"1983", "\[Rule]", "1444"}], ",", 
       RowBox[{"1983", "\[Rule]", "2308"}], ",", 
       RowBox[{"1983", "\[Rule]", "2308"}], ",", 
       RowBox[{"1983", "\[Rule]", "1984"}], ",", 
       RowBox[{"2173", "\[Rule]", "1850"}], ",", 
       RowBox[{"2173", "\[Rule]", "1850"}], ",", 
       RowBox[{"2173", "\[Rule]", "2714"}], ",", 
       RowBox[{"2173", "\[Rule]", "2714"}], ",", 
       RowBox[{"2173", "\[Rule]", "1742"}], ",", 
       RowBox[{"2173", "\[Rule]", "1742"}], ",", 
       RowBox[{"2173", "\[Rule]", "2606"}], ",", 
       RowBox[{"2173", "\[Rule]", "2606"}], ",", 
       RowBox[{"2173", "\[Rule]", "2174"}], ",", 
       RowBox[{"1849", "\[Rule]", "1418"}], ",", 
       RowBox[{"1849", "\[Rule]", "1418"}], ",", 
       RowBox[{"1849", "\[Rule]", "2282"}], ",", 
       RowBox[{"1849", "\[Rule]", "2282"}], ",", 
       RowBox[{"1849", "\[Rule]", "1310"}], ",", 
       RowBox[{"1849", "\[Rule]", "1310"}], ",", 
       RowBox[{"1849", "\[Rule]", "2174"}], ",", 
       RowBox[{"1849", "\[Rule]", "2174"}], ",", 
       RowBox[{"1849", "\[Rule]", "1850"}], ",", 
       RowBox[{"2185", "\[Rule]", "1862"}], ",", 
       RowBox[{"2185", "\[Rule]", "1862"}], ",", 
       RowBox[{"2185", "\[Rule]", "2726"}], ",", 
       RowBox[{"2185", "\[Rule]", "2726"}], ",", 
       RowBox[{"2185", "\[Rule]", "1754"}], ",", 
       RowBox[{"2185", "\[Rule]", "1754"}], ",", 
       RowBox[{"2185", "\[Rule]", "2618"}], ",", 
       RowBox[{"2185", "\[Rule]", "2618"}], ",", 
       RowBox[{"2185", "\[Rule]", "2186"}], ",", 
       RowBox[{"1861", "\[Rule]", "1430"}], ",", 
       RowBox[{"1861", "\[Rule]", "1430"}], ",", 
       RowBox[{"1861", "\[Rule]", "2294"}], ",", 
       RowBox[{"1861", "\[Rule]", "2294"}], ",", 
       RowBox[{"1861", "\[Rule]", "1322"}], ",", 
       RowBox[{"1861", "\[Rule]", "1322"}], ",", 
       RowBox[{"1861", "\[Rule]", "2186"}], ",", 
       RowBox[{"1861", "\[Rule]", "2186"}], ",", 
       RowBox[{"1861", "\[Rule]", "1862"}], ",", 
       RowBox[{"2199", "\[Rule]", "1876"}], ",", 
       RowBox[{"2199", "\[Rule]", "1876"}], ",", 
       RowBox[{"2199", "\[Rule]", "2740"}], ",", 
       RowBox[{"2199", "\[Rule]", "2740"}], ",", 
       RowBox[{"2199", "\[Rule]", "1768"}], ",", 
       RowBox[{"2199", "\[Rule]", "1768"}], ",", 
       RowBox[{"2199", "\[Rule]", "2632"}], ",", 
       RowBox[{"2199", "\[Rule]", "2632"}], ",", 
       RowBox[{"2199", "\[Rule]", "2200"}], ",", 
       RowBox[{"1875", "\[Rule]", "1444"}], ",", 
       RowBox[{"1875", "\[Rule]", "1444"}], ",", 
       RowBox[{"1875", "\[Rule]", "2308"}], ",", 
       RowBox[{"1875", "\[Rule]", "2308"}], ",", 
       RowBox[{"1875", "\[Rule]", "1336"}], ",", 
       RowBox[{"1875", "\[Rule]", "1336"}], ",", 
       RowBox[{"1875", "\[Rule]", "2200"}], ",", 
       RowBox[{"1875", "\[Rule]", "2200"}], ",", 
       RowBox[{"1875", "\[Rule]", "1876"}], ",", 
       RowBox[{"2589", "\[Rule]", "2158"}], ",", 
       RowBox[{"2589", "\[Rule]", "2158"}], ",", 
       RowBox[{"2589", "\[Rule]", "3022"}], ",", 
       RowBox[{"2589", "\[Rule]", "3022"}], ",", 
       RowBox[{"2589", "\[Rule]", "2590"}], ",", 
       RowBox[{"2157", "\[Rule]", "1726"}], ",", 
       RowBox[{"2157", "\[Rule]", "1726"}], ",", 
       RowBox[{"2157", "\[Rule]", "2590"}], ",", 
       RowBox[{"2157", "\[Rule]", "2590"}], ",", 
       RowBox[{"2157", "\[Rule]", "1618"}], ",", 
       RowBox[{"2157", "\[Rule]", "1618"}], ",", 
       RowBox[{"2157", "\[Rule]", "2482"}], ",", 
       RowBox[{"2157", "\[Rule]", "2482"}], ",", 
       RowBox[{"2157", "\[Rule]", "2158"}], ",", 
       RowBox[{"2571", "\[Rule]", "2140"}], ",", 
       RowBox[{"2571", "\[Rule]", "2140"}], ",", 
       RowBox[{"2571", "\[Rule]", "3004"}], ",", 
       RowBox[{"2571", "\[Rule]", "3004"}], ",", 
       RowBox[{"2571", "\[Rule]", "2572"}], ",", 
       RowBox[{"2139", "\[Rule]", "1708"}], ",", 
       RowBox[{"2139", "\[Rule]", "1708"}], ",", 
       RowBox[{"2139", "\[Rule]", "2572"}], ",", 
       RowBox[{"2139", "\[Rule]", "2572"}], ",", 
       RowBox[{"2139", "\[Rule]", "1600"}], ",", 
       RowBox[{"2139", "\[Rule]", "1600"}], ",", 
       RowBox[{"2139", "\[Rule]", "2464"}], ",", 
       RowBox[{"2139", "\[Rule]", "2464"}], ",", 
       RowBox[{"2139", "\[Rule]", "2140"}], ",", 
       RowBox[{"2553", "\[Rule]", "2122"}], ",", 
       RowBox[{"2553", "\[Rule]", "2122"}], ",", 
       RowBox[{"2553", "\[Rule]", "2986"}], ",", 
       RowBox[{"2553", "\[Rule]", "2986"}], ",", 
       RowBox[{"2553", "\[Rule]", "2554"}], ",", 
       RowBox[{"2121", "\[Rule]", "1690"}], ",", 
       RowBox[{"2121", "\[Rule]", "1690"}], ",", 
       RowBox[{"2121", "\[Rule]", "2554"}], ",", 
       RowBox[{"2121", "\[Rule]", "2554"}], ",", 
       RowBox[{"2121", "\[Rule]", "1582"}], ",", 
       RowBox[{"2121", "\[Rule]", "1582"}], ",", 
       RowBox[{"2121", "\[Rule]", "2446"}], ",", 
       RowBox[{"2121", "\[Rule]", "2446"}], ",", 
       RowBox[{"2121", "\[Rule]", "2122"}], ",", 
       RowBox[{"2535", "\[Rule]", "2104"}], ",", 
       RowBox[{"2535", "\[Rule]", "2104"}], ",", 
       RowBox[{"2535", "\[Rule]", "2968"}], ",", 
       RowBox[{"2535", "\[Rule]", "2968"}], ",", 
       RowBox[{"2535", "\[Rule]", "2536"}], ",", 
       RowBox[{"2427", "\[Rule]", "2104"}], ",", 
       RowBox[{"2427", "\[Rule]", "2104"}], ",", 
       RowBox[{"2427", "\[Rule]", "2968"}], ",", 
       RowBox[{"2427", "\[Rule]", "2968"}], ",", 
       RowBox[{"2427", "\[Rule]", "1996"}], ",", 
       RowBox[{"2427", "\[Rule]", "1996"}], ",", 
       RowBox[{"2427", "\[Rule]", "2860"}], ",", 
       RowBox[{"2427", "\[Rule]", "2860"}], ",", 
       RowBox[{"2427", "\[Rule]", "2428"}], ",", 
       RowBox[{"2103", "\[Rule]", "1672"}], ",", 
       RowBox[{"2103", "\[Rule]", "1672"}], ",", 
       RowBox[{"2103", "\[Rule]", "2536"}], ",", 
       RowBox[{"2103", "\[Rule]", "2536"}], ",", 
       RowBox[{"2103", "\[Rule]", "1564"}], ",", 
       RowBox[{"2103", "\[Rule]", "1564"}], ",", 
       RowBox[{"2103", "\[Rule]", "2428"}], ",", 
       RowBox[{"2103", "\[Rule]", "2428"}], ",", 
       RowBox[{"2103", "\[Rule]", "2104"}], ",", 
       RowBox[{"2319", "\[Rule]", "1996"}], ",", 
       RowBox[{"2319", "\[Rule]", "1996"}], ",", 
       RowBox[{"2319", "\[Rule]", "2860"}], ",", 
       RowBox[{"2319", "\[Rule]", "2860"}], ",", 
       RowBox[{"2319", "\[Rule]", "1888"}], ",", 
       RowBox[{"2319", "\[Rule]", "1888"}], ",", 
       RowBox[{"2319", "\[Rule]", "2752"}], ",", 
       RowBox[{"2319", "\[Rule]", "2752"}], ",", 
       RowBox[{"2319", "\[Rule]", "2320"}], ",", 
       RowBox[{"1995", "\[Rule]", "1564"}], ",", 
       RowBox[{"1995", "\[Rule]", "1564"}], ",", 
       RowBox[{"1995", "\[Rule]", "2428"}], ",", 
       RowBox[{"1995", "\[Rule]", "2428"}], ",", 
       RowBox[{"1995", "\[Rule]", "1456"}], ",", 
       RowBox[{"1995", "\[Rule]", "1456"}], ",", 
       RowBox[{"1995", "\[Rule]", "2320"}], ",", 
       RowBox[{"1995", "\[Rule]", "2320"}], ",", 
       RowBox[{"1995", "\[Rule]", "1996"}], ",", 
       RowBox[{"2211", "\[Rule]", "1888"}], ",", 
       RowBox[{"2211", "\[Rule]", "1888"}], ",", 
       RowBox[{"2211", "\[Rule]", "2752"}], ",", 
       RowBox[{"2211", "\[Rule]", "2752"}], ",", 
       RowBox[{"2211", "\[Rule]", "1780"}], ",", 
       RowBox[{"2211", "\[Rule]", "1780"}], ",", 
       RowBox[{"2211", "\[Rule]", "2644"}], ",", 
       RowBox[{"2211", "\[Rule]", "2644"}], ",", 
       RowBox[{"2211", "\[Rule]", "2212"}], ",", 
       RowBox[{"1887", "\[Rule]", "1456"}], ",", 
       RowBox[{"1887", "\[Rule]", "1456"}], ",", 
       RowBox[{"1887", "\[Rule]", "2320"}], ",", 
       RowBox[{"1887", "\[Rule]", "2320"}], ",", 
       RowBox[{"1887", "\[Rule]", "1348"}], ",", 
       RowBox[{"1887", "\[Rule]", "1348"}], ",", 
       RowBox[{"1887", "\[Rule]", "2212"}], ",", 
       RowBox[{"1887", "\[Rule]", "2212"}], ",", 
       RowBox[{"1887", "\[Rule]", "1888"}], ",", 
       RowBox[{"13", "\[Rule]", "446"}], ",", 
       RowBox[{"13", "\[Rule]", "446"}], ",", 
       RowBox[{"13", "\[Rule]", "14"}], ",", 
       RowBox[{"25", "\[Rule]", "458"}], ",", 
       RowBox[{"25", "\[Rule]", "458"}], ",", 
       RowBox[{"25", "\[Rule]", "26"}], ",", 
       RowBox[{"877", "\[Rule]", "446"}], ",", 
       RowBox[{"877", "\[Rule]", "446"}], ",", 
       RowBox[{"877", "\[Rule]", "1310"}], ",", 
       RowBox[{"877", "\[Rule]", "878"}], ",", 
       RowBox[{"889", "\[Rule]", "458"}], ",", 
       RowBox[{"889", "\[Rule]", "458"}], ",", 
       RowBox[{"889", "\[Rule]", "1322"}], ",", 
       RowBox[{"889", "\[Rule]", "890"}], ",", 
       RowBox[{"39", "\[Rule]", "472"}], ",", 
       RowBox[{"39", "\[Rule]", "472"}], ",", 
       RowBox[{"39", "\[Rule]", "40"}], ",", 
       RowBox[{"903", "\[Rule]", "472"}], ",", 
       RowBox[{"903", "\[Rule]", "472"}], ",", 
       RowBox[{"903", "\[Rule]", "1336"}], ",", 
       RowBox[{"903", "\[Rule]", "904"}], ",", 
       RowBox[{"51", "\[Rule]", "484"}], ",", 
       RowBox[{"51", "\[Rule]", "484"}], ",", 
       RowBox[{"51", "\[Rule]", "52"}], ",", 
       RowBox[{"915", "\[Rule]", "484"}], ",", 
       RowBox[{"915", "\[Rule]", "484"}], ",", 
       RowBox[{"915", "\[Rule]", "1348"}], ",", 
       RowBox[{"915", "\[Rule]", "916"}], ",", 
       RowBox[{"1741", "\[Rule]", "1310"}], ",", 
       RowBox[{"1741", "\[Rule]", "2174"}], ",", 
       RowBox[{"1741", "\[Rule]", "2174"}], ",", 
       RowBox[{"1741", "\[Rule]", "1742"}], ",", 
       RowBox[{"1753", "\[Rule]", "1322"}], ",", 
       RowBox[{"1753", "\[Rule]", "2186"}], ",", 
       RowBox[{"1753", "\[Rule]", "2186"}], ",", 
       RowBox[{"1753", "\[Rule]", "1754"}], ",", 
       RowBox[{"1767", "\[Rule]", "1336"}], ",", 
       RowBox[{"1767", "\[Rule]", "2200"}], ",", 
       RowBox[{"1767", "\[Rule]", "2200"}], ",", 
       RowBox[{"1767", "\[Rule]", "1768"}], ",", 
       RowBox[{"1779", "\[Rule]", "1348"}], ",", 
       RowBox[{"1779", "\[Rule]", "2212"}], ",", 
       RowBox[{"1779", "\[Rule]", "2212"}], ",", 
       RowBox[{"1779", "\[Rule]", "1780"}], ",", 
       RowBox[{"857", "\[Rule]", "426"}], ",", 
       RowBox[{"857", "\[Rule]", "426"}], ",", 
       RowBox[{"857", "\[Rule]", "1290"}], ",", 
       RowBox[{"857", "\[Rule]", "1290"}], ",", 
       RowBox[{"857", "\[Rule]", "858"}], ",", 
       RowBox[{"425", "\[Rule]", "858"}], ",", 
       RowBox[{"425", "\[Rule]", "858"}], ",", 
       RowBox[{"425", "\[Rule]", "750"}], ",", 
       RowBox[{"425", "\[Rule]", "750"}], ",", 
       RowBox[{"425", "\[Rule]", "426"}], ",", 
       RowBox[{"1721", "\[Rule]", "1290"}], ",", 
       RowBox[{"1721", "\[Rule]", "1290"}], ",", 
       RowBox[{"1721", "\[Rule]", "2154"}], ",", 
       RowBox[{"1721", "\[Rule]", "2154"}], ",", 
       RowBox[{"1721", "\[Rule]", "1722"}], ",", 
       RowBox[{"1289", "\[Rule]", "858"}], ",", 
       RowBox[{"1289", "\[Rule]", "858"}], ",", 
       RowBox[{"1289", "\[Rule]", "1722"}], ",", 
       RowBox[{"1289", "\[Rule]", "1722"}], ",", 
       RowBox[{"1289", "\[Rule]", "750"}], ",", 
       RowBox[{"1289", "\[Rule]", "750"}], ",", 
       RowBox[{"1289", "\[Rule]", "1614"}], ",", 
       RowBox[{"1289", "\[Rule]", "1614"}], ",", 
       RowBox[{"1289", "\[Rule]", "1290"}], ",", 
       RowBox[{"839", "\[Rule]", "408"}], ",", 
       RowBox[{"839", "\[Rule]", "408"}], ",", 
       RowBox[{"839", "\[Rule]", "1272"}], ",", 
       RowBox[{"839", "\[Rule]", "1272"}], ",", 
       RowBox[{"839", "\[Rule]", "840"}], ",", 
       RowBox[{"407", "\[Rule]", "840"}], ",", 
       RowBox[{"407", "\[Rule]", "840"}], ",", 
       RowBox[{"407", "\[Rule]", "732"}], ",", 
       RowBox[{"407", "\[Rule]", "732"}], ",", 
       RowBox[{"407", "\[Rule]", "408"}], ",", 
       RowBox[{"1703", "\[Rule]", "1272"}], ",", 
       RowBox[{"1703", "\[Rule]", "1272"}], ",", 
       RowBox[{"1703", "\[Rule]", "2136"}], ",", 
       RowBox[{"1703", "\[Rule]", "2136"}], ",", 
       RowBox[{"1703", "\[Rule]", "1704"}], ",", 
       RowBox[{"1271", "\[Rule]", "840"}], ",", 
       RowBox[{"1271", "\[Rule]", "840"}], ",", 
       RowBox[{"1271", "\[Rule]", "1704"}], ",", 
       RowBox[{"1271", "\[Rule]", "1704"}], ",", 
       RowBox[{"1271", "\[Rule]", "732"}], ",", 
       RowBox[{"1271", "\[Rule]", "732"}], ",", 
       RowBox[{"1271", "\[Rule]", "1596"}], ",", 
       RowBox[{"1271", "\[Rule]", "1596"}], ",", 
       RowBox[{"1271", "\[Rule]", "1272"}], ",", 
       RowBox[{"2585", "\[Rule]", "2154"}], ",", 
       RowBox[{"2585", "\[Rule]", "2154"}], ",", 
       RowBox[{"2585", "\[Rule]", "3018"}], ",", 
       RowBox[{"2585", "\[Rule]", "3018"}], ",", 
       RowBox[{"2585", "\[Rule]", "2586"}], ",", 
       RowBox[{"2153", "\[Rule]", "1722"}], ",", 
       RowBox[{"2153", "\[Rule]", "1722"}], ",", 
       RowBox[{"2153", "\[Rule]", "2586"}], ",", 
       RowBox[{"2153", "\[Rule]", "2586"}], ",", 
       RowBox[{"2153", "\[Rule]", "1614"}], ",", 
       RowBox[{"2153", "\[Rule]", "1614"}], ",", 
       RowBox[{"2153", "\[Rule]", "2478"}], ",", 
       RowBox[{"2153", "\[Rule]", "2478"}], ",", 
       RowBox[{"2153", "\[Rule]", "2154"}], ",", 
       RowBox[{"2567", "\[Rule]", "2136"}], ",", 
       RowBox[{"2567", "\[Rule]", "2136"}], ",", 
       RowBox[{"2567", "\[Rule]", "3000"}], ",", 
       RowBox[{"2567", "\[Rule]", "3000"}], ",", 
       RowBox[{"2567", "\[Rule]", "2568"}], ",", 
       RowBox[{"2135", "\[Rule]", "1704"}], ",", 
       RowBox[{"2135", "\[Rule]", "1704"}], ",", 
       RowBox[{"2135", "\[Rule]", "2568"}], ",", 
       RowBox[{"2135", "\[Rule]", "2568"}], ",", 
       RowBox[{"2135", "\[Rule]", "1596"}], ",", 
       RowBox[{"2135", "\[Rule]", "1596"}], ",", 
       RowBox[{"2135", "\[Rule]", "2460"}], ",", 
       RowBox[{"2135", "\[Rule]", "2460"}], ",", 
       RowBox[{"2135", "\[Rule]", "2136"}], ",", 
       RowBox[{"821", "\[Rule]", "390"}], ",", 
       RowBox[{"821", "\[Rule]", "390"}], ",", 
       RowBox[{"821", "\[Rule]", "1254"}], ",", 
       RowBox[{"821", "\[Rule]", "1254"}], ",", 
       RowBox[{"821", "\[Rule]", "822"}], ",", 
       RowBox[{"713", "\[Rule]", "390"}], ",", 
       RowBox[{"713", "\[Rule]", "390"}], ",", 
       RowBox[{"713", "\[Rule]", "1254"}], ",", 
       RowBox[{"713", "\[Rule]", "1254"}], ",", 
       RowBox[{"713", "\[Rule]", "282"}], ",", 
       RowBox[{"713", "\[Rule]", "282"}], ",", 
       RowBox[{"713", "\[Rule]", "1146"}], ",", 
       RowBox[{"713", "\[Rule]", "1146"}], ",", 
       RowBox[{"713", "\[Rule]", "714"}], ",", 
       RowBox[{"389", "\[Rule]", "822"}], ",", 
       RowBox[{"389", "\[Rule]", "822"}], ",", 
       RowBox[{"389", "\[Rule]", "714"}], ",", 
       RowBox[{"389", "\[Rule]", "714"}], ",", 
       RowBox[{"389", "\[Rule]", "390"}], ",", 
       RowBox[{"1685", "\[Rule]", "1254"}], ",", 
       RowBox[{"1685", "\[Rule]", "1254"}], ",", 
       RowBox[{"1685", "\[Rule]", "2118"}], ",", 
       RowBox[{"1685", "\[Rule]", "2118"}], ",", 
       RowBox[{"1685", "\[Rule]", "1686"}], ",", 
       RowBox[{"1577", "\[Rule]", "1254"}], ",", 
       RowBox[{"1577", "\[Rule]", "1254"}], ",", 
       RowBox[{"1577", "\[Rule]", "2118"}], ",", 
       RowBox[{"1577", "\[Rule]", "2118"}], ",", 
       RowBox[{"1577", "\[Rule]", "1146"}], ",", 
       RowBox[{"1577", "\[Rule]", "1146"}], ",", 
       RowBox[{"1577", "\[Rule]", "2010"}], ",", 
       RowBox[{"1577", "\[Rule]", "2010"}], ",", 
       RowBox[{"1577", "\[Rule]", "1578"}], ",", 
       RowBox[{"1253", "\[Rule]", "822"}], ",", 
       RowBox[{"1253", "\[Rule]", "822"}], ",", 
       RowBox[{"1253", "\[Rule]", "1686"}], ",", 
       RowBox[{"1253", "\[Rule]", "1686"}], ",", 
       RowBox[{"1253", "\[Rule]", "714"}], ",", 
       RowBox[{"1253", "\[Rule]", "714"}], ",", 
       RowBox[{"1253", "\[Rule]", "1578"}], ",", 
       RowBox[{"1253", "\[Rule]", "1578"}], ",", 
       RowBox[{"1253", "\[Rule]", "1254"}], ",", 
       RowBox[{"605", "\[Rule]", "282"}], ",", 
       RowBox[{"605", "\[Rule]", "282"}], ",", 
       RowBox[{"605", "\[Rule]", "1146"}], ",", 
       RowBox[{"605", "\[Rule]", "1146"}], ",", 
       RowBox[{"605", "\[Rule]", "174"}], ",", 
       RowBox[{"605", "\[Rule]", "1038"}], ",", 
       RowBox[{"605", "\[Rule]", "606"}], ",", 
       RowBox[{"281", "\[Rule]", "714"}], ",", 
       RowBox[{"281", "\[Rule]", "714"}], ",", 
       RowBox[{"281", "\[Rule]", "606"}], ",", 
       RowBox[{"281", "\[Rule]", "606"}], ",", 
       RowBox[{"281", "\[Rule]", "282"}], ",", 
       RowBox[{"1469", "\[Rule]", "1146"}], ",", 
       RowBox[{"1469", "\[Rule]", "1146"}], ",", 
       RowBox[{"1469", "\[Rule]", "2010"}], ",", 
       RowBox[{"1469", "\[Rule]", "2010"}], ",", 
       RowBox[{"1469", "\[Rule]", "1038"}], ",", 
       RowBox[{"1469", "\[Rule]", "1038"}], ",", 
       RowBox[{"1469", "\[Rule]", "1902"}], ",", 
       RowBox[{"1469", "\[Rule]", "1902"}], ",", 
       RowBox[{"1469", "\[Rule]", "1470"}], ",", 
       RowBox[{"1145", "\[Rule]", "714"}], ",", 
       RowBox[{"1145", "\[Rule]", "714"}], ",", 
       RowBox[{"1145", "\[Rule]", "1578"}], ",", 
       RowBox[{"1145", "\[Rule]", "1578"}], ",", 
       RowBox[{"1145", "\[Rule]", "606"}], ",", 
       RowBox[{"1145", "\[Rule]", "606"}], ",", 
       RowBox[{"1145", "\[Rule]", "1470"}], ",", 
       RowBox[{"1145", "\[Rule]", "1470"}], ",", 
       RowBox[{"1145", "\[Rule]", "1146"}], ",", 
       RowBox[{"497", "\[Rule]", "174"}], ",", 
       RowBox[{"497", "\[Rule]", "1038"}], ",", 
       RowBox[{"497", "\[Rule]", "66"}], ",", 
       RowBox[{"497", "\[Rule]", "66"}], ",", 
       RowBox[{"497", "\[Rule]", "930"}], ",", 
       RowBox[{"497", "\[Rule]", "930"}], ",", 
       RowBox[{"497", "\[Rule]", "498"}], ",", 
       RowBox[{"173", "\[Rule]", "606"}], ",", 
       RowBox[{"173", "\[Rule]", "498"}], ",", 
       RowBox[{"173", "\[Rule]", "174"}], ",", 
       RowBox[{"1361", "\[Rule]", "1038"}], ",", 
       RowBox[{"1361", "\[Rule]", "1038"}], ",", 
       RowBox[{"1361", "\[Rule]", "1902"}], ",", 
       RowBox[{"1361", "\[Rule]", "1902"}], ",", 
       RowBox[{"1361", "\[Rule]", "930"}], ",", 
       RowBox[{"1361", "\[Rule]", "1794"}], ",", 
       RowBox[{"1361", "\[Rule]", "1362"}], ",", 
       RowBox[{"1037", "\[Rule]", "606"}], ",", 
       RowBox[{"1037", "\[Rule]", "1470"}], ",", 
       RowBox[{"1037", "\[Rule]", "1470"}], ",", 
       RowBox[{"1037", "\[Rule]", "498"}], ",", 
       RowBox[{"1037", "\[Rule]", "1362"}], ",", 
       RowBox[{"1037", "\[Rule]", "1362"}], ",", 
       RowBox[{"1037", "\[Rule]", "1038"}], ",", 
       RowBox[{"2549", "\[Rule]", "2118"}], ",", 
       RowBox[{"2549", "\[Rule]", "2118"}], ",", 
       RowBox[{"2549", "\[Rule]", "2982"}], ",", 
       RowBox[{"2549", "\[Rule]", "2982"}], ",", 
       RowBox[{"2549", "\[Rule]", "2550"}], ",", 
       RowBox[{"2441", "\[Rule]", "2118"}], ",", 
       RowBox[{"2441", "\[Rule]", "2118"}], ",", 
       RowBox[{"2441", "\[Rule]", "2982"}], ",", 
       RowBox[{"2441", "\[Rule]", "2982"}], ",", 
       RowBox[{"2441", "\[Rule]", "2010"}], ",", 
       RowBox[{"2441", "\[Rule]", "2010"}], ",", 
       RowBox[{"2441", "\[Rule]", "2874"}], ",", 
       RowBox[{"2441", "\[Rule]", "2874"}], ",", 
       RowBox[{"2441", "\[Rule]", "2442"}], ",", 
       RowBox[{"2117", "\[Rule]", "1686"}], ",", 
       RowBox[{"2117", "\[Rule]", "1686"}], ",", 
       RowBox[{"2117", "\[Rule]", "2550"}], ",", 
       RowBox[{"2117", "\[Rule]", "2550"}], ",", 
       RowBox[{"2117", "\[Rule]", "1578"}], ",", 
       RowBox[{"2117", "\[Rule]", "1578"}], ",", 
       RowBox[{"2117", "\[Rule]", "2442"}], ",", 
       RowBox[{"2117", "\[Rule]", "2442"}], ",", 
       RowBox[{"2117", "\[Rule]", "2118"}], ",", 
       RowBox[{"2333", "\[Rule]", "2010"}], ",", 
       RowBox[{"2333", "\[Rule]", "2010"}], ",", 
       RowBox[{"2333", "\[Rule]", "2874"}], ",", 
       RowBox[{"2333", "\[Rule]", "2874"}], ",", 
       RowBox[{"2333", "\[Rule]", "1902"}], ",", 
       RowBox[{"2333", "\[Rule]", "1902"}], ",", 
       RowBox[{"2333", "\[Rule]", "2766"}], ",", 
       RowBox[{"2333", "\[Rule]", "2766"}], ",", 
       RowBox[{"2333", "\[Rule]", "2334"}], ",", 
       RowBox[{"2009", "\[Rule]", "1578"}], ",", 
       RowBox[{"2009", "\[Rule]", "1578"}], ",", 
       RowBox[{"2009", "\[Rule]", "2442"}], ",", 
       RowBox[{"2009", "\[Rule]", "2442"}], ",", 
       RowBox[{"2009", "\[Rule]", "1470"}], ",", 
       RowBox[{"2009", "\[Rule]", "1470"}], ",", 
       RowBox[{"2009", "\[Rule]", "2334"}], ",", 
       RowBox[{"2009", "\[Rule]", "2334"}], ",", 
       RowBox[{"2009", "\[Rule]", "2010"}], ",", 
       RowBox[{"2225", "\[Rule]", "1902"}], ",", 
       RowBox[{"2225", "\[Rule]", "1902"}], ",", 
       RowBox[{"2225", "\[Rule]", "2766"}], ",", 
       RowBox[{"2225", "\[Rule]", "2766"}], ",", 
       RowBox[{"2225", "\[Rule]", "1794"}], ",", 
       RowBox[{"2225", "\[Rule]", "1794"}], ",", 
       RowBox[{"2225", "\[Rule]", "2658"}], ",", 
       RowBox[{"2225", "\[Rule]", "2658"}], ",", 
       RowBox[{"2225", "\[Rule]", "2226"}], ",", 
       RowBox[{"1901", "\[Rule]", "1470"}], ",", 
       RowBox[{"1901", "\[Rule]", "1470"}], ",", 
       RowBox[{"1901", "\[Rule]", "2334"}], ",", 
       RowBox[{"1901", "\[Rule]", "2334"}], ",", 
       RowBox[{"1901", "\[Rule]", "1362"}], ",", 
       RowBox[{"1901", "\[Rule]", "1362"}], ",", 
       RowBox[{"1901", "\[Rule]", "2226"}], ",", 
       RowBox[{"1901", "\[Rule]", "2226"}], ",", 
       RowBox[{"1901", "\[Rule]", "1902"}], ",", 
       RowBox[{"65", "\[Rule]", "498"}], ",", 
       RowBox[{"65", "\[Rule]", "498"}], ",", 
       RowBox[{"65", "\[Rule]", "66"}], ",", 
       RowBox[{"929", "\[Rule]", "498"}], ",", 
       RowBox[{"929", "\[Rule]", "498"}], ",", 
       RowBox[{"929", "\[Rule]", "1362"}], ",", 
       RowBox[{"929", "\[Rule]", "930"}], ",", 
       RowBox[{"1793", "\[Rule]", "1362"}], ",", 
       RowBox[{"1793", "\[Rule]", "2226"}], ",", 
       RowBox[{"1793", "\[Rule]", "2226"}], ",", 
       RowBox[{"1793", "\[Rule]", "1794"}], ",", 
       RowBox[{"853", "\[Rule]", "422"}], ",", 
       RowBox[{"853", "\[Rule]", "422"}], ",", 
       RowBox[{"853", "\[Rule]", "1286"}], ",", 
       RowBox[{"853", "\[Rule]", "1286"}], ",", 
       RowBox[{"853", "\[Rule]", "854"}], ",", 
       RowBox[{"421", "\[Rule]", "854"}], ",", 
       RowBox[{"421", "\[Rule]", "854"}], ",", 
       RowBox[{"421", "\[Rule]", "746"}], ",", 
       RowBox[{"421", "\[Rule]", "746"}], ",", 
       RowBox[{"421", "\[Rule]", "422"}], ",", 
       RowBox[{"1717", "\[Rule]", "1286"}], ",", 
       RowBox[{"1717", "\[Rule]", "1286"}], ",", 
       RowBox[{"1717", "\[Rule]", "2150"}], ",", 
       RowBox[{"1717", "\[Rule]", "2150"}], ",", 
       RowBox[{"1717", "\[Rule]", "1718"}], ",", 
       RowBox[{"1285", "\[Rule]", "854"}], ",", 
       RowBox[{"1285", "\[Rule]", "854"}], ",", 
       RowBox[{"1285", "\[Rule]", "1718"}], ",", 
       RowBox[{"1285", "\[Rule]", "1718"}], ",", 
       RowBox[{"1285", "\[Rule]", "746"}], ",", 
       RowBox[{"1285", "\[Rule]", "746"}], ",", 
       RowBox[{"1285", "\[Rule]", "1610"}], ",", 
       RowBox[{"1285", "\[Rule]", "1610"}], ",", 
       RowBox[{"1285", "\[Rule]", "1286"}], ",", 
       RowBox[{"2581", "\[Rule]", "2150"}], ",", 
       RowBox[{"2581", "\[Rule]", "2150"}], ",", 
       RowBox[{"2581", "\[Rule]", "3014"}], ",", 
       RowBox[{"2581", "\[Rule]", "3014"}], ",", 
       RowBox[{"2581", "\[Rule]", "2582"}], ",", 
       RowBox[{"2149", "\[Rule]", "1718"}], ",", 
       RowBox[{"2149", "\[Rule]", "1718"}], ",", 
       RowBox[{"2149", "\[Rule]", "2582"}], ",", 
       RowBox[{"2149", "\[Rule]", "2582"}], ",", 
       RowBox[{"2149", "\[Rule]", "1610"}], ",", 
       RowBox[{"2149", "\[Rule]", "1610"}], ",", 
       RowBox[{"2149", "\[Rule]", "2474"}], ",", 
       RowBox[{"2149", "\[Rule]", "2474"}], ",", 
       RowBox[{"2149", "\[Rule]", "2150"}], ",", 
       RowBox[{"835", "\[Rule]", "404"}], ",", 
       RowBox[{"835", "\[Rule]", "404"}], ",", 
       RowBox[{"835", "\[Rule]", "1268"}], ",", 
       RowBox[{"835", "\[Rule]", "1268"}], ",", 
       RowBox[{"835", "\[Rule]", "836"}], ",", 
       RowBox[{"727", "\[Rule]", "404"}], ",", 
       RowBox[{"727", "\[Rule]", "404"}], ",", 
       RowBox[{"727", "\[Rule]", "1268"}], ",", 
       RowBox[{"727", "\[Rule]", "1268"}], ",", 
       RowBox[{"727", "\[Rule]", "296"}], ",", 
       RowBox[{"727", "\[Rule]", "296"}], ",", 
       RowBox[{"727", "\[Rule]", "1160"}], ",", 
       RowBox[{"727", "\[Rule]", "1160"}], ",", 
       RowBox[{"727", "\[Rule]", "728"}], ",", 
       RowBox[{"403", "\[Rule]", "836"}], ",", 
       RowBox[{"403", "\[Rule]", "836"}], ",", 
       RowBox[{"403", "\[Rule]", "728"}], ",", 
       RowBox[{"403", "\[Rule]", "728"}], ",", 
       RowBox[{"403", "\[Rule]", "404"}], ",", 
       RowBox[{"1699", "\[Rule]", "1268"}], ",", 
       RowBox[{"1699", "\[Rule]", "1268"}], ",", 
       RowBox[{"1699", "\[Rule]", "2132"}], ",", 
       RowBox[{"1699", "\[Rule]", "2132"}], ",", 
       RowBox[{"1699", "\[Rule]", "1700"}], ",", 
       RowBox[{"1591", "\[Rule]", "1268"}], ",", 
       RowBox[{"1591", "\[Rule]", "1268"}], ",", 
       RowBox[{"1591", "\[Rule]", "2132"}], ",", 
       RowBox[{"1591", "\[Rule]", "2132"}], ",", 
       RowBox[{"1591", "\[Rule]", "1160"}], ",", 
       RowBox[{"1591", "\[Rule]", "1160"}], ",", 
       RowBox[{"1591", "\[Rule]", "2024"}], ",", 
       RowBox[{"1591", "\[Rule]", "2024"}], ",", 
       RowBox[{"1591", "\[Rule]", "1592"}], ",", 
       RowBox[{"1267", "\[Rule]", "836"}], ",", 
       RowBox[{"1267", "\[Rule]", "836"}], ",", 
       RowBox[{"1267", "\[Rule]", "1700"}], ",", 
       RowBox[{"1267", "\[Rule]", "1700"}], ",", 
       RowBox[{"1267", "\[Rule]", "728"}], ",", 
       RowBox[{"1267", "\[Rule]", "728"}], ",", 
       RowBox[{"1267", "\[Rule]", "1592"}], ",", 
       RowBox[{"1267", "\[Rule]", "1592"}], ",", 
       RowBox[{"1267", "\[Rule]", "1268"}], ",", 
       RowBox[{"619", "\[Rule]", "296"}], ",", 
       RowBox[{"619", "\[Rule]", "296"}], ",", 
       RowBox[{"619", "\[Rule]", "1160"}], ",", 
       RowBox[{"619", "\[Rule]", "1160"}], ",", 
       RowBox[{"619", "\[Rule]", "188"}], ",", 
       RowBox[{"619", "\[Rule]", "1052"}], ",", 
       RowBox[{"619", "\[Rule]", "620"}], ",", 
       RowBox[{"295", "\[Rule]", "728"}], ",", 
       RowBox[{"295", "\[Rule]", "728"}], ",", 
       RowBox[{"295", "\[Rule]", "620"}], ",", 
       RowBox[{"295", "\[Rule]", "620"}], ",", 
       RowBox[{"295", "\[Rule]", "296"}], ",", 
       RowBox[{"1483", "\[Rule]", "1160"}], ",", 
       RowBox[{"1483", "\[Rule]", "1160"}], ",", 
       RowBox[{"1483", "\[Rule]", "2024"}], ",", 
       RowBox[{"1483", "\[Rule]", "2024"}], ",", 
       RowBox[{"1483", "\[Rule]", "1052"}], ",", 
       RowBox[{"1483", "\[Rule]", "1052"}], ",", 
       RowBox[{"1483", "\[Rule]", "1916"}], ",", 
       RowBox[{"1483", "\[Rule]", "1916"}], ",", 
       RowBox[{"1483", "\[Rule]", "1484"}], ",", 
       RowBox[{"1159", "\[Rule]", "728"}], ",", 
       RowBox[{"1159", "\[Rule]", "728"}], ",", 
       RowBox[{"1159", "\[Rule]", "1592"}], ",", 
       RowBox[{"1159", "\[Rule]", "1592"}], ",", 
       RowBox[{"1159", "\[Rule]", "620"}], ",", 
       RowBox[{"1159", "\[Rule]", "620"}], ",", 
       RowBox[{"1159", "\[Rule]", "1484"}], ",", 
       RowBox[{"1159", "\[Rule]", "1484"}], ",", 
       RowBox[{"1159", "\[Rule]", "1160"}], ",", 
       RowBox[{"511", "\[Rule]", "188"}], ",", 
       RowBox[{"511", "\[Rule]", "1052"}], ",", 
       RowBox[{"511", "\[Rule]", "80"}], ",", 
       RowBox[{"511", "\[Rule]", "80"}], ",", 
       RowBox[{"511", "\[Rule]", "944"}], ",", 
       RowBox[{"511", "\[Rule]", "944"}], ",", 
       RowBox[{"511", "\[Rule]", "512"}], ",", 
       RowBox[{"187", "\[Rule]", "620"}], ",", 
       RowBox[{"187", "\[Rule]", "512"}], ",", 
       RowBox[{"187", "\[Rule]", "188"}], ",", 
       RowBox[{"1375", "\[Rule]", "1052"}], ",", 
       RowBox[{"1375", "\[Rule]", "1052"}], ",", 
       RowBox[{"1375", "\[Rule]", "1916"}], ",", 
       RowBox[{"1375", "\[Rule]", "1916"}], ",", 
       RowBox[{"1375", "\[Rule]", "944"}], ",", 
       RowBox[{"1375", "\[Rule]", "1808"}], ",", 
       RowBox[{"1375", "\[Rule]", "1376"}], ",", 
       RowBox[{"1051", "\[Rule]", "620"}], ",", 
       RowBox[{"1051", "\[Rule]", "1484"}], ",", 
       RowBox[{"1051", "\[Rule]", "1484"}], ",", 
       RowBox[{"1051", "\[Rule]", "512"}], ",", 
       RowBox[{"1051", "\[Rule]", "1376"}], ",", 
       RowBox[{"1051", "\[Rule]", "1376"}], ",", 
       RowBox[{"1051", "\[Rule]", "1052"}], ",", 
       RowBox[{"2563", "\[Rule]", "2132"}], ",", 
       RowBox[{"2563", "\[Rule]", "2132"}], ",", 
       RowBox[{"2563", "\[Rule]", "2996"}], ",", 
       RowBox[{"2563", "\[Rule]", "2996"}], ",", 
       RowBox[{"2563", "\[Rule]", "2564"}], ",", 
       RowBox[{"2455", "\[Rule]", "2132"}], ",", 
       RowBox[{"2455", "\[Rule]", "2132"}], ",", 
       RowBox[{"2455", "\[Rule]", "2996"}], ",", 
       RowBox[{"2455", "\[Rule]", "2996"}], ",", 
       RowBox[{"2455", "\[Rule]", "2024"}], ",", 
       RowBox[{"2455", "\[Rule]", "2024"}], ",", 
       RowBox[{"2455", "\[Rule]", "2888"}], ",", 
       RowBox[{"2455", "\[Rule]", "2888"}], ",", 
       RowBox[{"2455", "\[Rule]", "2456"}], ",", 
       RowBox[{"2131", "\[Rule]", "1700"}], ",", 
       RowBox[{"2131", "\[Rule]", "1700"}], ",", 
       RowBox[{"2131", "\[Rule]", "2564"}], ",", 
       RowBox[{"2131", "\[Rule]", "2564"}], ",", 
       RowBox[{"2131", "\[Rule]", "1592"}], ",", 
       RowBox[{"2131", "\[Rule]", "1592"}], ",", 
       RowBox[{"2131", "\[Rule]", "2456"}], ",", 
       RowBox[{"2131", "\[Rule]", "2456"}], ",", 
       RowBox[{"2131", "\[Rule]", "2132"}], ",", 
       RowBox[{"2347", "\[Rule]", "2024"}], ",", 
       RowBox[{"2347", "\[Rule]", "2024"}], ",", 
       RowBox[{"2347", "\[Rule]", "2888"}], ",", 
       RowBox[{"2347", "\[Rule]", "2888"}], ",", 
       RowBox[{"2347", "\[Rule]", "1916"}], ",", 
       RowBox[{"2347", "\[Rule]", "1916"}], ",", 
       RowBox[{"2347", "\[Rule]", "2780"}], ",", 
       RowBox[{"2347", "\[Rule]", "2780"}], ",", 
       RowBox[{"2347", "\[Rule]", "2348"}], ",", 
       RowBox[{"2023", "\[Rule]", "1592"}], ",", 
       RowBox[{"2023", "\[Rule]", "1592"}], ",", 
       RowBox[{"2023", "\[Rule]", "2456"}], ",", 
       RowBox[{"2023", "\[Rule]", "2456"}], ",", 
       RowBox[{"2023", "\[Rule]", "1484"}], ",", 
       RowBox[{"2023", "\[Rule]", "1484"}], ",", 
       RowBox[{"2023", "\[Rule]", "2348"}], ",", 
       RowBox[{"2023", "\[Rule]", "2348"}], ",", 
       RowBox[{"2023", "\[Rule]", "2024"}], ",", 
       RowBox[{"2239", "\[Rule]", "1916"}], ",", 
       RowBox[{"2239", "\[Rule]", "1916"}], ",", 
       RowBox[{"2239", "\[Rule]", "2780"}], ",", 
       RowBox[{"2239", "\[Rule]", "2780"}], ",", 
       RowBox[{"2239", "\[Rule]", "1808"}], ",", 
       RowBox[{"2239", "\[Rule]", "1808"}], ",", 
       RowBox[{"2239", "\[Rule]", "2672"}], ",", 
       RowBox[{"2239", "\[Rule]", "2672"}], ",", 
       RowBox[{"2239", "\[Rule]", "2240"}], ",", 
       RowBox[{"1915", "\[Rule]", "1484"}], ",", 
       RowBox[{"1915", "\[Rule]", "1484"}], ",", 
       RowBox[{"1915", "\[Rule]", "2348"}], ",", 
       RowBox[{"1915", "\[Rule]", "2348"}], ",", 
       RowBox[{"1915", "\[Rule]", "1376"}], ",", 
       RowBox[{"1915", "\[Rule]", "1376"}], ",", 
       RowBox[{"1915", "\[Rule]", "2240"}], ",", 
       RowBox[{"1915", "\[Rule]", "2240"}], ",", 
       RowBox[{"1915", "\[Rule]", "1916"}], ",", 
       RowBox[{"79", "\[Rule]", "512"}], ",", 
       RowBox[{"79", "\[Rule]", "512"}], ",", 
       RowBox[{"79", "\[Rule]", "80"}], ",", 
       RowBox[{"943", "\[Rule]", "512"}], ",", 
       RowBox[{"943", "\[Rule]", "512"}], ",", 
       RowBox[{"943", "\[Rule]", "1376"}], ",", 
       RowBox[{"943", "\[Rule]", "944"}], ",", 
       RowBox[{"1807", "\[Rule]", "1376"}], ",", 
       RowBox[{"1807", "\[Rule]", "2240"}], ",", 
       RowBox[{"1807", "\[Rule]", "2240"}], ",", 
       RowBox[{"1807", "\[Rule]", "1808"}], ",", 
       RowBox[{"2945", "\[Rule]", "2514"}], ",", 
       RowBox[{"2945", "\[Rule]", "2514"}], ",", 
       RowBox[{"2945", "\[Rule]", "2406"}], ",", 
       RowBox[{"2945", "\[Rule]", "2406"}], ",", 
       RowBox[{"2945", "\[Rule]", "2946"}], ",", 
       RowBox[{"2929", "\[Rule]", "2498"}], ",", 
       RowBox[{"2929", "\[Rule]", "2498"}], ",", 
       RowBox[{"2929", "\[Rule]", "2390"}], ",", 
       RowBox[{"2929", "\[Rule]", "2390"}], ",", 
       RowBox[{"2929", "\[Rule]", "2930"}], ",", 
       RowBox[{"2975", "\[Rule]", "2544"}], ",", 
       RowBox[{"2975", "\[Rule]", "2544"}], ",", 
       RowBox[{"2975", "\[Rule]", "2436"}], ",", 
       RowBox[{"2975", "\[Rule]", "2436"}], ",", 
       RowBox[{"2975", "\[Rule]", "2976"}], ",", 
       RowBox[{"2959", "\[Rule]", "2528"}], ",", 
       RowBox[{"2959", "\[Rule]", "2528"}], ",", 
       RowBox[{"2959", "\[Rule]", "2420"}], ",", 
       RowBox[{"2959", "\[Rule]", "2420"}], ",", 
       RowBox[{"2959", "\[Rule]", "2960"}], ",", 
       RowBox[{"2941", "\[Rule]", "2510"}], ",", 
       RowBox[{"2941", "\[Rule]", "2510"}], ",", 
       RowBox[{"2941", "\[Rule]", "2402"}], ",", 
       RowBox[{"2941", "\[Rule]", "2402"}], ",", 
       RowBox[{"2941", "\[Rule]", "2942"}], ",", 
       RowBox[{"2837", "\[Rule]", "2406"}], ",", 
       RowBox[{"2837", "\[Rule]", "2406"}], ",", 
       RowBox[{"2837", "\[Rule]", "2298"}], ",", 
       RowBox[{"2837", "\[Rule]", "2298"}], ",", 
       RowBox[{"2837", "\[Rule]", "2838"}], ",", 
       RowBox[{"2821", "\[Rule]", "2390"}], ",", 
       RowBox[{"2821", "\[Rule]", "2390"}], ",", 
       RowBox[{"2821", "\[Rule]", "2282"}], ",", 
       RowBox[{"2821", "\[Rule]", "2282"}], ",", 
       RowBox[{"2821", "\[Rule]", "2822"}], ",", 
       RowBox[{"2867", "\[Rule]", "2436"}], ",", 
       RowBox[{"2867", "\[Rule]", "2436"}], ",", 
       RowBox[{"2867", "\[Rule]", "2328"}], ",", 
       RowBox[{"2867", "\[Rule]", "2328"}], ",", 
       RowBox[{"2867", "\[Rule]", "2868"}], ",", 
       RowBox[{"2851", "\[Rule]", "2420"}], ",", 
       RowBox[{"2851", "\[Rule]", "2420"}], ",", 
       RowBox[{"2851", "\[Rule]", "2312"}], ",", 
       RowBox[{"2851", "\[Rule]", "2312"}], ",", 
       RowBox[{"2851", "\[Rule]", "2852"}], ",", 
       RowBox[{"2833", "\[Rule]", "2402"}], ",", 
       RowBox[{"2833", "\[Rule]", "2402"}], ",", 
       RowBox[{"2833", "\[Rule]", "2294"}], ",", 
       RowBox[{"2833", "\[Rule]", "2294"}], ",", 
       RowBox[{"2833", "\[Rule]", "2834"}], ",", 
       RowBox[{"3007", "\[Rule]", "2576"}], ",", 
       RowBox[{"3007", "\[Rule]", "2576"}], ",", 
       RowBox[{"3007", "\[Rule]", "2468"}], ",", 
       RowBox[{"3007", "\[Rule]", "2468"}], ",", 
       RowBox[{"3007", "\[Rule]", "3008"}], ",", 
       RowBox[{"2989", "\[Rule]", "2558"}], ",", 
       RowBox[{"2989", "\[Rule]", "2558"}], ",", 
       RowBox[{"2989", "\[Rule]", "2450"}], ",", 
       RowBox[{"2989", "\[Rule]", "2450"}], ",", 
       RowBox[{"2989", "\[Rule]", "2990"}], ",", 
       RowBox[{"2971", "\[Rule]", "2540"}], ",", 
       RowBox[{"2971", "\[Rule]", "2540"}], ",", 
       RowBox[{"2971", "\[Rule]", "2432"}], ",", 
       RowBox[{"2971", "\[Rule]", "2432"}], ",", 
       RowBox[{"2971", "\[Rule]", "2972"}], ",", 
       RowBox[{"2899", "\[Rule]", "2468"}], ",", 
       RowBox[{"2899", "\[Rule]", "2468"}], ",", 
       RowBox[{"2899", "\[Rule]", "2360"}], ",", 
       RowBox[{"2899", "\[Rule]", "2360"}], ",", 
       RowBox[{"2899", "\[Rule]", "2900"}], ",", 
       RowBox[{"2881", "\[Rule]", "2450"}], ",", 
       RowBox[{"2881", "\[Rule]", "2450"}], ",", 
       RowBox[{"2881", "\[Rule]", "2342"}], ",", 
       RowBox[{"2881", "\[Rule]", "2342"}], ",", 
       RowBox[{"2881", "\[Rule]", "2882"}], ",", 
       RowBox[{"2863", "\[Rule]", "2432"}], ",", 
       RowBox[{"2863", "\[Rule]", "2432"}], ",", 
       RowBox[{"2863", "\[Rule]", "2324"}], ",", 
       RowBox[{"2863", "\[Rule]", "2324"}], ",", 
       RowBox[{"2863", "\[Rule]", "2864"}], ",", 
       RowBox[{"2955", "\[Rule]", "2524"}], ",", 
       RowBox[{"2955", "\[Rule]", "2524"}], ",", 
       RowBox[{"2955", "\[Rule]", "2416"}], ",", 
       RowBox[{"2955", "\[Rule]", "2416"}], ",", 
       RowBox[{"2955", "\[Rule]", "2956"}], ",", 
       RowBox[{"2847", "\[Rule]", "2416"}], ",", 
       RowBox[{"2847", "\[Rule]", "2416"}], ",", 
       RowBox[{"2847", "\[Rule]", "2308"}], ",", 
       RowBox[{"2847", "\[Rule]", "2308"}], ",", 
       RowBox[{"2847", "\[Rule]", "2848"}], ",", 
       RowBox[{"2729", "\[Rule]", "2298"}], ",", 
       RowBox[{"2729", "\[Rule]", "2298"}], ",", 
       RowBox[{"2729", "\[Rule]", "2190"}], ",", 
       RowBox[{"2729", "\[Rule]", "2190"}], ",", 
       RowBox[{"2729", "\[Rule]", "2730"}], ",", 
       RowBox[{"2713", "\[Rule]", "2282"}], ",", 
       RowBox[{"2713", "\[Rule]", "2282"}], ",", 
       RowBox[{"2713", "\[Rule]", "2174"}], ",", 
       RowBox[{"2713", "\[Rule]", "2174"}], ",", 
       RowBox[{"2713", "\[Rule]", "2714"}], ",", 
       RowBox[{"2759", "\[Rule]", "2328"}], ",", 
       RowBox[{"2759", "\[Rule]", "2328"}], ",", 
       RowBox[{"2759", "\[Rule]", "2220"}], ",", 
       RowBox[{"2759", "\[Rule]", "2220"}], ",", 
       RowBox[{"2759", "\[Rule]", "2760"}], ",", 
       RowBox[{"2743", "\[Rule]", "2312"}], ",", 
       RowBox[{"2743", "\[Rule]", "2312"}], ",", 
       RowBox[{"2743", "\[Rule]", "2204"}], ",", 
       RowBox[{"2743", "\[Rule]", "2204"}], ",", 
       RowBox[{"2743", "\[Rule]", "2744"}], ",", 
       RowBox[{"2725", "\[Rule]", "2294"}], ",", 
       RowBox[{"2725", "\[Rule]", "2294"}], ",", 
       RowBox[{"2725", "\[Rule]", "2186"}], ",", 
       RowBox[{"2725", "\[Rule]", "2186"}], ",", 
       RowBox[{"2725", "\[Rule]", "2726"}], ",", 
       RowBox[{"2791", "\[Rule]", "2360"}], ",", 
       RowBox[{"2791", "\[Rule]", "2360"}], ",", 
       RowBox[{"2791", "\[Rule]", "2252"}], ",", 
       RowBox[{"2791", "\[Rule]", "2252"}], ",", 
       RowBox[{"2791", "\[Rule]", "2792"}], ",", 
       RowBox[{"2773", "\[Rule]", "2342"}], ",", 
       RowBox[{"2773", "\[Rule]", "2342"}], ",", 
       RowBox[{"2773", "\[Rule]", "2234"}], ",", 
       RowBox[{"2773", "\[Rule]", "2234"}], ",", 
       RowBox[{"2773", "\[Rule]", "2774"}], ",", 
       RowBox[{"2755", "\[Rule]", "2324"}], ",", 
       RowBox[{"2755", "\[Rule]", "2324"}], ",", 
       RowBox[{"2755", "\[Rule]", "2216"}], ",", 
       RowBox[{"2755", "\[Rule]", "2216"}], ",", 
       RowBox[{"2755", "\[Rule]", "2756"}], ",", 
       RowBox[{"2739", "\[Rule]", "2308"}], ",", 
       RowBox[{"2739", "\[Rule]", "2308"}], ",", 
       RowBox[{"2739", "\[Rule]", "2200"}], ",", 
       RowBox[{"2739", "\[Rule]", "2200"}], ",", 
       RowBox[{"2739", "\[Rule]", "2740"}], ",", 
       RowBox[{"3021", "\[Rule]", "2590"}], ",", 
       RowBox[{"3021", "\[Rule]", "2590"}], ",", 
       RowBox[{"3021", "\[Rule]", "2482"}], ",", 
       RowBox[{"3021", "\[Rule]", "2482"}], ",", 
       RowBox[{"3021", "\[Rule]", "3022"}], ",", 
       RowBox[{"3003", "\[Rule]", "2572"}], ",", 
       RowBox[{"3003", "\[Rule]", "2572"}], ",", 
       RowBox[{"3003", "\[Rule]", "2464"}], ",", 
       RowBox[{"3003", "\[Rule]", "2464"}], ",", 
       RowBox[{"3003", "\[Rule]", "3004"}], ",", 
       RowBox[{"2913", "\[Rule]", "2482"}], ",", 
       RowBox[{"2913", "\[Rule]", "2482"}], ",", 
       RowBox[{"2913", "\[Rule]", "2374"}], ",", 
       RowBox[{"2913", "\[Rule]", "2374"}], ",", 
       RowBox[{"2913", "\[Rule]", "2914"}], ",", 
       RowBox[{"2895", "\[Rule]", "2464"}], ",", 
       RowBox[{"2895", "\[Rule]", "2464"}], ",", 
       RowBox[{"2895", "\[Rule]", "2356"}], ",", 
       RowBox[{"2895", "\[Rule]", "2356"}], ",", 
       RowBox[{"2895", "\[Rule]", "2896"}], ",", 
       RowBox[{"2985", "\[Rule]", "2554"}], ",", 
       RowBox[{"2985", "\[Rule]", "2554"}], ",", 
       RowBox[{"2985", "\[Rule]", "2446"}], ",", 
       RowBox[{"2985", "\[Rule]", "2446"}], ",", 
       RowBox[{"2985", "\[Rule]", "2986"}], ",", 
       RowBox[{"2877", "\[Rule]", "2446"}], ",", 
       RowBox[{"2877", "\[Rule]", "2446"}], ",", 
       RowBox[{"2877", "\[Rule]", "2338"}], ",", 
       RowBox[{"2877", "\[Rule]", "2338"}], ",", 
       RowBox[{"2877", "\[Rule]", "2878"}], ",", 
       RowBox[{"2805", "\[Rule]", "2374"}], ",", 
       RowBox[{"2805", "\[Rule]", "2374"}], ",", 
       RowBox[{"2805", "\[Rule]", "2266"}], ",", 
       RowBox[{"2805", "\[Rule]", "2266"}], ",", 
       RowBox[{"2805", "\[Rule]", "2806"}], ",", 
       RowBox[{"2787", "\[Rule]", "2356"}], ",", 
       RowBox[{"2787", "\[Rule]", "2356"}], ",", 
       RowBox[{"2787", "\[Rule]", "2248"}], ",", 
       RowBox[{"2787", "\[Rule]", "2248"}], ",", 
       RowBox[{"2787", "\[Rule]", "2788"}], ",", 
       RowBox[{"2769", "\[Rule]", "2338"}], ",", 
       RowBox[{"2769", "\[Rule]", "2338"}], ",", 
       RowBox[{"2769", "\[Rule]", "2230"}], ",", 
       RowBox[{"2769", "\[Rule]", "2230"}], ",", 
       RowBox[{"2769", "\[Rule]", "2770"}], ",", 
       RowBox[{"2967", "\[Rule]", "2536"}], ",", 
       RowBox[{"2967", "\[Rule]", "2536"}], ",", 
       RowBox[{"2967", "\[Rule]", "2428"}], ",", 
       RowBox[{"2967", "\[Rule]", "2428"}], ",", 
       RowBox[{"2967", "\[Rule]", "2968"}], ",", 
       RowBox[{"2859", "\[Rule]", "2428"}], ",", 
       RowBox[{"2859", "\[Rule]", "2428"}], ",", 
       RowBox[{"2859", "\[Rule]", "2320"}], ",", 
       RowBox[{"2859", "\[Rule]", "2320"}], ",", 
       RowBox[{"2859", "\[Rule]", "2860"}], ",", 
       RowBox[{"2751", "\[Rule]", "2320"}], ",", 
       RowBox[{"2751", "\[Rule]", "2320"}], ",", 
       RowBox[{"2751", "\[Rule]", "2212"}], ",", 
       RowBox[{"2751", "\[Rule]", "2212"}], ",", 
       RowBox[{"2751", "\[Rule]", "2752"}], ",", 
       RowBox[{"2621", "\[Rule]", "2190"}], ",", 
       RowBox[{"2621", "\[Rule]", "2190"}], ",", 
       RowBox[{"2621", "\[Rule]", "2622"}], ",", 
       RowBox[{"2605", "\[Rule]", "2174"}], ",", 
       RowBox[{"2605", "\[Rule]", "2174"}], ",", 
       RowBox[{"2605", "\[Rule]", "2606"}], ",", 
       RowBox[{"2651", "\[Rule]", "2220"}], ",", 
       RowBox[{"2651", "\[Rule]", "2220"}], ",", 
       RowBox[{"2651", "\[Rule]", "2652"}], ",", 
       RowBox[{"2635", "\[Rule]", "2204"}], ",", 
       RowBox[{"2635", "\[Rule]", "2204"}], ",", 
       RowBox[{"2635", "\[Rule]", "2636"}], ",", 
       RowBox[{"2617", "\[Rule]", "2186"}], ",", 
       RowBox[{"2617", "\[Rule]", "2186"}], ",", 
       RowBox[{"2617", "\[Rule]", "2618"}], ",", 
       RowBox[{"2683", "\[Rule]", "2252"}], ",", 
       RowBox[{"2683", "\[Rule]", "2252"}], ",", 
       RowBox[{"2683", "\[Rule]", "2684"}], ",", 
       RowBox[{"2665", "\[Rule]", "2234"}], ",", 
       RowBox[{"2665", "\[Rule]", "2234"}], ",", 
       RowBox[{"2665", "\[Rule]", "2666"}], ",", 
       RowBox[{"2647", "\[Rule]", "2216"}], ",", 
       RowBox[{"2647", "\[Rule]", "2216"}], ",", 
       RowBox[{"2647", "\[Rule]", "2648"}], ",", 
       RowBox[{"2631", "\[Rule]", "2200"}], ",", 
       RowBox[{"2631", "\[Rule]", "2200"}], ",", 
       RowBox[{"2631", "\[Rule]", "2632"}], ",", 
       RowBox[{"2697", "\[Rule]", "2266"}], ",", 
       RowBox[{"2697", "\[Rule]", "2266"}], ",", 
       RowBox[{"2697", "\[Rule]", "2698"}], ",", 
       RowBox[{"2679", "\[Rule]", "2248"}], ",", 
       RowBox[{"2679", "\[Rule]", "2248"}], ",", 
       RowBox[{"2679", "\[Rule]", "2680"}], ",", 
       RowBox[{"2661", "\[Rule]", "2230"}], ",", 
       RowBox[{"2661", "\[Rule]", "2230"}], ",", 
       RowBox[{"2661", "\[Rule]", "2662"}], ",", 
       RowBox[{"2643", "\[Rule]", "2212"}], ",", 
       RowBox[{"2643", "\[Rule]", "2212"}], ",", 
       RowBox[{"2643", "\[Rule]", "2644"}], ",", 
       RowBox[{"3017", "\[Rule]", "2586"}], ",", 
       RowBox[{"3017", "\[Rule]", "2586"}], ",", 
       RowBox[{"3017", "\[Rule]", "2478"}], ",", 
       RowBox[{"3017", "\[Rule]", "2478"}], ",", 
       RowBox[{"3017", "\[Rule]", "3018"}], ",", 
       RowBox[{"2909", "\[Rule]", "2478"}], ",", 
       RowBox[{"2909", "\[Rule]", "2478"}], ",", 
       RowBox[{"2909", "\[Rule]", "2370"}], ",", 
       RowBox[{"2909", "\[Rule]", "2370"}], ",", 
       RowBox[{"2909", "\[Rule]", "2910"}], ",", 
       RowBox[{"2801", "\[Rule]", "2370"}], ",", 
       RowBox[{"2801", "\[Rule]", "2370"}], ",", 
       RowBox[{"2801", "\[Rule]", "2262"}], ",", 
       RowBox[{"2801", "\[Rule]", "2262"}], ",", 
       RowBox[{"2801", "\[Rule]", "2802"}], ",", 
       RowBox[{"2999", "\[Rule]", "2568"}], ",", 
       RowBox[{"2999", "\[Rule]", "2568"}], ",", 
       RowBox[{"2999", "\[Rule]", "2460"}], ",", 
       RowBox[{"2999", "\[Rule]", "2460"}], ",", 
       RowBox[{"2999", "\[Rule]", "3000"}], ",", 
       RowBox[{"2891", "\[Rule]", "2460"}], ",", 
       RowBox[{"2891", "\[Rule]", "2460"}], ",", 
       RowBox[{"2891", "\[Rule]", "2352"}], ",", 
       RowBox[{"2891", "\[Rule]", "2352"}], ",", 
       RowBox[{"2891", "\[Rule]", "2892"}], ",", 
       RowBox[{"2783", "\[Rule]", "2352"}], ",", 
       RowBox[{"2783", "\[Rule]", "2352"}], ",", 
       RowBox[{"2783", "\[Rule]", "2244"}], ",", 
       RowBox[{"2783", "\[Rule]", "2244"}], ",", 
       RowBox[{"2783", "\[Rule]", "2784"}], ",", 
       RowBox[{"2693", "\[Rule]", "2262"}], ",", 
       RowBox[{"2693", "\[Rule]", "2262"}], ",", 
       RowBox[{"2693", "\[Rule]", "2694"}], ",", 
       RowBox[{"2675", "\[Rule]", "2244"}], ",", 
       RowBox[{"2675", "\[Rule]", "2244"}], ",", 
       RowBox[{"2675", "\[Rule]", "2676"}], ",", 
       RowBox[{"2981", "\[Rule]", "2550"}], ",", 
       RowBox[{"2981", "\[Rule]", "2550"}], ",", 
       RowBox[{"2981", "\[Rule]", "2442"}], ",", 
       RowBox[{"2981", "\[Rule]", "2442"}], ",", 
       RowBox[{"2981", "\[Rule]", "2982"}], ",", 
       RowBox[{"2873", "\[Rule]", "2442"}], ",", 
       RowBox[{"2873", "\[Rule]", "2442"}], ",", 
       RowBox[{"2873", "\[Rule]", "2334"}], ",", 
       RowBox[{"2873", "\[Rule]", "2334"}], ",", 
       RowBox[{"2873", "\[Rule]", "2874"}], ",", 
       RowBox[{"2765", "\[Rule]", "2334"}], ",", 
       RowBox[{"2765", "\[Rule]", "2334"}], ",", 
       RowBox[{"2765", "\[Rule]", "2226"}], ",", 
       RowBox[{"2765", "\[Rule]", "2226"}], ",", 
       RowBox[{"2765", "\[Rule]", "2766"}], ",", 
       RowBox[{"2657", "\[Rule]", "2226"}], ",", 
       RowBox[{"2657", "\[Rule]", "2226"}], ",", 
       RowBox[{"2657", "\[Rule]", "2658"}], ",", 
       RowBox[{"3013", "\[Rule]", "2582"}], ",", 
       RowBox[{"3013", "\[Rule]", "2582"}], ",", 
       RowBox[{"3013", "\[Rule]", "2474"}], ",", 
       RowBox[{"3013", "\[Rule]", "2474"}], ",", 
       RowBox[{"3013", "\[Rule]", "3014"}], ",", 
       RowBox[{"2905", "\[Rule]", "2474"}], ",", 
       RowBox[{"2905", "\[Rule]", "2474"}], ",", 
       RowBox[{"2905", "\[Rule]", "2366"}], ",", 
       RowBox[{"2905", "\[Rule]", "2366"}], ",", 
       RowBox[{"2905", "\[Rule]", "2906"}], ",", 
       RowBox[{"2797", "\[Rule]", "2366"}], ",", 
       RowBox[{"2797", "\[Rule]", "2366"}], ",", 
       RowBox[{"2797", "\[Rule]", "2258"}], ",", 
       RowBox[{"2797", "\[Rule]", "2258"}], ",", 
       RowBox[{"2797", "\[Rule]", "2798"}], ",", 
       RowBox[{"2689", "\[Rule]", "2258"}], ",", 
       RowBox[{"2689", "\[Rule]", "2258"}], ",", 
       RowBox[{"2689", "\[Rule]", "2690"}], ",", 
       RowBox[{"2995", "\[Rule]", "2564"}], ",", 
       RowBox[{"2995", "\[Rule]", "2564"}], ",", 
       RowBox[{"2995", "\[Rule]", "2456"}], ",", 
       RowBox[{"2995", "\[Rule]", "2456"}], ",", 
       RowBox[{"2995", "\[Rule]", "2996"}], ",", 
       RowBox[{"2887", "\[Rule]", "2456"}], ",", 
       RowBox[{"2887", "\[Rule]", "2456"}], ",", 
       RowBox[{"2887", "\[Rule]", "2348"}], ",", 
       RowBox[{"2887", "\[Rule]", "2348"}], ",", 
       RowBox[{"2887", "\[Rule]", "2888"}], ",", 
       RowBox[{"2779", "\[Rule]", "2348"}], ",", 
       RowBox[{"2779", "\[Rule]", "2348"}], ",", 
       RowBox[{"2779", "\[Rule]", "2240"}], ",", 
       RowBox[{"2779", "\[Rule]", "2240"}], ",", 
       RowBox[{"2779", "\[Rule]", "2780"}], ",", 
       RowBox[{"2671", "\[Rule]", "2240"}], ",", 
       RowBox[{"2671", "\[Rule]", "2240"}], ",", 
       RowBox[{"2671", "\[Rule]", "2672"}], ",", 
       RowBox[{"849", "\[Rule]", "418"}], ",", 
       RowBox[{"849", "\[Rule]", "418"}], ",", 
       RowBox[{"849", "\[Rule]", "1282"}], ",", 
       RowBox[{"849", "\[Rule]", "1282"}], ",", 
       RowBox[{"849", "\[Rule]", "850"}], ",", 
       RowBox[{"741", "\[Rule]", "418"}], ",", 
       RowBox[{"741", "\[Rule]", "418"}], ",", 
       RowBox[{"741", "\[Rule]", "1282"}], ",", 
       RowBox[{"741", "\[Rule]", "1282"}], ",", 
       RowBox[{"741", "\[Rule]", "310"}], ",", 
       RowBox[{"741", "\[Rule]", "310"}], ",", 
       RowBox[{"741", "\[Rule]", "1174"}], ",", 
       RowBox[{"741", "\[Rule]", "1174"}], ",", 
       RowBox[{"741", "\[Rule]", "742"}], ",", 
       RowBox[{"417", "\[Rule]", "850"}], ",", 
       RowBox[{"417", "\[Rule]", "850"}], ",", 
       RowBox[{"417", "\[Rule]", "742"}], ",", 
       RowBox[{"417", "\[Rule]", "742"}], ",", 
       RowBox[{"417", "\[Rule]", "418"}], ",", 
       RowBox[{"1713", "\[Rule]", "1282"}], ",", 
       RowBox[{"1713", "\[Rule]", "1282"}], ",", 
       RowBox[{"1713", "\[Rule]", "2146"}], ",", 
       RowBox[{"1713", "\[Rule]", "2146"}], ",", 
       RowBox[{"1713", "\[Rule]", "1714"}], ",", 
       RowBox[{"1605", "\[Rule]", "1282"}], ",", 
       RowBox[{"1605", "\[Rule]", "1282"}], ",", 
       RowBox[{"1605", "\[Rule]", "2146"}], ",", 
       RowBox[{"1605", "\[Rule]", "2146"}], ",", 
       RowBox[{"1605", "\[Rule]", "1174"}], ",", 
       RowBox[{"1605", "\[Rule]", "1174"}], ",", 
       RowBox[{"1605", "\[Rule]", "2038"}], ",", 
       RowBox[{"1605", "\[Rule]", "2038"}], ",", 
       RowBox[{"1605", "\[Rule]", "1606"}], ",", 
       RowBox[{"1281", "\[Rule]", "850"}], ",", 
       RowBox[{"1281", "\[Rule]", "850"}], ",", 
       RowBox[{"1281", "\[Rule]", "1714"}], ",", 
       RowBox[{"1281", "\[Rule]", "1714"}], ",", 
       RowBox[{"1281", "\[Rule]", "742"}], ",", 
       RowBox[{"1281", "\[Rule]", "742"}], ",", 
       RowBox[{"1281", "\[Rule]", "1606"}], ",", 
       RowBox[{"1281", "\[Rule]", "1606"}], ",", 
       RowBox[{"1281", "\[Rule]", "1282"}], ",", 
       RowBox[{"633", "\[Rule]", "310"}], ",", 
       RowBox[{"633", "\[Rule]", "310"}], ",", 
       RowBox[{"633", "\[Rule]", "1174"}], ",", 
       RowBox[{"633", "\[Rule]", "1174"}], ",", 
       RowBox[{"633", "\[Rule]", "202"}], ",", 
       RowBox[{"633", "\[Rule]", "1066"}], ",", 
       RowBox[{"633", "\[Rule]", "634"}], ",", 
       RowBox[{"309", "\[Rule]", "742"}], ",", 
       RowBox[{"309", "\[Rule]", "742"}], ",", 
       RowBox[{"309", "\[Rule]", "634"}], ",", 
       RowBox[{"309", "\[Rule]", "634"}], ",", 
       RowBox[{"309", "\[Rule]", "310"}], ",", 
       RowBox[{"1497", "\[Rule]", "1174"}], ",", 
       RowBox[{"1497", "\[Rule]", "1174"}], ",", 
       RowBox[{"1497", "\[Rule]", "2038"}], ",", 
       RowBox[{"1497", "\[Rule]", "2038"}], ",", 
       RowBox[{"1497", "\[Rule]", "1066"}], ",", 
       RowBox[{"1497", "\[Rule]", "1066"}], ",", 
       RowBox[{"1497", "\[Rule]", "1930"}], ",", 
       RowBox[{"1497", "\[Rule]", "1930"}], ",", 
       RowBox[{"1497", "\[Rule]", "1498"}], ",", 
       RowBox[{"1173", "\[Rule]", "742"}], ",", 
       RowBox[{"1173", "\[Rule]", "742"}], ",", 
       RowBox[{"1173", "\[Rule]", "1606"}], ",", 
       RowBox[{"1173", "\[Rule]", "1606"}], ",", 
       RowBox[{"1173", "\[Rule]", "634"}], ",", 
       RowBox[{"1173", "\[Rule]", "634"}], ",", 
       RowBox[{"1173", "\[Rule]", "1498"}], ",", 
       RowBox[{"1173", "\[Rule]", "1498"}], ",", 
       RowBox[{"1173", "\[Rule]", "1174"}], ",", 
       RowBox[{"525", "\[Rule]", "202"}], ",", 
       RowBox[{"525", "\[Rule]", "1066"}], ",", 
       RowBox[{"525", "\[Rule]", "94"}], ",", 
       RowBox[{"525", "\[Rule]", "94"}], ",", 
       RowBox[{"525", "\[Rule]", "958"}], ",", 
       RowBox[{"525", "\[Rule]", "958"}], ",", 
       RowBox[{"525", "\[Rule]", "526"}], ",", 
       RowBox[{"201", "\[Rule]", "634"}], ",", 
       RowBox[{"201", "\[Rule]", "526"}], ",", 
       RowBox[{"201", "\[Rule]", "202"}], ",", 
       RowBox[{"1389", "\[Rule]", "1066"}], ",", 
       RowBox[{"1389", "\[Rule]", "1066"}], ",", 
       RowBox[{"1389", "\[Rule]", "1930"}], ",", 
       RowBox[{"1389", "\[Rule]", "1930"}], ",", 
       RowBox[{"1389", "\[Rule]", "958"}], ",", 
       RowBox[{"1389", "\[Rule]", "1822"}], ",", 
       RowBox[{"1389", "\[Rule]", "1390"}], ",", 
       RowBox[{"1065", "\[Rule]", "634"}], ",", 
       RowBox[{"1065", "\[Rule]", "1498"}], ",", 
       RowBox[{"1065", "\[Rule]", "1498"}], ",", 
       RowBox[{"1065", "\[Rule]", "526"}], ",", 
       RowBox[{"1065", "\[Rule]", "1390"}], ",", 
       RowBox[{"1065", "\[Rule]", "1390"}], ",", 
       RowBox[{"1065", "\[Rule]", "1066"}], ",", 
       RowBox[{"2577", "\[Rule]", "2146"}], ",", 
       RowBox[{"2577", "\[Rule]", "2146"}], ",", 
       RowBox[{"2577", "\[Rule]", "3010"}], ",", 
       RowBox[{"2577", "\[Rule]", "3010"}], ",", 
       RowBox[{"2577", "\[Rule]", "2578"}], ",", 
       RowBox[{"2469", "\[Rule]", "2146"}], ",", 
       RowBox[{"2469", "\[Rule]", "2146"}], ",", 
       RowBox[{"2469", "\[Rule]", "3010"}], ",", 
       RowBox[{"2469", "\[Rule]", "3010"}], ",", 
       RowBox[{"2469", "\[Rule]", "2038"}], ",", 
       RowBox[{"2469", "\[Rule]", "2038"}], ",", 
       RowBox[{"2469", "\[Rule]", "2902"}], ",", 
       RowBox[{"2469", "\[Rule]", "2902"}], ",", 
       RowBox[{"2469", "\[Rule]", "2470"}], ",", 
       RowBox[{"2145", "\[Rule]", "1714"}], ",", 
       RowBox[{"2145", "\[Rule]", "1714"}], ",", 
       RowBox[{"2145", "\[Rule]", "2578"}], ",", 
       RowBox[{"2145", "\[Rule]", "2578"}], ",", 
       RowBox[{"2145", "\[Rule]", "1606"}], ",", 
       RowBox[{"2145", "\[Rule]", "1606"}], ",", 
       RowBox[{"2145", "\[Rule]", "2470"}], ",", 
       RowBox[{"2145", "\[Rule]", "2470"}], ",", 
       RowBox[{"2145", "\[Rule]", "2146"}], ",", 
       RowBox[{"2361", "\[Rule]", "2038"}], ",", 
       RowBox[{"2361", "\[Rule]", "2038"}], ",", 
       RowBox[{"2361", "\[Rule]", "2902"}], ",", 
       RowBox[{"2361", "\[Rule]", "2902"}], ",", 
       RowBox[{"2361", "\[Rule]", "1930"}], ",", 
       RowBox[{"2361", "\[Rule]", "1930"}], ",", 
       RowBox[{"2361", "\[Rule]", "2794"}], ",", 
       RowBox[{"2361", "\[Rule]", "2794"}], ",", 
       RowBox[{"2361", "\[Rule]", "2362"}], ",", 
       RowBox[{"2037", "\[Rule]", "1606"}], ",", 
       RowBox[{"2037", "\[Rule]", "1606"}], ",", 
       RowBox[{"2037", "\[Rule]", "2470"}], ",", 
       RowBox[{"2037", "\[Rule]", "2470"}], ",", 
       RowBox[{"2037", "\[Rule]", "1498"}], ",", 
       RowBox[{"2037", "\[Rule]", "1498"}], ",", 
       RowBox[{"2037", "\[Rule]", "2362"}], ",", 
       RowBox[{"2037", "\[Rule]", "2362"}], ",", 
       RowBox[{"2037", "\[Rule]", "2038"}], ",", 
       RowBox[{"2253", "\[Rule]", "1930"}], ",", 
       RowBox[{"2253", "\[Rule]", "1930"}], ",", 
       RowBox[{"2253", "\[Rule]", "2794"}], ",", 
       RowBox[{"2253", "\[Rule]", "2794"}], ",", 
       RowBox[{"2253", "\[Rule]", "1822"}], ",", 
       RowBox[{"2253", "\[Rule]", "1822"}], ",", 
       RowBox[{"2253", "\[Rule]", "2686"}], ",", 
       RowBox[{"2253", "\[Rule]", "2686"}], ",", 
       RowBox[{"2253", "\[Rule]", "2254"}], ",", 
       RowBox[{"1929", "\[Rule]", "1498"}], ",", 
       RowBox[{"1929", "\[Rule]", "1498"}], ",", 
       RowBox[{"1929", "\[Rule]", "2362"}], ",", 
       RowBox[{"1929", "\[Rule]", "2362"}], ",", 
       RowBox[{"1929", "\[Rule]", "1390"}], ",", 
       RowBox[{"1929", "\[Rule]", "1390"}], ",", 
       RowBox[{"1929", "\[Rule]", "2254"}], ",", 
       RowBox[{"1929", "\[Rule]", "2254"}], ",", 
       RowBox[{"1929", "\[Rule]", "1930"}], ",", 
       RowBox[{"93", "\[Rule]", "526"}], ",", 
       RowBox[{"93", "\[Rule]", "526"}], ",", 
       RowBox[{"93", "\[Rule]", "94"}], ",", 
       RowBox[{"957", "\[Rule]", "526"}], ",", 
       RowBox[{"957", "\[Rule]", "526"}], ",", 
       RowBox[{"957", "\[Rule]", "1390"}], ",", 
       RowBox[{"957", "\[Rule]", "958"}], ",", 
       RowBox[{"1821", "\[Rule]", "1390"}], ",", 
       RowBox[{"1821", "\[Rule]", "2254"}], ",", 
       RowBox[{"1821", "\[Rule]", "2254"}], ",", 
       RowBox[{"1821", "\[Rule]", "1822"}], ",", 
       RowBox[{"3009", "\[Rule]", "2578"}], ",", 
       RowBox[{"3009", "\[Rule]", "2578"}], ",", 
       RowBox[{"3009", "\[Rule]", "2470"}], ",", 
       RowBox[{"3009", "\[Rule]", "2470"}], ",", 
       RowBox[{"3009", "\[Rule]", "3010"}], ",", 
       RowBox[{"2901", "\[Rule]", "2470"}], ",", 
       RowBox[{"2901", "\[Rule]", "2470"}], ",", 
       RowBox[{"2901", "\[Rule]", "2362"}], ",", 
       RowBox[{"2901", "\[Rule]", "2362"}], ",", 
       RowBox[{"2901", "\[Rule]", "2902"}], ",", 
       RowBox[{"2793", "\[Rule]", "2362"}], ",", 
       RowBox[{"2793", "\[Rule]", "2362"}], ",", 
       RowBox[{"2793", "\[Rule]", "2254"}], ",", 
       RowBox[{"2793", "\[Rule]", "2254"}], ",", 
       RowBox[{"2793", "\[Rule]", "2794"}], ",", 
       RowBox[{"2685", "\[Rule]", "2254"}], ",", 
       RowBox[{"2685", "\[Rule]", "2254"}], ",", 
       RowBox[{"2685", "\[Rule]", "2686"}], ",", 
       RowBox[{"786", "\[Rule]", "771"}], ",", 
       RowBox[{"786", "\[Rule]", "801"}], ",", 
       RowBox[{"786", "\[Rule]", "783"}], ",", 
       RowBox[{"338", "\[Rule]", "351"}], ",", 
       RowBox[{"338", "\[Rule]", "339"}], ",", 
       RowBox[{"338", "\[Rule]", "335"}], ",", 
       RowBox[{"1202", "\[Rule]", "1215"}], ",", 
       RowBox[{"1202", "\[Rule]", "1203"}], ",", 
       RowBox[{"1202", "\[Rule]", "1199"}], ",", 
       RowBox[{"770", "\[Rule]", "783"}], ",", 
       RowBox[{"770", "\[Rule]", "771"}], ",", 
       RowBox[{"770", "\[Rule]", "767"}], ",", 
       RowBox[{"230", "\[Rule]", "243"}], ",", 
       RowBox[{"230", "\[Rule]", "231"}], ",", 
       RowBox[{"230", "\[Rule]", "227"}], ",", 
       RowBox[{"1094", "\[Rule]", "1107"}], ",", 
       RowBox[{"1094", "\[Rule]", "1095"}], ",", 
       RowBox[{"1094", "\[Rule]", "1091"}], ",", 
       RowBox[{"662", "\[Rule]", "675"}], ",", 
       RowBox[{"662", "\[Rule]", "663"}], ",", 
       RowBox[{"662", "\[Rule]", "659"}], ",", 
       RowBox[{"816", "\[Rule]", "801"}], ",", 
       RowBox[{"816", "\[Rule]", "831"}], ",", 
       RowBox[{"816", "\[Rule]", "813"}], ",", 
       RowBox[{"800", "\[Rule]", "783"}], ",", 
       RowBox[{"800", "\[Rule]", "813"}], ",", 
       RowBox[{"800", "\[Rule]", "801"}], ",", 
       RowBox[{"800", "\[Rule]", "797"}], ",", 
       RowBox[{"350", "\[Rule]", "335"}], ",", 
       RowBox[{"350", "\[Rule]", "365"}], ",", 
       RowBox[{"350", "\[Rule]", "351"}], ",", 
       RowBox[{"350", "\[Rule]", "347"}], ",", 
       RowBox[{"1214", "\[Rule]", "1199"}], ",", 
       RowBox[{"1214", "\[Rule]", "1229"}], ",", 
       RowBox[{"1214", "\[Rule]", "1215"}], ",", 
       RowBox[{"1214", "\[Rule]", "1211"}], ",", 
       RowBox[{"782", "\[Rule]", "767"}], ",", 
       RowBox[{"782", "\[Rule]", "797"}], ",", 
       RowBox[{"782", "\[Rule]", "783"}], ",", 
       RowBox[{"782", "\[Rule]", "779"}], ",", 
       RowBox[{"242", "\[Rule]", "227"}], ",", 
       RowBox[{"242", "\[Rule]", "257"}], ",", 
       RowBox[{"242", "\[Rule]", "243"}], ",", 
       RowBox[{"242", "\[Rule]", "239"}], ",", 
       RowBox[{"1106", "\[Rule]", "1091"}], ",", 
       RowBox[{"1106", "\[Rule]", "1121"}], ",", 
       RowBox[{"1106", "\[Rule]", "1107"}], ",", 
       RowBox[{"1106", "\[Rule]", "1103"}], ",", 
       RowBox[{"674", "\[Rule]", "659"}], ",", 
       RowBox[{"674", "\[Rule]", "689"}], ",", 
       RowBox[{"674", "\[Rule]", "675"}], ",", 
       RowBox[{"674", "\[Rule]", "671"}], ",", 
       RowBox[{"1650", "\[Rule]", "1635"}], ",", 
       RowBox[{"1650", "\[Rule]", "1665"}], ",", 
       RowBox[{"1650", "\[Rule]", "1647"}], ",", 
       RowBox[{"2066", "\[Rule]", "2079"}], ",", 
       RowBox[{"2066", "\[Rule]", "2067"}], ",", 
       RowBox[{"2066", "\[Rule]", "2063"}], ",", 
       RowBox[{"1634", "\[Rule]", "1647"}], ",", 
       RowBox[{"1634", "\[Rule]", "1635"}], ",", 
       RowBox[{"1634", "\[Rule]", "1631"}], ",", 
       RowBox[{"1958", "\[Rule]", "1971"}], ",", 
       RowBox[{"1958", "\[Rule]", "1959"}], ",", 
       RowBox[{"1958", "\[Rule]", "1955"}], ",", 
       RowBox[{"1526", "\[Rule]", "1539"}], ",", 
       RowBox[{"1526", "\[Rule]", "1527"}], ",", 
       RowBox[{"1526", "\[Rule]", "1523"}], ",", 
       RowBox[{"1680", "\[Rule]", "1665"}], ",", 
       RowBox[{"1680", "\[Rule]", "1695"}], ",", 
       RowBox[{"1680", "\[Rule]", "1677"}], ",", 
       RowBox[{"1664", "\[Rule]", "1647"}], ",", 
       RowBox[{"1664", "\[Rule]", "1677"}], ",", 
       RowBox[{"1664", "\[Rule]", "1665"}], ",", 
       RowBox[{"1664", "\[Rule]", "1661"}], ",", 
       RowBox[{"2078", "\[Rule]", "2063"}], ",", 
       RowBox[{"2078", "\[Rule]", "2093"}], ",", 
       RowBox[{"2078", "\[Rule]", "2079"}], ",", 
       RowBox[{"2078", "\[Rule]", "2075"}], ",", 
       RowBox[{"1646", "\[Rule]", "1631"}], ",", 
       RowBox[{"1646", "\[Rule]", "1661"}], ",", 
       RowBox[{"1646", "\[Rule]", "1647"}], ",", 
       RowBox[{"1646", "\[Rule]", "1643"}], ",", 
       RowBox[{"1970", "\[Rule]", "1955"}], ",", 
       RowBox[{"1970", "\[Rule]", "1985"}], ",", 
       RowBox[{"1970", "\[Rule]", "1971"}], ",", 
       RowBox[{"1970", "\[Rule]", "1967"}], ",", 
       RowBox[{"1538", "\[Rule]", "1523"}], ",", 
       RowBox[{"1538", "\[Rule]", "1553"}], ",", 
       RowBox[{"1538", "\[Rule]", "1539"}], ",", 
       RowBox[{"1538", "\[Rule]", "1535"}], ",", 
       RowBox[{"122", "\[Rule]", "135"}], ",", 
       RowBox[{"122", "\[Rule]", "123"}], ",", 
       RowBox[{"122", "\[Rule]", "119"}], ",", 
       RowBox[{"986", "\[Rule]", "999"}], ",", 
       RowBox[{"986", "\[Rule]", "987"}], ",", 
       RowBox[{"986", "\[Rule]", "983"}], ",", 
       RowBox[{"554", "\[Rule]", "567"}], ",", 
       RowBox[{"554", "\[Rule]", "555"}], ",", 
       RowBox[{"554", "\[Rule]", "551"}], ",", 
       RowBox[{"134", "\[Rule]", "119"}], ",", 
       RowBox[{"134", "\[Rule]", "149"}], ",", 
       RowBox[{"134", "\[Rule]", "135"}], ",", 
       RowBox[{"134", "\[Rule]", "131"}], ",", 
       RowBox[{"998", "\[Rule]", "983"}], ",", 
       RowBox[{"998", "\[Rule]", "1013"}], ",", 
       RowBox[{"998", "\[Rule]", "999"}], ",", 
       RowBox[{"998", "\[Rule]", "995"}], ",", 
       RowBox[{"566", "\[Rule]", "551"}], ",", 
       RowBox[{"566", "\[Rule]", "581"}], ",", 
       RowBox[{"566", "\[Rule]", "567"}], ",", 
       RowBox[{"566", "\[Rule]", "563"}], ",", 
       RowBox[{"1850", "\[Rule]", "1863"}], ",", 
       RowBox[{"1850", "\[Rule]", "1851"}], ",", 
       RowBox[{"1850", "\[Rule]", "1847"}], ",", 
       RowBox[{"1418", "\[Rule]", "1431"}], ",", 
       RowBox[{"1418", "\[Rule]", "1419"}], ",", 
       RowBox[{"1418", "\[Rule]", "1415"}], ",", 
       RowBox[{"1862", "\[Rule]", "1847"}], ",", 
       RowBox[{"1862", "\[Rule]", "1877"}], ",", 
       RowBox[{"1862", "\[Rule]", "1863"}], ",", 
       RowBox[{"1862", "\[Rule]", "1859"}], ",", 
       RowBox[{"1430", "\[Rule]", "1415"}], ",", 
       RowBox[{"1430", "\[Rule]", "1445"}], ",", 
       RowBox[{"1430", "\[Rule]", "1431"}], ",", 
       RowBox[{"1430", "\[Rule]", "1427"}], ",", 
       RowBox[{"848", "\[Rule]", "831"}], ",", 
       RowBox[{"848", "\[Rule]", "863"}], ",", 
       RowBox[{"848", "\[Rule]", "845"}], ",", 
       RowBox[{"830", "\[Rule]", "813"}], ",", 
       RowBox[{"830", "\[Rule]", "845"}], ",", 
       RowBox[{"830", "\[Rule]", "831"}], ",", 
       RowBox[{"830", "\[Rule]", "827"}], ",", 
       RowBox[{"812", "\[Rule]", "797"}], ",", 
       RowBox[{"812", "\[Rule]", "827"}], ",", 
       RowBox[{"812", "\[Rule]", "813"}], ",", 
       RowBox[{"812", "\[Rule]", "809"}], ",", 
       RowBox[{"1712", "\[Rule]", "1695"}], ",", 
       RowBox[{"1712", "\[Rule]", "1727"}], ",", 
       RowBox[{"1712", "\[Rule]", "1709"}], ",", 
       RowBox[{"1694", "\[Rule]", "1677"}], ",", 
       RowBox[{"1694", "\[Rule]", "1709"}], ",", 
       RowBox[{"1694", "\[Rule]", "1695"}], ",", 
       RowBox[{"1694", "\[Rule]", "1691"}], ",", 
       RowBox[{"1676", "\[Rule]", "1661"}], ",", 
       RowBox[{"1676", "\[Rule]", "1691"}], ",", 
       RowBox[{"1676", "\[Rule]", "1677"}], ",", 
       RowBox[{"1676", "\[Rule]", "1673"}], ",", 
       RowBox[{"364", "\[Rule]", "347"}], ",", 
       RowBox[{"364", "\[Rule]", "377"}], ",", 
       RowBox[{"364", "\[Rule]", "365"}], ",", 
       RowBox[{"364", "\[Rule]", "361"}], ",", 
       RowBox[{"1228", "\[Rule]", "1211"}], ",", 
       RowBox[{"1228", "\[Rule]", "1241"}], ",", 
       RowBox[{"1228", "\[Rule]", "1229"}], ",", 
       RowBox[{"1228", "\[Rule]", "1225"}], ",", 
       RowBox[{"796", "\[Rule]", "779"}], ",", 
       RowBox[{"796", "\[Rule]", "809"}], ",", 
       RowBox[{"796", "\[Rule]", "797"}], ",", 
       RowBox[{"796", "\[Rule]", "793"}], ",", 
       RowBox[{"256", "\[Rule]", "239"}], ",", 
       RowBox[{"256", "\[Rule]", "269"}], ",", 
       RowBox[{"256", "\[Rule]", "257"}], ",", 
       RowBox[{"256", "\[Rule]", "253"}], ",", 
       RowBox[{"1120", "\[Rule]", "1103"}], ",", 
       RowBox[{"1120", "\[Rule]", "1133"}], ",", 
       RowBox[{"1120", "\[Rule]", "1121"}], ",", 
       RowBox[{"1120", "\[Rule]", "1117"}], ",", 
       RowBox[{"688", "\[Rule]", "671"}], ",", 
       RowBox[{"688", "\[Rule]", "701"}], ",", 
       RowBox[{"688", "\[Rule]", "689"}], ",", 
       RowBox[{"688", "\[Rule]", "685"}], ",", 
       RowBox[{"2092", "\[Rule]", "2075"}], ",", 
       RowBox[{"2092", "\[Rule]", "2105"}], ",", 
       RowBox[{"2092", "\[Rule]", "2093"}], ",", 
       RowBox[{"2092", "\[Rule]", "2089"}], ",", 
       RowBox[{"1660", "\[Rule]", "1643"}], ",", 
       RowBox[{"1660", "\[Rule]", "1673"}], ",", 
       RowBox[{"1660", "\[Rule]", "1661"}], ",", 
       RowBox[{"1660", "\[Rule]", "1657"}], ",", 
       RowBox[{"1984", "\[Rule]", "1967"}], ",", 
       RowBox[{"1984", "\[Rule]", "1997"}], ",", 
       RowBox[{"1984", "\[Rule]", "1985"}], ",", 
       RowBox[{"1984", "\[Rule]", "1981"}], ",", 
       RowBox[{"1552", "\[Rule]", "1535"}], ",", 
       RowBox[{"1552", "\[Rule]", "1565"}], ",", 
       RowBox[{"1552", "\[Rule]", "1553"}], ",", 
       RowBox[{"1552", "\[Rule]", "1549"}], ",", 
       RowBox[{"148", "\[Rule]", "131"}], ",", 
       RowBox[{"148", "\[Rule]", "161"}], ",", 
       RowBox[{"148", "\[Rule]", "149"}], ",", 
       RowBox[{"148", "\[Rule]", "145"}], ",", 
       RowBox[{"1012", "\[Rule]", "995"}], ",", 
       RowBox[{"1012", "\[Rule]", "1025"}], ",", 
       RowBox[{"1012", "\[Rule]", "1013"}], ",", 
       RowBox[{"1012", "\[Rule]", "1009"}], ",", 
       RowBox[{"580", "\[Rule]", "563"}], ",", 
       RowBox[{"580", "\[Rule]", "593"}], ",", 
       RowBox[{"580", "\[Rule]", "581"}], ",", 
       RowBox[{"580", "\[Rule]", "577"}], ",", 
       RowBox[{"1876", "\[Rule]", "1859"}], ",", 
       RowBox[{"1876", "\[Rule]", "1889"}], ",", 
       RowBox[{"1876", "\[Rule]", "1877"}], ",", 
       RowBox[{"1876", "\[Rule]", "1873"}], ",", 
       RowBox[{"1444", "\[Rule]", "1427"}], ",", 
       RowBox[{"1444", "\[Rule]", "1457"}], ",", 
       RowBox[{"1444", "\[Rule]", "1445"}], ",", 
       RowBox[{"1444", "\[Rule]", "1441"}], ",", 
       RowBox[{"14", "\[Rule]", "27"}], ",", 
       RowBox[{"14", "\[Rule]", "15"}], ",", 
       RowBox[{"14", "\[Rule]", "11"}], ",", 
       RowBox[{"878", "\[Rule]", "891"}], ",", 
       RowBox[{"878", "\[Rule]", "879"}], ",", 
       RowBox[{"878", "\[Rule]", "875"}], ",", 
       RowBox[{"446", "\[Rule]", "459"}], ",", 
       RowBox[{"446", "\[Rule]", "447"}], ",", 
       RowBox[{"446", "\[Rule]", "443"}], ",", 
       RowBox[{"26", "\[Rule]", "11"}], ",", 
       RowBox[{"26", "\[Rule]", "41"}], ",", 
       RowBox[{"26", "\[Rule]", "27"}], ",", 
       RowBox[{"26", "\[Rule]", "23"}], ",", 
       RowBox[{"890", "\[Rule]", "875"}], ",", 
       RowBox[{"890", "\[Rule]", "905"}], ",", 
       RowBox[{"890", "\[Rule]", "891"}], ",", 
       RowBox[{"890", "\[Rule]", "887"}], ",", 
       RowBox[{"458", "\[Rule]", "443"}], ",", 
       RowBox[{"458", "\[Rule]", "473"}], ",", 
       RowBox[{"458", "\[Rule]", "459"}], ",", 
       RowBox[{"458", "\[Rule]", "455"}], ",", 
       RowBox[{"1742", "\[Rule]", "1755"}], ",", 
       RowBox[{"1742", "\[Rule]", "1743"}], ",", 
       RowBox[{"1742", "\[Rule]", "1739"}], ",", 
       RowBox[{"1310", "\[Rule]", "1323"}], ",", 
       RowBox[{"1310", "\[Rule]", "1311"}], ",", 
       RowBox[{"1310", "\[Rule]", "1307"}], ",", 
       RowBox[{"1754", "\[Rule]", "1739"}], ",", 
       RowBox[{"1754", "\[Rule]", "1769"}], ",", 
       RowBox[{"1754", "\[Rule]", "1755"}], ",", 
       RowBox[{"1754", "\[Rule]", "1751"}], ",", 
       RowBox[{"1322", "\[Rule]", "1307"}], ",", 
       RowBox[{"1322", "\[Rule]", "1337"}], ",", 
       RowBox[{"1322", "\[Rule]", "1323"}], ",", 
       RowBox[{"1322", "\[Rule]", "1319"}], ",", 
       RowBox[{"40", "\[Rule]", "23"}], ",", 
       RowBox[{"40", "\[Rule]", "53"}], ",", 
       RowBox[{"40", "\[Rule]", "41"}], ",", 
       RowBox[{"40", "\[Rule]", "37"}], ",", 
       RowBox[{"904", "\[Rule]", "887"}], ",", 
       RowBox[{"904", "\[Rule]", "917"}], ",", 
       RowBox[{"904", "\[Rule]", "905"}], ",", 
       RowBox[{"904", "\[Rule]", "901"}], ",", 
       RowBox[{"472", "\[Rule]", "455"}], ",", 
       RowBox[{"472", "\[Rule]", "485"}], ",", 
       RowBox[{"472", "\[Rule]", "473"}], ",", 
       RowBox[{"472", "\[Rule]", "469"}], ",", 
       RowBox[{"1768", "\[Rule]", "1751"}], ",", 
       RowBox[{"1768", "\[Rule]", "1781"}], ",", 
       RowBox[{"1768", "\[Rule]", "1769"}], ",", 
       RowBox[{"1768", "\[Rule]", "1765"}], ",", 
       RowBox[{"1336", "\[Rule]", "1319"}], ",", 
       RowBox[{"1336", "\[Rule]", "1349"}], ",", 
       RowBox[{"1336", "\[Rule]", "1337"}], ",", 
       RowBox[{"1336", "\[Rule]", "1333"}], ",", 
       RowBox[{"862", "\[Rule]", "845"}], ",", 
       RowBox[{"862", "\[Rule]", "863"}], ",", 
       RowBox[{"862", "\[Rule]", "859"}], ",", 
       RowBox[{"844", "\[Rule]", "827"}], ",", 
       RowBox[{"844", "\[Rule]", "859"}], ",", 
       RowBox[{"844", "\[Rule]", "845"}], ",", 
       RowBox[{"844", "\[Rule]", "841"}], ",", 
       RowBox[{"1726", "\[Rule]", "1709"}], ",", 
       RowBox[{"1726", "\[Rule]", "1727"}], ",", 
       RowBox[{"1726", "\[Rule]", "1723"}], ",", 
       RowBox[{"1708", "\[Rule]", "1691"}], ",", 
       RowBox[{"1708", "\[Rule]", "1723"}], ",", 
       RowBox[{"1708", "\[Rule]", "1709"}], ",", 
       RowBox[{"1708", "\[Rule]", "1705"}], ",", 
       RowBox[{"826", "\[Rule]", "809"}], ",", 
       RowBox[{"826", "\[Rule]", "841"}], ",", 
       RowBox[{"826", "\[Rule]", "827"}], ",", 
       RowBox[{"826", "\[Rule]", "823"}], ",", 
       RowBox[{"1690", "\[Rule]", "1673"}], ",", 
       RowBox[{"1690", "\[Rule]", "1705"}], ",", 
       RowBox[{"1690", "\[Rule]", "1691"}], ",", 
       RowBox[{"1690", "\[Rule]", "1687"}], ",", 
       RowBox[{"376", "\[Rule]", "361"}], ",", 
       RowBox[{"376", "\[Rule]", "391"}], ",", 
       RowBox[{"376", "\[Rule]", "377"}], ",", 
       RowBox[{"376", "\[Rule]", "373"}], ",", 
       RowBox[{"1240", "\[Rule]", "1225"}], ",", 
       RowBox[{"1240", "\[Rule]", "1255"}], ",", 
       RowBox[{"1240", "\[Rule]", "1241"}], ",", 
       RowBox[{"1240", "\[Rule]", "1237"}], ",", 
       RowBox[{"808", "\[Rule]", "793"}], ",", 
       RowBox[{"808", "\[Rule]", "823"}], ",", 
       RowBox[{"808", "\[Rule]", "809"}], ",", 
       RowBox[{"808", "\[Rule]", "805"}], ",", 
       RowBox[{"268", "\[Rule]", "253"}], ",", 
       RowBox[{"268", "\[Rule]", "283"}], ",", 
       RowBox[{"268", "\[Rule]", "269"}], ",", 
       RowBox[{"268", "\[Rule]", "265"}], ",", 
       RowBox[{"1132", "\[Rule]", "1117"}], ",", 
       RowBox[{"1132", "\[Rule]", "1147"}], ",", 
       RowBox[{"1132", "\[Rule]", "1133"}], ",", 
       RowBox[{"1132", "\[Rule]", "1129"}], ",", 
       RowBox[{"700", "\[Rule]", "685"}], ",", 
       RowBox[{"700", "\[Rule]", "715"}], ",", 
       RowBox[{"700", "\[Rule]", "701"}], ",", 
       RowBox[{"700", "\[Rule]", "697"}], ",", 
       RowBox[{"2104", "\[Rule]", "2089"}], ",", 
       RowBox[{"2104", "\[Rule]", "2119"}], ",", 
       RowBox[{"2104", "\[Rule]", "2105"}], ",", 
       RowBox[{"2104", "\[Rule]", "2101"}], ",", 
       RowBox[{"1672", "\[Rule]", "1657"}], ",", 
       RowBox[{"1672", "\[Rule]", "1687"}], ",", 
       RowBox[{"1672", "\[Rule]", "1673"}], ",", 
       RowBox[{"1672", "\[Rule]", "1669"}], ",", 
       RowBox[{"1996", "\[Rule]", "1981"}], ",", 
       RowBox[{"1996", "\[Rule]", "2011"}], ",", 
       RowBox[{"1996", "\[Rule]", "1997"}], ",", 
       RowBox[{"1996", "\[Rule]", "1993"}], ",", 
       RowBox[{"1564", "\[Rule]", "1549"}], ",", 
       RowBox[{"1564", "\[Rule]", "1579"}], ",", 
       RowBox[{"1564", "\[Rule]", "1565"}], ",", 
       RowBox[{"1564", "\[Rule]", "1561"}], ",", 
       RowBox[{"160", "\[Rule]", "145"}], ",", 
       RowBox[{"160", "\[Rule]", "175"}], ",", 
       RowBox[{"160", "\[Rule]", "161"}], ",", 
       RowBox[{"160", "\[Rule]", "157"}], ",", 
       RowBox[{"1024", "\[Rule]", "1009"}], ",", 
       RowBox[{"1024", "\[Rule]", "1039"}], ",", 
       RowBox[{"1024", "\[Rule]", "1025"}], ",", 
       RowBox[{"1024", "\[Rule]", "1021"}], ",", 
       RowBox[{"592", "\[Rule]", "577"}], ",", 
       RowBox[{"592", "\[Rule]", "607"}], ",", 
       RowBox[{"592", "\[Rule]", "593"}], ",", 
       RowBox[{"592", "\[Rule]", "589"}], ",", 
       RowBox[{"1888", "\[Rule]", "1873"}], ",", 
       RowBox[{"1888", "\[Rule]", "1903"}], ",", 
       RowBox[{"1888", "\[Rule]", "1889"}], ",", 
       RowBox[{"1888", "\[Rule]", "1885"}], ",", 
       RowBox[{"1456", "\[Rule]", "1441"}], ",", 
       RowBox[{"1456", "\[Rule]", "1471"}], ",", 
       RowBox[{"1456", "\[Rule]", "1457"}], ",", 
       RowBox[{"1456", "\[Rule]", "1453"}], ",", 
       RowBox[{"52", "\[Rule]", "37"}], ",", 
       RowBox[{"52", "\[Rule]", "67"}], ",", 
       RowBox[{"52", "\[Rule]", "53"}], ",", 
       RowBox[{"52", "\[Rule]", "49"}], ",", 
       RowBox[{"916", "\[Rule]", "901"}], ",", 
       RowBox[{"916", "\[Rule]", "931"}], ",", 
       RowBox[{"916", "\[Rule]", "917"}], ",", 
       RowBox[{"916", "\[Rule]", "913"}], ",", 
       RowBox[{"484", "\[Rule]", "469"}], ",", 
       RowBox[{"484", "\[Rule]", "499"}], ",", 
       RowBox[{"484", "\[Rule]", "485"}], ",", 
       RowBox[{"484", "\[Rule]", "481"}], ",", 
       RowBox[{"1780", "\[Rule]", "1765"}], ",", 
       RowBox[{"1780", "\[Rule]", "1795"}], ",", 
       RowBox[{"1780", "\[Rule]", "1781"}], ",", 
       RowBox[{"1780", "\[Rule]", "1777"}], ",", 
       RowBox[{"1348", "\[Rule]", "1333"}], ",", 
       RowBox[{"1348", "\[Rule]", "1363"}], ",", 
       RowBox[{"1348", "\[Rule]", "1349"}], ",", 
       RowBox[{"1348", "\[Rule]", "1345"}], ",", 
       RowBox[{"2514", "\[Rule]", "2499"}], ",", 
       RowBox[{"2514", "\[Rule]", "2529"}], ",", 
       RowBox[{"2514", "\[Rule]", "2511"}], ",", 
       RowBox[{"2930", "\[Rule]", "2943"}], ",", 
       RowBox[{"2930", "\[Rule]", "2931"}], ",", 
       RowBox[{"2930", "\[Rule]", "2927"}], ",", 
       RowBox[{"2498", "\[Rule]", "2511"}], ",", 
       RowBox[{"2498", "\[Rule]", "2499"}], ",", 
       RowBox[{"2498", "\[Rule]", "2495"}], ",", 
       RowBox[{"2822", "\[Rule]", "2835"}], ",", 
       RowBox[{"2822", "\[Rule]", "2823"}], ",", 
       RowBox[{"2822", "\[Rule]", "2819"}], ",", 
       RowBox[{"2390", "\[Rule]", "2403"}], ",", 
       RowBox[{"2390", "\[Rule]", "2391"}], ",", 
       RowBox[{"2390", "\[Rule]", "2387"}], ",", 
       RowBox[{"2544", "\[Rule]", "2529"}], ",", 
       RowBox[{"2544", "\[Rule]", "2559"}], ",", 
       RowBox[{"2544", "\[Rule]", "2541"}], ",", 
       RowBox[{"2528", "\[Rule]", "2511"}], ",", 
       RowBox[{"2528", "\[Rule]", "2541"}], ",", 
       RowBox[{"2528", "\[Rule]", "2529"}], ",", 
       RowBox[{"2528", "\[Rule]", "2525"}], ",", 
       RowBox[{"2942", "\[Rule]", "2927"}], ",", 
       RowBox[{"2942", "\[Rule]", "2957"}], ",", 
       RowBox[{"2942", "\[Rule]", "2943"}], ",", 
       RowBox[{"2942", "\[Rule]", "2939"}], ",", 
       RowBox[{"2510", "\[Rule]", "2495"}], ",", 
       RowBox[{"2510", "\[Rule]", "2525"}], ",", 
       RowBox[{"2510", "\[Rule]", "2511"}], ",", 
       RowBox[{"2510", "\[Rule]", "2507"}], ",", 
       RowBox[{"2834", "\[Rule]", "2819"}], ",", 
       RowBox[{"2834", "\[Rule]", "2849"}], ",", 
       RowBox[{"2834", "\[Rule]", "2835"}], ",", 
       RowBox[{"2834", "\[Rule]", "2831"}], ",", 
       RowBox[{"2402", "\[Rule]", "2387"}], ",", 
       RowBox[{"2402", "\[Rule]", "2417"}], ",", 
       RowBox[{"2402", "\[Rule]", "2403"}], ",", 
       RowBox[{"2402", "\[Rule]", "2399"}], ",", 
       RowBox[{"2714", "\[Rule]", "2727"}], ",", 
       RowBox[{"2714", "\[Rule]", "2715"}], ",", 
       RowBox[{"2714", "\[Rule]", "2711"}], ",", 
       RowBox[{"2282", "\[Rule]", "2295"}], ",", 
       RowBox[{"2282", "\[Rule]", "2283"}], ",", 
       RowBox[{"2282", "\[Rule]", "2279"}], ",", 
       RowBox[{"2726", "\[Rule]", "2711"}], ",", 
       RowBox[{"2726", "\[Rule]", "2741"}], ",", 
       RowBox[{"2726", "\[Rule]", "2727"}], ",", 
       RowBox[{"2726", "\[Rule]", "2723"}], ",", 
       RowBox[{"2294", "\[Rule]", "2279"}], ",", 
       RowBox[{"2294", "\[Rule]", "2309"}], ",", 
       RowBox[{"2294", "\[Rule]", "2295"}], ",", 
       RowBox[{"2294", "\[Rule]", "2291"}], ",", 
       RowBox[{"2576", "\[Rule]", "2559"}], ",", 
       RowBox[{"2576", "\[Rule]", "2591"}], ",", 
       RowBox[{"2576", "\[Rule]", "2573"}], ",", 
       RowBox[{"2558", "\[Rule]", "2541"}], ",", 
       RowBox[{"2558", "\[Rule]", "2573"}], ",", 
       RowBox[{"2558", "\[Rule]", "2559"}], ",", 
       RowBox[{"2558", "\[Rule]", "2555"}], ",", 
       RowBox[{"2540", "\[Rule]", "2525"}], ",", 
       RowBox[{"2540", "\[Rule]", "2555"}], ",", 
       RowBox[{"2540", "\[Rule]", "2541"}], ",", 
       RowBox[{"2540", "\[Rule]", "2537"}], ",", 
       RowBox[{"2956", "\[Rule]", "2939"}], ",", 
       RowBox[{"2956", "\[Rule]", "2969"}], ",", 
       RowBox[{"2956", "\[Rule]", "2957"}], ",", 
       RowBox[{"2956", "\[Rule]", "2953"}], ",", 
       RowBox[{"2524", "\[Rule]", "2507"}], ",", 
       RowBox[{"2524", "\[Rule]", "2537"}], ",", 
       RowBox[{"2524", "\[Rule]", "2525"}], ",", 
       RowBox[{"2524", "\[Rule]", "2521"}], ",", 
       RowBox[{"2848", "\[Rule]", "2831"}], ",", 
       RowBox[{"2848", "\[Rule]", "2861"}], ",", 
       RowBox[{"2848", "\[Rule]", "2849"}], ",", 
       RowBox[{"2848", "\[Rule]", "2845"}], ",", 
       RowBox[{"2416", "\[Rule]", "2399"}], ",", 
       RowBox[{"2416", "\[Rule]", "2429"}], ",", 
       RowBox[{"2416", "\[Rule]", "2417"}], ",", 
       RowBox[{"2416", "\[Rule]", "2413"}], ",", 
       RowBox[{"2740", "\[Rule]", "2723"}], ",", 
       RowBox[{"2740", "\[Rule]", "2753"}], ",", 
       RowBox[{"2740", "\[Rule]", "2741"}], ",", 
       RowBox[{"2740", "\[Rule]", "2737"}], ",", 
       RowBox[{"2308", "\[Rule]", "2291"}], ",", 
       RowBox[{"2308", "\[Rule]", "2321"}], ",", 
       RowBox[{"2308", "\[Rule]", "2309"}], ",", 
       RowBox[{"2308", "\[Rule]", "2305"}], ",", 
       RowBox[{"2606", "\[Rule]", "2619"}], ",", 
       RowBox[{"2606", "\[Rule]", "2607"}], ",", 
       RowBox[{"2606", "\[Rule]", "2603"}], ",", 
       RowBox[{"2174", "\[Rule]", "2187"}], ",", 
       RowBox[{"2174", "\[Rule]", "2175"}], ",", 
       RowBox[{"2174", "\[Rule]", "2171"}], ",", 
       RowBox[{"2618", "\[Rule]", "2603"}], ",", 
       RowBox[{"2618", "\[Rule]", "2633"}], ",", 
       RowBox[{"2618", "\[Rule]", "2619"}], ",", 
       RowBox[{"2618", "\[Rule]", "2615"}], ",", 
       RowBox[{"2186", "\[Rule]", "2171"}], ",", 
       RowBox[{"2186", "\[Rule]", "2201"}], ",", 
       RowBox[{"2186", "\[Rule]", "2187"}], ",", 
       RowBox[{"2186", "\[Rule]", "2183"}], ",", 
       RowBox[{"2632", "\[Rule]", "2615"}], ",", 
       RowBox[{"2632", "\[Rule]", "2645"}], ",", 
       RowBox[{"2632", "\[Rule]", "2633"}], ",", 
       RowBox[{"2632", "\[Rule]", "2629"}], ",", 
       RowBox[{"2200", "\[Rule]", "2183"}], ",", 
       RowBox[{"2200", "\[Rule]", "2213"}], ",", 
       RowBox[{"2200", "\[Rule]", "2201"}], ",", 
       RowBox[{"2200", "\[Rule]", "2197"}], ",", 
       RowBox[{"2590", "\[Rule]", "2573"}], ",", 
       RowBox[{"2590", "\[Rule]", "2591"}], ",", 
       RowBox[{"2590", "\[Rule]", "2587"}], ",", 
       RowBox[{"2572", "\[Rule]", "2555"}], ",", 
       RowBox[{"2572", "\[Rule]", "2587"}], ",", 
       RowBox[{"2572", "\[Rule]", "2573"}], ",", 
       RowBox[{"2572", "\[Rule]", "2569"}], ",", 
       RowBox[{"2554", "\[Rule]", "2537"}], ",", 
       RowBox[{"2554", "\[Rule]", "2569"}], ",", 
       RowBox[{"2554", "\[Rule]", "2555"}], ",", 
       RowBox[{"2554", "\[Rule]", "2551"}], ",", 
       RowBox[{"2968", "\[Rule]", "2953"}], ",", 
       RowBox[{"2968", "\[Rule]", "2983"}], ",", 
       RowBox[{"2968", "\[Rule]", "2969"}], ",", 
       RowBox[{"2968", "\[Rule]", "2965"}], ",", 
       RowBox[{"2536", "\[Rule]", "2521"}], ",", 
       RowBox[{"2536", "\[Rule]", "2551"}], ",", 
       RowBox[{"2536", "\[Rule]", "2537"}], ",", 
       RowBox[{"2536", "\[Rule]", "2533"}], ",", 
       RowBox[{"2860", "\[Rule]", "2845"}], ",", 
       RowBox[{"2860", "\[Rule]", "2875"}], ",", 
       RowBox[{"2860", "\[Rule]", "2861"}], ",", 
       RowBox[{"2860", "\[Rule]", "2857"}], ",", 
       RowBox[{"2428", "\[Rule]", "2413"}], ",", 
       RowBox[{"2428", "\[Rule]", "2443"}], ",", 
       RowBox[{"2428", "\[Rule]", "2429"}], ",", 
       RowBox[{"2428", "\[Rule]", "2425"}], ",", 
       RowBox[{"2752", "\[Rule]", "2737"}], ",", 
       RowBox[{"2752", "\[Rule]", "2767"}], ",", 
       RowBox[{"2752", "\[Rule]", "2753"}], ",", 
       RowBox[{"2752", "\[Rule]", "2749"}], ",", 
       RowBox[{"2320", "\[Rule]", "2305"}], ",", 
       RowBox[{"2320", "\[Rule]", "2335"}], ",", 
       RowBox[{"2320", "\[Rule]", "2321"}], ",", 
       RowBox[{"2320", "\[Rule]", "2317"}], ",", 
       RowBox[{"2644", "\[Rule]", "2629"}], ",", 
       RowBox[{"2644", "\[Rule]", "2659"}], ",", 
       RowBox[{"2644", "\[Rule]", "2645"}], ",", 
       RowBox[{"2644", "\[Rule]", "2641"}], ",", 
       RowBox[{"2212", "\[Rule]", "2197"}], ",", 
       RowBox[{"2212", "\[Rule]", "2227"}], ",", 
       RowBox[{"2212", "\[Rule]", "2213"}], ",", 
       RowBox[{"2212", "\[Rule]", "2209"}], ",", 
       RowBox[{"858", "\[Rule]", "841"}], ",", 
       RowBox[{"858", "\[Rule]", "859"}], ",", 
       RowBox[{"858", "\[Rule]", "855"}], ",", 
       RowBox[{"1722", "\[Rule]", "1705"}], ",", 
       RowBox[{"1722", "\[Rule]", "1723"}], ",", 
       RowBox[{"1722", "\[Rule]", "1719"}], ",", 
       RowBox[{"840", "\[Rule]", "823"}], ",", 
       RowBox[{"840", "\[Rule]", "855"}], ",", 
       RowBox[{"840", "\[Rule]", "841"}], ",", 
       RowBox[{"840", "\[Rule]", "837"}], ",", 
       RowBox[{"1704", "\[Rule]", "1687"}], ",", 
       RowBox[{"1704", "\[Rule]", "1719"}], ",", 
       RowBox[{"1704", "\[Rule]", "1705"}], ",", 
       RowBox[{"1704", "\[Rule]", "1701"}], ",", 
       RowBox[{"2586", "\[Rule]", "2569"}], ",", 
       RowBox[{"2586", "\[Rule]", "2587"}], ",", 
       RowBox[{"2586", "\[Rule]", "2583"}], ",", 
       RowBox[{"2568", "\[Rule]", "2551"}], ",", 
       RowBox[{"2568", "\[Rule]", "2583"}], ",", 
       RowBox[{"2568", "\[Rule]", "2569"}], ",", 
       RowBox[{"2568", "\[Rule]", "2565"}], ",", 
       RowBox[{"390", "\[Rule]", "373"}], ",", 
       RowBox[{"390", "\[Rule]", "405"}], ",", 
       RowBox[{"390", "\[Rule]", "391"}], ",", 
       RowBox[{"390", "\[Rule]", "387"}], ",", 
       RowBox[{"1254", "\[Rule]", "1237"}], ",", 
       RowBox[{"1254", "\[Rule]", "1269"}], ",", 
       RowBox[{"1254", "\[Rule]", "1255"}], ",", 
       RowBox[{"1254", "\[Rule]", "1251"}], ",", 
       RowBox[{"822", "\[Rule]", "805"}], ",", 
       RowBox[{"822", "\[Rule]", "837"}], ",", 
       RowBox[{"822", "\[Rule]", "823"}], ",", 
       RowBox[{"822", "\[Rule]", "819"}], ",", 
       RowBox[{"282", "\[Rule]", "265"}], ",", 
       RowBox[{"282", "\[Rule]", "297"}], ",", 
       RowBox[{"282", "\[Rule]", "283"}], ",", 
       RowBox[{"282", "\[Rule]", "279"}], ",", 
       RowBox[{"1146", "\[Rule]", "1129"}], ",", 
       RowBox[{"1146", "\[Rule]", "1161"}], ",", 
       RowBox[{"1146", "\[Rule]", "1147"}], ",", 
       RowBox[{"1146", "\[Rule]", "1143"}], ",", 
       RowBox[{"714", "\[Rule]", "697"}], ",", 
       RowBox[{"714", "\[Rule]", "729"}], ",", 
       RowBox[{"714", "\[Rule]", "715"}], ",", 
       RowBox[{"714", "\[Rule]", "711"}], ",", 
       RowBox[{"2118", "\[Rule]", "2101"}], ",", 
       RowBox[{"2118", "\[Rule]", "2133"}], ",", 
       RowBox[{"2118", "\[Rule]", "2119"}], ",", 
       RowBox[{"2118", "\[Rule]", "2115"}], ",", 
       RowBox[{"1686", "\[Rule]", "1669"}], ",", 
       RowBox[{"1686", "\[Rule]", "1701"}], ",", 
       RowBox[{"1686", "\[Rule]", "1687"}], ",", 
       RowBox[{"1686", "\[Rule]", "1683"}], ",", 
       RowBox[{"2010", "\[Rule]", "1993"}], ",", 
       RowBox[{"2010", "\[Rule]", "2025"}], ",", 
       RowBox[{"2010", "\[Rule]", "2011"}], ",", 
       RowBox[{"2010", "\[Rule]", "2007"}], ",", 
       RowBox[{"1578", "\[Rule]", "1561"}], ",", 
       RowBox[{"1578", "\[Rule]", "1593"}], ",", 
       RowBox[{"1578", "\[Rule]", "1579"}], ",", 
       RowBox[{"1578", "\[Rule]", "1575"}], ",", 
       RowBox[{"174", "\[Rule]", "157"}], ",", 
       RowBox[{"174", "\[Rule]", "189"}], ",", 
       RowBox[{"174", "\[Rule]", "175"}], ",", 
       RowBox[{"174", "\[Rule]", "171"}], ",", 
       RowBox[{"1038", "\[Rule]", "1021"}], ",", 
       RowBox[{"1038", "\[Rule]", "1053"}], ",", 
       RowBox[{"1038", "\[Rule]", "1039"}], ",", 
       RowBox[{"1038", "\[Rule]", "1035"}], ",", 
       RowBox[{"606", "\[Rule]", "589"}], ",", 
       RowBox[{"606", "\[Rule]", "621"}], ",", 
       RowBox[{"606", "\[Rule]", "607"}], ",", 
       RowBox[{"606", "\[Rule]", "603"}], ",", 
       RowBox[{"1902", "\[Rule]", "1885"}], ",", 
       RowBox[{"1902", "\[Rule]", "1917"}], ",", 
       RowBox[{"1902", "\[Rule]", "1903"}], ",", 
       RowBox[{"1902", "\[Rule]", "1899"}], ",", 
       RowBox[{"1470", "\[Rule]", "1453"}], ",", 
       RowBox[{"1470", "\[Rule]", "1485"}], ",", 
       RowBox[{"1470", "\[Rule]", "1471"}], ",", 
       RowBox[{"1470", "\[Rule]", "1467"}], ",", 
       RowBox[{"66", "\[Rule]", "49"}], ",", 
       RowBox[{"66", "\[Rule]", "81"}], ",", 
       RowBox[{"66", "\[Rule]", "67"}], ",", 
       RowBox[{"66", "\[Rule]", "63"}], ",", 
       RowBox[{"930", "\[Rule]", "913"}], ",", 
       RowBox[{"930", "\[Rule]", "945"}], ",", 
       RowBox[{"930", "\[Rule]", "931"}], ",", 
       RowBox[{"930", "\[Rule]", "927"}], ",", 
       RowBox[{"498", "\[Rule]", "481"}], ",", 
       RowBox[{"498", "\[Rule]", "513"}], ",", 
       RowBox[{"498", "\[Rule]", "499"}], ",", 
       RowBox[{"498", "\[Rule]", "495"}], ",", 
       RowBox[{"1794", "\[Rule]", "1777"}], ",", 
       RowBox[{"1794", "\[Rule]", "1809"}], ",", 
       RowBox[{"1794", "\[Rule]", "1795"}], ",", 
       RowBox[{"1794", "\[Rule]", "1791"}], ",", 
       RowBox[{"1362", "\[Rule]", "1345"}], ",", 
       RowBox[{"1362", "\[Rule]", "1377"}], ",", 
       RowBox[{"1362", "\[Rule]", "1363"}], ",", 
       RowBox[{"1362", "\[Rule]", "1359"}], ",", 
       RowBox[{"2982", "\[Rule]", "2965"}], ",", 
       RowBox[{"2982", "\[Rule]", "2997"}], ",", 
       RowBox[{"2982", "\[Rule]", "2983"}], ",", 
       RowBox[{"2982", "\[Rule]", "2979"}], ",", 
       RowBox[{"2550", "\[Rule]", "2533"}], ",", 
       RowBox[{"2550", "\[Rule]", "2565"}], ",", 
       RowBox[{"2550", "\[Rule]", "2551"}], ",", 
       RowBox[{"2550", "\[Rule]", "2547"}], ",", 
       RowBox[{"2874", "\[Rule]", "2857"}], ",", 
       RowBox[{"2874", "\[Rule]", "2889"}], ",", 
       RowBox[{"2874", "\[Rule]", "2875"}], ",", 
       RowBox[{"2874", "\[Rule]", "2871"}], ",", 
       RowBox[{"2442", "\[Rule]", "2425"}], ",", 
       RowBox[{"2442", "\[Rule]", "2457"}], ",", 
       RowBox[{"2442", "\[Rule]", "2443"}], ",", 
       RowBox[{"2442", "\[Rule]", "2439"}], ",", 
       RowBox[{"2766", "\[Rule]", "2749"}], ",", 
       RowBox[{"2766", "\[Rule]", "2781"}], ",", 
       RowBox[{"2766", "\[Rule]", "2767"}], ",", 
       RowBox[{"2766", "\[Rule]", "2763"}], ",", 
       RowBox[{"2334", "\[Rule]", "2317"}], ",", 
       RowBox[{"2334", "\[Rule]", "2349"}], ",", 
       RowBox[{"2334", "\[Rule]", "2335"}], ",", 
       RowBox[{"2334", "\[Rule]", "2331"}], ",", 
       RowBox[{"2658", "\[Rule]", "2641"}], ",", 
       RowBox[{"2658", "\[Rule]", "2673"}], ",", 
       RowBox[{"2658", "\[Rule]", "2659"}], ",", 
       RowBox[{"2658", "\[Rule]", "2655"}], ",", 
       RowBox[{"2226", "\[Rule]", "2209"}], ",", 
       RowBox[{"2226", "\[Rule]", "2241"}], ",", 
       RowBox[{"2226", "\[Rule]", "2227"}], ",", 
       RowBox[{"2226", "\[Rule]", "2223"}], ",", 
       RowBox[{"854", "\[Rule]", "837"}], ",", 
       RowBox[{"854", "\[Rule]", "855"}], ",", 
       RowBox[{"854", "\[Rule]", "851"}], ",", 
       RowBox[{"1718", "\[Rule]", "1701"}], ",", 
       RowBox[{"1718", "\[Rule]", "1719"}], ",", 
       RowBox[{"1718", "\[Rule]", "1715"}], ",", 
       RowBox[{"2582", "\[Rule]", "2565"}], ",", 
       RowBox[{"2582", "\[Rule]", "2583"}], ",", 
       RowBox[{"2582", "\[Rule]", "2579"}], ",", 
       RowBox[{"404", "\[Rule]", "387"}], ",", 
       RowBox[{"404", "\[Rule]", "419"}], ",", 
       RowBox[{"404", "\[Rule]", "405"}], ",", 
       RowBox[{"404", "\[Rule]", "401"}], ",", 
       RowBox[{"1268", "\[Rule]", "1251"}], ",", 
       RowBox[{"1268", "\[Rule]", "1283"}], ",", 
       RowBox[{"1268", "\[Rule]", "1269"}], ",", 
       RowBox[{"1268", "\[Rule]", "1265"}], ",", 
       RowBox[{"836", "\[Rule]", "819"}], ",", 
       RowBox[{"836", "\[Rule]", "851"}], ",", 
       RowBox[{"836", "\[Rule]", "837"}], ",", 
       RowBox[{"836", "\[Rule]", "833"}], ",", 
       RowBox[{"296", "\[Rule]", "279"}], ",", 
       RowBox[{"296", "\[Rule]", "311"}], ",", 
       RowBox[{"296", "\[Rule]", "297"}], ",", 
       RowBox[{"296", "\[Rule]", "293"}], ",", 
       RowBox[{"1160", "\[Rule]", "1143"}], ",", 
       RowBox[{"1160", "\[Rule]", "1175"}], ",", 
       RowBox[{"1160", "\[Rule]", "1161"}], ",", 
       RowBox[{"1160", "\[Rule]", "1157"}], ",", 
       RowBox[{"728", "\[Rule]", "711"}], ",", 
       RowBox[{"728", "\[Rule]", "743"}], ",", 
       RowBox[{"728", "\[Rule]", "729"}], ",", 
       RowBox[{"728", "\[Rule]", "725"}], ",", 
       RowBox[{"2132", "\[Rule]", "2115"}], ",", 
       RowBox[{"2132", "\[Rule]", "2147"}], ",", 
       RowBox[{"2132", "\[Rule]", "2133"}], ",", 
       RowBox[{"2132", "\[Rule]", "2129"}], ",", 
       RowBox[{"1700", "\[Rule]", "1683"}], ",", 
       RowBox[{"1700", "\[Rule]", "1715"}], ",", 
       RowBox[{"1700", "\[Rule]", "1701"}], ",", 
       RowBox[{"1700", "\[Rule]", "1697"}], ",", 
       RowBox[{"2024", "\[Rule]", "2007"}], ",", 
       RowBox[{"2024", "\[Rule]", "2039"}], ",", 
       RowBox[{"2024", "\[Rule]", "2025"}], ",", 
       RowBox[{"2024", "\[Rule]", "2021"}], ",", 
       RowBox[{"1592", "\[Rule]", "1575"}], ",", 
       RowBox[{"1592", "\[Rule]", "1607"}], ",", 
       RowBox[{"1592", "\[Rule]", "1593"}], ",", 
       RowBox[{"1592", "\[Rule]", "1589"}], ",", 
       RowBox[{"188", "\[Rule]", "171"}], ",", 
       RowBox[{"188", "\[Rule]", "203"}], ",", 
       RowBox[{"188", "\[Rule]", "189"}], ",", 
       RowBox[{"188", "\[Rule]", "185"}], ",", 
       RowBox[{"1052", "\[Rule]", "1035"}], ",", 
       RowBox[{"1052", "\[Rule]", "1067"}], ",", 
       RowBox[{"1052", "\[Rule]", "1053"}], ",", 
       RowBox[{"1052", "\[Rule]", "1049"}], ",", 
       RowBox[{"620", "\[Rule]", "603"}], ",", 
       RowBox[{"620", "\[Rule]", "635"}], ",", 
       RowBox[{"620", "\[Rule]", "621"}], ",", 
       RowBox[{"620", "\[Rule]", "617"}], ",", 
       RowBox[{"1916", "\[Rule]", "1899"}], ",", 
       RowBox[{"1916", "\[Rule]", "1931"}], ",", 
       RowBox[{"1916", "\[Rule]", "1917"}], ",", 
       RowBox[{"1916", "\[Rule]", "1913"}], ",", 
       RowBox[{"1484", "\[Rule]", "1467"}], ",", 
       RowBox[{"1484", "\[Rule]", "1499"}], ",", 
       RowBox[{"1484", "\[Rule]", "1485"}], ",", 
       RowBox[{"1484", "\[Rule]", "1481"}], ",", 
       RowBox[{"80", "\[Rule]", "63"}], ",", 
       RowBox[{"80", "\[Rule]", "95"}], ",", 
       RowBox[{"80", "\[Rule]", "81"}], ",", 
       RowBox[{"80", "\[Rule]", "77"}], ",", 
       RowBox[{"944", "\[Rule]", "927"}], ",", 
       RowBox[{"944", "\[Rule]", "959"}], ",", 
       RowBox[{"944", "\[Rule]", "945"}], ",", 
       RowBox[{"944", "\[Rule]", "941"}], ",", 
       RowBox[{"512", "\[Rule]", "495"}], ",", 
       RowBox[{"512", "\[Rule]", "527"}], ",", 
       RowBox[{"512", "\[Rule]", "513"}], ",", 
       RowBox[{"512", "\[Rule]", "509"}], ",", 
       RowBox[{"1808", "\[Rule]", "1791"}], ",", 
       RowBox[{"1808", "\[Rule]", "1823"}], ",", 
       RowBox[{"1808", "\[Rule]", "1809"}], ",", 
       RowBox[{"1808", "\[Rule]", "1805"}], ",", 
       RowBox[{"1376", "\[Rule]", "1359"}], ",", 
       RowBox[{"1376", "\[Rule]", "1391"}], ",", 
       RowBox[{"1376", "\[Rule]", "1377"}], ",", 
       RowBox[{"1376", "\[Rule]", "1373"}], ",", 
       RowBox[{"2996", "\[Rule]", "2979"}], ",", 
       RowBox[{"2996", "\[Rule]", "3011"}], ",", 
       RowBox[{"2996", "\[Rule]", "2997"}], ",", 
       RowBox[{"2996", "\[Rule]", "2993"}], ",", 
       RowBox[{"2564", "\[Rule]", "2547"}], ",", 
       RowBox[{"2564", "\[Rule]", "2579"}], ",", 
       RowBox[{"2564", "\[Rule]", "2565"}], ",", 
       RowBox[{"2564", "\[Rule]", "2561"}], ",", 
       RowBox[{"2888", "\[Rule]", "2871"}], ",", 
       RowBox[{"2888", "\[Rule]", "2903"}], ",", 
       RowBox[{"2888", "\[Rule]", "2889"}], ",", 
       RowBox[{"2888", "\[Rule]", "2885"}], ",", 
       RowBox[{"2456", "\[Rule]", "2439"}], ",", 
       RowBox[{"2456", "\[Rule]", "2471"}], ",", 
       RowBox[{"2456", "\[Rule]", "2457"}], ",", 
       RowBox[{"2456", "\[Rule]", "2453"}], ",", 
       RowBox[{"2780", "\[Rule]", "2763"}], ",", 
       RowBox[{"2780", "\[Rule]", "2795"}], ",", 
       RowBox[{"2780", "\[Rule]", "2781"}], ",", 
       RowBox[{"2780", "\[Rule]", "2777"}], ",", 
       RowBox[{"2348", "\[Rule]", "2331"}], ",", 
       RowBox[{"2348", "\[Rule]", "2363"}], ",", 
       RowBox[{"2348", "\[Rule]", "2349"}], ",", 
       RowBox[{"2348", "\[Rule]", "2345"}], ",", 
       RowBox[{"2672", "\[Rule]", "2655"}], ",", 
       RowBox[{"2672", "\[Rule]", "2687"}], ",", 
       RowBox[{"2672", "\[Rule]", "2673"}], ",", 
       RowBox[{"2672", "\[Rule]", "2669"}], ",", 
       RowBox[{"2240", "\[Rule]", "2223"}], ",", 
       RowBox[{"2240", "\[Rule]", "2255"}], ",", 
       RowBox[{"2240", "\[Rule]", "2241"}], ",", 
       RowBox[{"2240", "\[Rule]", "2237"}], ",", 
       RowBox[{"418", "\[Rule]", "401"}], ",", 
       RowBox[{"418", "\[Rule]", "419"}], ",", 
       RowBox[{"1282", "\[Rule]", "1265"}], ",", 
       RowBox[{"1282", "\[Rule]", "1283"}], ",", 
       RowBox[{"850", "\[Rule]", "833"}], ",", 
       RowBox[{"850", "\[Rule]", "851"}], ",", 
       RowBox[{"310", "\[Rule]", "293"}], ",", 
       RowBox[{"310", "\[Rule]", "311"}], ",", 
       RowBox[{"1174", "\[Rule]", "1157"}], ",", 
       RowBox[{"1174", "\[Rule]", "1175"}], ",", 
       RowBox[{"742", "\[Rule]", "725"}], ",", 
       RowBox[{"742", "\[Rule]", "743"}], ",", 
       RowBox[{"2146", "\[Rule]", "2129"}], ",", 
       RowBox[{"2146", "\[Rule]", "2147"}], ",", 
       RowBox[{"1714", "\[Rule]", "1697"}], ",", 
       RowBox[{"1714", "\[Rule]", "1715"}], ",", 
       RowBox[{"2038", "\[Rule]", "2021"}], ",", 
       RowBox[{"2038", "\[Rule]", "2039"}], ",", 
       RowBox[{"1606", "\[Rule]", "1589"}], ",", 
       RowBox[{"1606", "\[Rule]", "1607"}], ",", 
       RowBox[{"202", "\[Rule]", "185"}], ",", 
       RowBox[{"202", "\[Rule]", "203"}], ",", 
       RowBox[{"1066", "\[Rule]", "1049"}], ",", 
       RowBox[{"1066", "\[Rule]", "1067"}], ",", 
       RowBox[{"634", "\[Rule]", "617"}], ",", 
       RowBox[{"634", "\[Rule]", "635"}], ",", 
       RowBox[{"1930", "\[Rule]", "1913"}], ",", 
       RowBox[{"1930", "\[Rule]", "1931"}], ",", 
       RowBox[{"1498", "\[Rule]", "1481"}], ",", 
       RowBox[{"1498", "\[Rule]", "1499"}], ",", 
       RowBox[{"94", "\[Rule]", "77"}], ",", 
       RowBox[{"94", "\[Rule]", "95"}], ",", 
       RowBox[{"958", "\[Rule]", "941"}], ",", 
       RowBox[{"958", "\[Rule]", "959"}], ",", 
       RowBox[{"526", "\[Rule]", "509"}], ",", 
       RowBox[{"526", "\[Rule]", "527"}], ",", 
       RowBox[{"1822", "\[Rule]", "1805"}], ",", 
       RowBox[{"1822", "\[Rule]", "1823"}], ",", 
       RowBox[{"1390", "\[Rule]", "1373"}], ",", 
       RowBox[{"1390", "\[Rule]", "1391"}], ",", 
       RowBox[{"3010", "\[Rule]", "2993"}], ",", 
       RowBox[{"3010", "\[Rule]", "3011"}], ",", 
       RowBox[{"2578", "\[Rule]", "2561"}], ",", 
       RowBox[{"2578", "\[Rule]", "2579"}], ",", 
       RowBox[{"2902", "\[Rule]", "2885"}], ",", 
       RowBox[{"2902", "\[Rule]", "2903"}], ",", 
       RowBox[{"2470", "\[Rule]", "2453"}], ",", 
       RowBox[{"2470", "\[Rule]", "2471"}], ",", 
       RowBox[{"2794", "\[Rule]", "2777"}], ",", 
       RowBox[{"2794", "\[Rule]", "2795"}], ",", 
       RowBox[{"2362", "\[Rule]", "2345"}], ",", 
       RowBox[{"2362", "\[Rule]", "2363"}], ",", 
       RowBox[{"2686", "\[Rule]", "2669"}], ",", 
       RowBox[{"2686", "\[Rule]", "2687"}], ",", 
       RowBox[{"2254", "\[Rule]", "2237"}], ",", 
       RowBox[{"2254", "\[Rule]", "2255"}], ",", 
       RowBox[{"771", "\[Rule]", "340"}], ",", 
       RowBox[{"771", "\[Rule]", "1204"}], ",", 
       RowBox[{"771", "\[Rule]", "1204"}], ",", 
       RowBox[{"771", "\[Rule]", "772"}], ",", 
       RowBox[{"801", "\[Rule]", "370"}], ",", 
       RowBox[{"801", "\[Rule]", "370"}], ",", 
       RowBox[{"801", "\[Rule]", "1234"}], ",", 
       RowBox[{"801", "\[Rule]", "802"}], ",", 
       RowBox[{"783", "\[Rule]", "352"}], ",", 
       RowBox[{"783", "\[Rule]", "1216"}], ",", 
       RowBox[{"783", "\[Rule]", "784"}], ",", 
       RowBox[{"335", "\[Rule]", "768"}], ",", 
       RowBox[{"335", "\[Rule]", "768"}], ",", 
       RowBox[{"335", "\[Rule]", "660"}], ",", 
       RowBox[{"335", "\[Rule]", "336"}], ",", 
       RowBox[{"1199", "\[Rule]", "768"}], ",", 
       RowBox[{"1199", "\[Rule]", "768"}], ",", 
       RowBox[{"1199", "\[Rule]", "1632"}], ",", 
       RowBox[{"1199", "\[Rule]", "1632"}], ",", 
       RowBox[{"1199", "\[Rule]", "660"}], ",", 
       RowBox[{"1199", "\[Rule]", "660"}], ",", 
       RowBox[{"1199", "\[Rule]", "1524"}], ",", 
       RowBox[{"1199", "\[Rule]", "1524"}], ",", 
       RowBox[{"1199", "\[Rule]", "1200"}], ",", 
       RowBox[{"767", "\[Rule]", "336"}], ",", 
       RowBox[{"767", "\[Rule]", "336"}], ",", 
       RowBox[{"767", "\[Rule]", "1200"}], ",", 
       RowBox[{"767", "\[Rule]", "1200"}], ",", 
       RowBox[{"767", "\[Rule]", "768"}], ",", 
       RowBox[{"227", "\[Rule]", "660"}], ",", 
       RowBox[{"227", "\[Rule]", "552"}], ",", 
       RowBox[{"227", "\[Rule]", "552"}], ",", 
       RowBox[{"227", "\[Rule]", "228"}], ",", 
       RowBox[{"1091", "\[Rule]", "660"}], ",", 
       RowBox[{"1091", "\[Rule]", "660"}], ",", 
       RowBox[{"1091", "\[Rule]", "1524"}], ",", 
       RowBox[{"1091", "\[Rule]", "1524"}], ",", 
       RowBox[{"1091", "\[Rule]", "552"}], ",", 
       RowBox[{"1091", "\[Rule]", "552"}], ",", 
       RowBox[{"1091", "\[Rule]", "1416"}], ",", 
       RowBox[{"1091", "\[Rule]", "1416"}], ",", 
       RowBox[{"1091", "\[Rule]", "1092"}], ",", 
       RowBox[{"659", "\[Rule]", "336"}], ",", 
       RowBox[{"659", "\[Rule]", "1200"}], ",", 
       RowBox[{"659", "\[Rule]", "1200"}], ",", 
       RowBox[{"659", "\[Rule]", "228"}], ",", 
       RowBox[{"659", "\[Rule]", "1092"}], ",", 
       RowBox[{"659", "\[Rule]", "1092"}], ",", 
       RowBox[{"659", "\[Rule]", "660"}], ",", 
       RowBox[{"831", "\[Rule]", "400"}], ",", 
       RowBox[{"831", "\[Rule]", "400"}], ",", 
       RowBox[{"831", "\[Rule]", "1264"}], ",", 
       RowBox[{"831", "\[Rule]", "1264"}], ",", 
       RowBox[{"831", "\[Rule]", "832"}], ",", 
       RowBox[{"813", "\[Rule]", "382"}], ",", 
       RowBox[{"813", "\[Rule]", "382"}], ",", 
       RowBox[{"813", "\[Rule]", "1246"}], ",", 
       RowBox[{"813", "\[Rule]", "1246"}], ",", 
       RowBox[{"813", "\[Rule]", "814"}], ",", 
       RowBox[{"797", "\[Rule]", "366"}], ",", 
       RowBox[{"797", "\[Rule]", "366"}], ",", 
       RowBox[{"797", "\[Rule]", "1230"}], ",", 
       RowBox[{"797", "\[Rule]", "1230"}], ",", 
       RowBox[{"797", "\[Rule]", "798"}], ",", 
       RowBox[{"347", "\[Rule]", "780"}], ",", 
       RowBox[{"347", "\[Rule]", "780"}], ",", 
       RowBox[{"347", "\[Rule]", "672"}], ",", 
       RowBox[{"347", "\[Rule]", "672"}], ",", 
       RowBox[{"347", "\[Rule]", "348"}], ",", 
       RowBox[{"1211", "\[Rule]", "780"}], ",", 
       RowBox[{"1211", "\[Rule]", "780"}], ",", 
       RowBox[{"1211", "\[Rule]", "1644"}], ",", 
       RowBox[{"1211", "\[Rule]", "1644"}], ",", 
       RowBox[{"1211", "\[Rule]", "672"}], ",", 
       RowBox[{"1211", "\[Rule]", "672"}], ",", 
       RowBox[{"1211", "\[Rule]", "1536"}], ",", 
       RowBox[{"1211", "\[Rule]", "1536"}], ",", 
       RowBox[{"1211", "\[Rule]", "1212"}], ",", 
       RowBox[{"779", "\[Rule]", "348"}], ",", 
       RowBox[{"779", "\[Rule]", "348"}], ",", 
       RowBox[{"779", "\[Rule]", "1212"}], ",", 
       RowBox[{"779", "\[Rule]", "1212"}], ",", 
       RowBox[{"779", "\[Rule]", "780"}], ",", 
       RowBox[{"239", "\[Rule]", "672"}], ",", 
       RowBox[{"239", "\[Rule]", "564"}], ",", 
       RowBox[{"239", "\[Rule]", "240"}], ",", 
       RowBox[{"1103", "\[Rule]", "672"}], ",", 
       RowBox[{"1103", "\[Rule]", "1536"}], ",", 
       RowBox[{"1103", "\[Rule]", "1536"}], ",", 
       RowBox[{"1103", "\[Rule]", "564"}], ",", 
       RowBox[{"1103", "\[Rule]", "1428"}], ",", 
       RowBox[{"1103", "\[Rule]", "1428"}], ",", 
       RowBox[{"1103", "\[Rule]", "1104"}], ",", 
       RowBox[{"671", "\[Rule]", "348"}], ",", 
       RowBox[{"671", "\[Rule]", "348"}], ",", 
       RowBox[{"671", "\[Rule]", "1212"}], ",", 
       RowBox[{"671", "\[Rule]", "1212"}], ",", 
       RowBox[{"671", "\[Rule]", "240"}], ",", 
       RowBox[{"671", "\[Rule]", "1104"}], ",", 
       RowBox[{"671", "\[Rule]", "672"}], ",", 
       RowBox[{"1635", "\[Rule]", "1204"}], ",", 
       RowBox[{"1635", "\[Rule]", "1204"}], ",", 
       RowBox[{"1635", "\[Rule]", "2068"}], ",", 
       RowBox[{"1635", "\[Rule]", "2068"}], ",", 
       RowBox[{"1635", "\[Rule]", "1636"}], ",", 
       RowBox[{"1665", "\[Rule]", "1234"}], ",", 
       RowBox[{"1665", "\[Rule]", "2098"}], ",", 
       RowBox[{"1665", "\[Rule]", "2098"}], ",", 
       RowBox[{"1665", "\[Rule]", "1666"}], ",", 
       RowBox[{"1647", "\[Rule]", "1216"}], ",", 
       RowBox[{"1647", "\[Rule]", "1216"}], ",", 
       RowBox[{"1647", "\[Rule]", "2080"}], ",", 
       RowBox[{"1647", "\[Rule]", "2080"}], ",", 
       RowBox[{"1647", "\[Rule]", "1648"}], ",", 
       RowBox[{"2063", "\[Rule]", "1632"}], ",", 
       RowBox[{"2063", "\[Rule]", "1632"}], ",", 
       RowBox[{"2063", "\[Rule]", "2496"}], ",", 
       RowBox[{"2063", "\[Rule]", "2496"}], ",", 
       RowBox[{"2063", "\[Rule]", "1524"}], ",", 
       RowBox[{"2063", "\[Rule]", "1524"}], ",", 
       RowBox[{"2063", "\[Rule]", "2388"}], ",", 
       RowBox[{"2063", "\[Rule]", "2388"}], ",", 
       RowBox[{"2063", "\[Rule]", "2064"}], ",", 
       RowBox[{"1631", "\[Rule]", "1200"}], ",", 
       RowBox[{"1631", "\[Rule]", "1200"}], ",", 
       RowBox[{"1631", "\[Rule]", "2064"}], ",", 
       RowBox[{"1631", "\[Rule]", "2064"}], ",", 
       RowBox[{"1631", "\[Rule]", "1632"}], ",", 
       RowBox[{"1955", "\[Rule]", "1524"}], ",", 
       RowBox[{"1955", "\[Rule]", "1524"}], ",", 
       RowBox[{"1955", "\[Rule]", "2388"}], ",", 
       RowBox[{"1955", "\[Rule]", "2388"}], ",", 
       RowBox[{"1955", "\[Rule]", "1416"}], ",", 
       RowBox[{"1955", "\[Rule]", "1416"}], ",", 
       RowBox[{"1955", "\[Rule]", "2280"}], ",", 
       RowBox[{"1955", "\[Rule]", "2280"}], ",", 
       RowBox[{"1955", "\[Rule]", "1956"}], ",", 
       RowBox[{"1523", "\[Rule]", "1200"}], ",", 
       RowBox[{"1523", "\[Rule]", "1200"}], ",", 
       RowBox[{"1523", "\[Rule]", "2064"}], ",", 
       RowBox[{"1523", "\[Rule]", "2064"}], ",", 
       RowBox[{"1523", "\[Rule]", "1092"}], ",", 
       RowBox[{"1523", "\[Rule]", "1092"}], ",", 
       RowBox[{"1523", "\[Rule]", "1956"}], ",", 
       RowBox[{"1523", "\[Rule]", "1956"}], ",", 
       RowBox[{"1523", "\[Rule]", "1524"}], ",", 
       RowBox[{"1695", "\[Rule]", "1264"}], ",", 
       RowBox[{"1695", "\[Rule]", "1264"}], ",", 
       RowBox[{"1695", "\[Rule]", "2128"}], ",", 
       RowBox[{"1695", "\[Rule]", "1696"}], ",", 
       RowBox[{"1677", "\[Rule]", "1246"}], ",", 
       RowBox[{"1677", "\[Rule]", "2110"}], ",", 
       RowBox[{"1677", "\[Rule]", "1678"}], ",", 
       RowBox[{"1661", "\[Rule]", "1230"}], ",", 
       RowBox[{"1661", "\[Rule]", "1230"}], ",", 
       RowBox[{"1661", "\[Rule]", "2094"}], ",", 
       RowBox[{"1661", "\[Rule]", "2094"}], ",", 
       RowBox[{"1661", "\[Rule]", "1662"}], ",", 
       RowBox[{"2075", "\[Rule]", "1644"}], ",", 
       RowBox[{"2075", "\[Rule]", "1644"}], ",", 
       RowBox[{"2075", "\[Rule]", "2508"}], ",", 
       RowBox[{"2075", "\[Rule]", "2508"}], ",", 
       RowBox[{"2075", "\[Rule]", "1536"}], ",", 
       RowBox[{"2075", "\[Rule]", "1536"}], ",", 
       RowBox[{"2075", "\[Rule]", "2400"}], ",", 
       RowBox[{"2075", "\[Rule]", "2400"}], ",", 
       RowBox[{"2075", "\[Rule]", "2076"}], ",", 
       RowBox[{"1643", "\[Rule]", "1212"}], ",", 
       RowBox[{"1643", "\[Rule]", "1212"}], ",", 
       RowBox[{"1643", "\[Rule]", "2076"}], ",", 
       RowBox[{"1643", "\[Rule]", "2076"}], ",", 
       RowBox[{"1643", "\[Rule]", "1644"}], ",", 
       RowBox[{"1967", "\[Rule]", "1536"}], ",", 
       RowBox[{"1967", "\[Rule]", "1536"}], ",", 
       RowBox[{"1967", "\[Rule]", "2400"}], ",", 
       RowBox[{"1967", "\[Rule]", "2400"}], ",", 
       RowBox[{"1967", "\[Rule]", "1428"}], ",", 
       RowBox[{"1967", "\[Rule]", "1428"}], ",", 
       RowBox[{"1967", "\[Rule]", "2292"}], ",", 
       RowBox[{"1967", "\[Rule]", "2292"}], ",", 
       RowBox[{"1967", "\[Rule]", "1968"}], ",", 
       RowBox[{"1535", "\[Rule]", "1212"}], ",", 
       RowBox[{"1535", "\[Rule]", "1212"}], ",", 
       RowBox[{"1535", "\[Rule]", "2076"}], ",", 
       RowBox[{"1535", "\[Rule]", "2076"}], ",", 
       RowBox[{"1535", "\[Rule]", "1104"}], ",", 
       RowBox[{"1535", "\[Rule]", "1104"}], ",", 
       RowBox[{"1535", "\[Rule]", "1968"}], ",", 
       RowBox[{"1535", "\[Rule]", "1968"}], ",", 
       RowBox[{"1535", "\[Rule]", "1536"}], ",", 
       RowBox[{"119", "\[Rule]", "552"}], ",", 
       RowBox[{"119", "\[Rule]", "444"}], ",", 
       RowBox[{"119", "\[Rule]", "120"}], ",", 
       RowBox[{"983", "\[Rule]", "552"}], ",", 
       RowBox[{"983", "\[Rule]", "1416"}], ",", 
       RowBox[{"983", "\[Rule]", "1416"}], ",", 
       RowBox[{"983", "\[Rule]", "444"}], ",", 
       RowBox[{"983", "\[Rule]", "1308"}], ",", 
       RowBox[{"983", "\[Rule]", "1308"}], ",", 
       RowBox[{"983", "\[Rule]", "984"}], ",", 
       RowBox[{"551", "\[Rule]", "228"}], ",", 
       RowBox[{"551", "\[Rule]", "228"}], ",", 
       RowBox[{"551", "\[Rule]", "1092"}], ",", 
       RowBox[{"551", "\[Rule]", "1092"}], ",", 
       RowBox[{"551", "\[Rule]", "120"}], ",", 
       RowBox[{"551", "\[Rule]", "984"}], ",", 
       RowBox[{"551", "\[Rule]", "552"}], ",", 
       RowBox[{"131", "\[Rule]", "564"}], ",", 
       RowBox[{"131", "\[Rule]", "456"}], ",", 
       RowBox[{"131", "\[Rule]", "132"}], ",", 
       RowBox[{"995", "\[Rule]", "564"}], ",", 
       RowBox[{"995", "\[Rule]", "1428"}], ",", 
       RowBox[{"995", "\[Rule]", "1428"}], ",", 
       RowBox[{"995", "\[Rule]", "456"}], ",", 
       RowBox[{"995", "\[Rule]", "1320"}], ",", 
       RowBox[{"995", "\[Rule]", "1320"}], ",", 
       RowBox[{"995", "\[Rule]", "996"}], ",", 
       RowBox[{"563", "\[Rule]", "240"}], ",", 
       RowBox[{"563", "\[Rule]", "1104"}], ",", 
       RowBox[{"563", "\[Rule]", "132"}], ",", 
       RowBox[{"563", "\[Rule]", "996"}], ",", 
       RowBox[{"563", "\[Rule]", "564"}], ",", 
       RowBox[{"1847", "\[Rule]", "1416"}], ",", 
       RowBox[{"1847", "\[Rule]", "1416"}], ",", 
       RowBox[{"1847", "\[Rule]", "2280"}], ",", 
       RowBox[{"1847", "\[Rule]", "2280"}], ",", 
       RowBox[{"1847", "\[Rule]", "1308"}], ",", 
       RowBox[{"1847", "\[Rule]", "1308"}], ",", 
       RowBox[{"1847", "\[Rule]", "2172"}], ",", 
       RowBox[{"1847", "\[Rule]", "2172"}], ",", 
       RowBox[{"1847", "\[Rule]", "1848"}], ",", 
       RowBox[{"1415", "\[Rule]", "1092"}], ",", 
       RowBox[{"1415", "\[Rule]", "1092"}], ",", 
       RowBox[{"1415", "\[Rule]", "1956"}], ",", 
       RowBox[{"1415", "\[Rule]", "1956"}], ",", 
       RowBox[{"1415", "\[Rule]", "984"}], ",", 
       RowBox[{"1415", "\[Rule]", "984"}], ",", 
       RowBox[{"1415", "\[Rule]", "1848"}], ",", 
       RowBox[{"1415", "\[Rule]", "1848"}], ",", 
       RowBox[{"1415", "\[Rule]", "1416"}], ",", 
       RowBox[{"1859", "\[Rule]", "1428"}], ",", 
       RowBox[{"1859", "\[Rule]", "1428"}], ",", 
       RowBox[{"1859", "\[Rule]", "2292"}], ",", 
       RowBox[{"1859", "\[Rule]", "2292"}], ",", 
       RowBox[{"1859", "\[Rule]", "1320"}], ",", 
       RowBox[{"1859", "\[Rule]", "1320"}], ",", 
       RowBox[{"1859", "\[Rule]", "2184"}], ",", 
       RowBox[{"1859", "\[Rule]", "2184"}], ",", 
       RowBox[{"1859", "\[Rule]", "1860"}], ",", 
       RowBox[{"1427", "\[Rule]", "1104"}], ",", 
       RowBox[{"1427", "\[Rule]", "1104"}], ",", 
       RowBox[{"1427", "\[Rule]", "1968"}], ",", 
       RowBox[{"1427", "\[Rule]", "1968"}], ",", 
       RowBox[{"1427", "\[Rule]", "996"}], ",", 
       RowBox[{"1427", "\[Rule]", "996"}], ",", 
       RowBox[{"1427", "\[Rule]", "1860"}], ",", 
       RowBox[{"1427", "\[Rule]", "1860"}], ",", 
       RowBox[{"1427", "\[Rule]", "1428"}], ",", 
       RowBox[{"863", "\[Rule]", "432"}], ",", 
       RowBox[{"863", "\[Rule]", "432"}], ",", 
       RowBox[{"863", "\[Rule]", "1296"}], ",", 
       RowBox[{"863", "\[Rule]", "1296"}], ",", 
       RowBox[{"863", "\[Rule]", "864"}], ",", 
       RowBox[{"845", "\[Rule]", "414"}], ",", 
       RowBox[{"845", "\[Rule]", "414"}], ",", 
       RowBox[{"845", "\[Rule]", "1278"}], ",", 
       RowBox[{"845", "\[Rule]", "1278"}], ",", 
       RowBox[{"845", "\[Rule]", "846"}], ",", 
       RowBox[{"827", "\[Rule]", "396"}], ",", 
       RowBox[{"827", "\[Rule]", "396"}], ",", 
       RowBox[{"827", "\[Rule]", "1260"}], ",", 
       RowBox[{"827", "\[Rule]", "1260"}], ",", 
       RowBox[{"827", "\[Rule]", "828"}], ",", 
       RowBox[{"809", "\[Rule]", "378"}], ",", 
       RowBox[{"809", "\[Rule]", "378"}], ",", 
       RowBox[{"809", "\[Rule]", "1242"}], ",", 
       RowBox[{"809", "\[Rule]", "1242"}], ",", 
       RowBox[{"809", "\[Rule]", "810"}], ",", 
       RowBox[{"1727", "\[Rule]", "1296"}], ",", 
       RowBox[{"1727", "\[Rule]", "1296"}], ",", 
       RowBox[{"1727", "\[Rule]", "2160"}], ",", 
       RowBox[{"1727", "\[Rule]", "2160"}], ",", 
       RowBox[{"1727", "\[Rule]", "1728"}], ",", 
       RowBox[{"1709", "\[Rule]", "1278"}], ",", 
       RowBox[{"1709", "\[Rule]", "1278"}], ",", 
       RowBox[{"1709", "\[Rule]", "2142"}], ",", 
       RowBox[{"1709", "\[Rule]", "2142"}], ",", 
       RowBox[{"1709", "\[Rule]", "1710"}], ",", 
       RowBox[{"1691", "\[Rule]", "1260"}], ",", 
       RowBox[{"1691", "\[Rule]", "1260"}], ",", 
       RowBox[{"1691", "\[Rule]", "2124"}], ",", 
       RowBox[{"1691", "\[Rule]", "2124"}], ",", 
       RowBox[{"1691", "\[Rule]", "1692"}], ",", 
       RowBox[{"1673", "\[Rule]", "1242"}], ",", 
       RowBox[{"1673", "\[Rule]", "1242"}], ",", 
       RowBox[{"1673", "\[Rule]", "2106"}], ",", 
       RowBox[{"1673", "\[Rule]", "2106"}], ",", 
       RowBox[{"1673", "\[Rule]", "1674"}], ",", 
       RowBox[{"361", "\[Rule]", "794"}], ",", 
       RowBox[{"361", "\[Rule]", "794"}], ",", 
       RowBox[{"361", "\[Rule]", "686"}], ",", 
       RowBox[{"361", "\[Rule]", "686"}], ",", 
       RowBox[{"361", "\[Rule]", "362"}], ",", 
       RowBox[{"1225", "\[Rule]", "794"}], ",", 
       RowBox[{"1225", "\[Rule]", "794"}], ",", 
       RowBox[{"1225", "\[Rule]", "1658"}], ",", 
       RowBox[{"1225", "\[Rule]", "1658"}], ",", 
       RowBox[{"1225", "\[Rule]", "686"}], ",", 
       RowBox[{"1225", "\[Rule]", "686"}], ",", 
       RowBox[{"1225", "\[Rule]", "1550"}], ",", 
       RowBox[{"1225", "\[Rule]", "1550"}], ",", 
       RowBox[{"1225", "\[Rule]", "1226"}], ",", 
       RowBox[{"793", "\[Rule]", "362"}], ",", 
       RowBox[{"793", "\[Rule]", "362"}], ",", 
       RowBox[{"793", "\[Rule]", "1226"}], ",", 
       RowBox[{"793", "\[Rule]", "1226"}], ",", 
       RowBox[{"793", "\[Rule]", "794"}], ",", 
       RowBox[{"253", "\[Rule]", "686"}], ",", 
       RowBox[{"253", "\[Rule]", "686"}], ",", 
       RowBox[{"253", "\[Rule]", "578"}], ",", 
       RowBox[{"253", "\[Rule]", "578"}], ",", 
       RowBox[{"253", "\[Rule]", "254"}], ",", 
       RowBox[{"1117", "\[Rule]", "686"}], ",", 
       RowBox[{"1117", "\[Rule]", "686"}], ",", 
       RowBox[{"1117", "\[Rule]", "1550"}], ",", 
       RowBox[{"1117", "\[Rule]", "1550"}], ",", 
       RowBox[{"1117", "\[Rule]", "578"}], ",", 
       RowBox[{"1117", "\[Rule]", "1442"}], ",", 
       RowBox[{"1117", "\[Rule]", "1118"}], ",", 
       RowBox[{"685", "\[Rule]", "362"}], ",", 
       RowBox[{"685", "\[Rule]", "362"}], ",", 
       RowBox[{"685", "\[Rule]", "1226"}], ",", 
       RowBox[{"685", "\[Rule]", "1226"}], ",", 
       RowBox[{"685", "\[Rule]", "254"}], ",", 
       RowBox[{"685", "\[Rule]", "254"}], ",", 
       RowBox[{"685", "\[Rule]", "1118"}], ",", 
       RowBox[{"685", "\[Rule]", "1118"}], ",", 
       RowBox[{"685", "\[Rule]", "686"}], ",", 
       RowBox[{"2089", "\[Rule]", "1658"}], ",", 
       RowBox[{"2089", "\[Rule]", "1658"}], ",", 
       RowBox[{"2089", "\[Rule]", "2522"}], ",", 
       RowBox[{"2089", "\[Rule]", "2522"}], ",", 
       RowBox[{"2089", "\[Rule]", "1550"}], ",", 
       RowBox[{"2089", "\[Rule]", "1550"}], ",", 
       RowBox[{"2089", "\[Rule]", "2414"}], ",", 
       RowBox[{"2089", "\[Rule]", "2414"}], ",", 
       RowBox[{"2089", "\[Rule]", "2090"}], ",", 
       RowBox[{"1657", "\[Rule]", "1226"}], ",", 
       RowBox[{"1657", "\[Rule]", "1226"}], ",", 
       RowBox[{"1657", "\[Rule]", "2090"}], ",", 
       RowBox[{"1657", "\[Rule]", "2090"}], ",", 
       RowBox[{"1657", "\[Rule]", "1658"}], ",", 
       RowBox[{"1981", "\[Rule]", "1550"}], ",", 
       RowBox[{"1981", "\[Rule]", "1550"}], ",", 
       RowBox[{"1981", "\[Rule]", "2414"}], ",", 
       RowBox[{"1981", "\[Rule]", "2414"}], ",", 
       RowBox[{"1981", "\[Rule]", "1442"}], ",", 
       RowBox[{"1981", "\[Rule]", "1442"}], ",", 
       RowBox[{"1981", "\[Rule]", "2306"}], ",", 
       RowBox[{"1981", "\[Rule]", "2306"}], ",", 
       RowBox[{"1981", "\[Rule]", "1982"}], ",", 
       RowBox[{"1549", "\[Rule]", "1226"}], ",", 
       RowBox[{"1549", "\[Rule]", "1226"}], ",", 
       RowBox[{"1549", "\[Rule]", "2090"}], ",", 
       RowBox[{"1549", "\[Rule]", "2090"}], ",", 
       RowBox[{"1549", "\[Rule]", "1118"}], ",", 
       RowBox[{"1549", "\[Rule]", "1118"}], ",", 
       RowBox[{"1549", "\[Rule]", "1982"}], ",", 
       RowBox[{"1549", "\[Rule]", "1982"}], ",", 
       RowBox[{"1549", "\[Rule]", "1550"}], ",", 
       RowBox[{"145", "\[Rule]", "578"}], ",", 
       RowBox[{"145", "\[Rule]", "470"}], ",", 
       RowBox[{"145", "\[Rule]", "146"}], ",", 
       RowBox[{"1009", "\[Rule]", "1442"}], ",", 
       RowBox[{"1009", "\[Rule]", "470"}], ",", 
       RowBox[{"1009", "\[Rule]", "1334"}], ",", 
       RowBox[{"1009", "\[Rule]", "1334"}], ",", 
       RowBox[{"1009", "\[Rule]", "1010"}], ",", 
       RowBox[{"577", "\[Rule]", "254"}], ",", 
       RowBox[{"577", "\[Rule]", "254"}], ",", 
       RowBox[{"577", "\[Rule]", "1118"}], ",", 
       RowBox[{"577", "\[Rule]", "146"}], ",", 
       RowBox[{"577", "\[Rule]", "578"}], ",", 
       RowBox[{"1873", "\[Rule]", "1442"}], ",", 
       RowBox[{"1873", "\[Rule]", "1442"}], ",", 
       RowBox[{"1873", "\[Rule]", "2306"}], ",", 
       RowBox[{"1873", "\[Rule]", "2306"}], ",", 
       RowBox[{"1873", "\[Rule]", "1334"}], ",", 
       RowBox[{"1873", "\[Rule]", "1334"}], ",", 
       RowBox[{"1873", "\[Rule]", "2198"}], ",", 
       RowBox[{"1873", "\[Rule]", "2198"}], ",", 
       RowBox[{"1873", "\[Rule]", "1874"}], ",", 
       RowBox[{"1441", "\[Rule]", "1118"}], ",", 
       RowBox[{"1441", "\[Rule]", "1982"}], ",", 
       RowBox[{"1441", "\[Rule]", "1982"}], ",", 
       RowBox[{"1441", "\[Rule]", "1010"}], ",", 
       RowBox[{"1441", "\[Rule]", "1874"}], ",", 
       RowBox[{"1441", "\[Rule]", "1874"}], ",", 
       RowBox[{"1441", "\[Rule]", "1442"}], ",", 
       RowBox[{"11", "\[Rule]", "444"}], ",", 
       RowBox[{"11", "\[Rule]", "444"}], ",", 
       RowBox[{"11", "\[Rule]", "12"}], ",", 
       RowBox[{"875", "\[Rule]", "444"}], ",", 
       RowBox[{"875", "\[Rule]", "444"}], ",", 
       RowBox[{"875", "\[Rule]", "1308"}], ",", 
       RowBox[{"875", "\[Rule]", "876"}], ",", 
       RowBox[{"443", "\[Rule]", "120"}], ",", 
       RowBox[{"443", "\[Rule]", "984"}], ",", 
       RowBox[{"443", "\[Rule]", "12"}], ",", 
       RowBox[{"443", "\[Rule]", "12"}], ",", 
       RowBox[{"443", "\[Rule]", "876"}], ",", 
       RowBox[{"443", "\[Rule]", "876"}], ",", 
       RowBox[{"443", "\[Rule]", "444"}], ",", 
       RowBox[{"23", "\[Rule]", "456"}], ",", 
       RowBox[{"23", "\[Rule]", "456"}], ",", 
       RowBox[{"23", "\[Rule]", "24"}], ",", 
       RowBox[{"887", "\[Rule]", "456"}], ",", 
       RowBox[{"887", "\[Rule]", "456"}], ",", 
       RowBox[{"887", "\[Rule]", "1320"}], ",", 
       RowBox[{"887", "\[Rule]", "888"}], ",", 
       RowBox[{"455", "\[Rule]", "132"}], ",", 
       RowBox[{"455", "\[Rule]", "996"}], ",", 
       RowBox[{"455", "\[Rule]", "24"}], ",", 
       RowBox[{"455", "\[Rule]", "24"}], ",", 
       RowBox[{"455", "\[Rule]", "888"}], ",", 
       RowBox[{"455", "\[Rule]", "888"}], ",", 
       RowBox[{"455", "\[Rule]", "456"}], ",", 
       RowBox[{"1739", "\[Rule]", "1308"}], ",", 
       RowBox[{"1739", "\[Rule]", "2172"}], ",", 
       RowBox[{"1739", "\[Rule]", "2172"}], ",", 
       RowBox[{"1739", "\[Rule]", "1740"}], ",", 
       RowBox[{"1307", "\[Rule]", "984"}], ",", 
       RowBox[{"1307", "\[Rule]", "984"}], ",", 
       RowBox[{"1307", "\[Rule]", "1848"}], ",", 
       RowBox[{"1307", "\[Rule]", "1848"}], ",", 
       RowBox[{"1307", "\[Rule]", "876"}], ",", 
       RowBox[{"1307", "\[Rule]", "1740"}], ",", 
       RowBox[{"1307", "\[Rule]", "1308"}], ",", 
       RowBox[{"1751", "\[Rule]", "1320"}], ",", 
       RowBox[{"1751", "\[Rule]", "2184"}], ",", 
       RowBox[{"1751", "\[Rule]", "2184"}], ",", 
       RowBox[{"1751", "\[Rule]", "1752"}], ",", 
       RowBox[{"1319", "\[Rule]", "996"}], ",", 
       RowBox[{"1319", "\[Rule]", "996"}], ",", 
       RowBox[{"1319", "\[Rule]", "1860"}], ",", 
       RowBox[{"1319", "\[Rule]", "1860"}], ",", 
       RowBox[{"1319", "\[Rule]", "888"}], ",", 
       RowBox[{"1319", "\[Rule]", "1752"}], ",", 
       RowBox[{"1319", "\[Rule]", "1320"}], ",", 
       RowBox[{"37", "\[Rule]", "470"}], ",", 
       RowBox[{"37", "\[Rule]", "470"}], ",", 
       RowBox[{"37", "\[Rule]", "38"}], ",", 
       RowBox[{"901", "\[Rule]", "470"}], ",", 
       RowBox[{"901", "\[Rule]", "470"}], ",", 
       RowBox[{"901", "\[Rule]", "1334"}], ",", 
       RowBox[{"901", "\[Rule]", "902"}], ",", 
       RowBox[{"469", "\[Rule]", "146"}], ",", 
       RowBox[{"469", "\[Rule]", "1010"}], ",", 
       RowBox[{"469", "\[Rule]", "38"}], ",", 
       RowBox[{"469", "\[Rule]", "38"}], ",", 
       RowBox[{"469", "\[Rule]", "902"}], ",", 
       RowBox[{"469", "\[Rule]", "902"}], ",", 
       RowBox[{"469", "\[Rule]", "470"}], ",", 
       RowBox[{"1765", "\[Rule]", "1334"}], ",", 
       RowBox[{"1765", "\[Rule]", "2198"}], ",", 
       RowBox[{"1765", "\[Rule]", "2198"}], ",", 
       RowBox[{"1765", "\[Rule]", "1766"}], ",", 
       RowBox[{"1333", "\[Rule]", "1010"}], ",", 
       RowBox[{"1333", "\[Rule]", "1010"}], ",", 
       RowBox[{"1333", "\[Rule]", "1874"}], ",", 
       RowBox[{"1333", "\[Rule]", "1874"}], ",", 
       RowBox[{"1333", "\[Rule]", "902"}], ",", 
       RowBox[{"1333", "\[Rule]", "1766"}], ",", 
       RowBox[{"1333", "\[Rule]", "1334"}], ",", 
       RowBox[{"859", "\[Rule]", "428"}], ",", 
       RowBox[{"859", "\[Rule]", "428"}], ",", 
       RowBox[{"859", "\[Rule]", "1292"}], ",", 
       RowBox[{"859", "\[Rule]", "1292"}], ",", 
       RowBox[{"859", "\[Rule]", "860"}], ",", 
       RowBox[{"841", "\[Rule]", "410"}], ",", 
       RowBox[{"841", "\[Rule]", "410"}], ",", 
       RowBox[{"841", "\[Rule]", "1274"}], ",", 
       RowBox[{"841", "\[Rule]", "1274"}], ",", 
       RowBox[{"841", "\[Rule]", "842"}], ",", 
       RowBox[{"1723", "\[Rule]", "1292"}], ",", 
       RowBox[{"1723", "\[Rule]", "1292"}], ",", 
       RowBox[{"1723", "\[Rule]", "2156"}], ",", 
       RowBox[{"1723", "\[Rule]", "2156"}], ",", 
       RowBox[{"1723", "\[Rule]", "1724"}], ",", 
       RowBox[{"1705", "\[Rule]", "1274"}], ",", 
       RowBox[{"1705", "\[Rule]", "1274"}], ",", 
       RowBox[{"1705", "\[Rule]", "2138"}], ",", 
       RowBox[{"1705", "\[Rule]", "2138"}], ",", 
       RowBox[{"1705", "\[Rule]", "1706"}], ",", 
       RowBox[{"823", "\[Rule]", "392"}], ",", 
       RowBox[{"823", "\[Rule]", "392"}], ",", 
       RowBox[{"823", "\[Rule]", "1256"}], ",", 
       RowBox[{"823", "\[Rule]", "1256"}], ",", 
       RowBox[{"823", "\[Rule]", "824"}], ",", 
       RowBox[{"1687", "\[Rule]", "1256"}], ",", 
       RowBox[{"1687", "\[Rule]", "1256"}], ",", 
       RowBox[{"1687", "\[Rule]", "2120"}], ",", 
       RowBox[{"1687", "\[Rule]", "2120"}], ",", 
       RowBox[{"1687", "\[Rule]", "1688"}], ",", 
       RowBox[{"373", "\[Rule]", "806"}], ",", 
       RowBox[{"373", "\[Rule]", "806"}], ",", 
       RowBox[{"373", "\[Rule]", "698"}], ",", 
       RowBox[{"373", "\[Rule]", "698"}], ",", 
       RowBox[{"373", "\[Rule]", "374"}], ",", 
       RowBox[{"1237", "\[Rule]", "806"}], ",", 
       RowBox[{"1237", "\[Rule]", "806"}], ",", 
       RowBox[{"1237", "\[Rule]", "1670"}], ",", 
       RowBox[{"1237", "\[Rule]", "1670"}], ",", 
       RowBox[{"1237", "\[Rule]", "698"}], ",", 
       RowBox[{"1237", "\[Rule]", "698"}], ",", 
       RowBox[{"1237", "\[Rule]", "1562"}], ",", 
       RowBox[{"1237", "\[Rule]", "1562"}], ",", 
       RowBox[{"1237", "\[Rule]", "1238"}], ",", 
       RowBox[{"805", "\[Rule]", "374"}], ",", 
       RowBox[{"805", "\[Rule]", "374"}], ",", 
       RowBox[{"805", "\[Rule]", "1238"}], ",", 
       RowBox[{"805", "\[Rule]", "1238"}], ",", 
       RowBox[{"805", "\[Rule]", "806"}], ",", 
       RowBox[{"265", "\[Rule]", "698"}], ",", 
       RowBox[{"265", "\[Rule]", "698"}], ",", 
       RowBox[{"265", "\[Rule]", "590"}], ",", 
       RowBox[{"265", "\[Rule]", "590"}], ",", 
       RowBox[{"265", "\[Rule]", "266"}], ",", 
       RowBox[{"1129", "\[Rule]", "698"}], ",", 
       RowBox[{"1129", "\[Rule]", "698"}], ",", 
       RowBox[{"1129", "\[Rule]", "1562"}], ",", 
       RowBox[{"1129", "\[Rule]", "1562"}], ",", 
       RowBox[{"1129", "\[Rule]", "590"}], ",", 
       RowBox[{"1129", "\[Rule]", "590"}], ",", 
       RowBox[{"1129", "\[Rule]", "1454"}], ",", 
       RowBox[{"1129", "\[Rule]", "1454"}], ",", 
       RowBox[{"1129", "\[Rule]", "1130"}], ",", 
       RowBox[{"697", "\[Rule]", "374"}], ",", 
       RowBox[{"697", "\[Rule]", "374"}], ",", 
       RowBox[{"697", "\[Rule]", "1238"}], ",", 
       RowBox[{"697", "\[Rule]", "1238"}], ",", 
       RowBox[{"697", "\[Rule]", "266"}], ",", 
       RowBox[{"697", "\[Rule]", "266"}], ",", 
       RowBox[{"697", "\[Rule]", "1130"}], ",", 
       RowBox[{"697", "\[Rule]", "1130"}], ",", 
       RowBox[{"697", "\[Rule]", "698"}], ",", 
       RowBox[{"2101", "\[Rule]", "1670"}], ",", 
       RowBox[{"2101", "\[Rule]", "1670"}], ",", 
       RowBox[{"2101", "\[Rule]", "2534"}], ",", 
       RowBox[{"2101", "\[Rule]", "2534"}], ",", 
       RowBox[{"2101", "\[Rule]", "1562"}], ",", 
       RowBox[{"2101", "\[Rule]", "1562"}], ",", 
       RowBox[{"2101", "\[Rule]", "2426"}], ",", 
       RowBox[{"2101", "\[Rule]", "2426"}], ",", 
       RowBox[{"2101", "\[Rule]", "2102"}], ",", 
       RowBox[{"1669", "\[Rule]", "1238"}], ",", 
       RowBox[{"1669", "\[Rule]", "1238"}], ",", 
       RowBox[{"1669", "\[Rule]", "2102"}], ",", 
       RowBox[{"1669", "\[Rule]", "2102"}], ",", 
       RowBox[{"1669", "\[Rule]", "1670"}], ",", 
       RowBox[{"1993", "\[Rule]", "1562"}], ",", 
       RowBox[{"1993", "\[Rule]", "1562"}], ",", 
       RowBox[{"1993", "\[Rule]", "2426"}], ",", 
       RowBox[{"1993", "\[Rule]", "2426"}], ",", 
       RowBox[{"1993", "\[Rule]", "1454"}], ",", 
       RowBox[{"1993", "\[Rule]", "1454"}], ",", 
       RowBox[{"1993", "\[Rule]", "2318"}], ",", 
       RowBox[{"1993", "\[Rule]", "2318"}], ",", 
       RowBox[{"1993", "\[Rule]", "1994"}], ",", 
       RowBox[{"1561", "\[Rule]", "1238"}], ",", 
       RowBox[{"1561", "\[Rule]", "1238"}], ",", 
       RowBox[{"1561", "\[Rule]", "2102"}], ",", 
       RowBox[{"1561", "\[Rule]", "2102"}], ",", 
       RowBox[{"1561", "\[Rule]", "1130"}], ",", 
       RowBox[{"1561", "\[Rule]", "1130"}], ",", 
       RowBox[{"1561", "\[Rule]", "1994"}], ",", 
       RowBox[{"1561", "\[Rule]", "1994"}], ",", 
       RowBox[{"1561", "\[Rule]", "1562"}], ",", 
       RowBox[{"157", "\[Rule]", "590"}], ",", 
       RowBox[{"157", "\[Rule]", "482"}], ",", 
       RowBox[{"157", "\[Rule]", "158"}], ",", 
       RowBox[{"1021", "\[Rule]", "590"}], ",", 
       RowBox[{"1021", "\[Rule]", "1454"}], ",", 
       RowBox[{"1021", "\[Rule]", "482"}], ",", 
       RowBox[{"1021", "\[Rule]", "1346"}], ",", 
       RowBox[{"1021", "\[Rule]", "1022"}], ",", 
       RowBox[{"589", "\[Rule]", "266"}], ",", 
       RowBox[{"589", "\[Rule]", "266"}], ",", 
       RowBox[{"589", "\[Rule]", "1130"}], ",", 
       RowBox[{"589", "\[Rule]", "1130"}], ",", 
       RowBox[{"589", "\[Rule]", "158"}], ",", 
       RowBox[{"589", "\[Rule]", "1022"}], ",", 
       RowBox[{"589", "\[Rule]", "590"}], ",", 
       RowBox[{"1885", "\[Rule]", "1454"}], ",", 
       RowBox[{"1885", "\[Rule]", "2318"}], ",", 
       RowBox[{"1885", "\[Rule]", "2318"}], ",", 
       RowBox[{"1885", "\[Rule]", "1346"}], ",", 
       RowBox[{"1885", "\[Rule]", "2210"}], ",", 
       RowBox[{"1885", "\[Rule]", "2210"}], ",", 
       RowBox[{"1885", "\[Rule]", "1886"}], ",", 
       RowBox[{"1453", "\[Rule]", "1130"}], ",", 
       RowBox[{"1453", "\[Rule]", "1130"}], ",", 
       RowBox[{"1453", "\[Rule]", "1994"}], ",", 
       RowBox[{"1453", "\[Rule]", "1994"}], ",", 
       RowBox[{"1453", "\[Rule]", "1022"}], ",", 
       RowBox[{"1453", "\[Rule]", "1886"}], ",", 
       RowBox[{"1453", "\[Rule]", "1454"}], ",", 
       RowBox[{"49", "\[Rule]", "482"}], ",", 
       RowBox[{"49", "\[Rule]", "482"}], ",", 
       RowBox[{"49", "\[Rule]", "50"}], ",", 
       RowBox[{"913", "\[Rule]", "482"}], ",", 
       RowBox[{"913", "\[Rule]", "482"}], ",", 
       RowBox[{"913", "\[Rule]", "1346"}], ",", 
       RowBox[{"913", "\[Rule]", "914"}], ",", 
       RowBox[{"481", "\[Rule]", "158"}], ",", 
       RowBox[{"481", "\[Rule]", "1022"}], ",", 
       RowBox[{"481", "\[Rule]", "50"}], ",", 
       RowBox[{"481", "\[Rule]", "50"}], ",", 
       RowBox[{"481", "\[Rule]", "914"}], ",", 
       RowBox[{"481", "\[Rule]", "914"}], ",", 
       RowBox[{"481", "\[Rule]", "482"}], ",", 
       RowBox[{"1777", "\[Rule]", "1346"}], ",", 
       RowBox[{"1777", "\[Rule]", "2210"}], ",", 
       RowBox[{"1777", "\[Rule]", "2210"}], ",", 
       RowBox[{"1777", "\[Rule]", "1778"}], ",", 
       RowBox[{"1345", "\[Rule]", "1022"}], ",", 
       RowBox[{"1345", "\[Rule]", "1886"}], ",", 
       RowBox[{"1345", "\[Rule]", "914"}], ",", 
       RowBox[{"1345", "\[Rule]", "1778"}], ",", 
       RowBox[{"1345", "\[Rule]", "1346"}], ",", 
       RowBox[{"2499", "\[Rule]", "2068"}], ",", 
       RowBox[{"2499", "\[Rule]", "2068"}], ",", 
       RowBox[{"2499", "\[Rule]", "2932"}], ",", 
       RowBox[{"2499", "\[Rule]", "2932"}], ",", 
       RowBox[{"2499", "\[Rule]", "2500"}], ",", 
       RowBox[{"2529", "\[Rule]", "2098"}], ",", 
       RowBox[{"2529", "\[Rule]", "2098"}], ",", 
       RowBox[{"2529", "\[Rule]", "2962"}], ",", 
       RowBox[{"2529", "\[Rule]", "2962"}], ",", 
       RowBox[{"2529", "\[Rule]", "2530"}], ",", 
       RowBox[{"2511", "\[Rule]", "2080"}], ",", 
       RowBox[{"2511", "\[Rule]", "2080"}], ",", 
       RowBox[{"2511", "\[Rule]", "2944"}], ",", 
       RowBox[{"2511", "\[Rule]", "2944"}], ",", 
       RowBox[{"2511", "\[Rule]", "2512"}], ",", 
       RowBox[{"2927", "\[Rule]", "2496"}], ",", 
       RowBox[{"2927", "\[Rule]", "2496"}], ",", 
       RowBox[{"2927", "\[Rule]", "2388"}], ",", 
       RowBox[{"2927", "\[Rule]", "2388"}], ",", 
       RowBox[{"2927", "\[Rule]", "2928"}], ",", 
       RowBox[{"2495", "\[Rule]", "2064"}], ",", 
       RowBox[{"2495", "\[Rule]", "2064"}], ",", 
       RowBox[{"2495", "\[Rule]", "2928"}], ",", 
       RowBox[{"2495", "\[Rule]", "2928"}], ",", 
       RowBox[{"2495", "\[Rule]", "2496"}], ",", 
       RowBox[{"2819", "\[Rule]", "2388"}], ",", 
       RowBox[{"2819", "\[Rule]", "2388"}], ",", 
       RowBox[{"2819", "\[Rule]", "2280"}], ",", 
       RowBox[{"2819", "\[Rule]", "2280"}], ",", 
       RowBox[{"2819", "\[Rule]", "2820"}], ",", 
       RowBox[{"2387", "\[Rule]", "2064"}], ",", 
       RowBox[{"2387", "\[Rule]", "2064"}], ",", 
       RowBox[{"2387", "\[Rule]", "2928"}], ",", 
       RowBox[{"2387", "\[Rule]", "2928"}], ",", 
       RowBox[{"2387", "\[Rule]", "1956"}], ",", 
       RowBox[{"2387", "\[Rule]", "1956"}], ",", 
       RowBox[{"2387", "\[Rule]", "2820"}], ",", 
       RowBox[{"2387", "\[Rule]", "2820"}], ",", 
       RowBox[{"2387", "\[Rule]", "2388"}], ",", 
       RowBox[{"2559", "\[Rule]", "2128"}], ",", 
       RowBox[{"2559", "\[Rule]", "2992"}], ",", 
       RowBox[{"2559", "\[Rule]", "2992"}], ",", 
       RowBox[{"2559", "\[Rule]", "2560"}], ",", 
       RowBox[{"2541", "\[Rule]", "2110"}], ",", 
       RowBox[{"2541", "\[Rule]", "2110"}], ",", 
       RowBox[{"2541", "\[Rule]", "2974"}], ",", 
       RowBox[{"2541", "\[Rule]", "2974"}], ",", 
       RowBox[{"2541", "\[Rule]", "2542"}], ",", 
       RowBox[{"2525", "\[Rule]", "2094"}], ",", 
       RowBox[{"2525", "\[Rule]", "2094"}], ",", 
       RowBox[{"2525", "\[Rule]", "2958"}], ",", 
       RowBox[{"2525", "\[Rule]", "2958"}], ",", 
       RowBox[{"2525", "\[Rule]", "2526"}], ",", 
       RowBox[{"2939", "\[Rule]", "2508"}], ",", 
       RowBox[{"2939", "\[Rule]", "2508"}], ",", 
       RowBox[{"2939", "\[Rule]", "2400"}], ",", 
       RowBox[{"2939", "\[Rule]", "2400"}], ",", 
       RowBox[{"2939", "\[Rule]", "2940"}], ",", 
       RowBox[{"2507", "\[Rule]", "2076"}], ",", 
       RowBox[{"2507", "\[Rule]", "2076"}], ",", 
       RowBox[{"2507", "\[Rule]", "2940"}], ",", 
       RowBox[{"2507", "\[Rule]", "2940"}], ",", 
       RowBox[{"2507", "\[Rule]", "2508"}], ",", 
       RowBox[{"2831", "\[Rule]", "2400"}], ",", 
       RowBox[{"2831", "\[Rule]", "2400"}], ",", 
       RowBox[{"2831", "\[Rule]", "2292"}], ",", 
       RowBox[{"2831", "\[Rule]", "2292"}], ",", 
       RowBox[{"2831", "\[Rule]", "2832"}], ",", 
       RowBox[{"2399", "\[Rule]", "2076"}], ",", 
       RowBox[{"2399", "\[Rule]", "2076"}], ",", 
       RowBox[{"2399", "\[Rule]", "2940"}], ",", 
       RowBox[{"2399", "\[Rule]", "2940"}], ",", 
       RowBox[{"2399", "\[Rule]", "1968"}], ",", 
       RowBox[{"2399", "\[Rule]", "1968"}], ",", 
       RowBox[{"2399", "\[Rule]", "2832"}], ",", 
       RowBox[{"2399", "\[Rule]", "2832"}], ",", 
       RowBox[{"2399", "\[Rule]", "2400"}], ",", 
       RowBox[{"2711", "\[Rule]", "2280"}], ",", 
       RowBox[{"2711", "\[Rule]", "2280"}], ",", 
       RowBox[{"2711", "\[Rule]", "2172"}], ",", 
       RowBox[{"2711", "\[Rule]", "2172"}], ",", 
       RowBox[{"2711", "\[Rule]", "2712"}], ",", 
       RowBox[{"2279", "\[Rule]", "1956"}], ",", 
       RowBox[{"2279", "\[Rule]", "1956"}], ",", 
       RowBox[{"2279", "\[Rule]", "2820"}], ",", 
       RowBox[{"2279", "\[Rule]", "2820"}], ",", 
       RowBox[{"2279", "\[Rule]", "1848"}], ",", 
       RowBox[{"2279", "\[Rule]", "1848"}], ",", 
       RowBox[{"2279", "\[Rule]", "2712"}], ",", 
       RowBox[{"2279", "\[Rule]", "2712"}], ",", 
       RowBox[{"2279", "\[Rule]", "2280"}], ",", 
       RowBox[{"2723", "\[Rule]", "2292"}], ",", 
       RowBox[{"2723", "\[Rule]", "2292"}], ",", 
       RowBox[{"2723", "\[Rule]", "2184"}], ",", 
       RowBox[{"2723", "\[Rule]", "2184"}], ",", 
       RowBox[{"2723", "\[Rule]", "2724"}], ",", 
       RowBox[{"2291", "\[Rule]", "1968"}], ",", 
       RowBox[{"2291", "\[Rule]", "1968"}], ",", 
       RowBox[{"2291", "\[Rule]", "2832"}], ",", 
       RowBox[{"2291", "\[Rule]", "2832"}], ",", 
       RowBox[{"2291", "\[Rule]", "1860"}], ",", 
       RowBox[{"2291", "\[Rule]", "1860"}], ",", 
       RowBox[{"2291", "\[Rule]", "2724"}], ",", 
       RowBox[{"2291", "\[Rule]", "2724"}], ",", 
       RowBox[{"2291", "\[Rule]", "2292"}], ",", 
       RowBox[{"2591", "\[Rule]", "2160"}], ",", 
       RowBox[{"2591", "\[Rule]", "2160"}], ",", 
       RowBox[{"2591", "\[Rule]", "3024"}], ",", 
       RowBox[{"2591", "\[Rule]", "2592"}], ",", 
       RowBox[{"2573", "\[Rule]", "2142"}], ",", 
       RowBox[{"2573", "\[Rule]", "3006"}], ",", 
       RowBox[{"2573", "\[Rule]", "2574"}], ",", 
       RowBox[{"2555", "\[Rule]", "2124"}], ",", 
       RowBox[{"2555", "\[Rule]", "2124"}], ",", 
       RowBox[{"2555", "\[Rule]", "2988"}], ",", 
       RowBox[{"2555", "\[Rule]", "2988"}], ",", 
       RowBox[{"2555", "\[Rule]", "2556"}], ",", 
       RowBox[{"2537", "\[Rule]", "2106"}], ",", 
       RowBox[{"2537", "\[Rule]", "2106"}], ",", 
       RowBox[{"2537", "\[Rule]", "2970"}], ",", 
       RowBox[{"2537", "\[Rule]", "2970"}], ",", 
       RowBox[{"2537", "\[Rule]", "2538"}], ",", 
       RowBox[{"2953", "\[Rule]", "2522"}], ",", 
       RowBox[{"2953", "\[Rule]", "2522"}], ",", 
       RowBox[{"2953", "\[Rule]", "2414"}], ",", 
       RowBox[{"2953", "\[Rule]", "2414"}], ",", 
       RowBox[{"2953", "\[Rule]", "2954"}], ",", 
       RowBox[{"2521", "\[Rule]", "2090"}], ",", 
       RowBox[{"2521", "\[Rule]", "2090"}], ",", 
       RowBox[{"2521", "\[Rule]", "2954"}], ",", 
       RowBox[{"2521", "\[Rule]", "2954"}], ",", 
       RowBox[{"2521", "\[Rule]", "2522"}], ",", 
       RowBox[{"2845", "\[Rule]", "2414"}], ",", 
       RowBox[{"2845", "\[Rule]", "2414"}], ",", 
       RowBox[{"2845", "\[Rule]", "2306"}], ",", 
       RowBox[{"2845", "\[Rule]", "2306"}], ",", 
       RowBox[{"2845", "\[Rule]", "2846"}], ",", 
       RowBox[{"2413", "\[Rule]", "2090"}], ",", 
       RowBox[{"2413", "\[Rule]", "2090"}], ",", 
       RowBox[{"2413", "\[Rule]", "2954"}], ",", 
       RowBox[{"2413", "\[Rule]", "2954"}], ",", 
       RowBox[{"2413", "\[Rule]", "1982"}], ",", 
       RowBox[{"2413", "\[Rule]", "1982"}], ",", 
       RowBox[{"2413", "\[Rule]", "2846"}], ",", 
       RowBox[{"2413", "\[Rule]", "2846"}], ",", 
       RowBox[{"2413", "\[Rule]", "2414"}], ",", 
       RowBox[{"2737", "\[Rule]", "2306"}], ",", 
       RowBox[{"2737", "\[Rule]", "2306"}], ",", 
       RowBox[{"2737", "\[Rule]", "2198"}], ",", 
       RowBox[{"2737", "\[Rule]", "2198"}], ",", 
       RowBox[{"2737", "\[Rule]", "2738"}], ",", 
       RowBox[{"2305", "\[Rule]", "1982"}], ",", 
       RowBox[{"2305", "\[Rule]", "1982"}], ",", 
       RowBox[{"2305", "\[Rule]", "2846"}], ",", 
       RowBox[{"2305", "\[Rule]", "2846"}], ",", 
       RowBox[{"2305", "\[Rule]", "1874"}], ",", 
       RowBox[{"2305", "\[Rule]", "1874"}], ",", 
       RowBox[{"2305", "\[Rule]", "2738"}], ",", 
       RowBox[{"2305", "\[Rule]", "2738"}], ",", 
       RowBox[{"2305", "\[Rule]", "2306"}], ",", 
       RowBox[{"2603", "\[Rule]", "2172"}], ",", 
       RowBox[{"2603", "\[Rule]", "2172"}], ",", 
       RowBox[{"2603", "\[Rule]", "2604"}], ",", 
       RowBox[{"2171", "\[Rule]", "1848"}], ",", 
       RowBox[{"2171", "\[Rule]", "1848"}], ",", 
       RowBox[{"2171", "\[Rule]", "2712"}], ",", 
       RowBox[{"2171", "\[Rule]", "2712"}], ",", 
       RowBox[{"2171", "\[Rule]", "1740"}], ",", 
       RowBox[{"2171", "\[Rule]", "1740"}], ",", 
       RowBox[{"2171", "\[Rule]", "2604"}], ",", 
       RowBox[{"2171", "\[Rule]", "2604"}], ",", 
       RowBox[{"2171", "\[Rule]", "2172"}], ",", 
       RowBox[{"2615", "\[Rule]", "2184"}], ",", 
       RowBox[{"2615", "\[Rule]", "2184"}], ",", 
       RowBox[{"2615", "\[Rule]", "2616"}], ",", 
       RowBox[{"2183", "\[Rule]", "1860"}], ",", 
       RowBox[{"2183", "\[Rule]", "1860"}], ",", 
       RowBox[{"2183", "\[Rule]", "2724"}], ",", 
       RowBox[{"2183", "\[Rule]", "2724"}], ",", 
       RowBox[{"2183", "\[Rule]", "1752"}], ",", 
       RowBox[{"2183", "\[Rule]", "1752"}], ",", 
       RowBox[{"2183", "\[Rule]", "2616"}], ",", 
       RowBox[{"2183", "\[Rule]", "2616"}], ",", 
       RowBox[{"2183", "\[Rule]", "2184"}], ",", 
       RowBox[{"2629", "\[Rule]", "2198"}], ",", 
       RowBox[{"2629", "\[Rule]", "2198"}], ",", 
       RowBox[{"2629", "\[Rule]", "2630"}], ",", 
       RowBox[{"2197", "\[Rule]", "1874"}], ",", 
       RowBox[{"2197", "\[Rule]", "1874"}], ",", 
       RowBox[{"2197", "\[Rule]", "2738"}], ",", 
       RowBox[{"2197", "\[Rule]", "2738"}], ",", 
       RowBox[{"2197", "\[Rule]", "1766"}], ",", 
       RowBox[{"2197", "\[Rule]", "1766"}], ",", 
       RowBox[{"2197", "\[Rule]", "2630"}], ",", 
       RowBox[{"2197", "\[Rule]", "2630"}], ",", 
       RowBox[{"2197", "\[Rule]", "2198"}], ",", 
       RowBox[{"2587", "\[Rule]", "2156"}], ",", 
       RowBox[{"2587", "\[Rule]", "2156"}], ",", 
       RowBox[{"2587", "\[Rule]", "3020"}], ",", 
       RowBox[{"2587", "\[Rule]", "3020"}], ",", 
       RowBox[{"2587", "\[Rule]", "2588"}], ",", 
       RowBox[{"2569", "\[Rule]", "2138"}], ",", 
       RowBox[{"2569", "\[Rule]", "2138"}], ",", 
       RowBox[{"2569", "\[Rule]", "3002"}], ",", 
       RowBox[{"2569", "\[Rule]", "3002"}], ",", 
       RowBox[{"2569", "\[Rule]", "2570"}], ",", 
       RowBox[{"2551", "\[Rule]", "2120"}], ",", 
       RowBox[{"2551", "\[Rule]", "2120"}], ",", 
       RowBox[{"2551", "\[Rule]", "2984"}], ",", 
       RowBox[{"2551", "\[Rule]", "2984"}], ",", 
       RowBox[{"2551", "\[Rule]", "2552"}], ",", 
       RowBox[{"2965", "\[Rule]", "2534"}], ",", 
       RowBox[{"2965", "\[Rule]", "2534"}], ",", 
       RowBox[{"2965", "\[Rule]", "2426"}], ",", 
       RowBox[{"2965", "\[Rule]", "2426"}], ",", 
       RowBox[{"2965", "\[Rule]", "2966"}], ",", 
       RowBox[{"2533", "\[Rule]", "2102"}], ",", 
       RowBox[{"2533", "\[Rule]", "2102"}], ",", 
       RowBox[{"2533", "\[Rule]", "2966"}], ",", 
       RowBox[{"2533", "\[Rule]", "2966"}], ",", 
       RowBox[{"2533", "\[Rule]", "2534"}], ",", 
       RowBox[{"2857", "\[Rule]", "2426"}], ",", 
       RowBox[{"2857", "\[Rule]", "2426"}], ",", 
       RowBox[{"2857", "\[Rule]", "2318"}], ",", 
       RowBox[{"2857", "\[Rule]", "2318"}], ",", 
       RowBox[{"2857", "\[Rule]", "2858"}], ",", 
       RowBox[{"2425", "\[Rule]", "2102"}], ",", 
       RowBox[{"2425", "\[Rule]", "2102"}], ",", 
       RowBox[{"2425", "\[Rule]", "2966"}], ",", 
       RowBox[{"2425", "\[Rule]", "2966"}], ",", 
       RowBox[{"2425", "\[Rule]", "1994"}], ",", 
       RowBox[{"2425", "\[Rule]", "1994"}], ",", 
       RowBox[{"2425", "\[Rule]", "2858"}], ",", 
       RowBox[{"2425", "\[Rule]", "2858"}], ",", 
       RowBox[{"2425", "\[Rule]", "2426"}], ",", 
       RowBox[{"2749", "\[Rule]", "2318"}], ",", 
       RowBox[{"2749", "\[Rule]", "2318"}], ",", 
       RowBox[{"2749", "\[Rule]", "2210"}], ",", 
       RowBox[{"2749", "\[Rule]", "2210"}], ",", 
       RowBox[{"2749", "\[Rule]", "2750"}], ",", 
       RowBox[{"2317", "\[Rule]", "1994"}], ",", 
       RowBox[{"2317", "\[Rule]", "1994"}], ",", 
       RowBox[{"2317", "\[Rule]", "2858"}], ",", 
       RowBox[{"2317", "\[Rule]", "2858"}], ",", 
       RowBox[{"2317", "\[Rule]", "1886"}], ",", 
       RowBox[{"2317", "\[Rule]", "1886"}], ",", 
       RowBox[{"2317", "\[Rule]", "2750"}], ",", 
       RowBox[{"2317", "\[Rule]", "2750"}], ",", 
       RowBox[{"2317", "\[Rule]", "2318"}], ",", 
       RowBox[{"2641", "\[Rule]", "2210"}], ",", 
       RowBox[{"2641", "\[Rule]", "2210"}], ",", 
       RowBox[{"2641", "\[Rule]", "2642"}], ",", 
       RowBox[{"2209", "\[Rule]", "1886"}], ",", 
       RowBox[{"2209", "\[Rule]", "1886"}], ",", 
       RowBox[{"2209", "\[Rule]", "2750"}], ",", 
       RowBox[{"2209", "\[Rule]", "2750"}], ",", 
       RowBox[{"2209", "\[Rule]", "1778"}], ",", 
       RowBox[{"2209", "\[Rule]", "1778"}], ",", 
       RowBox[{"2209", "\[Rule]", "2642"}], ",", 
       RowBox[{"2209", "\[Rule]", "2642"}], ",", 
       RowBox[{"2209", "\[Rule]", "2210"}], ",", 
       RowBox[{"855", "\[Rule]", "424"}], ",", 
       RowBox[{"855", "\[Rule]", "424"}], ",", 
       RowBox[{"855", "\[Rule]", "1288"}], ",", 
       RowBox[{"855", "\[Rule]", "1288"}], ",", 
       RowBox[{"855", "\[Rule]", "856"}], ",", 
       RowBox[{"1719", "\[Rule]", "1288"}], ",", 
       RowBox[{"1719", "\[Rule]", "1288"}], ",", 
       RowBox[{"1719", "\[Rule]", "2152"}], ",", 
       RowBox[{"1719", "\[Rule]", "2152"}], ",", 
       RowBox[{"1719", "\[Rule]", "1720"}], ",", 
       RowBox[{"837", "\[Rule]", "406"}], ",", 
       RowBox[{"837", "\[Rule]", "406"}], ",", 
       RowBox[{"837", "\[Rule]", "1270"}], ",", 
       RowBox[{"837", "\[Rule]", "1270"}], ",", 
       RowBox[{"837", "\[Rule]", "838"}], ",", 
       RowBox[{"1701", "\[Rule]", "1270"}], ",", 
       RowBox[{"1701", "\[Rule]", "1270"}], ",", 
       RowBox[{"1701", "\[Rule]", "2134"}], ",", 
       RowBox[{"1701", "\[Rule]", "2134"}], ",", 
       RowBox[{"1701", "\[Rule]", "1702"}], ",", 
       RowBox[{"2583", "\[Rule]", "2152"}], ",", 
       RowBox[{"2583", "\[Rule]", "2152"}], ",", 
       RowBox[{"2583", "\[Rule]", "3016"}], ",", 
       RowBox[{"2583", "\[Rule]", "3016"}], ",", 
       RowBox[{"2583", "\[Rule]", "2584"}], ",", 
       RowBox[{"2565", "\[Rule]", "2134"}], ",", 
       RowBox[{"2565", "\[Rule]", "2134"}], ",", 
       RowBox[{"2565", "\[Rule]", "2998"}], ",", 
       RowBox[{"2565", "\[Rule]", "2998"}], ",", 
       RowBox[{"2565", "\[Rule]", "2566"}], ",", 
       RowBox[{"387", "\[Rule]", "820"}], ",", 
       RowBox[{"387", "\[Rule]", "820"}], ",", 
       RowBox[{"387", "\[Rule]", "712"}], ",", 
       RowBox[{"387", "\[Rule]", "712"}], ",", 
       RowBox[{"387", "\[Rule]", "388"}], ",", 
       RowBox[{"1251", "\[Rule]", "820"}], ",", 
       RowBox[{"1251", "\[Rule]", "820"}], ",", 
       RowBox[{"1251", "\[Rule]", "1684"}], ",", 
       RowBox[{"1251", "\[Rule]", "1684"}], ",", 
       RowBox[{"1251", "\[Rule]", "712"}], ",", 
       RowBox[{"1251", "\[Rule]", "712"}], ",", 
       RowBox[{"1251", "\[Rule]", "1576"}], ",", 
       RowBox[{"1251", "\[Rule]", "1576"}], ",", 
       RowBox[{"1251", "\[Rule]", "1252"}], ",", 
       RowBox[{"819", "\[Rule]", "388"}], ",", 
       RowBox[{"819", "\[Rule]", "388"}], ",", 
       RowBox[{"819", "\[Rule]", "1252"}], ",", 
       RowBox[{"819", "\[Rule]", "1252"}], ",", 
       RowBox[{"819", "\[Rule]", "820"}], ",", 
       RowBox[{"279", "\[Rule]", "712"}], ",", 
       RowBox[{"279", "\[Rule]", "712"}], ",", 
       RowBox[{"279", "\[Rule]", "604"}], ",", 
       RowBox[{"279", "\[Rule]", "604"}], ",", 
       RowBox[{"279", "\[Rule]", "280"}], ",", 
       RowBox[{"1143", "\[Rule]", "712"}], ",", 
       RowBox[{"1143", "\[Rule]", "712"}], ",", 
       RowBox[{"1143", "\[Rule]", "1576"}], ",", 
       RowBox[{"1143", "\[Rule]", "1576"}], ",", 
       RowBox[{"1143", "\[Rule]", "604"}], ",", 
       RowBox[{"1143", "\[Rule]", "604"}], ",", 
       RowBox[{"1143", "\[Rule]", "1468"}], ",", 
       RowBox[{"1143", "\[Rule]", "1468"}], ",", 
       RowBox[{"1143", "\[Rule]", "1144"}], ",", 
       RowBox[{"711", "\[Rule]", "388"}], ",", 
       RowBox[{"711", "\[Rule]", "388"}], ",", 
       RowBox[{"711", "\[Rule]", "1252"}], ",", 
       RowBox[{"711", "\[Rule]", "1252"}], ",", 
       RowBox[{"711", "\[Rule]", "280"}], ",", 
       RowBox[{"711", "\[Rule]", "280"}], ",", 
       RowBox[{"711", "\[Rule]", "1144"}], ",", 
       RowBox[{"711", "\[Rule]", "1144"}], ",", 
       RowBox[{"711", "\[Rule]", "712"}], ",", 
       RowBox[{"2115", "\[Rule]", "1684"}], ",", 
       RowBox[{"2115", "\[Rule]", "1684"}], ",", 
       RowBox[{"2115", "\[Rule]", "2548"}], ",", 
       RowBox[{"2115", "\[Rule]", "2548"}], ",", 
       RowBox[{"2115", "\[Rule]", "1576"}], ",", 
       RowBox[{"2115", "\[Rule]", "1576"}], ",", 
       RowBox[{"2115", "\[Rule]", "2440"}], ",", 
       RowBox[{"2115", "\[Rule]", "2440"}], ",", 
       RowBox[{"2115", "\[Rule]", "2116"}], ",", 
       RowBox[{"1683", "\[Rule]", "1252"}], ",", 
       RowBox[{"1683", "\[Rule]", "1252"}], ",", 
       RowBox[{"1683", "\[Rule]", "2116"}], ",", 
       RowBox[{"1683", "\[Rule]", "2116"}], ",", 
       RowBox[{"1683", "\[Rule]", "1684"}], ",", 
       RowBox[{"2007", "\[Rule]", "1576"}], ",", 
       RowBox[{"2007", "\[Rule]", "1576"}], ",", 
       RowBox[{"2007", "\[Rule]", "2440"}], ",", 
       RowBox[{"2007", "\[Rule]", "2440"}], ",", 
       RowBox[{"2007", "\[Rule]", "1468"}], ",", 
       RowBox[{"2007", "\[Rule]", "1468"}], ",", 
       RowBox[{"2007", "\[Rule]", "2332"}], ",", 
       RowBox[{"2007", "\[Rule]", "2332"}], ",", 
       RowBox[{"2007", "\[Rule]", "2008"}], ",", 
       RowBox[{"1575", "\[Rule]", "1252"}], ",", 
       RowBox[{"1575", "\[Rule]", "1252"}], ",", 
       RowBox[{"1575", "\[Rule]", "2116"}], ",", 
       RowBox[{"1575", "\[Rule]", "2116"}], ",", 
       RowBox[{"1575", "\[Rule]", "1144"}], ",", 
       RowBox[{"1575", "\[Rule]", "1144"}], ",", 
       RowBox[{"1575", "\[Rule]", "2008"}], ",", 
       RowBox[{"1575", "\[Rule]", "2008"}], ",", 
       RowBox[{"1575", "\[Rule]", "1576"}], ",", 
       RowBox[{"171", "\[Rule]", "604"}], ",", 
       RowBox[{"171", "\[Rule]", "496"}], ",", 
       RowBox[{"171", "\[Rule]", "172"}], ",", 
       RowBox[{"1035", "\[Rule]", "604"}], ",", 
       RowBox[{"1035", "\[Rule]", "1468"}], ",", 
       RowBox[{"1035", "\[Rule]", "1468"}], ",", 
       RowBox[{"1035", "\[Rule]", "496"}], ",", 
       RowBox[{"1035", "\[Rule]", "1360"}], ",", 
       RowBox[{"1035", "\[Rule]", "1360"}], ",", 
       RowBox[{"1035", "\[Rule]", "1036"}], ",", 
       RowBox[{"603", "\[Rule]", "280"}], ",", 
       RowBox[{"603", "\[Rule]", "280"}], ",", 
       RowBox[{"603", "\[Rule]", "1144"}], ",", 
       RowBox[{"603", "\[Rule]", "1144"}], ",", 
       RowBox[{"603", "\[Rule]", "172"}], ",", 
       RowBox[{"603", "\[Rule]", "1036"}], ",", 
       RowBox[{"603", "\[Rule]", "604"}], ",", 
       RowBox[{"1899", "\[Rule]", "1468"}], ",", 
       RowBox[{"1899", "\[Rule]", "1468"}], ",", 
       RowBox[{"1899", "\[Rule]", "2332"}], ",", 
       RowBox[{"1899", "\[Rule]", "2332"}], ",", 
       RowBox[{"1899", "\[Rule]", "1360"}], ",", 
       RowBox[{"1899", "\[Rule]", "2224"}], ",", 
       RowBox[{"1899", "\[Rule]", "1900"}], ",", 
       RowBox[{"1467", "\[Rule]", "1144"}], ",", 
       RowBox[{"1467", "\[Rule]", "1144"}], ",", 
       RowBox[{"1467", "\[Rule]", "2008"}], ",", 
       RowBox[{"1467", "\[Rule]", "2008"}], ",", 
       RowBox[{"1467", "\[Rule]", "1036"}], ",", 
       RowBox[{"1467", "\[Rule]", "1036"}], ",", 
       RowBox[{"1467", "\[Rule]", "1900"}], ",", 
       RowBox[{"1467", "\[Rule]", "1900"}], ",", 
       RowBox[{"1467", "\[Rule]", "1468"}], ",", 
       RowBox[{"63", "\[Rule]", "496"}], ",", 
       RowBox[{"63", "\[Rule]", "496"}], ",", 
       RowBox[{"63", "\[Rule]", "64"}], ",", 
       RowBox[{"927", "\[Rule]", "496"}], ",", 
       RowBox[{"927", "\[Rule]", "496"}], ",", 
       RowBox[{"927", "\[Rule]", "1360"}], ",", 
       RowBox[{"927", "\[Rule]", "928"}], ",", 
       RowBox[{"495", "\[Rule]", "172"}], ",", 
       RowBox[{"495", "\[Rule]", "1036"}], ",", 
       RowBox[{"495", "\[Rule]", "64"}], ",", 
       RowBox[{"495", "\[Rule]", "64"}], ",", 
       RowBox[{"495", "\[Rule]", "928"}], ",", 
       RowBox[{"495", "\[Rule]", "928"}], ",", 
       RowBox[{"495", "\[Rule]", "496"}], ",", 
       RowBox[{"1791", "\[Rule]", "2224"}], ",", 
       RowBox[{"1791", "\[Rule]", "1792"}], ",", 
       RowBox[{"1359", "\[Rule]", "1036"}], ",", 
       RowBox[{"1359", "\[Rule]", "1036"}], ",", 
       RowBox[{"1359", "\[Rule]", "1900"}], ",", 
       RowBox[{"1359", "\[Rule]", "928"}], ",", 
       RowBox[{"1359", "\[Rule]", "1360"}], ",", 
       RowBox[{"2979", "\[Rule]", "2548"}], ",", 
       RowBox[{"2979", "\[Rule]", "2548"}], ",", 
       RowBox[{"2979", "\[Rule]", "2440"}], ",", 
       RowBox[{"2979", "\[Rule]", "2440"}], ",", 
       RowBox[{"2979", "\[Rule]", "2980"}], ",", 
       RowBox[{"2547", "\[Rule]", "2116"}], ",", 
       RowBox[{"2547", "\[Rule]", "2116"}], ",", 
       RowBox[{"2547", "\[Rule]", "2980"}], ",", 
       RowBox[{"2547", "\[Rule]", "2980"}], ",", 
       RowBox[{"2547", "\[Rule]", "2548"}], ",", 
       RowBox[{"2871", "\[Rule]", "2440"}], ",", 
       RowBox[{"2871", "\[Rule]", "2440"}], ",", 
       RowBox[{"2871", "\[Rule]", "2332"}], ",", 
       RowBox[{"2871", "\[Rule]", "2332"}], ",", 
       RowBox[{"2871", "\[Rule]", "2872"}], ",", 
       RowBox[{"2439", "\[Rule]", "2116"}], ",", 
       RowBox[{"2439", "\[Rule]", "2116"}], ",", 
       RowBox[{"2439", "\[Rule]", "2980"}], ",", 
       RowBox[{"2439", "\[Rule]", "2980"}], ",", 
       RowBox[{"2439", "\[Rule]", "2008"}], ",", 
       RowBox[{"2439", "\[Rule]", "2008"}], ",", 
       RowBox[{"2439", "\[Rule]", "2872"}], ",", 
       RowBox[{"2439", "\[Rule]", "2872"}], ",", 
       RowBox[{"2439", "\[Rule]", "2440"}], ",", 
       RowBox[{"2763", "\[Rule]", "2332"}], ",", 
       RowBox[{"2763", "\[Rule]", "2332"}], ",", 
       RowBox[{"2763", "\[Rule]", "2224"}], ",", 
       RowBox[{"2763", "\[Rule]", "2224"}], ",", 
       RowBox[{"2763", "\[Rule]", "2764"}], ",", 
       RowBox[{"2331", "\[Rule]", "2008"}], ",", 
       RowBox[{"2331", "\[Rule]", "2008"}], ",", 
       RowBox[{"2331", "\[Rule]", "2872"}], ",", 
       RowBox[{"2331", "\[Rule]", "2872"}], ",", 
       RowBox[{"2331", "\[Rule]", "1900"}], ",", 
       RowBox[{"2331", "\[Rule]", "1900"}], ",", 
       RowBox[{"2331", "\[Rule]", "2764"}], ",", 
       RowBox[{"2331", "\[Rule]", "2764"}], ",", 
       RowBox[{"2331", "\[Rule]", "2332"}], ",", 
       RowBox[{"2655", "\[Rule]", "2224"}], ",", 
       RowBox[{"2655", "\[Rule]", "2224"}], ",", 
       RowBox[{"2655", "\[Rule]", "2656"}], ",", 
       RowBox[{"2223", "\[Rule]", "1900"}], ",", 
       RowBox[{"2223", "\[Rule]", "2764"}], ",", 
       RowBox[{"2223", "\[Rule]", "2764"}], ",", 
       RowBox[{"2223", "\[Rule]", "1792"}], ",", 
       RowBox[{"2223", "\[Rule]", "2656"}], ",", 
       RowBox[{"2223", "\[Rule]", "2656"}], ",", 
       RowBox[{"2223", "\[Rule]", "2224"}], ",", 
       RowBox[{"851", "\[Rule]", "420"}], ",", 
       RowBox[{"851", "\[Rule]", "420"}], ",", 
       RowBox[{"851", "\[Rule]", "1284"}], ",", 
       RowBox[{"851", "\[Rule]", "1284"}], ",", 
       RowBox[{"851", "\[Rule]", "852"}], ",", 
       RowBox[{"1715", "\[Rule]", "1284"}], ",", 
       RowBox[{"1715", "\[Rule]", "1284"}], ",", 
       RowBox[{"1715", "\[Rule]", "2148"}], ",", 
       RowBox[{"1715", "\[Rule]", "2148"}], ",", 
       RowBox[{"1715", "\[Rule]", "1716"}], ",", 
       RowBox[{"2579", "\[Rule]", "2148"}], ",", 
       RowBox[{"2579", "\[Rule]", "2148"}], ",", 
       RowBox[{"2579", "\[Rule]", "3012"}], ",", 
       RowBox[{"2579", "\[Rule]", "3012"}], ",", 
       RowBox[{"2579", "\[Rule]", "2580"}], ",", 
       RowBox[{"401", "\[Rule]", "834"}], ",", 
       RowBox[{"401", "\[Rule]", "834"}], ",", 
       RowBox[{"401", "\[Rule]", "726"}], ",", 
       RowBox[{"401", "\[Rule]", "726"}], ",", 
       RowBox[{"401", "\[Rule]", "402"}], ",", 
       RowBox[{"1265", "\[Rule]", "834"}], ",", 
       RowBox[{"1265", "\[Rule]", "834"}], ",", 
       RowBox[{"1265", "\[Rule]", "1698"}], ",", 
       RowBox[{"1265", "\[Rule]", "1698"}], ",", 
       RowBox[{"1265", "\[Rule]", "726"}], ",", 
       RowBox[{"1265", "\[Rule]", "726"}], ",", 
       RowBox[{"1265", "\[Rule]", "1590"}], ",", 
       RowBox[{"1265", "\[Rule]", "1590"}], ",", 
       RowBox[{"1265", "\[Rule]", "1266"}], ",", 
       RowBox[{"833", "\[Rule]", "402"}], ",", 
       RowBox[{"833", "\[Rule]", "402"}], ",", 
       RowBox[{"833", "\[Rule]", "1266"}], ",", 
       RowBox[{"833", "\[Rule]", "1266"}], ",", 
       RowBox[{"833", "\[Rule]", "834"}], ",", 
       RowBox[{"293", "\[Rule]", "726"}], ",", 
       RowBox[{"293", "\[Rule]", "726"}], ",", 
       RowBox[{"293", "\[Rule]", "618"}], ",", 
       RowBox[{"293", "\[Rule]", "618"}], ",", 
       RowBox[{"293", "\[Rule]", "294"}], ",", 
       RowBox[{"1157", "\[Rule]", "726"}], ",", 
       RowBox[{"1157", "\[Rule]", "726"}], ",", 
       RowBox[{"1157", "\[Rule]", "1590"}], ",", 
       RowBox[{"1157", "\[Rule]", "1590"}], ",", 
       RowBox[{"1157", "\[Rule]", "618"}], ",", 
       RowBox[{"1157", "\[Rule]", "618"}], ",", 
       RowBox[{"1157", "\[Rule]", "1482"}], ",", 
       RowBox[{"1157", "\[Rule]", "1482"}], ",", 
       RowBox[{"1157", "\[Rule]", "1158"}], ",", 
       RowBox[{"725", "\[Rule]", "402"}], ",", 
       RowBox[{"725", "\[Rule]", "402"}], ",", 
       RowBox[{"725", "\[Rule]", "1266"}], ",", 
       RowBox[{"725", "\[Rule]", "1266"}], ",", 
       RowBox[{"725", "\[Rule]", "294"}], ",", 
       RowBox[{"725", "\[Rule]", "294"}], ",", 
       RowBox[{"725", "\[Rule]", "1158"}], ",", 
       RowBox[{"725", "\[Rule]", "1158"}], ",", 
       RowBox[{"725", "\[Rule]", "726"}], ",", 
       RowBox[{"2129", "\[Rule]", "1698"}], ",", 
       RowBox[{"2129", "\[Rule]", "1698"}], ",", 
       RowBox[{"2129", "\[Rule]", "2562"}], ",", 
       RowBox[{"2129", "\[Rule]", "2562"}], ",", 
       RowBox[{"2129", "\[Rule]", "1590"}], ",", 
       RowBox[{"2129", "\[Rule]", "1590"}], ",", 
       RowBox[{"2129", "\[Rule]", "2454"}], ",", 
       RowBox[{"2129", "\[Rule]", "2454"}], ",", 
       RowBox[{"2129", "\[Rule]", "2130"}], ",", 
       RowBox[{"1697", "\[Rule]", "1266"}], ",", 
       RowBox[{"1697", "\[Rule]", "1266"}], ",", 
       RowBox[{"1697", "\[Rule]", "2130"}], ",", 
       RowBox[{"1697", "\[Rule]", "2130"}], ",", 
       RowBox[{"1697", "\[Rule]", "1698"}], ",", 
       RowBox[{"2021", "\[Rule]", "1590"}], ",", 
       RowBox[{"2021", "\[Rule]", "1590"}], ",", 
       RowBox[{"2021", "\[Rule]", "2454"}], ",", 
       RowBox[{"2021", "\[Rule]", "2454"}], ",", 
       RowBox[{"2021", "\[Rule]", "1482"}], ",", 
       RowBox[{"2021", "\[Rule]", "1482"}], ",", 
       RowBox[{"2021", "\[Rule]", "2346"}], ",", 
       RowBox[{"2021", "\[Rule]", "2346"}], ",", 
       RowBox[{"2021", "\[Rule]", "2022"}], ",", 
       RowBox[{"1589", "\[Rule]", "1266"}], ",", 
       RowBox[{"1589", "\[Rule]", "1266"}], ",", 
       RowBox[{"1589", "\[Rule]", "2130"}], ",", 
       RowBox[{"1589", "\[Rule]", "2130"}], ",", 
       RowBox[{"1589", "\[Rule]", "1158"}], ",", 
       RowBox[{"1589", "\[Rule]", "1158"}], ",", 
       RowBox[{"1589", "\[Rule]", "2022"}], ",", 
       RowBox[{"1589", "\[Rule]", "2022"}], ",", 
       RowBox[{"1589", "\[Rule]", "1590"}], ",", 
       RowBox[{"185", "\[Rule]", "618"}], ",", 
       RowBox[{"185", "\[Rule]", "510"}], ",", 
       RowBox[{"185", "\[Rule]", "186"}], ",", 
       RowBox[{"1049", "\[Rule]", "618"}], ",", 
       RowBox[{"1049", "\[Rule]", "1482"}], ",", 
       RowBox[{"1049", "\[Rule]", "1482"}], ",", 
       RowBox[{"1049", "\[Rule]", "510"}], ",", 
       RowBox[{"1049", "\[Rule]", "1374"}], ",", 
       RowBox[{"1049", "\[Rule]", "1374"}], ",", 
       RowBox[{"1049", "\[Rule]", "1050"}], ",", 
       RowBox[{"617", "\[Rule]", "294"}], ",", 
       RowBox[{"617", "\[Rule]", "294"}], ",", 
       RowBox[{"617", "\[Rule]", "1158"}], ",", 
       RowBox[{"617", "\[Rule]", "1158"}], ",", 
       RowBox[{"617", "\[Rule]", "186"}], ",", 
       RowBox[{"617", "\[Rule]", "1050"}], ",", 
       RowBox[{"617", "\[Rule]", "618"}], ",", 
       RowBox[{"1913", "\[Rule]", "1482"}], ",", 
       RowBox[{"1913", "\[Rule]", "1482"}], ",", 
       RowBox[{"1913", "\[Rule]", "2346"}], ",", 
       RowBox[{"1913", "\[Rule]", "2346"}], ",", 
       RowBox[{"1913", "\[Rule]", "1374"}], ",", 
       RowBox[{"1913", "\[Rule]", "1374"}], ",", 
       RowBox[{"1913", "\[Rule]", "2238"}], ",", 
       RowBox[{"1913", "\[Rule]", "2238"}], ",", 
       RowBox[{"1913", "\[Rule]", "1914"}], ",", 
       RowBox[{"1481", "\[Rule]", "1158"}], ",", 
       RowBox[{"1481", "\[Rule]", "1158"}], ",", 
       RowBox[{"1481", "\[Rule]", "2022"}], ",", 
       RowBox[{"1481", "\[Rule]", "2022"}], ",", 
       RowBox[{"1481", "\[Rule]", "1050"}], ",", 
       RowBox[{"1481", "\[Rule]", "1050"}], ",", 
       RowBox[{"1481", "\[Rule]", "1914"}], ",", 
       RowBox[{"1481", "\[Rule]", "1914"}], ",", 
       RowBox[{"1481", "\[Rule]", "1482"}], ",", 
       RowBox[{"77", "\[Rule]", "510"}], ",", 
       RowBox[{"77", "\[Rule]", "510"}], ",", 
       RowBox[{"77", "\[Rule]", "78"}], ",", 
       RowBox[{"941", "\[Rule]", "510"}], ",", 
       RowBox[{"941", "\[Rule]", "510"}], ",", 
       RowBox[{"941", "\[Rule]", "1374"}], ",", 
       RowBox[{"941", "\[Rule]", "942"}], ",", 
       RowBox[{"509", "\[Rule]", "186"}], ",", 
       RowBox[{"509", "\[Rule]", "1050"}], ",", 
       RowBox[{"509", "\[Rule]", "78"}], ",", 
       RowBox[{"509", "\[Rule]", "78"}], ",", 
       RowBox[{"509", "\[Rule]", "942"}], ",", 
       RowBox[{"509", "\[Rule]", "942"}], ",", 
       RowBox[{"509", "\[Rule]", "510"}], ",", 
       RowBox[{"1805", "\[Rule]", "1374"}], ",", 
       RowBox[{"1805", "\[Rule]", "2238"}], ",", 
       RowBox[{"1805", "\[Rule]", "1806"}], ",", 
       RowBox[{"1373", "\[Rule]", "1050"}], ",", 
       RowBox[{"1373", "\[Rule]", "1050"}], ",", 
       RowBox[{"1373", "\[Rule]", "1914"}], ",", 
       RowBox[{"1373", "\[Rule]", "1914"}], ",", 
       RowBox[{"1373", "\[Rule]", "942"}], ",", 
       RowBox[{"1373", "\[Rule]", "1806"}], ",", 
       RowBox[{"1373", "\[Rule]", "1374"}], ",", 
       RowBox[{"2993", "\[Rule]", "2562"}], ",", 
       RowBox[{"2993", "\[Rule]", "2562"}], ",", 
       RowBox[{"2993", "\[Rule]", "2454"}], ",", 
       RowBox[{"2993", "\[Rule]", "2454"}], ",", 
       RowBox[{"2993", "\[Rule]", "2994"}], ",", 
       RowBox[{"2561", "\[Rule]", "2130"}], ",", 
       RowBox[{"2561", "\[Rule]", "2130"}], ",", 
       RowBox[{"2561", "\[Rule]", "2994"}], ",", 
       RowBox[{"2561", "\[Rule]", "2994"}], ",", 
       RowBox[{"2561", "\[Rule]", "2562"}], ",", 
       RowBox[{"2885", "\[Rule]", "2454"}], ",", 
       RowBox[{"2885", "\[Rule]", "2454"}], ",", 
       RowBox[{"2885", "\[Rule]", "2346"}], ",", 
       RowBox[{"2885", "\[Rule]", "2346"}], ",", 
       RowBox[{"2885", "\[Rule]", "2886"}], ",", 
       RowBox[{"2453", "\[Rule]", "2130"}], ",", 
       RowBox[{"2453", "\[Rule]", "2130"}], ",", 
       RowBox[{"2453", "\[Rule]", "2994"}], ",", 
       RowBox[{"2453", "\[Rule]", "2994"}], ",", 
       RowBox[{"2453", "\[Rule]", "2022"}], ",", 
       RowBox[{"2453", "\[Rule]", "2022"}], ",", 
       RowBox[{"2453", "\[Rule]", "2886"}], ",", 
       RowBox[{"2453", "\[Rule]", "2886"}], ",", 
       RowBox[{"2453", "\[Rule]", "2454"}], ",", 
       RowBox[{"2777", "\[Rule]", "2346"}], ",", 
       RowBox[{"2777", "\[Rule]", "2346"}], ",", 
       RowBox[{"2777", "\[Rule]", "2238"}], ",", 
       RowBox[{"2777", "\[Rule]", "2238"}], ",", 
       RowBox[{"2777", "\[Rule]", "2778"}], ",", 
       RowBox[{"2345", "\[Rule]", "2022"}], ",", 
       RowBox[{"2345", "\[Rule]", "2022"}], ",", 
       RowBox[{"2345", "\[Rule]", "2886"}], ",", 
       RowBox[{"2345", "\[Rule]", "2886"}], ",", 
       RowBox[{"2345", "\[Rule]", "1914"}], ",", 
       RowBox[{"2345", "\[Rule]", "1914"}], ",", 
       RowBox[{"2345", "\[Rule]", "2778"}], ",", 
       RowBox[{"2345", "\[Rule]", "2778"}], ",", 
       RowBox[{"2345", "\[Rule]", "2346"}], ",", 
       RowBox[{"2669", "\[Rule]", "2238"}], ",", 
       RowBox[{"2669", "\[Rule]", "2670"}], ",", 
       RowBox[{"2237", "\[Rule]", "1914"}], ",", 
       RowBox[{"2237", "\[Rule]", "1914"}], ",", 
       RowBox[{"2237", "\[Rule]", "2778"}], ",", 
       RowBox[{"2237", "\[Rule]", "2778"}], ",", 
       RowBox[{"2237", "\[Rule]", "1806"}], ",", 
       RowBox[{"2237", "\[Rule]", "2670"}], ",", 
       RowBox[{"2237", "\[Rule]", "2238"}], ",", 
       RowBox[{"768", "\[Rule]", "781"}], ",", 
       RowBox[{"768", "\[Rule]", "769"}], ",", 
       RowBox[{"768", "\[Rule]", "765"}], ",", 
       RowBox[{"660", "\[Rule]", "673"}], ",", 
       RowBox[{"660", "\[Rule]", "661"}], ",", 
       RowBox[{"660", "\[Rule]", "657"}], ",", 
       RowBox[{"336", "\[Rule]", "349"}], ",", 
       RowBox[{"336", "\[Rule]", "337"}], ",", 
       RowBox[{"336", "\[Rule]", "333"}], ",", 
       RowBox[{"1632", "\[Rule]", "1645"}], ",", 
       RowBox[{"1632", "\[Rule]", "1633"}], ",", 
       RowBox[{"1632", "\[Rule]", "1629"}], ",", 
       RowBox[{"1524", "\[Rule]", "1537"}], ",", 
       RowBox[{"1524", "\[Rule]", "1525"}], ",", 
       RowBox[{"1524", "\[Rule]", "1521"}], ",", 
       RowBox[{"1200", "\[Rule]", "1213"}], ",", 
       RowBox[{"1200", "\[Rule]", "1201"}], ",", 
       RowBox[{"1200", "\[Rule]", "1197"}], ",", 
       RowBox[{"552", "\[Rule]", "565"}], ",", 
       RowBox[{"552", "\[Rule]", "553"}], ",", 
       RowBox[{"552", "\[Rule]", "549"}], ",", 
       RowBox[{"228", "\[Rule]", "241"}], ",", 
       RowBox[{"228", "\[Rule]", "229"}], ",", 
       RowBox[{"228", "\[Rule]", "225"}], ",", 
       RowBox[{"1416", "\[Rule]", "1429"}], ",", 
       RowBox[{"1416", "\[Rule]", "1417"}], ",", 
       RowBox[{"1416", "\[Rule]", "1413"}], ",", 
       RowBox[{"1092", "\[Rule]", "1105"}], ",", 
       RowBox[{"1092", "\[Rule]", "1093"}], ",", 
       RowBox[{"1092", "\[Rule]", "1089"}], ",", 
       RowBox[{"780", "\[Rule]", "765"}], ",", 
       RowBox[{"780", "\[Rule]", "795"}], ",", 
       RowBox[{"780", "\[Rule]", "781"}], ",", 
       RowBox[{"780", "\[Rule]", "777"}], ",", 
       RowBox[{"672", "\[Rule]", "657"}], ",", 
       RowBox[{"672", "\[Rule]", "687"}], ",", 
       RowBox[{"672", "\[Rule]", "673"}], ",", 
       RowBox[{"672", "\[Rule]", "669"}], ",", 
       RowBox[{"348", "\[Rule]", "333"}], ",", 
       RowBox[{"348", "\[Rule]", "363"}], ",", 
       RowBox[{"348", "\[Rule]", "349"}], ",", 
       RowBox[{"348", "\[Rule]", "345"}], ",", 
       RowBox[{"1644", "\[Rule]", "1629"}], ",", 
       RowBox[{"1644", "\[Rule]", "1659"}], ",", 
       RowBox[{"1644", "\[Rule]", "1645"}], ",", 
       RowBox[{"1644", "\[Rule]", "1641"}], ",", 
       RowBox[{"1536", "\[Rule]", "1521"}], ",", 
       RowBox[{"1536", "\[Rule]", "1551"}], ",", 
       RowBox[{"1536", "\[Rule]", "1537"}], ",", 
       RowBox[{"1536", "\[Rule]", "1533"}], ",", 
       RowBox[{"1212", "\[Rule]", "1197"}], ",", 
       RowBox[{"1212", "\[Rule]", "1227"}], ",", 
       RowBox[{"1212", "\[Rule]", "1213"}], ",", 
       RowBox[{"1212", "\[Rule]", "1209"}], ",", 
       RowBox[{"564", "\[Rule]", "549"}], ",", 
       RowBox[{"564", "\[Rule]", "579"}], ",", 
       RowBox[{"564", "\[Rule]", "565"}], ",", 
       RowBox[{"564", "\[Rule]", "561"}], ",", 
       RowBox[{"240", "\[Rule]", "225"}], ",", 
       RowBox[{"240", "\[Rule]", "255"}], ",", 
       RowBox[{"240", "\[Rule]", "241"}], ",", 
       RowBox[{"240", "\[Rule]", "237"}], ",", 
       RowBox[{"1428", "\[Rule]", "1413"}], ",", 
       RowBox[{"1428", "\[Rule]", "1443"}], ",", 
       RowBox[{"1428", "\[Rule]", "1429"}], ",", 
       RowBox[{"1428", "\[Rule]", "1425"}], ",", 
       RowBox[{"1104", "\[Rule]", "1089"}], ",", 
       RowBox[{"1104", "\[Rule]", "1119"}], ",", 
       RowBox[{"1104", "\[Rule]", "1105"}], ",", 
       RowBox[{"1104", "\[Rule]", "1101"}], ",", 
       RowBox[{"2496", "\[Rule]", "2509"}], ",", 
       RowBox[{"2496", "\[Rule]", "2497"}], ",", 
       RowBox[{"2496", "\[Rule]", "2493"}], ",", 
       RowBox[{"2388", "\[Rule]", "2401"}], ",", 
       RowBox[{"2388", "\[Rule]", "2389"}], ",", 
       RowBox[{"2388", "\[Rule]", "2385"}], ",", 
       RowBox[{"2064", "\[Rule]", "2077"}], ",", 
       RowBox[{"2064", "\[Rule]", "2065"}], ",", 
       RowBox[{"2064", "\[Rule]", "2061"}], ",", 
       RowBox[{"2280", "\[Rule]", "2293"}], ",", 
       RowBox[{"2280", "\[Rule]", "2281"}], ",", 
       RowBox[{"2280", "\[Rule]", "2277"}], ",", 
       RowBox[{"1956", "\[Rule]", "1969"}], ",", 
       RowBox[{"1956", "\[Rule]", "1957"}], ",", 
       RowBox[{"1956", "\[Rule]", "1953"}], ",", 
       RowBox[{"2508", "\[Rule]", "2493"}], ",", 
       RowBox[{"2508", "\[Rule]", "2523"}], ",", 
       RowBox[{"2508", "\[Rule]", "2509"}], ",", 
       RowBox[{"2508", "\[Rule]", "2505"}], ",", 
       RowBox[{"2400", "\[Rule]", "2385"}], ",", 
       RowBox[{"2400", "\[Rule]", "2415"}], ",", 
       RowBox[{"2400", "\[Rule]", "2401"}], ",", 
       RowBox[{"2400", "\[Rule]", "2397"}], ",", 
       RowBox[{"2076", "\[Rule]", "2061"}], ",", 
       RowBox[{"2076", "\[Rule]", "2091"}], ",", 
       RowBox[{"2076", "\[Rule]", "2077"}], ",", 
       RowBox[{"2076", "\[Rule]", "2073"}], ",", 
       RowBox[{"2292", "\[Rule]", "2277"}], ",", 
       RowBox[{"2292", "\[Rule]", "2307"}], ",", 
       RowBox[{"2292", "\[Rule]", "2293"}], ",", 
       RowBox[{"2292", "\[Rule]", "2289"}], ",", 
       RowBox[{"1968", "\[Rule]", "1953"}], ",", 
       RowBox[{"1968", "\[Rule]", "1983"}], ",", 
       RowBox[{"1968", "\[Rule]", "1969"}], ",", 
       RowBox[{"1968", "\[Rule]", "1965"}], ",", 
       RowBox[{"444", "\[Rule]", "457"}], ",", 
       RowBox[{"444", "\[Rule]", "445"}], ",", 
       RowBox[{"444", "\[Rule]", "441"}], ",", 
       RowBox[{"120", "\[Rule]", "133"}], ",", 
       RowBox[{"120", "\[Rule]", "121"}], ",", 
       RowBox[{"120", "\[Rule]", "117"}], ",", 
       RowBox[{"1308", "\[Rule]", "1321"}], ",", 
       RowBox[{"1308", "\[Rule]", "1309"}], ",", 
       RowBox[{"1308", "\[Rule]", "1305"}], ",", 
       RowBox[{"984", "\[Rule]", "997"}], ",", 
       RowBox[{"984", "\[Rule]", "985"}], ",", 
       RowBox[{"984", "\[Rule]", "981"}], ",", 
       RowBox[{"456", "\[Rule]", "441"}], ",", 
       RowBox[{"456", "\[Rule]", "471"}], ",", 
       RowBox[{"456", "\[Rule]", "457"}], ",", 
       RowBox[{"456", "\[Rule]", "453"}], ",", 
       RowBox[{"132", "\[Rule]", "117"}], ",", 
       RowBox[{"132", "\[Rule]", "147"}], ",", 
       RowBox[{"132", "\[Rule]", "133"}], ",", 
       RowBox[{"132", "\[Rule]", "129"}], ",", 
       RowBox[{"1320", "\[Rule]", "1305"}], ",", 
       RowBox[{"1320", "\[Rule]", "1335"}], ",", 
       RowBox[{"1320", "\[Rule]", "1321"}], ",", 
       RowBox[{"1320", "\[Rule]", "1317"}], ",", 
       RowBox[{"996", "\[Rule]", "981"}], ",", 
       RowBox[{"996", "\[Rule]", "1011"}], ",", 
       RowBox[{"996", "\[Rule]", "997"}], ",", 
       RowBox[{"996", "\[Rule]", "993"}], ",", 
       RowBox[{"2172", "\[Rule]", "2185"}], ",", 
       RowBox[{"2172", "\[Rule]", "2173"}], ",", 
       RowBox[{"2172", "\[Rule]", "2169"}], ",", 
       RowBox[{"1848", "\[Rule]", "1861"}], ",", 
       RowBox[{"1848", "\[Rule]", "1849"}], ",", 
       RowBox[{"1848", "\[Rule]", "1845"}], ",", 
       RowBox[{"2184", "\[Rule]", "2169"}], ",", 
       RowBox[{"2184", "\[Rule]", "2199"}], ",", 
       RowBox[{"2184", "\[Rule]", "2185"}], ",", 
       RowBox[{"2184", "\[Rule]", "2181"}], ",", 
       RowBox[{"1860", "\[Rule]", "1845"}], ",", 
       RowBox[{"1860", "\[Rule]", "1875"}], ",", 
       RowBox[{"1860", "\[Rule]", "1861"}], ",", 
       RowBox[{"1860", "\[Rule]", "1857"}], ",", 
       RowBox[{"794", "\[Rule]", "777"}], ",", 
       RowBox[{"794", "\[Rule]", "807"}], ",", 
       RowBox[{"794", "\[Rule]", "795"}], ",", 
       RowBox[{"794", "\[Rule]", "791"}], ",", 
       RowBox[{"686", "\[Rule]", "669"}], ",", 
       RowBox[{"686", "\[Rule]", "699"}], ",", 
       RowBox[{"686", "\[Rule]", "687"}], ",", 
       RowBox[{"686", "\[Rule]", "683"}], ",", 
       RowBox[{"362", "\[Rule]", "345"}], ",", 
       RowBox[{"362", "\[Rule]", "375"}], ",", 
       RowBox[{"362", "\[Rule]", "363"}], ",", 
       RowBox[{"362", "\[Rule]", "359"}], ",", 
       RowBox[{"1658", "\[Rule]", "1641"}], ",", 
       RowBox[{"1658", "\[Rule]", "1671"}], ",", 
       RowBox[{"1658", "\[Rule]", "1659"}], ",", 
       RowBox[{"1658", "\[Rule]", "1655"}], ",", 
       RowBox[{"1550", "\[Rule]", "1533"}], ",", 
       RowBox[{"1550", "\[Rule]", "1563"}], ",", 
       RowBox[{"1550", "\[Rule]", "1551"}], ",", 
       RowBox[{"1550", "\[Rule]", "1547"}], ",", 
       RowBox[{"1226", "\[Rule]", "1209"}], ",", 
       RowBox[{"1226", "\[Rule]", "1239"}], ",", 
       RowBox[{"1226", "\[Rule]", "1227"}], ",", 
       RowBox[{"1226", "\[Rule]", "1223"}], ",", 
       RowBox[{"578", "\[Rule]", "561"}], ",", 
       RowBox[{"578", "\[Rule]", "591"}], ",", 
       RowBox[{"578", "\[Rule]", "579"}], ",", 
       RowBox[{"578", "\[Rule]", "575"}], ",", 
       RowBox[{"254", "\[Rule]", "237"}], ",", 
       RowBox[{"254", "\[Rule]", "267"}], ",", 
       RowBox[{"254", "\[Rule]", "255"}], ",", 
       RowBox[{"254", "\[Rule]", "251"}], ",", 
       RowBox[{"1442", "\[Rule]", "1425"}], ",", 
       RowBox[{"1442", "\[Rule]", "1455"}], ",", 
       RowBox[{"1442", "\[Rule]", "1443"}], ",", 
       RowBox[{"1442", "\[Rule]", "1439"}], ",", 
       RowBox[{"1118", "\[Rule]", "1101"}], ",", 
       RowBox[{"1118", "\[Rule]", "1131"}], ",", 
       RowBox[{"1118", "\[Rule]", "1119"}], ",", 
       RowBox[{"1118", "\[Rule]", "1115"}], ",", 
       RowBox[{"2522", "\[Rule]", "2505"}], ",", 
       RowBox[{"2522", "\[Rule]", "2535"}], ",", 
       RowBox[{"2522", "\[Rule]", "2523"}], ",", 
       RowBox[{"2522", "\[Rule]", "2519"}], ",", 
       RowBox[{"2414", "\[Rule]", "2397"}], ",", 
       RowBox[{"2414", "\[Rule]", "2427"}], ",", 
       RowBox[{"2414", "\[Rule]", "2415"}], ",", 
       RowBox[{"2414", "\[Rule]", "2411"}], ",", 
       RowBox[{"2090", "\[Rule]", "2073"}], ",", 
       RowBox[{"2090", "\[Rule]", "2103"}], ",", 
       RowBox[{"2090", "\[Rule]", "2091"}], ",", 
       RowBox[{"2090", "\[Rule]", "2087"}], ",", 
       RowBox[{"2306", "\[Rule]", "2289"}], ",", 
       RowBox[{"2306", "\[Rule]", "2319"}], ",", 
       RowBox[{"2306", "\[Rule]", "2307"}], ",", 
       RowBox[{"2306", "\[Rule]", "2303"}], ",", 
       RowBox[{"1982", "\[Rule]", "1965"}], ",", 
       RowBox[{"1982", "\[Rule]", "1995"}], ",", 
       RowBox[{"1982", "\[Rule]", "1983"}], ",", 
       RowBox[{"1982", "\[Rule]", "1979"}], ",", 
       RowBox[{"470", "\[Rule]", "453"}], ",", 
       RowBox[{"470", "\[Rule]", "483"}], ",", 
       RowBox[{"470", "\[Rule]", "471"}], ",", 
       RowBox[{"470", "\[Rule]", "467"}], ",", 
       RowBox[{"146", "\[Rule]", "129"}], ",", 
       RowBox[{"146", "\[Rule]", "159"}], ",", 
       RowBox[{"146", "\[Rule]", "147"}], ",", 
       RowBox[{"146", "\[Rule]", "143"}], ",", 
       RowBox[{"1334", "\[Rule]", "1317"}], ",", 
       RowBox[{"1334", "\[Rule]", "1347"}], ",", 
       RowBox[{"1334", "\[Rule]", "1335"}], ",", 
       RowBox[{"1334", "\[Rule]", "1331"}], ",", 
       RowBox[{"1010", "\[Rule]", "993"}], ",", 
       RowBox[{"1010", "\[Rule]", "1023"}], ",", 
       RowBox[{"1010", "\[Rule]", "1011"}], ",", 
       RowBox[{"1010", "\[Rule]", "1007"}], ",", 
       RowBox[{"2198", "\[Rule]", "2181"}], ",", 
       RowBox[{"2198", "\[Rule]", "2211"}], ",", 
       RowBox[{"2198", "\[Rule]", "2199"}], ",", 
       RowBox[{"2198", "\[Rule]", "2195"}], ",", 
       RowBox[{"1874", "\[Rule]", "1857"}], ",", 
       RowBox[{"1874", "\[Rule]", "1887"}], ",", 
       RowBox[{"1874", "\[Rule]", "1875"}], ",", 
       RowBox[{"1874", "\[Rule]", "1871"}], ",", 
       RowBox[{"12", "\[Rule]", "25"}], ",", 
       RowBox[{"12", "\[Rule]", "13"}], ",", 
       RowBox[{"12", "\[Rule]", "9"}], ",", 
       RowBox[{"876", "\[Rule]", "889"}], ",", 
       RowBox[{"876", "\[Rule]", "877"}], ",", 
       RowBox[{"876", "\[Rule]", "873"}], ",", 
       RowBox[{"24", "\[Rule]", "9"}], ",", 
       RowBox[{"24", "\[Rule]", "39"}], ",", 
       RowBox[{"24", "\[Rule]", "25"}], ",", 
       RowBox[{"24", "\[Rule]", "21"}], ",", 
       RowBox[{"888", "\[Rule]", "873"}], ",", 
       RowBox[{"888", "\[Rule]", "903"}], ",", 
       RowBox[{"888", "\[Rule]", "889"}], ",", 
       RowBox[{"888", "\[Rule]", "885"}], ",", 
       RowBox[{"1740", "\[Rule]", "1753"}], ",", 
       RowBox[{"1740", "\[Rule]", "1741"}], ",", 
       RowBox[{"1740", "\[Rule]", "1737"}], ",", 
       RowBox[{"1752", "\[Rule]", "1737"}], ",", 
       RowBox[{"1752", "\[Rule]", "1767"}], ",", 
       RowBox[{"1752", "\[Rule]", "1753"}], ",", 
       RowBox[{"1752", "\[Rule]", "1749"}], ",", 
       RowBox[{"38", "\[Rule]", "21"}], ",", 
       RowBox[{"38", "\[Rule]", "51"}], ",", 
       RowBox[{"38", "\[Rule]", "39"}], ",", 
       RowBox[{"38", "\[Rule]", "35"}], ",", 
       RowBox[{"902", "\[Rule]", "885"}], ",", 
       RowBox[{"902", "\[Rule]", "915"}], ",", 
       RowBox[{"902", "\[Rule]", "903"}], ",", 
       RowBox[{"902", "\[Rule]", "899"}], ",", 
       RowBox[{"1766", "\[Rule]", "1749"}], ",", 
       RowBox[{"1766", "\[Rule]", "1779"}], ",", 
       RowBox[{"1766", "\[Rule]", "1767"}], ",", 
       RowBox[{"1766", "\[Rule]", "1763"}], ",", 
       RowBox[{"806", "\[Rule]", "791"}], ",", 
       RowBox[{"806", "\[Rule]", "821"}], ",", 
       RowBox[{"806", "\[Rule]", "807"}], ",", 
       RowBox[{"806", "\[Rule]", "803"}], ",", 
       RowBox[{"698", "\[Rule]", "683"}], ",", 
       RowBox[{"698", "\[Rule]", "713"}], ",", 
       RowBox[{"698", "\[Rule]", "699"}], ",", 
       RowBox[{"698", "\[Rule]", "695"}], ",", 
       RowBox[{"374", "\[Rule]", "359"}], ",", 
       RowBox[{"374", "\[Rule]", "389"}], ",", 
       RowBox[{"374", "\[Rule]", "375"}], ",", 
       RowBox[{"374", "\[Rule]", "371"}], ",", 
       RowBox[{"1670", "\[Rule]", "1655"}], ",", 
       RowBox[{"1670", "\[Rule]", "1685"}], ",", 
       RowBox[{"1670", "\[Rule]", "1671"}], ",", 
       RowBox[{"1670", "\[Rule]", "1667"}], ",", 
       RowBox[{"1562", "\[Rule]", "1547"}], ",", 
       RowBox[{"1562", "\[Rule]", "1577"}], ",", 
       RowBox[{"1562", "\[Rule]", "1563"}], ",", 
       RowBox[{"1562", "\[Rule]", "1559"}], ",", 
       RowBox[{"1238", "\[Rule]", "1223"}], ",", 
       RowBox[{"1238", "\[Rule]", "1253"}], ",", 
       RowBox[{"1238", "\[Rule]", "1239"}], ",", 
       RowBox[{"1238", "\[Rule]", "1235"}], ",", 
       RowBox[{"590", "\[Rule]", "575"}], ",", 
       RowBox[{"590", "\[Rule]", "605"}], ",", 
       RowBox[{"590", "\[Rule]", "591"}], ",", 
       RowBox[{"590", "\[Rule]", "587"}], ",", 
       RowBox[{"266", "\[Rule]", "251"}], ",", 
       RowBox[{"266", "\[Rule]", "281"}], ",", 
       RowBox[{"266", "\[Rule]", "267"}], ",", 
       RowBox[{"266", "\[Rule]", "263"}], ",", 
       RowBox[{"1454", "\[Rule]", "1439"}], ",", 
       RowBox[{"1454", "\[Rule]", "1469"}], ",", 
       RowBox[{"1454", "\[Rule]", "1455"}], ",", 
       RowBox[{"1454", "\[Rule]", "1451"}], ",", 
       RowBox[{"1130", "\[Rule]", "1115"}], ",", 
       RowBox[{"1130", "\[Rule]", "1145"}], ",", 
       RowBox[{"1130", "\[Rule]", "1131"}], ",", 
       RowBox[{"1130", "\[Rule]", "1127"}], ",", 
       RowBox[{"2534", "\[Rule]", "2519"}], ",", 
       RowBox[{"2534", "\[Rule]", "2549"}], ",", 
       RowBox[{"2534", "\[Rule]", "2535"}], ",", 
       RowBox[{"2534", "\[Rule]", "2531"}], ",", 
       RowBox[{"2426", "\[Rule]", "2411"}], ",", 
       RowBox[{"2426", "\[Rule]", "2441"}], ",", 
       RowBox[{"2426", "\[Rule]", "2427"}], ",", 
       RowBox[{"2426", "\[Rule]", "2423"}], ",", 
       RowBox[{"2102", "\[Rule]", "2087"}], ",", 
       RowBox[{"2102", "\[Rule]", "2117"}], ",", 
       RowBox[{"2102", "\[Rule]", "2103"}], ",", 
       RowBox[{"2102", "\[Rule]", "2099"}], ",", 
       RowBox[{"2318", "\[Rule]", "2303"}], ",", 
       RowBox[{"2318", "\[Rule]", "2333"}], ",", 
       RowBox[{"2318", "\[Rule]", "2319"}], ",", 
       RowBox[{"2318", "\[Rule]", "2315"}], ",", 
       RowBox[{"1994", "\[Rule]", "1979"}], ",", 
       RowBox[{"1994", "\[Rule]", "2009"}], ",", 
       RowBox[{"1994", "\[Rule]", "1995"}], ",", 
       RowBox[{"1994", "\[Rule]", "1991"}], ",", 
       RowBox[{"482", "\[Rule]", "467"}], ",", 
       RowBox[{"482", "\[Rule]", "497"}], ",", 
       RowBox[{"482", "\[Rule]", "483"}], ",", 
       RowBox[{"482", "\[Rule]", "479"}], ",", 
       RowBox[{"158", "\[Rule]", "143"}], ",", 
       RowBox[{"158", "\[Rule]", "173"}], ",", 
       RowBox[{"158", "\[Rule]", "159"}], ",", 
       RowBox[{"158", "\[Rule]", "155"}], ",", 
       RowBox[{"1346", "\[Rule]", "1331"}], ",", 
       RowBox[{"1346", "\[Rule]", "1361"}], ",", 
       RowBox[{"1346", "\[Rule]", "1347"}], ",", 
       RowBox[{"1346", "\[Rule]", "1343"}], ",", 
       RowBox[{"1022", "\[Rule]", "1007"}], ",", 
       RowBox[{"1022", "\[Rule]", "1037"}], ",", 
       RowBox[{"1022", "\[Rule]", "1023"}], ",", 
       RowBox[{"1022", "\[Rule]", "1019"}], ",", 
       RowBox[{"2210", "\[Rule]", "2195"}], ",", 
       RowBox[{"2210", "\[Rule]", "2225"}], ",", 
       RowBox[{"2210", "\[Rule]", "2211"}], ",", 
       RowBox[{"2210", "\[Rule]", "2207"}], ",", 
       RowBox[{"1886", "\[Rule]", "1871"}], ",", 
       RowBox[{"1886", "\[Rule]", "1901"}], ",", 
       RowBox[{"1886", "\[Rule]", "1887"}], ",", 
       RowBox[{"1886", "\[Rule]", "1883"}], ",", 
       RowBox[{"50", "\[Rule]", "35"}], ",", 
       RowBox[{"50", "\[Rule]", "65"}], ",", 
       RowBox[{"50", "\[Rule]", "51"}], ",", 
       RowBox[{"50", "\[Rule]", "47"}], ",", 
       RowBox[{"914", "\[Rule]", "899"}], ",", 
       RowBox[{"914", "\[Rule]", "929"}], ",", 
       RowBox[{"914", "\[Rule]", "915"}], ",", 
       RowBox[{"914", "\[Rule]", "911"}], ",", 
       RowBox[{"1778", "\[Rule]", "1763"}], ",", 
       RowBox[{"1778", "\[Rule]", "1793"}], ",", 
       RowBox[{"1778", "\[Rule]", "1779"}], ",", 
       RowBox[{"1778", "\[Rule]", "1775"}], ",", 
       RowBox[{"2928", "\[Rule]", "2941"}], ",", 
       RowBox[{"2928", "\[Rule]", "2929"}], ",", 
       RowBox[{"2928", "\[Rule]", "2925"}], ",", 
       RowBox[{"2820", "\[Rule]", "2833"}], ",", 
       RowBox[{"2820", "\[Rule]", "2821"}], ",", 
       RowBox[{"2820", "\[Rule]", "2817"}], ",", 
       RowBox[{"2940", "\[Rule]", "2925"}], ",", 
       RowBox[{"2940", "\[Rule]", "2955"}], ",", 
       RowBox[{"2940", "\[Rule]", "2941"}], ",", 
       RowBox[{"2940", "\[Rule]", "2937"}], ",", 
       RowBox[{"2832", "\[Rule]", "2817"}], ",", 
       RowBox[{"2832", "\[Rule]", "2847"}], ",", 
       RowBox[{"2832", "\[Rule]", "2833"}], ",", 
       RowBox[{"2832", "\[Rule]", "2829"}], ",", 
       RowBox[{"2712", "\[Rule]", "2725"}], ",", 
       RowBox[{"2712", "\[Rule]", "2713"}], ",", 
       RowBox[{"2712", "\[Rule]", "2709"}], ",", 
       RowBox[{"2724", "\[Rule]", "2709"}], ",", 
       RowBox[{"2724", "\[Rule]", "2739"}], ",", 
       RowBox[{"2724", "\[Rule]", "2725"}], ",", 
       RowBox[{"2724", "\[Rule]", "2721"}], ",", 
       RowBox[{"2954", "\[Rule]", "2937"}], ",", 
       RowBox[{"2954", "\[Rule]", "2967"}], ",", 
       RowBox[{"2954", "\[Rule]", "2955"}], ",", 
       RowBox[{"2954", "\[Rule]", "2951"}], ",", 
       RowBox[{"2846", "\[Rule]", "2829"}], ",", 
       RowBox[{"2846", "\[Rule]", "2859"}], ",", 
       RowBox[{"2846", "\[Rule]", "2847"}], ",", 
       RowBox[{"2846", "\[Rule]", "2843"}], ",", 
       RowBox[{"2738", "\[Rule]", "2721"}], ",", 
       RowBox[{"2738", "\[Rule]", "2751"}], ",", 
       RowBox[{"2738", "\[Rule]", "2739"}], ",", 
       RowBox[{"2738", "\[Rule]", "2735"}], ",", 
       RowBox[{"2604", "\[Rule]", "2617"}], ",", 
       RowBox[{"2604", "\[Rule]", "2605"}], ",", 
       RowBox[{"2604", "\[Rule]", "2601"}], ",", 
       RowBox[{"2616", "\[Rule]", "2601"}], ",", 
       RowBox[{"2616", "\[Rule]", "2631"}], ",", 
       RowBox[{"2616", "\[Rule]", "2617"}], ",", 
       RowBox[{"2616", "\[Rule]", "2613"}], ",", 
       RowBox[{"2630", "\[Rule]", "2613"}], ",", 
       RowBox[{"2630", "\[Rule]", "2643"}], ",", 
       RowBox[{"2630", "\[Rule]", "2631"}], ",", 
       RowBox[{"2630", "\[Rule]", "2627"}], ",", 
       RowBox[{"2966", "\[Rule]", "2951"}], ",", 
       RowBox[{"2966", "\[Rule]", "2981"}], ",", 
       RowBox[{"2966", "\[Rule]", "2967"}], ",", 
       RowBox[{"2966", "\[Rule]", "2963"}], ",", 
       RowBox[{"2858", "\[Rule]", "2843"}], ",", 
       RowBox[{"2858", "\[Rule]", "2873"}], ",", 
       RowBox[{"2858", "\[Rule]", "2859"}], ",", 
       RowBox[{"2858", "\[Rule]", "2855"}], ",", 
       RowBox[{"2750", "\[Rule]", "2735"}], ",", 
       RowBox[{"2750", "\[Rule]", "2765"}], ",", 
       RowBox[{"2750", "\[Rule]", "2751"}], ",", 
       RowBox[{"2750", "\[Rule]", "2747"}], ",", 
       RowBox[{"2642", "\[Rule]", "2627"}], ",", 
       RowBox[{"2642", "\[Rule]", "2657"}], ",", 
       RowBox[{"2642", "\[Rule]", "2643"}], ",", 
       RowBox[{"2642", "\[Rule]", "2639"}], ",", 
       RowBox[{"820", "\[Rule]", "803"}], ",", 
       RowBox[{"820", "\[Rule]", "835"}], ",", 
       RowBox[{"820", "\[Rule]", "821"}], ",", 
       RowBox[{"820", "\[Rule]", "817"}], ",", 
       RowBox[{"712", "\[Rule]", "695"}], ",", 
       RowBox[{"712", "\[Rule]", "727"}], ",", 
       RowBox[{"712", "\[Rule]", "713"}], ",", 
       RowBox[{"712", "\[Rule]", "709"}], ",", 
       RowBox[{"388", "\[Rule]", "371"}], ",", 
       RowBox[{"388", "\[Rule]", "403"}], ",", 
       RowBox[{"388", "\[Rule]", "389"}], ",", 
       RowBox[{"388", "\[Rule]", "385"}], ",", 
       RowBox[{"1684", "\[Rule]", "1667"}], ",", 
       RowBox[{"1684", "\[Rule]", "1699"}], ",", 
       RowBox[{"1684", "\[Rule]", "1685"}], ",", 
       RowBox[{"1684", "\[Rule]", "1681"}], ",", 
       RowBox[{"1576", "\[Rule]", "1559"}], ",", 
       RowBox[{"1576", "\[Rule]", "1591"}], ",", 
       RowBox[{"1576", "\[Rule]", "1577"}], ",", 
       RowBox[{"1576", "\[Rule]", "1573"}], ",", 
       RowBox[{"1252", "\[Rule]", "1235"}], ",", 
       RowBox[{"1252", "\[Rule]", "1267"}], ",", 
       RowBox[{"1252", "\[Rule]", "1253"}], ",", 
       RowBox[{"1252", "\[Rule]", "1249"}], ",", 
       RowBox[{"604", "\[Rule]", "587"}], ",", 
       RowBox[{"604", "\[Rule]", "619"}], ",", 
       RowBox[{"604", "\[Rule]", "605"}], ",", 
       RowBox[{"604", "\[Rule]", "601"}], ",", 
       RowBox[{"280", "\[Rule]", "263"}], ",", 
       RowBox[{"280", "\[Rule]", "295"}], ",", 
       RowBox[{"280", "\[Rule]", "281"}], ",", 
       RowBox[{"280", "\[Rule]", "277"}], ",", 
       RowBox[{"1468", "\[Rule]", "1451"}], ",", 
       RowBox[{"1468", "\[Rule]", "1483"}], ",", 
       RowBox[{"1468", "\[Rule]", "1469"}], ",", 
       RowBox[{"1468", "\[Rule]", "1465"}], ",", 
       RowBox[{"1144", "\[Rule]", "1127"}], ",", 
       RowBox[{"1144", "\[Rule]", "1159"}], ",", 
       RowBox[{"1144", "\[Rule]", "1145"}], ",", 
       RowBox[{"1144", "\[Rule]", "1141"}], ",", 
       RowBox[{"2548", "\[Rule]", "2531"}], ",", 
       RowBox[{"2548", "\[Rule]", "2563"}], ",", 
       RowBox[{"2548", "\[Rule]", "2549"}], ",", 
       RowBox[{"2548", "\[Rule]", "2545"}], ",", 
       RowBox[{"2440", "\[Rule]", "2423"}], ",", 
       RowBox[{"2440", "\[Rule]", "2455"}], ",", 
       RowBox[{"2440", "\[Rule]", "2441"}], ",", 
       RowBox[{"2440", "\[Rule]", "2437"}], ",", 
       RowBox[{"2116", "\[Rule]", "2099"}], ",", 
       RowBox[{"2116", "\[Rule]", "2131"}], ",", 
       RowBox[{"2116", "\[Rule]", "2117"}], ",", 
       RowBox[{"2116", "\[Rule]", "2113"}], ",", 
       RowBox[{"2332", "\[Rule]", "2315"}], ",", 
       RowBox[{"2332", "\[Rule]", "2347"}], ",", 
       RowBox[{"2332", "\[Rule]", "2333"}], ",", 
       RowBox[{"2332", "\[Rule]", "2329"}], ",", 
       RowBox[{"2008", "\[Rule]", "1991"}], ",", 
       RowBox[{"2008", "\[Rule]", "2023"}], ",", 
       RowBox[{"2008", "\[Rule]", "2009"}], ",", 
       RowBox[{"2008", "\[Rule]", "2005"}], ",", 
       RowBox[{"496", "\[Rule]", "479"}], ",", 
       RowBox[{"496", "\[Rule]", "511"}], ",", 
       RowBox[{"496", "\[Rule]", "497"}], ",", 
       RowBox[{"496", "\[Rule]", "493"}], ",", 
       RowBox[{"172", "\[Rule]", "155"}], ",", 
       RowBox[{"172", "\[Rule]", "187"}], ",", 
       RowBox[{"172", "\[Rule]", "173"}], ",", 
       RowBox[{"172", "\[Rule]", "169"}], ",", 
       RowBox[{"1360", "\[Rule]", "1343"}], ",", 
       RowBox[{"1360", "\[Rule]", "1375"}], ",", 
       RowBox[{"1360", "\[Rule]", "1361"}], ",", 
       RowBox[{"1360", "\[Rule]", "1357"}], ",", 
       RowBox[{"1036", "\[Rule]", "1019"}], ",", 
       RowBox[{"1036", "\[Rule]", "1051"}], ",", 
       RowBox[{"1036", "\[Rule]", "1037"}], ",", 
       RowBox[{"1036", "\[Rule]", "1033"}], ",", 
       RowBox[{"2224", "\[Rule]", "2207"}], ",", 
       RowBox[{"2224", "\[Rule]", "2239"}], ",", 
       RowBox[{"2224", "\[Rule]", "2225"}], ",", 
       RowBox[{"2224", "\[Rule]", "2221"}], ",", 
       RowBox[{"1900", "\[Rule]", "1883"}], ",", 
       RowBox[{"1900", "\[Rule]", "1915"}], ",", 
       RowBox[{"1900", "\[Rule]", "1901"}], ",", 
       RowBox[{"1900", "\[Rule]", "1897"}], ",", 
       RowBox[{"64", "\[Rule]", "47"}], ",", 
       RowBox[{"64", "\[Rule]", "79"}], ",", 
       RowBox[{"64", "\[Rule]", "65"}], ",", 
       RowBox[{"64", "\[Rule]", "61"}], ",", 
       RowBox[{"928", "\[Rule]", "911"}], ",", 
       RowBox[{"928", "\[Rule]", "943"}], ",", 
       RowBox[{"928", "\[Rule]", "929"}], ",", 
       RowBox[{"928", "\[Rule]", "925"}], ",", 
       RowBox[{"1792", "\[Rule]", "1775"}], ",", 
       RowBox[{"1792", "\[Rule]", "1807"}], ",", 
       RowBox[{"1792", "\[Rule]", "1793"}], ",", 
       RowBox[{"1792", "\[Rule]", "1789"}], ",", 
       RowBox[{"2980", "\[Rule]", "2963"}], ",", 
       RowBox[{"2980", "\[Rule]", "2995"}], ",", 
       RowBox[{"2980", "\[Rule]", "2981"}], ",", 
       RowBox[{"2980", "\[Rule]", "2977"}], ",", 
       RowBox[{"2872", "\[Rule]", "2855"}], ",", 
       RowBox[{"2872", "\[Rule]", "2887"}], ",", 
       RowBox[{"2872", "\[Rule]", "2873"}], ",", 
       RowBox[{"2872", "\[Rule]", "2869"}], ",", 
       RowBox[{"2764", "\[Rule]", "2747"}], ",", 
       RowBox[{"2764", "\[Rule]", "2779"}], ",", 
       RowBox[{"2764", "\[Rule]", "2765"}], ",", 
       RowBox[{"2764", "\[Rule]", "2761"}], ",", 
       RowBox[{"2656", "\[Rule]", "2639"}], ",", 
       RowBox[{"2656", "\[Rule]", "2671"}], ",", 
       RowBox[{"2656", "\[Rule]", "2657"}], ",", 
       RowBox[{"2656", "\[Rule]", "2653"}], ",", 
       RowBox[{"834", "\[Rule]", "817"}], ",", 
       RowBox[{"834", "\[Rule]", "849"}], ",", 
       RowBox[{"834", "\[Rule]", "835"}], ",", 
       RowBox[{"726", "\[Rule]", "709"}], ",", 
       RowBox[{"726", "\[Rule]", "741"}], ",", 
       RowBox[{"726", "\[Rule]", "727"}], ",", 
       RowBox[{"402", "\[Rule]", "385"}], ",", 
       RowBox[{"402", "\[Rule]", "417"}], ",", 
       RowBox[{"402", "\[Rule]", "403"}], ",", 
       RowBox[{"1698", "\[Rule]", "1681"}], ",", 
       RowBox[{"1698", "\[Rule]", "1713"}], ",", 
       RowBox[{"1698", "\[Rule]", "1699"}], ",", 
       RowBox[{"1590", "\[Rule]", "1573"}], ",", 
       RowBox[{"1590", "\[Rule]", "1605"}], ",", 
       RowBox[{"1590", "\[Rule]", "1591"}], ",", 
       RowBox[{"1266", "\[Rule]", "1249"}], ",", 
       RowBox[{"1266", "\[Rule]", "1281"}], ",", 
       RowBox[{"1266", "\[Rule]", "1267"}], ",", 
       RowBox[{"618", "\[Rule]", "601"}], ",", 
       RowBox[{"618", "\[Rule]", "633"}], ",", 
       RowBox[{"618", "\[Rule]", "619"}], ",", 
       RowBox[{"294", "\[Rule]", "277"}], ",", 
       RowBox[{"294", "\[Rule]", "309"}], ",", 
       RowBox[{"294", "\[Rule]", "295"}], ",", 
       RowBox[{"1482", "\[Rule]", "1465"}], ",", 
       RowBox[{"1482", "\[Rule]", "1497"}], ",", 
       RowBox[{"1482", "\[Rule]", "1483"}], ",", 
       RowBox[{"1158", "\[Rule]", "1141"}], ",", 
       RowBox[{"1158", "\[Rule]", "1173"}], ",", 
       RowBox[{"1158", "\[Rule]", "1159"}], ",", 
       RowBox[{"2562", "\[Rule]", "2545"}], ",", 
       RowBox[{"2562", "\[Rule]", "2577"}], ",", 
       RowBox[{"2562", "\[Rule]", "2563"}], ",", 
       RowBox[{"2454", "\[Rule]", "2437"}], ",", 
       RowBox[{"2454", "\[Rule]", "2469"}], ",", 
       RowBox[{"2454", "\[Rule]", "2455"}], ",", 
       RowBox[{"2130", "\[Rule]", "2113"}], ",", 
       RowBox[{"2130", "\[Rule]", "2145"}], ",", 
       RowBox[{"2130", "\[Rule]", "2131"}], ",", 
       RowBox[{"2346", "\[Rule]", "2329"}], ",", 
       RowBox[{"2346", "\[Rule]", "2361"}], ",", 
       RowBox[{"2346", "\[Rule]", "2347"}], ",", 
       RowBox[{"2022", "\[Rule]", "2005"}], ",", 
       RowBox[{"2022", "\[Rule]", "2037"}], ",", 
       RowBox[{"2022", "\[Rule]", "2023"}], ",", 
       RowBox[{"510", "\[Rule]", "493"}], ",", 
       RowBox[{"510", "\[Rule]", "525"}], ",", 
       RowBox[{"510", "\[Rule]", "511"}], ",", 
       RowBox[{"186", "\[Rule]", "169"}], ",", 
       RowBox[{"186", "\[Rule]", "201"}], ",", 
       RowBox[{"186", "\[Rule]", "187"}], ",", 
       RowBox[{"1374", "\[Rule]", "1357"}], ",", 
       RowBox[{"1374", "\[Rule]", "1389"}], ",", 
       RowBox[{"1374", "\[Rule]", "1375"}], ",", 
       RowBox[{"1050", "\[Rule]", "1033"}], ",", 
       RowBox[{"1050", "\[Rule]", "1065"}], ",", 
       RowBox[{"1050", "\[Rule]", "1051"}], ",", 
       RowBox[{"2238", "\[Rule]", "2221"}], ",", 
       RowBox[{"2238", "\[Rule]", "2253"}], ",", 
       RowBox[{"2238", "\[Rule]", "2239"}], ",", 
       RowBox[{"1914", "\[Rule]", "1897"}], ",", 
       RowBox[{"1914", "\[Rule]", "1929"}], ",", 
       RowBox[{"1914", "\[Rule]", "1915"}], ",", 
       RowBox[{"78", "\[Rule]", "61"}], ",", 
       RowBox[{"78", "\[Rule]", "93"}], ",", 
       RowBox[{"78", "\[Rule]", "79"}], ",", 
       RowBox[{"942", "\[Rule]", "925"}], ",", 
       RowBox[{"942", "\[Rule]", "957"}], ",", 
       RowBox[{"942", "\[Rule]", "943"}], ",", 
       RowBox[{"1806", "\[Rule]", "1789"}], ",", 
       RowBox[{"1806", "\[Rule]", "1821"}], ",", 
       RowBox[{"1806", "\[Rule]", "1807"}], ",", 
       RowBox[{"2994", "\[Rule]", "2977"}], ",", 
       RowBox[{"2994", "\[Rule]", "3009"}], ",", 
       RowBox[{"2994", "\[Rule]", "2995"}], ",", 
       RowBox[{"2886", "\[Rule]", "2869"}], ",", 
       RowBox[{"2886", "\[Rule]", "2901"}], ",", 
       RowBox[{"2886", "\[Rule]", "2887"}], ",", 
       RowBox[{"2778", "\[Rule]", "2761"}], ",", 
       RowBox[{"2778", "\[Rule]", "2793"}], ",", 
       RowBox[{"2778", "\[Rule]", "2779"}], ",", 
       RowBox[{"2670", "\[Rule]", "2653"}], ",", 
       RowBox[{"2670", "\[Rule]", "2685"}], ",", 
       RowBox[{"2670", "\[Rule]", "2671"}], ",", 
       RowBox[{"765", "\[Rule]", "334"}], ",", 
       RowBox[{"765", "\[Rule]", "334"}], ",", 
       RowBox[{"765", "\[Rule]", "1198"}], ",", 
       RowBox[{"765", "\[Rule]", "1198"}], ",", 
       RowBox[{"765", "\[Rule]", "766"}], ",", 
       RowBox[{"657", "\[Rule]", "334"}], ",", 
       RowBox[{"657", "\[Rule]", "334"}], ",", 
       RowBox[{"657", "\[Rule]", "1198"}], ",", 
       RowBox[{"657", "\[Rule]", "1198"}], ",", 
       RowBox[{"657", "\[Rule]", "226"}], ",", 
       RowBox[{"657", "\[Rule]", "226"}], ",", 
       RowBox[{"657", "\[Rule]", "1090"}], ",", 
       RowBox[{"657", "\[Rule]", "1090"}], ",", 
       RowBox[{"657", "\[Rule]", "658"}], ",", 
       RowBox[{"333", "\[Rule]", "766"}], ",", 
       RowBox[{"333", "\[Rule]", "766"}], ",", 
       RowBox[{"333", "\[Rule]", "658"}], ",", 
       RowBox[{"333", "\[Rule]", "658"}], ",", 
       RowBox[{"333", "\[Rule]", "334"}], ",", 
       RowBox[{"1629", "\[Rule]", "1198"}], ",", 
       RowBox[{"1629", "\[Rule]", "1198"}], ",", 
       RowBox[{"1629", "\[Rule]", "2062"}], ",", 
       RowBox[{"1629", "\[Rule]", "2062"}], ",", 
       RowBox[{"1629", "\[Rule]", "1630"}], ",", 
       RowBox[{"1521", "\[Rule]", "1198"}], ",", 
       RowBox[{"1521", "\[Rule]", "1198"}], ",", 
       RowBox[{"1521", "\[Rule]", "2062"}], ",", 
       RowBox[{"1521", "\[Rule]", "2062"}], ",", 
       RowBox[{"1521", "\[Rule]", "1090"}], ",", 
       RowBox[{"1521", "\[Rule]", "1090"}], ",", 
       RowBox[{"1521", "\[Rule]", "1954"}], ",", 
       RowBox[{"1521", "\[Rule]", "1954"}], ",", 
       RowBox[{"1521", "\[Rule]", "1522"}], ",", 
       RowBox[{"1197", "\[Rule]", "766"}], ",", 
       RowBox[{"1197", "\[Rule]", "766"}], ",", 
       RowBox[{"1197", "\[Rule]", "1630"}], ",", 
       RowBox[{"1197", "\[Rule]", "1630"}], ",", 
       RowBox[{"1197", "\[Rule]", "658"}], ",", 
       RowBox[{"1197", "\[Rule]", "658"}], ",", 
       RowBox[{"1197", "\[Rule]", "1522"}], ",", 
       RowBox[{"1197", "\[Rule]", "1522"}], ",", 
       RowBox[{"1197", "\[Rule]", "1198"}], ",", 
       RowBox[{"549", "\[Rule]", "226"}], ",", 
       RowBox[{"549", "\[Rule]", "226"}], ",", 
       RowBox[{"549", "\[Rule]", "1090"}], ",", 
       RowBox[{"549", "\[Rule]", "1090"}], ",", 
       RowBox[{"549", "\[Rule]", "118"}], ",", 
       RowBox[{"549", "\[Rule]", "982"}], ",", 
       RowBox[{"549", "\[Rule]", "550"}], ",", 
       RowBox[{"225", "\[Rule]", "658"}], ",", 
       RowBox[{"225", "\[Rule]", "658"}], ",", 
       RowBox[{"225", "\[Rule]", "550"}], ",", 
       RowBox[{"225", "\[Rule]", "550"}], ",", 
       RowBox[{"225", "\[Rule]", "226"}], ",", 
       RowBox[{"1413", "\[Rule]", "1090"}], ",", 
       RowBox[{"1413", "\[Rule]", "1090"}], ",", 
       RowBox[{"1413", "\[Rule]", "1954"}], ",", 
       RowBox[{"1413", "\[Rule]", "1954"}], ",", 
       RowBox[{"1413", "\[Rule]", "982"}], ",", 
       RowBox[{"1413", "\[Rule]", "982"}], ",", 
       RowBox[{"1413", "\[Rule]", "1846"}], ",", 
       RowBox[{"1413", "\[Rule]", "1846"}], ",", 
       RowBox[{"1413", "\[Rule]", "1414"}], ",", 
       RowBox[{"1089", "\[Rule]", "658"}], ",", 
       RowBox[{"1089", "\[Rule]", "658"}], ",", 
       RowBox[{"1089", "\[Rule]", "1522"}], ",", 
       RowBox[{"1089", "\[Rule]", "1522"}], ",", 
       RowBox[{"1089", "\[Rule]", "550"}], ",", 
       RowBox[{"1089", "\[Rule]", "550"}], ",", 
       RowBox[{"1089", "\[Rule]", "1414"}], ",", 
       RowBox[{"1089", "\[Rule]", "1414"}], ",", 
       RowBox[{"1089", "\[Rule]", "1090"}], ",", 
       RowBox[{"777", "\[Rule]", "346"}], ",", 
       RowBox[{"777", "\[Rule]", "346"}], ",", 
       RowBox[{"777", "\[Rule]", "1210"}], ",", 
       RowBox[{"777", "\[Rule]", "1210"}], ",", 
       RowBox[{"777", "\[Rule]", "778"}], ",", 
       RowBox[{"669", "\[Rule]", "346"}], ",", 
       RowBox[{"669", "\[Rule]", "346"}], ",", 
       RowBox[{"669", "\[Rule]", "1210"}], ",", 
       RowBox[{"669", "\[Rule]", "1210"}], ",", 
       RowBox[{"669", "\[Rule]", "238"}], ",", 
       RowBox[{"669", "\[Rule]", "238"}], ",", 
       RowBox[{"669", "\[Rule]", "1102"}], ",", 
       RowBox[{"669", "\[Rule]", "1102"}], ",", 
       RowBox[{"669", "\[Rule]", "670"}], ",", 
       RowBox[{"345", "\[Rule]", "778"}], ",", 
       RowBox[{"345", "\[Rule]", "778"}], ",", 
       RowBox[{"345", "\[Rule]", "670"}], ",", 
       RowBox[{"345", "\[Rule]", "670"}], ",", 
       RowBox[{"345", "\[Rule]", "346"}], ",", 
       RowBox[{"1641", "\[Rule]", "1210"}], ",", 
       RowBox[{"1641", "\[Rule]", "1210"}], ",", 
       RowBox[{"1641", "\[Rule]", "2074"}], ",", 
       RowBox[{"1641", "\[Rule]", "2074"}], ",", 
       RowBox[{"1641", "\[Rule]", "1642"}], ",", 
       RowBox[{"1533", "\[Rule]", "1210"}], ",", 
       RowBox[{"1533", "\[Rule]", "1210"}], ",", 
       RowBox[{"1533", "\[Rule]", "2074"}], ",", 
       RowBox[{"1533", "\[Rule]", "2074"}], ",", 
       RowBox[{"1533", "\[Rule]", "1102"}], ",", 
       RowBox[{"1533", "\[Rule]", "1102"}], ",", 
       RowBox[{"1533", "\[Rule]", "1966"}], ",", 
       RowBox[{"1533", "\[Rule]", "1966"}], ",", 
       RowBox[{"1533", "\[Rule]", "1534"}], ",", 
       RowBox[{"1209", "\[Rule]", "778"}], ",", 
       RowBox[{"1209", "\[Rule]", "778"}], ",", 
       RowBox[{"1209", "\[Rule]", "1642"}], ",", 
       RowBox[{"1209", "\[Rule]", "1642"}], ",", 
       RowBox[{"1209", "\[Rule]", "670"}], ",", 
       RowBox[{"1209", "\[Rule]", "670"}], ",", 
       RowBox[{"1209", "\[Rule]", "1534"}], ",", 
       RowBox[{"1209", "\[Rule]", "1534"}], ",", 
       RowBox[{"1209", "\[Rule]", "1210"}], ",", 
       RowBox[{"561", "\[Rule]", "238"}], ",", 
       RowBox[{"561", "\[Rule]", "238"}], ",", 
       RowBox[{"561", "\[Rule]", "1102"}], ",", 
       RowBox[{"561", "\[Rule]", "1102"}], ",", 
       RowBox[{"561", "\[Rule]", "130"}], ",", 
       RowBox[{"561", "\[Rule]", "994"}], ",", 
       RowBox[{"561", "\[Rule]", "562"}], ",", 
       RowBox[{"237", "\[Rule]", "670"}], ",", 
       RowBox[{"237", "\[Rule]", "670"}], ",", 
       RowBox[{"237", "\[Rule]", "562"}], ",", 
       RowBox[{"237", "\[Rule]", "562"}], ",", 
       RowBox[{"237", "\[Rule]", "238"}], ",", 
       RowBox[{"1425", "\[Rule]", "1102"}], ",", 
       RowBox[{"1425", "\[Rule]", "1102"}], ",", 
       RowBox[{"1425", "\[Rule]", "1966"}], ",", 
       RowBox[{"1425", "\[Rule]", "1966"}], ",", 
       RowBox[{"1425", "\[Rule]", "994"}], ",", 
       RowBox[{"1425", "\[Rule]", "994"}], ",", 
       RowBox[{"1425", "\[Rule]", "1858"}], ",", 
       RowBox[{"1425", "\[Rule]", "1858"}], ",", 
       RowBox[{"1425", "\[Rule]", "1426"}], ",", 
       RowBox[{"1101", "\[Rule]", "670"}], ",", 
       RowBox[{"1101", "\[Rule]", "670"}], ",", 
       RowBox[{"1101", "\[Rule]", "1534"}], ",", 
       RowBox[{"1101", "\[Rule]", "1534"}], ",", 
       RowBox[{"1101", "\[Rule]", "562"}], ",", 
       RowBox[{"1101", "\[Rule]", "562"}], ",", 
       RowBox[{"1101", "\[Rule]", "1426"}], ",", 
       RowBox[{"1101", "\[Rule]", "1426"}], ",", 
       RowBox[{"1101", "\[Rule]", "1102"}], ",", 
       RowBox[{"2493", "\[Rule]", "2062"}], ",", 
       RowBox[{"2493", "\[Rule]", "2062"}], ",", 
       RowBox[{"2493", "\[Rule]", "2926"}], ",", 
       RowBox[{"2493", "\[Rule]", "2926"}], ",", 
       RowBox[{"2493", "\[Rule]", "2494"}], ",", 
       RowBox[{"2385", "\[Rule]", "2062"}], ",", 
       RowBox[{"2385", "\[Rule]", "2062"}], ",", 
       RowBox[{"2385", "\[Rule]", "2926"}], ",", 
       RowBox[{"2385", "\[Rule]", "2926"}], ",", 
       RowBox[{"2385", "\[Rule]", "1954"}], ",", 
       RowBox[{"2385", "\[Rule]", "1954"}], ",", 
       RowBox[{"2385", "\[Rule]", "2818"}], ",", 
       RowBox[{"2385", "\[Rule]", "2818"}], ",", 
       RowBox[{"2385", "\[Rule]", "2386"}], ",", 
       RowBox[{"2061", "\[Rule]", "1630"}], ",", 
       RowBox[{"2061", "\[Rule]", "1630"}], ",", 
       RowBox[{"2061", "\[Rule]", "2494"}], ",", 
       RowBox[{"2061", "\[Rule]", "2494"}], ",", 
       RowBox[{"2061", "\[Rule]", "1522"}], ",", 
       RowBox[{"2061", "\[Rule]", "1522"}], ",", 
       RowBox[{"2061", "\[Rule]", "2386"}], ",", 
       RowBox[{"2061", "\[Rule]", "2386"}], ",", 
       RowBox[{"2061", "\[Rule]", "2062"}], ",", 
       RowBox[{"2277", "\[Rule]", "1954"}], ",", 
       RowBox[{"2277", "\[Rule]", "1954"}], ",", 
       RowBox[{"2277", "\[Rule]", "2818"}], ",", 
       RowBox[{"2277", "\[Rule]", "2818"}], ",", 
       RowBox[{"2277", "\[Rule]", "1846"}], ",", 
       RowBox[{"2277", "\[Rule]", "1846"}], ",", 
       RowBox[{"2277", "\[Rule]", "2710"}], ",", 
       RowBox[{"2277", "\[Rule]", "2710"}], ",", 
       RowBox[{"2277", "\[Rule]", "2278"}], ",", 
       RowBox[{"1953", "\[Rule]", "1522"}], ",", 
       RowBox[{"1953", "\[Rule]", "1522"}], ",", 
       RowBox[{"1953", "\[Rule]", "2386"}], ",", 
       RowBox[{"1953", "\[Rule]", "2386"}], ",", 
       RowBox[{"1953", "\[Rule]", "1414"}], ",", 
       RowBox[{"1953", "\[Rule]", "1414"}], ",", 
       RowBox[{"1953", "\[Rule]", "2278"}], ",", 
       RowBox[{"1953", "\[Rule]", "2278"}], ",", 
       RowBox[{"1953", "\[Rule]", "1954"}], ",", 
       RowBox[{"2505", "\[Rule]", "2074"}], ",", 
       RowBox[{"2505", "\[Rule]", "2074"}], ",", 
       RowBox[{"2505", "\[Rule]", "2938"}], ",", 
       RowBox[{"2505", "\[Rule]", "2938"}], ",", 
       RowBox[{"2505", "\[Rule]", "2506"}], ",", 
       RowBox[{"2397", "\[Rule]", "2074"}], ",", 
       RowBox[{"2397", "\[Rule]", "2074"}], ",", 
       RowBox[{"2397", "\[Rule]", "2938"}], ",", 
       RowBox[{"2397", "\[Rule]", "2938"}], ",", 
       RowBox[{"2397", "\[Rule]", "1966"}], ",", 
       RowBox[{"2397", "\[Rule]", "1966"}], ",", 
       RowBox[{"2397", "\[Rule]", "2830"}], ",", 
       RowBox[{"2397", "\[Rule]", "2830"}], ",", 
       RowBox[{"2397", "\[Rule]", "2398"}], ",", 
       RowBox[{"2073", "\[Rule]", "1642"}], ",", 
       RowBox[{"2073", "\[Rule]", "1642"}], ",", 
       RowBox[{"2073", "\[Rule]", "2506"}], ",", 
       RowBox[{"2073", "\[Rule]", "2506"}], ",", 
       RowBox[{"2073", "\[Rule]", "1534"}], ",", 
       RowBox[{"2073", "\[Rule]", "1534"}], ",", 
       RowBox[{"2073", "\[Rule]", "2398"}], ",", 
       RowBox[{"2073", "\[Rule]", "2398"}], ",", 
       RowBox[{"2073", "\[Rule]", "2074"}], ",", 
       RowBox[{"2289", "\[Rule]", "1966"}], ",", 
       RowBox[{"2289", "\[Rule]", "1966"}], ",", 
       RowBox[{"2289", "\[Rule]", "2830"}], ",", 
       RowBox[{"2289", "\[Rule]", "2830"}], ",", 
       RowBox[{"2289", "\[Rule]", "1858"}], ",", 
       RowBox[{"2289", "\[Rule]", "1858"}], ",", 
       RowBox[{"2289", "\[Rule]", "2722"}], ",", 
       RowBox[{"2289", "\[Rule]", "2722"}], ",", 
       RowBox[{"2289", "\[Rule]", "2290"}], ",", 
       RowBox[{"1965", "\[Rule]", "1534"}], ",", 
       RowBox[{"1965", "\[Rule]", "1534"}], ",", 
       RowBox[{"1965", "\[Rule]", "2398"}], ",", 
       RowBox[{"1965", "\[Rule]", "2398"}], ",", 
       RowBox[{"1965", "\[Rule]", "1426"}], ",", 
       RowBox[{"1965", "\[Rule]", "1426"}], ",", 
       RowBox[{"1965", "\[Rule]", "2290"}], ",", 
       RowBox[{"1965", "\[Rule]", "2290"}], ",", 
       RowBox[{"1965", "\[Rule]", "1966"}], ",", 
       RowBox[{"441", "\[Rule]", "118"}], ",", 
       RowBox[{"441", "\[Rule]", "982"}], ",", 
       RowBox[{"441", "\[Rule]", "10"}], ",", 
       RowBox[{"441", "\[Rule]", "10"}], ",", 
       RowBox[{"441", "\[Rule]", "874"}], ",", 
       RowBox[{"441", "\[Rule]", "874"}], ",", 
       RowBox[{"441", "\[Rule]", "442"}], ",", 
       RowBox[{"117", "\[Rule]", "550"}], ",", 
       RowBox[{"117", "\[Rule]", "442"}], ",", 
       RowBox[{"117", "\[Rule]", "118"}], ",", 
       RowBox[{"1305", "\[Rule]", "982"}], ",", 
       RowBox[{"1305", "\[Rule]", "982"}], ",", 
       RowBox[{"1305", "\[Rule]", "1846"}], ",", 
       RowBox[{"1305", "\[Rule]", "1846"}], ",", 
       RowBox[{"1305", "\[Rule]", "874"}], ",", 
       RowBox[{"1305", "\[Rule]", "1738"}], ",", 
       RowBox[{"1305", "\[Rule]", "1306"}], ",", 
       RowBox[{"981", "\[Rule]", "550"}], ",", 
       RowBox[{"981", "\[Rule]", "1414"}], ",", 
       RowBox[{"981", "\[Rule]", "1414"}], ",", 
       RowBox[{"981", "\[Rule]", "442"}], ",", 
       RowBox[{"981", "\[Rule]", "1306"}], ",", 
       RowBox[{"981", "\[Rule]", "1306"}], ",", 
       RowBox[{"981", "\[Rule]", "982"}], ",", 
       RowBox[{"453", "\[Rule]", "130"}], ",", 
       RowBox[{"453", "\[Rule]", "994"}], ",", 
       RowBox[{"453", "\[Rule]", "22"}], ",", 
       RowBox[{"453", "\[Rule]", "22"}], ",", 
       RowBox[{"453", "\[Rule]", "886"}], ",", 
       RowBox[{"453", "\[Rule]", "886"}], ",", 
       RowBox[{"453", "\[Rule]", "454"}], ",", 
       RowBox[{"129", "\[Rule]", "562"}], ",", 
       RowBox[{"129", "\[Rule]", "454"}], ",", 
       RowBox[{"129", "\[Rule]", "130"}], ",", 
       RowBox[{"1317", "\[Rule]", "994"}], ",", 
       RowBox[{"1317", "\[Rule]", "994"}], ",", 
       RowBox[{"1317", "\[Rule]", "1858"}], ",", 
       RowBox[{"1317", "\[Rule]", "1858"}], ",", 
       RowBox[{"1317", "\[Rule]", "886"}], ",", 
       RowBox[{"1317", "\[Rule]", "1750"}], ",", 
       RowBox[{"1317", "\[Rule]", "1318"}], ",", 
       RowBox[{"993", "\[Rule]", "562"}], ",", 
       RowBox[{"993", "\[Rule]", "1426"}], ",", 
       RowBox[{"993", "\[Rule]", "1426"}], ",", 
       RowBox[{"993", "\[Rule]", "454"}], ",", 
       RowBox[{"993", "\[Rule]", "1318"}], ",", 
       RowBox[{"993", "\[Rule]", "1318"}], ",", 
       RowBox[{"993", "\[Rule]", "994"}], ",", 
       RowBox[{"2169", "\[Rule]", "1846"}], ",", 
       RowBox[{"2169", "\[Rule]", "1846"}], ",", 
       RowBox[{"2169", "\[Rule]", "2710"}], ",", 
       RowBox[{"2169", "\[Rule]", "2710"}], ",", 
       RowBox[{"2169", "\[Rule]", "1738"}], ",", 
       RowBox[{"2169", "\[Rule]", "1738"}], ",", 
       RowBox[{"2169", "\[Rule]", "2602"}], ",", 
       RowBox[{"2169", "\[Rule]", "2602"}], ",", 
       RowBox[{"2169", "\[Rule]", "2170"}], ",", 
       RowBox[{"1845", "\[Rule]", "1414"}], ",", 
       RowBox[{"1845", "\[Rule]", "1414"}], ",", 
       RowBox[{"1845", "\[Rule]", "2278"}], ",", 
       RowBox[{"1845", "\[Rule]", "2278"}], ",", 
       RowBox[{"1845", "\[Rule]", "1306"}], ",", 
       RowBox[{"1845", "\[Rule]", "1306"}], ",", 
       RowBox[{"1845", "\[Rule]", "2170"}], ",", 
       RowBox[{"1845", "\[Rule]", "2170"}], ",", 
       RowBox[{"1845", "\[Rule]", "1846"}], ",", 
       RowBox[{"2181", "\[Rule]", "1858"}], ",", 
       RowBox[{"2181", "\[Rule]", "1858"}], ",", 
       RowBox[{"2181", "\[Rule]", "2722"}], ",", 
       RowBox[{"2181", "\[Rule]", "2722"}], ",", 
       RowBox[{"2181", "\[Rule]", "1750"}], ",", 
       RowBox[{"2181", "\[Rule]", "1750"}], ",", 
       RowBox[{"2181", "\[Rule]", "2614"}], ",", 
       RowBox[{"2181", "\[Rule]", "2614"}], ",", 
       RowBox[{"2181", "\[Rule]", "2182"}], ",", 
       RowBox[{"1857", "\[Rule]", "1426"}], ",", 
       RowBox[{"1857", "\[Rule]", "1426"}], ",", 
       RowBox[{"1857", "\[Rule]", "2290"}], ",", 
       RowBox[{"1857", "\[Rule]", "2290"}], ",", 
       RowBox[{"1857", "\[Rule]", "1318"}], ",", 
       RowBox[{"1857", "\[Rule]", "1318"}], ",", 
       RowBox[{"1857", "\[Rule]", "2182"}], ",", 
       RowBox[{"1857", "\[Rule]", "2182"}], ",", 
       RowBox[{"1857", "\[Rule]", "1858"}], ",", 
       RowBox[{"791", "\[Rule]", "360"}], ",", 
       RowBox[{"791", "\[Rule]", "360"}], ",", 
       RowBox[{"791", "\[Rule]", "1224"}], ",", 
       RowBox[{"791", "\[Rule]", "1224"}], ",", 
       RowBox[{"791", "\[Rule]", "792"}], ",", 
       RowBox[{"683", "\[Rule]", "360"}], ",", 
       RowBox[{"683", "\[Rule]", "360"}], ",", 
       RowBox[{"683", "\[Rule]", "1224"}], ",", 
       RowBox[{"683", "\[Rule]", "1224"}], ",", 
       RowBox[{"683", "\[Rule]", "252"}], ",", 
       RowBox[{"683", "\[Rule]", "252"}], ",", 
       RowBox[{"683", "\[Rule]", "1116"}], ",", 
       RowBox[{"683", "\[Rule]", "1116"}], ",", 
       RowBox[{"683", "\[Rule]", "684"}], ",", 
       RowBox[{"359", "\[Rule]", "792"}], ",", 
       RowBox[{"359", "\[Rule]", "792"}], ",", 
       RowBox[{"359", "\[Rule]", "684"}], ",", 
       RowBox[{"359", "\[Rule]", "684"}], ",", 
       RowBox[{"359", "\[Rule]", "360"}], ",", 
       RowBox[{"1655", "\[Rule]", "1224"}], ",", 
       RowBox[{"1655", "\[Rule]", "1224"}], ",", 
       RowBox[{"1655", "\[Rule]", "2088"}], ",", 
       RowBox[{"1655", "\[Rule]", "2088"}], ",", 
       RowBox[{"1655", "\[Rule]", "1656"}], ",", 
       RowBox[{"1547", "\[Rule]", "1224"}], ",", 
       RowBox[{"1547", "\[Rule]", "1224"}], ",", 
       RowBox[{"1547", "\[Rule]", "2088"}], ",", 
       RowBox[{"1547", "\[Rule]", "2088"}], ",", 
       RowBox[{"1547", "\[Rule]", "1116"}], ",", 
       RowBox[{"1547", "\[Rule]", "1116"}], ",", 
       RowBox[{"1547", "\[Rule]", "1980"}], ",", 
       RowBox[{"1547", "\[Rule]", "1980"}], ",", 
       RowBox[{"1547", "\[Rule]", "1548"}], ",", 
       RowBox[{"1223", "\[Rule]", "792"}], ",", 
       RowBox[{"1223", "\[Rule]", "792"}], ",", 
       RowBox[{"1223", "\[Rule]", "1656"}], ",", 
       RowBox[{"1223", "\[Rule]", "1656"}], ",", 
       RowBox[{"1223", "\[Rule]", "684"}], ",", 
       RowBox[{"1223", "\[Rule]", "684"}], ",", 
       RowBox[{"1223", "\[Rule]", "1548"}], ",", 
       RowBox[{"1223", "\[Rule]", "1548"}], ",", 
       RowBox[{"1223", "\[Rule]", "1224"}], ",", 
       RowBox[{"575", "\[Rule]", "252"}], ",", 
       RowBox[{"575", "\[Rule]", "252"}], ",", 
       RowBox[{"575", "\[Rule]", "1116"}], ",", 
       RowBox[{"575", "\[Rule]", "1116"}], ",", 
       RowBox[{"575", "\[Rule]", "144"}], ",", 
       RowBox[{"575", "\[Rule]", "1008"}], ",", 
       RowBox[{"575", "\[Rule]", "576"}], ",", 
       RowBox[{"251", "\[Rule]", "684"}], ",", 
       RowBox[{"251", "\[Rule]", "684"}], ",", 
       RowBox[{"251", "\[Rule]", "576"}], ",", 
       RowBox[{"251", "\[Rule]", "576"}], ",", 
       RowBox[{"251", "\[Rule]", "252"}], ",", 
       RowBox[{"1439", "\[Rule]", "1116"}], ",", 
       RowBox[{"1439", "\[Rule]", "1116"}], ",", 
       RowBox[{"1439", "\[Rule]", "1980"}], ",", 
       RowBox[{"1439", "\[Rule]", "1980"}], ",", 
       RowBox[{"1439", "\[Rule]", "1008"}], ",", 
       RowBox[{"1439", "\[Rule]", "1008"}], ",", 
       RowBox[{"1439", "\[Rule]", "1872"}], ",", 
       RowBox[{"1439", "\[Rule]", "1872"}], ",", 
       RowBox[{"1439", "\[Rule]", "1440"}], ",", 
       RowBox[{"1115", "\[Rule]", "684"}], ",", 
       RowBox[{"1115", "\[Rule]", "684"}], ",", 
       RowBox[{"1115", "\[Rule]", "1548"}], ",", 
       RowBox[{"1115", "\[Rule]", "1548"}], ",", 
       RowBox[{"1115", "\[Rule]", "576"}], ",", 
       RowBox[{"1115", "\[Rule]", "576"}], ",", 
       RowBox[{"1115", "\[Rule]", "1440"}], ",", 
       RowBox[{"1115", "\[Rule]", "1440"}], ",", 
       RowBox[{"1115", "\[Rule]", "1116"}], ",", 
       RowBox[{"2519", "\[Rule]", "2088"}], ",", 
       RowBox[{"2519", "\[Rule]", "2088"}], ",", 
       RowBox[{"2519", "\[Rule]", "2952"}], ",", 
       RowBox[{"2519", "\[Rule]", "2952"}], ",", 
       RowBox[{"2519", "\[Rule]", "2520"}], ",", 
       RowBox[{"2411", "\[Rule]", "2088"}], ",", 
       RowBox[{"2411", "\[Rule]", "2088"}], ",", 
       RowBox[{"2411", "\[Rule]", "2952"}], ",", 
       RowBox[{"2411", "\[Rule]", "2952"}], ",", 
       RowBox[{"2411", "\[Rule]", "1980"}], ",", 
       RowBox[{"2411", "\[Rule]", "1980"}], ",", 
       RowBox[{"2411", "\[Rule]", "2844"}], ",", 
       RowBox[{"2411", "\[Rule]", "2844"}], ",", 
       RowBox[{"2411", "\[Rule]", "2412"}], ",", 
       RowBox[{"2087", "\[Rule]", "1656"}], ",", 
       RowBox[{"2087", "\[Rule]", "1656"}], ",", 
       RowBox[{"2087", "\[Rule]", "2520"}], ",", 
       RowBox[{"2087", "\[Rule]", "2520"}], ",", 
       RowBox[{"2087", "\[Rule]", "1548"}], ",", 
       RowBox[{"2087", "\[Rule]", "1548"}], ",", 
       RowBox[{"2087", "\[Rule]", "2412"}], ",", 
       RowBox[{"2087", "\[Rule]", "2412"}], ",", 
       RowBox[{"2087", "\[Rule]", "2088"}], ",", 
       RowBox[{"2303", "\[Rule]", "1980"}], ",", 
       RowBox[{"2303", "\[Rule]", "1980"}], ",", 
       RowBox[{"2303", "\[Rule]", "2844"}], ",", 
       RowBox[{"2303", "\[Rule]", "2844"}], ",", 
       RowBox[{"2303", "\[Rule]", "1872"}], ",", 
       RowBox[{"2303", "\[Rule]", "1872"}], ",", 
       RowBox[{"2303", "\[Rule]", "2736"}], ",", 
       RowBox[{"2303", "\[Rule]", "2736"}], ",", 
       RowBox[{"2303", "\[Rule]", "2304"}], ",", 
       RowBox[{"1979", "\[Rule]", "1548"}], ",", 
       RowBox[{"1979", "\[Rule]", "1548"}], ",", 
       RowBox[{"1979", "\[Rule]", "2412"}], ",", 
       RowBox[{"1979", "\[Rule]", "2412"}], ",", 
       RowBox[{"1979", "\[Rule]", "1440"}], ",", 
       RowBox[{"1979", "\[Rule]", "1440"}], ",", 
       RowBox[{"1979", "\[Rule]", "2304"}], ",", 
       RowBox[{"1979", "\[Rule]", "2304"}], ",", 
       RowBox[{"1979", "\[Rule]", "1980"}], ",", 
       RowBox[{"467", "\[Rule]", "144"}], ",", 
       RowBox[{"467", "\[Rule]", "1008"}], ",", 
       RowBox[{"467", "\[Rule]", "36"}], ",", 
       RowBox[{"467", "\[Rule]", "36"}], ",", 
       RowBox[{"467", "\[Rule]", "900"}], ",", 
       RowBox[{"467", "\[Rule]", "900"}], ",", 
       RowBox[{"467", "\[Rule]", "468"}], ",", 
       RowBox[{"143", "\[Rule]", "576"}], ",", 
       RowBox[{"143", "\[Rule]", "468"}], ",", 
       RowBox[{"143", "\[Rule]", "144"}], ",", 
       RowBox[{"1331", "\[Rule]", "1008"}], ",", 
       RowBox[{"1331", "\[Rule]", "1008"}], ",", 
       RowBox[{"1331", "\[Rule]", "1872"}], ",", 
       RowBox[{"1331", "\[Rule]", "1872"}], ",", 
       RowBox[{"1331", "\[Rule]", "900"}], ",", 
       RowBox[{"1331", "\[Rule]", "1764"}], ",", 
       RowBox[{"1331", "\[Rule]", "1332"}], ",", 
       RowBox[{"1007", "\[Rule]", "576"}], ",", 
       RowBox[{"1007", "\[Rule]", "1440"}], ",", 
       RowBox[{"1007", "\[Rule]", "1440"}], ",", 
       RowBox[{"1007", "\[Rule]", "468"}], ",", 
       RowBox[{"1007", "\[Rule]", "1332"}], ",", 
       RowBox[{"1007", "\[Rule]", "1332"}], ",", 
       RowBox[{"1007", "\[Rule]", "1008"}], ",", 
       RowBox[{"2195", "\[Rule]", "1872"}], ",", 
       RowBox[{"2195", "\[Rule]", "1872"}], ",", 
       RowBox[{"2195", "\[Rule]", "2736"}], ",", 
       RowBox[{"2195", "\[Rule]", "2736"}], ",", 
       RowBox[{"2195", "\[Rule]", "1764"}], ",", 
       RowBox[{"2195", "\[Rule]", "1764"}], ",", 
       RowBox[{"2195", "\[Rule]", "2628"}], ",", 
       RowBox[{"2195", "\[Rule]", "2628"}], ",", 
       RowBox[{"2195", "\[Rule]", "2196"}], ",", 
       RowBox[{"1871", "\[Rule]", "1440"}], ",", 
       RowBox[{"1871", "\[Rule]", "1440"}], ",", 
       RowBox[{"1871", "\[Rule]", "2304"}], ",", 
       RowBox[{"1871", "\[Rule]", "2304"}], ",", 
       RowBox[{"1871", "\[Rule]", "1332"}], ",", 
       RowBox[{"1871", "\[Rule]", "1332"}], ",", 
       RowBox[{"1871", "\[Rule]", "2196"}], ",", 
       RowBox[{"1871", "\[Rule]", "2196"}], ",", 
       RowBox[{"1871", "\[Rule]", "1872"}], ",", 
       RowBox[{"9", "\[Rule]", "442"}], ",", 
       RowBox[{"9", "\[Rule]", "442"}], ",", 
       RowBox[{"9", "\[Rule]", "10"}], ",", 
       RowBox[{"873", "\[Rule]", "442"}], ",", 
       RowBox[{"873", "\[Rule]", "442"}], ",", 
       RowBox[{"873", "\[Rule]", "1306"}], ",", 
       RowBox[{"873", "\[Rule]", "874"}], ",", 
       RowBox[{"21", "\[Rule]", "454"}], ",", 
       RowBox[{"21", "\[Rule]", "454"}], ",", 
       RowBox[{"21", "\[Rule]", "22"}], ",", 
       RowBox[{"885", "\[Rule]", "454"}], ",", 
       RowBox[{"885", "\[Rule]", "454"}], ",", 
       RowBox[{"885", "\[Rule]", "1318"}], ",", 
       RowBox[{"885", "\[Rule]", "886"}], ",", 
       RowBox[{"1737", "\[Rule]", "1306"}], ",", 
       RowBox[{"1737", "\[Rule]", "2170"}], ",", 
       RowBox[{"1737", "\[Rule]", "2170"}], ",", 
       RowBox[{"1737", "\[Rule]", "1738"}], ",", 
       RowBox[{"1749", "\[Rule]", "1318"}], ",", 
       RowBox[{"1749", "\[Rule]", "2182"}], ",", 
       RowBox[{"1749", "\[Rule]", "2182"}], ",", 
       RowBox[{"1749", "\[Rule]", "1750"}], ",", 
       RowBox[{"35", "\[Rule]", "468"}], ",", 
       RowBox[{"35", "\[Rule]", "468"}], ",", 
       RowBox[{"35", "\[Rule]", "36"}], ",", 
       RowBox[{"899", "\[Rule]", "468"}], ",", 
       RowBox[{"899", "\[Rule]", "468"}], ",", 
       RowBox[{"899", "\[Rule]", "1332"}], ",", 
       RowBox[{"899", "\[Rule]", "900"}], ",", 
       RowBox[{"1763", "\[Rule]", "1332"}], ",", 
       RowBox[{"1763", "\[Rule]", "2196"}], ",", 
       RowBox[{"1763", "\[Rule]", "2196"}], ",", 
       RowBox[{"1763", "\[Rule]", "1764"}], ",", 
       RowBox[{"803", "\[Rule]", "372"}], ",", 
       RowBox[{"803", "\[Rule]", "372"}], ",", 
       RowBox[{"803", "\[Rule]", "1236"}], ",", 
       RowBox[{"803", "\[Rule]", "1236"}], ",", 
       RowBox[{"803", "\[Rule]", "804"}], ",", 
       RowBox[{"695", "\[Rule]", "372"}], ",", 
       RowBox[{"695", "\[Rule]", "372"}], ",", 
       RowBox[{"695", "\[Rule]", "1236"}], ",", 
       RowBox[{"695", "\[Rule]", "1236"}], ",", 
       RowBox[{"695", "\[Rule]", "264"}], ",", 
       RowBox[{"695", "\[Rule]", "264"}], ",", 
       RowBox[{"695", "\[Rule]", "1128"}], ",", 
       RowBox[{"695", "\[Rule]", "1128"}], ",", 
       RowBox[{"695", "\[Rule]", "696"}], ",", 
       RowBox[{"371", "\[Rule]", "804"}], ",", 
       RowBox[{"371", "\[Rule]", "804"}], ",", 
       RowBox[{"371", "\[Rule]", "696"}], ",", 
       RowBox[{"371", "\[Rule]", "696"}], ",", 
       RowBox[{"371", "\[Rule]", "372"}], ",", 
       RowBox[{"1667", "\[Rule]", "1236"}], ",", 
       RowBox[{"1667", "\[Rule]", "1236"}], ",", 
       RowBox[{"1667", "\[Rule]", "2100"}], ",", 
       RowBox[{"1667", "\[Rule]", "2100"}], ",", 
       RowBox[{"1667", "\[Rule]", "1668"}], ",", 
       RowBox[{"1559", "\[Rule]", "1236"}], ",", 
       RowBox[{"1559", "\[Rule]", "1236"}], ",", 
       RowBox[{"1559", "\[Rule]", "2100"}], ",", 
       RowBox[{"1559", "\[Rule]", "2100"}], ",", 
       RowBox[{"1559", "\[Rule]", "1128"}], ",", 
       RowBox[{"1559", "\[Rule]", "1128"}], ",", 
       RowBox[{"1559", "\[Rule]", "1992"}], ",", 
       RowBox[{"1559", "\[Rule]", "1992"}], ",", 
       RowBox[{"1559", "\[Rule]", "1560"}], ",", 
       RowBox[{"1235", "\[Rule]", "804"}], ",", 
       RowBox[{"1235", "\[Rule]", "804"}], ",", 
       RowBox[{"1235", "\[Rule]", "1668"}], ",", 
       RowBox[{"1235", "\[Rule]", "1668"}], ",", 
       RowBox[{"1235", "\[Rule]", "696"}], ",", 
       RowBox[{"1235", "\[Rule]", "696"}], ",", 
       RowBox[{"1235", "\[Rule]", "1560"}], ",", 
       RowBox[{"1235", "\[Rule]", "1560"}], ",", 
       RowBox[{"1235", "\[Rule]", "1236"}], ",", 
       RowBox[{"587", "\[Rule]", "264"}], ",", 
       RowBox[{"587", "\[Rule]", "264"}], ",", 
       RowBox[{"587", "\[Rule]", "1128"}], ",", 
       RowBox[{"587", "\[Rule]", "1128"}], ",", 
       RowBox[{"587", "\[Rule]", "156"}], ",", 
       RowBox[{"587", "\[Rule]", "1020"}], ",", 
       RowBox[{"587", "\[Rule]", "588"}], ",", 
       RowBox[{"263", "\[Rule]", "696"}], ",", 
       RowBox[{"263", "\[Rule]", "696"}], ",", 
       RowBox[{"263", "\[Rule]", "588"}], ",", 
       RowBox[{"263", "\[Rule]", "588"}], ",", 
       RowBox[{"263", "\[Rule]", "264"}], ",", 
       RowBox[{"1451", "\[Rule]", "1128"}], ",", 
       RowBox[{"1451", "\[Rule]", "1128"}], ",", 
       RowBox[{"1451", "\[Rule]", "1992"}], ",", 
       RowBox[{"1451", "\[Rule]", "1992"}], ",", 
       RowBox[{"1451", "\[Rule]", "1020"}], ",", 
       RowBox[{"1451", "\[Rule]", "1020"}], ",", 
       RowBox[{"1451", "\[Rule]", "1884"}], ",", 
       RowBox[{"1451", "\[Rule]", "1884"}], ",", 
       RowBox[{"1451", "\[Rule]", "1452"}], ",", 
       RowBox[{"1127", "\[Rule]", "696"}], ",", 
       RowBox[{"1127", "\[Rule]", "696"}], ",", 
       RowBox[{"1127", "\[Rule]", "1560"}], ",", 
       RowBox[{"1127", "\[Rule]", "1560"}], ",", 
       RowBox[{"1127", "\[Rule]", "588"}], ",", 
       RowBox[{"1127", "\[Rule]", "588"}], ",", 
       RowBox[{"1127", "\[Rule]", "1452"}], ",", 
       RowBox[{"1127", "\[Rule]", "1452"}], ",", 
       RowBox[{"1127", "\[Rule]", "1128"}], ",", 
       RowBox[{"2531", "\[Rule]", "2100"}], ",", 
       RowBox[{"2531", "\[Rule]", "2100"}], ",", 
       RowBox[{"2531", "\[Rule]", "2964"}], ",", 
       RowBox[{"2531", "\[Rule]", "2964"}], ",", 
       RowBox[{"2531", "\[Rule]", "2532"}], ",", 
       RowBox[{"2423", "\[Rule]", "2100"}], ",", 
       RowBox[{"2423", "\[Rule]", "2100"}], ",", 
       RowBox[{"2423", "\[Rule]", "2964"}], ",", 
       RowBox[{"2423", "\[Rule]", "2964"}], ",", 
       RowBox[{"2423", "\[Rule]", "1992"}], ",", 
       RowBox[{"2423", "\[Rule]", "1992"}], ",", 
       RowBox[{"2423", "\[Rule]", "2856"}], ",", 
       RowBox[{"2423", "\[Rule]", "2856"}], ",", 
       RowBox[{"2423", "\[Rule]", "2424"}], ",", 
       RowBox[{"2099", "\[Rule]", "1668"}], ",", 
       RowBox[{"2099", "\[Rule]", "1668"}], ",", 
       RowBox[{"2099", "\[Rule]", "2532"}], ",", 
       RowBox[{"2099", "\[Rule]", "2532"}], ",", 
       RowBox[{"2099", "\[Rule]", "1560"}], ",", 
       RowBox[{"2099", "\[Rule]", "1560"}], ",", 
       RowBox[{"2099", "\[Rule]", "2424"}], ",", 
       RowBox[{"2099", "\[Rule]", "2424"}], ",", 
       RowBox[{"2099", "\[Rule]", "2100"}], ",", 
       RowBox[{"2315", "\[Rule]", "1992"}], ",", 
       RowBox[{"2315", "\[Rule]", "1992"}], ",", 
       RowBox[{"2315", "\[Rule]", "2856"}], ",", 
       RowBox[{"2315", "\[Rule]", "2856"}], ",", 
       RowBox[{"2315", "\[Rule]", "1884"}], ",", 
       RowBox[{"2315", "\[Rule]", "1884"}], ",", 
       RowBox[{"2315", "\[Rule]", "2748"}], ",", 
       RowBox[{"2315", "\[Rule]", "2748"}], ",", 
       RowBox[{"2315", "\[Rule]", "2316"}], ",", 
       RowBox[{"1991", "\[Rule]", "1560"}], ",", 
       RowBox[{"1991", "\[Rule]", "1560"}], ",", 
       RowBox[{"1991", "\[Rule]", "2424"}], ",", 
       RowBox[{"1991", "\[Rule]", "2424"}], ",", 
       RowBox[{"1991", "\[Rule]", "1452"}], ",", 
       RowBox[{"1991", "\[Rule]", "1452"}], ",", 
       RowBox[{"1991", "\[Rule]", "2316"}], ",", 
       RowBox[{"1991", "\[Rule]", "2316"}], ",", 
       RowBox[{"1991", "\[Rule]", "1992"}], ",", 
       RowBox[{"479", "\[Rule]", "156"}], ",", 
       RowBox[{"479", "\[Rule]", "1020"}], ",", 
       RowBox[{"479", "\[Rule]", "48"}], ",", 
       RowBox[{"479", "\[Rule]", "48"}], ",", 
       RowBox[{"479", "\[Rule]", "912"}], ",", 
       RowBox[{"479", "\[Rule]", "912"}], ",", 
       RowBox[{"479", "\[Rule]", "480"}], ",", 
       RowBox[{"155", "\[Rule]", "588"}], ",", 
       RowBox[{"155", "\[Rule]", "480"}], ",", 
       RowBox[{"155", "\[Rule]", "156"}], ",", 
       RowBox[{"1343", "\[Rule]", "1020"}], ",", 
       RowBox[{"1343", "\[Rule]", "1020"}], ",", 
       RowBox[{"1343", "\[Rule]", "1884"}], ",", 
       RowBox[{"1343", "\[Rule]", "1884"}], ",", 
       RowBox[{"1343", "\[Rule]", "912"}], ",", 
       RowBox[{"1343", "\[Rule]", "1776"}], ",", 
       RowBox[{"1343", "\[Rule]", "1344"}], ",", 
       RowBox[{"1019", "\[Rule]", "588"}], ",", 
       RowBox[{"1019", "\[Rule]", "1452"}], ",", 
       RowBox[{"1019", "\[Rule]", "1452"}], ",", 
       RowBox[{"1019", "\[Rule]", "480"}], ",", 
       RowBox[{"1019", "\[Rule]", "1344"}], ",", 
       RowBox[{"1019", "\[Rule]", "1344"}], ",", 
       RowBox[{"1019", "\[Rule]", "1020"}], ",", 
       RowBox[{"2207", "\[Rule]", "1884"}], ",", 
       RowBox[{"2207", "\[Rule]", "1884"}], ",", 
       RowBox[{"2207", "\[Rule]", "2748"}], ",", 
       RowBox[{"2207", "\[Rule]", "2748"}], ",", 
       RowBox[{"2207", "\[Rule]", "1776"}], ",", 
       RowBox[{"2207", "\[Rule]", "1776"}], ",", 
       RowBox[{"2207", "\[Rule]", "2640"}], ",", 
       RowBox[{"2207", "\[Rule]", "2640"}], ",", 
       RowBox[{"2207", "\[Rule]", "2208"}], ",", 
       RowBox[{"1883", "\[Rule]", "1452"}], ",", 
       RowBox[{"1883", "\[Rule]", "1452"}], ",", 
       RowBox[{"1883", "\[Rule]", "2316"}], ",", 
       RowBox[{"1883", "\[Rule]", "2316"}], ",", 
       RowBox[{"1883", "\[Rule]", "1344"}], ",", 
       RowBox[{"1883", "\[Rule]", "1344"}], ",", 
       RowBox[{"1883", "\[Rule]", "2208"}], ",", 
       RowBox[{"1883", "\[Rule]", "2208"}], ",", 
       RowBox[{"1883", "\[Rule]", "1884"}], ",", 
       RowBox[{"47", "\[Rule]", "480"}], ",", 
       RowBox[{"47", "\[Rule]", "480"}], ",", 
       RowBox[{"47", "\[Rule]", "48"}], ",", 
       RowBox[{"911", "\[Rule]", "480"}], ",", 
       RowBox[{"911", "\[Rule]", "480"}], ",", 
       RowBox[{"911", "\[Rule]", "1344"}], ",", 
       RowBox[{"911", "\[Rule]", "912"}], ",", 
       RowBox[{"1775", "\[Rule]", "1344"}], ",", 
       RowBox[{"1775", "\[Rule]", "2208"}], ",", 
       RowBox[{"1775", "\[Rule]", "2208"}], ",", 
       RowBox[{"1775", "\[Rule]", "1776"}], ",", 
       RowBox[{"2925", "\[Rule]", "2494"}], ",", 
       RowBox[{"2925", "\[Rule]", "2494"}], ",", 
       RowBox[{"2925", "\[Rule]", "2386"}], ",", 
       RowBox[{"2925", "\[Rule]", "2386"}], ",", 
       RowBox[{"2925", "\[Rule]", "2926"}], ",", 
       RowBox[{"2817", "\[Rule]", "2386"}], ",", 
       RowBox[{"2817", "\[Rule]", "2386"}], ",", 
       RowBox[{"2817", "\[Rule]", "2278"}], ",", 
       RowBox[{"2817", "\[Rule]", "2278"}], ",", 
       RowBox[{"2817", "\[Rule]", "2818"}], ",", 
       RowBox[{"2937", "\[Rule]", "2506"}], ",", 
       RowBox[{"2937", "\[Rule]", "2506"}], ",", 
       RowBox[{"2937", "\[Rule]", "2398"}], ",", 
       RowBox[{"2937", "\[Rule]", "2398"}], ",", 
       RowBox[{"2937", "\[Rule]", "2938"}], ",", 
       RowBox[{"2829", "\[Rule]", "2398"}], ",", 
       RowBox[{"2829", "\[Rule]", "2398"}], ",", 
       RowBox[{"2829", "\[Rule]", "2290"}], ",", 
       RowBox[{"2829", "\[Rule]", "2290"}], ",", 
       RowBox[{"2829", "\[Rule]", "2830"}], ",", 
       RowBox[{"2709", "\[Rule]", "2278"}], ",", 
       RowBox[{"2709", "\[Rule]", "2278"}], ",", 
       RowBox[{"2709", "\[Rule]", "2170"}], ",", 
       RowBox[{"2709", "\[Rule]", "2170"}], ",", 
       RowBox[{"2709", "\[Rule]", "2710"}], ",", 
       RowBox[{"2721", "\[Rule]", "2290"}], ",", 
       RowBox[{"2721", "\[Rule]", "2290"}], ",", 
       RowBox[{"2721", "\[Rule]", "2182"}], ",", 
       RowBox[{"2721", "\[Rule]", "2182"}], ",", 
       RowBox[{"2721", "\[Rule]", "2722"}], ",", 
       RowBox[{"2951", "\[Rule]", "2520"}], ",", 
       RowBox[{"2951", "\[Rule]", "2520"}], ",", 
       RowBox[{"2951", "\[Rule]", "2412"}], ",", 
       RowBox[{"2951", "\[Rule]", "2412"}], ",", 
       RowBox[{"2951", "\[Rule]", "2952"}], ",", 
       RowBox[{"2843", "\[Rule]", "2412"}], ",", 
       RowBox[{"2843", "\[Rule]", "2412"}], ",", 
       RowBox[{"2843", "\[Rule]", "2304"}], ",", 
       RowBox[{"2843", "\[Rule]", "2304"}], ",", 
       RowBox[{"2843", "\[Rule]", "2844"}], ",", 
       RowBox[{"2735", "\[Rule]", "2304"}], ",", 
       RowBox[{"2735", "\[Rule]", "2304"}], ",", 
       RowBox[{"2735", "\[Rule]", "2196"}], ",", 
       RowBox[{"2735", "\[Rule]", "2196"}], ",", 
       RowBox[{"2735", "\[Rule]", "2736"}], ",", 
       RowBox[{"2601", "\[Rule]", "2170"}], ",", 
       RowBox[{"2601", "\[Rule]", "2170"}], ",", 
       RowBox[{"2601", "\[Rule]", "2602"}], ",", 
       RowBox[{"2613", "\[Rule]", "2182"}], ",", 
       RowBox[{"2613", "\[Rule]", "2182"}], ",", 
       RowBox[{"2613", "\[Rule]", "2614"}], ",", 
       RowBox[{"2627", "\[Rule]", "2196"}], ",", 
       RowBox[{"2627", "\[Rule]", "2196"}], ",", 
       RowBox[{"2627", "\[Rule]", "2628"}], ",", 
       RowBox[{"2963", "\[Rule]", "2532"}], ",", 
       RowBox[{"2963", "\[Rule]", "2532"}], ",", 
       RowBox[{"2963", "\[Rule]", "2424"}], ",", 
       RowBox[{"2963", "\[Rule]", "2424"}], ",", 
       RowBox[{"2963", "\[Rule]", "2964"}], ",", 
       RowBox[{"2855", "\[Rule]", "2424"}], ",", 
       RowBox[{"2855", "\[Rule]", "2424"}], ",", 
       RowBox[{"2855", "\[Rule]", "2316"}], ",", 
       RowBox[{"2855", "\[Rule]", "2316"}], ",", 
       RowBox[{"2855", "\[Rule]", "2856"}], ",", 
       RowBox[{"2747", "\[Rule]", "2316"}], ",", 
       RowBox[{"2747", "\[Rule]", "2316"}], ",", 
       RowBox[{"2747", "\[Rule]", "2208"}], ",", 
       RowBox[{"2747", "\[Rule]", "2208"}], ",", 
       RowBox[{"2747", "\[Rule]", "2748"}], ",", 
       RowBox[{"2639", "\[Rule]", "2208"}], ",", 
       RowBox[{"2639", "\[Rule]", "2208"}], ",", 
       RowBox[{"2639", "\[Rule]", "2640"}], ",", 
       RowBox[{"817", "\[Rule]", "386"}], ",", 
       RowBox[{"817", "\[Rule]", "386"}], ",", 
       RowBox[{"817", "\[Rule]", "1250"}], ",", 
       RowBox[{"817", "\[Rule]", "1250"}], ",", 
       RowBox[{"817", "\[Rule]", "818"}], ",", 
       RowBox[{"709", "\[Rule]", "386"}], ",", 
       RowBox[{"709", "\[Rule]", "386"}], ",", 
       RowBox[{"709", "\[Rule]", "1250"}], ",", 
       RowBox[{"709", "\[Rule]", "1250"}], ",", 
       RowBox[{"709", "\[Rule]", "278"}], ",", 
       RowBox[{"709", "\[Rule]", "278"}], ",", 
       RowBox[{"709", "\[Rule]", "1142"}], ",", 
       RowBox[{"709", "\[Rule]", "1142"}], ",", 
       RowBox[{"709", "\[Rule]", "710"}], ",", 
       RowBox[{"385", "\[Rule]", "818"}], ",", 
       RowBox[{"385", "\[Rule]", "818"}], ",", 
       RowBox[{"385", "\[Rule]", "710"}], ",", 
       RowBox[{"385", "\[Rule]", "710"}], ",", 
       RowBox[{"385", "\[Rule]", "386"}], ",", 
       RowBox[{"1681", "\[Rule]", "1250"}], ",", 
       RowBox[{"1681", "\[Rule]", "1250"}], ",", 
       RowBox[{"1681", "\[Rule]", "2114"}], ",", 
       RowBox[{"1681", "\[Rule]", "2114"}], ",", 
       RowBox[{"1681", "\[Rule]", "1682"}], ",", 
       RowBox[{"1573", "\[Rule]", "1250"}], ",", 
       RowBox[{"1573", "\[Rule]", "1250"}], ",", 
       RowBox[{"1573", "\[Rule]", "2114"}], ",", 
       RowBox[{"1573", "\[Rule]", "2114"}], ",", 
       RowBox[{"1573", "\[Rule]", "1142"}], ",", 
       RowBox[{"1573", "\[Rule]", "1142"}], ",", 
       RowBox[{"1573", "\[Rule]", "2006"}], ",", 
       RowBox[{"1573", "\[Rule]", "2006"}], ",", 
       RowBox[{"1573", "\[Rule]", "1574"}], ",", 
       RowBox[{"1249", "\[Rule]", "818"}], ",", 
       RowBox[{"1249", "\[Rule]", "818"}], ",", 
       RowBox[{"1249", "\[Rule]", "1682"}], ",", 
       RowBox[{"1249", "\[Rule]", "1682"}], ",", 
       RowBox[{"1249", "\[Rule]", "710"}], ",", 
       RowBox[{"1249", "\[Rule]", "710"}], ",", 
       RowBox[{"1249", "\[Rule]", "1574"}], ",", 
       RowBox[{"1249", "\[Rule]", "1574"}], ",", 
       RowBox[{"1249", "\[Rule]", "1250"}], ",", 
       RowBox[{"601", "\[Rule]", "278"}], ",", 
       RowBox[{"601", "\[Rule]", "278"}], ",", 
       RowBox[{"601", "\[Rule]", "1142"}], ",", 
       RowBox[{"601", "\[Rule]", "1142"}], ",", 
       RowBox[{"601", "\[Rule]", "170"}], ",", 
       RowBox[{"601", "\[Rule]", "1034"}], ",", 
       RowBox[{"601", "\[Rule]", "602"}], ",", 
       RowBox[{"277", "\[Rule]", "710"}], ",", 
       RowBox[{"277", "\[Rule]", "710"}], ",", 
       RowBox[{"277", "\[Rule]", "602"}], ",", 
       RowBox[{"277", "\[Rule]", "602"}], ",", 
       RowBox[{"277", "\[Rule]", "278"}], ",", 
       RowBox[{"1465", "\[Rule]", "1142"}], ",", 
       RowBox[{"1465", "\[Rule]", "1142"}], ",", 
       RowBox[{"1465", "\[Rule]", "2006"}], ",", 
       RowBox[{"1465", "\[Rule]", "2006"}], ",", 
       RowBox[{"1465", "\[Rule]", "1034"}], ",", 
       RowBox[{"1465", "\[Rule]", "1034"}], ",", 
       RowBox[{"1465", "\[Rule]", "1898"}], ",", 
       RowBox[{"1465", "\[Rule]", "1898"}], ",", 
       RowBox[{"1465", "\[Rule]", "1466"}], ",", 
       RowBox[{"1141", "\[Rule]", "710"}], ",", 
       RowBox[{"1141", "\[Rule]", "710"}], ",", 
       RowBox[{"1141", "\[Rule]", "1574"}], ",", 
       RowBox[{"1141", "\[Rule]", "1574"}], ",", 
       RowBox[{"1141", "\[Rule]", "602"}], ",", 
       RowBox[{"1141", "\[Rule]", "602"}], ",", 
       RowBox[{"1141", "\[Rule]", "1466"}], ",", 
       RowBox[{"1141", "\[Rule]", "1466"}], ",", 
       RowBox[{"1141", "\[Rule]", "1142"}], ",", 
       RowBox[{"2545", "\[Rule]", "2114"}], ",", 
       RowBox[{"2545", "\[Rule]", "2114"}], ",", 
       RowBox[{"2545", "\[Rule]", "2978"}], ",", 
       RowBox[{"2545", "\[Rule]", "2978"}], ",", 
       RowBox[{"2545", "\[Rule]", "2546"}], ",", 
       RowBox[{"2437", "\[Rule]", "2114"}], ",", 
       RowBox[{"2437", "\[Rule]", "2114"}], ",", 
       RowBox[{"2437", "\[Rule]", "2978"}], ",", 
       RowBox[{"2437", "\[Rule]", "2978"}], ",", 
       RowBox[{"2437", "\[Rule]", "2006"}], ",", 
       RowBox[{"2437", "\[Rule]", "2006"}], ",", 
       RowBox[{"2437", "\[Rule]", "2870"}], ",", 
       RowBox[{"2437", "\[Rule]", "2870"}], ",", 
       RowBox[{"2437", "\[Rule]", "2438"}], ",", 
       RowBox[{"2113", "\[Rule]", "1682"}], ",", 
       RowBox[{"2113", "\[Rule]", "1682"}], ",", 
       RowBox[{"2113", "\[Rule]", "2546"}], ",", 
       RowBox[{"2113", "\[Rule]", "2546"}], ",", 
       RowBox[{"2113", "\[Rule]", "1574"}], ",", 
       RowBox[{"2113", "\[Rule]", "1574"}], ",", 
       RowBox[{"2113", "\[Rule]", "2438"}], ",", 
       RowBox[{"2113", "\[Rule]", "2438"}], ",", 
       RowBox[{"2113", "\[Rule]", "2114"}], ",", 
       RowBox[{"2329", "\[Rule]", "2006"}], ",", 
       RowBox[{"2329", "\[Rule]", "2006"}], ",", 
       RowBox[{"2329", "\[Rule]", "2870"}], ",", 
       RowBox[{"2329", "\[Rule]", "2870"}], ",", 
       RowBox[{"2329", "\[Rule]", "1898"}], ",", 
       RowBox[{"2329", "\[Rule]", "1898"}], ",", 
       RowBox[{"2329", "\[Rule]", "2762"}], ",", 
       RowBox[{"2329", "\[Rule]", "2762"}], ",", 
       RowBox[{"2329", "\[Rule]", "2330"}], ",", 
       RowBox[{"2005", "\[Rule]", "1574"}], ",", 
       RowBox[{"2005", "\[Rule]", "1574"}], ",", 
       RowBox[{"2005", "\[Rule]", "2438"}], ",", 
       RowBox[{"2005", "\[Rule]", "2438"}], ",", 
       RowBox[{"2005", "\[Rule]", "1466"}], ",", 
       RowBox[{"2005", "\[Rule]", "1466"}], ",", 
       RowBox[{"2005", "\[Rule]", "2330"}], ",", 
       RowBox[{"2005", "\[Rule]", "2330"}], ",", 
       RowBox[{"2005", "\[Rule]", "2006"}], ",", 
       RowBox[{"493", "\[Rule]", "170"}], ",", 
       RowBox[{"493", "\[Rule]", "1034"}], ",", 
       RowBox[{"493", "\[Rule]", "62"}], ",", 
       RowBox[{"493", "\[Rule]", "62"}], ",", 
       RowBox[{"493", "\[Rule]", "926"}], ",", 
       RowBox[{"493", "\[Rule]", "926"}], ",", 
       RowBox[{"493", "\[Rule]", "494"}], ",", 
       RowBox[{"169", "\[Rule]", "602"}], ",", 
       RowBox[{"169", "\[Rule]", "494"}], ",", 
       RowBox[{"169", "\[Rule]", "170"}], ",", 
       RowBox[{"1357", "\[Rule]", "1034"}], ",", 
       RowBox[{"1357", "\[Rule]", "1034"}], ",", 
       RowBox[{"1357", "\[Rule]", "1898"}], ",", 
       RowBox[{"1357", "\[Rule]", "1898"}], ",", 
       RowBox[{"1357", "\[Rule]", "926"}], ",", 
       RowBox[{"1357", "\[Rule]", "1790"}], ",", 
       RowBox[{"1357", "\[Rule]", "1358"}], ",", 
       RowBox[{"1033", "\[Rule]", "602"}], ",", 
       RowBox[{"1033", "\[Rule]", "1466"}], ",", 
       RowBox[{"1033", "\[Rule]", "1466"}], ",", 
       RowBox[{"1033", "\[Rule]", "494"}], ",", 
       RowBox[{"1033", "\[Rule]", "1358"}], ",", 
       RowBox[{"1033", "\[Rule]", "1358"}], ",", 
       RowBox[{"1033", "\[Rule]", "1034"}], ",", 
       RowBox[{"2221", "\[Rule]", "1898"}], ",", 
       RowBox[{"2221", "\[Rule]", "1898"}], ",", 
       RowBox[{"2221", "\[Rule]", "2762"}], ",", 
       RowBox[{"2221", "\[Rule]", "2762"}], ",", 
       RowBox[{"2221", "\[Rule]", "1790"}], ",", 
       RowBox[{"2221", "\[Rule]", "1790"}], ",", 
       RowBox[{"2221", "\[Rule]", "2654"}], ",", 
       RowBox[{"2221", "\[Rule]", "2654"}], ",", 
       RowBox[{"2221", "\[Rule]", "2222"}], ",", 
       RowBox[{"1897", "\[Rule]", "1466"}], ",", 
       RowBox[{"1897", "\[Rule]", "1466"}], ",", 
       RowBox[{"1897", "\[Rule]", "2330"}], ",", 
       RowBox[{"1897", "\[Rule]", "2330"}], ",", 
       RowBox[{"1897", "\[Rule]", "1358"}], ",", 
       RowBox[{"1897", "\[Rule]", "1358"}], ",", 
       RowBox[{"1897", "\[Rule]", "2222"}], ",", 
       RowBox[{"1897", "\[Rule]", "2222"}], ",", 
       RowBox[{"1897", "\[Rule]", "1898"}], ",", 
       RowBox[{"61", "\[Rule]", "494"}], ",", 
       RowBox[{"61", "\[Rule]", "494"}], ",", 
       RowBox[{"61", "\[Rule]", "62"}], ",", 
       RowBox[{"925", "\[Rule]", "494"}], ",", 
       RowBox[{"925", "\[Rule]", "494"}], ",", 
       RowBox[{"925", "\[Rule]", "1358"}], ",", 
       RowBox[{"925", "\[Rule]", "926"}], ",", 
       RowBox[{"1789", "\[Rule]", "1358"}], ",", 
       RowBox[{"1789", "\[Rule]", "2222"}], ",", 
       RowBox[{"1789", "\[Rule]", "2222"}], ",", 
       RowBox[{"1789", "\[Rule]", "1790"}], ",", 
       RowBox[{"2977", "\[Rule]", "2546"}], ",", 
       RowBox[{"2977", "\[Rule]", "2546"}], ",", 
       RowBox[{"2977", "\[Rule]", "2438"}], ",", 
       RowBox[{"2977", "\[Rule]", "2438"}], ",", 
       RowBox[{"2977", "\[Rule]", "2978"}], ",", 
       RowBox[{"2869", "\[Rule]", "2438"}], ",", 
       RowBox[{"2869", "\[Rule]", "2438"}], ",", 
       RowBox[{"2869", "\[Rule]", "2330"}], ",", 
       RowBox[{"2869", "\[Rule]", "2330"}], ",", 
       RowBox[{"2869", "\[Rule]", "2870"}], ",", 
       RowBox[{"2761", "\[Rule]", "2330"}], ",", 
       RowBox[{"2761", "\[Rule]", "2330"}], ",", 
       RowBox[{"2761", "\[Rule]", "2222"}], ",", 
       RowBox[{"2761", "\[Rule]", "2222"}], ",", 
       RowBox[{"2761", "\[Rule]", "2762"}], ",", 
       RowBox[{"2653", "\[Rule]", "2222"}], ",", 
       RowBox[{"2653", "\[Rule]", "2222"}], ",", 
       RowBox[{"2653", "\[Rule]", "2654"}], ",", 
       RowBox[{"334", "\[Rule]", "347"}], ",", 
       RowBox[{"334", "\[Rule]", "335"}], ",", 
       RowBox[{"334", "\[Rule]", "331"}], ",", 
       RowBox[{"1198", "\[Rule]", "1211"}], ",", 
       RowBox[{"1198", "\[Rule]", "1199"}], ",", 
       RowBox[{"1198", "\[Rule]", "1195"}], ",", 
       RowBox[{"766", "\[Rule]", "779"}], ",", 
       RowBox[{"766", "\[Rule]", "767"}], ",", 
       RowBox[{"766", "\[Rule]", "763"}], ",", 
       RowBox[{"226", "\[Rule]", "239"}], ",", 
       RowBox[{"226", "\[Rule]", "227"}], ",", 
       RowBox[{"226", "\[Rule]", "223"}], ",", 
       RowBox[{"1090", "\[Rule]", "1103"}], ",", 
       RowBox[{"1090", "\[Rule]", "1091"}], ",", 
       RowBox[{"1090", "\[Rule]", "1087"}], ",", 
       RowBox[{"658", "\[Rule]", "671"}], ",", 
       RowBox[{"658", "\[Rule]", "659"}], ",", 
       RowBox[{"658", "\[Rule]", "655"}], ",", 
       RowBox[{"2062", "\[Rule]", "2075"}], ",", 
       RowBox[{"2062", "\[Rule]", "2063"}], ",", 
       RowBox[{"2062", "\[Rule]", "2059"}], ",", 
       RowBox[{"1630", "\[Rule]", "1643"}], ",", 
       RowBox[{"1630", "\[Rule]", "1631"}], ",", 
       RowBox[{"1630", "\[Rule]", "1627"}], ",", 
       RowBox[{"1954", "\[Rule]", "1967"}], ",", 
       RowBox[{"1954", "\[Rule]", "1955"}], ",", 
       RowBox[{"1954", "\[Rule]", "1951"}], ",", 
       RowBox[{"1522", "\[Rule]", "1535"}], ",", 
       RowBox[{"1522", "\[Rule]", "1523"}], ",", 
       RowBox[{"1522", "\[Rule]", "1519"}], ",", 
       RowBox[{"118", "\[Rule]", "131"}], ",", 
       RowBox[{"118", "\[Rule]", "119"}], ",", 
       RowBox[{"118", "\[Rule]", "115"}], ",", 
       RowBox[{"982", "\[Rule]", "995"}], ",", 
       RowBox[{"982", "\[Rule]", "983"}], ",", 
       RowBox[{"982", "\[Rule]", "979"}], ",", 
       RowBox[{"550", "\[Rule]", "563"}], ",", 
       RowBox[{"550", "\[Rule]", "551"}], ",", 
       RowBox[{"550", "\[Rule]", "547"}], ",", 
       RowBox[{"1846", "\[Rule]", "1859"}], ",", 
       RowBox[{"1846", "\[Rule]", "1847"}], ",", 
       RowBox[{"1846", "\[Rule]", "1843"}], ",", 
       RowBox[{"1414", "\[Rule]", "1427"}], ",", 
       RowBox[{"1414", "\[Rule]", "1415"}], ",", 
       RowBox[{"1414", "\[Rule]", "1411"}], ",", 
       RowBox[{"346", "\[Rule]", "331"}], ",", 
       RowBox[{"346", "\[Rule]", "361"}], ",", 
       RowBox[{"346", "\[Rule]", "347"}], ",", 
       RowBox[{"1210", "\[Rule]", "1195"}], ",", 
       RowBox[{"1210", "\[Rule]", "1225"}], ",", 
       RowBox[{"1210", "\[Rule]", "1211"}], ",", 
       RowBox[{"778", "\[Rule]", "763"}], ",", 
       RowBox[{"778", "\[Rule]", "793"}], ",", 
       RowBox[{"778", "\[Rule]", "779"}], ",", 
       RowBox[{"238", "\[Rule]", "223"}], ",", 
       RowBox[{"238", "\[Rule]", "253"}], ",", 
       RowBox[{"238", "\[Rule]", "239"}], ",", 
       RowBox[{"1102", "\[Rule]", "1087"}], ",", 
       RowBox[{"1102", "\[Rule]", "1117"}], ",", 
       RowBox[{"1102", "\[Rule]", "1103"}], ",", 
       RowBox[{"670", "\[Rule]", "655"}], ",", 
       RowBox[{"670", "\[Rule]", "685"}], ",", 
       RowBox[{"670", "\[Rule]", "671"}], ",", 
       RowBox[{"2074", "\[Rule]", "2059"}], ",", 
       RowBox[{"2074", "\[Rule]", "2089"}], ",", 
       RowBox[{"2074", "\[Rule]", "2075"}], ",", 
       RowBox[{"1642", "\[Rule]", "1627"}], ",", 
       RowBox[{"1642", "\[Rule]", "1657"}], ",", 
       RowBox[{"1642", "\[Rule]", "1643"}], ",", 
       RowBox[{"1966", "\[Rule]", "1951"}], ",", 
       RowBox[{"1966", "\[Rule]", "1981"}], ",", 
       RowBox[{"1966", "\[Rule]", "1967"}], ",", 
       RowBox[{"1534", "\[Rule]", "1519"}], ",", 
       RowBox[{"1534", "\[Rule]", "1549"}], ",", 
       RowBox[{"1534", "\[Rule]", "1535"}], ",", 
       RowBox[{"130", "\[Rule]", "115"}], ",", 
       RowBox[{"130", "\[Rule]", "145"}], ",", 
       RowBox[{"130", "\[Rule]", "131"}], ",", 
       RowBox[{"994", "\[Rule]", "979"}], ",", 
       RowBox[{"994", "\[Rule]", "1009"}], ",", 
       RowBox[{"994", "\[Rule]", "995"}], ",", 
       RowBox[{"562", "\[Rule]", "547"}], ",", 
       RowBox[{"562", "\[Rule]", "577"}], ",", 
       RowBox[{"562", "\[Rule]", "563"}], ",", 
       RowBox[{"1858", "\[Rule]", "1843"}], ",", 
       RowBox[{"1858", "\[Rule]", "1873"}], ",", 
       RowBox[{"1858", "\[Rule]", "1859"}], ",", 
       RowBox[{"1426", "\[Rule]", "1411"}], ",", 
       RowBox[{"1426", "\[Rule]", "1441"}], ",", 
       RowBox[{"1426", "\[Rule]", "1427"}], ",", 
       RowBox[{"2926", "\[Rule]", "2939"}], ",", 
       RowBox[{"2926", "\[Rule]", "2927"}], ",", 
       RowBox[{"2926", "\[Rule]", "2923"}], ",", 
       RowBox[{"2494", "\[Rule]", "2507"}], ",", 
       RowBox[{"2494", "\[Rule]", "2495"}], ",", 
       RowBox[{"2494", "\[Rule]", "2491"}], ",", 
       RowBox[{"2818", "\[Rule]", "2831"}], ",", 
       RowBox[{"2818", "\[Rule]", "2819"}], ",", 
       RowBox[{"2818", "\[Rule]", "2815"}], ",", 
       RowBox[{"2386", "\[Rule]", "2399"}], ",", 
       RowBox[{"2386", "\[Rule]", "2387"}], ",", 
       RowBox[{"2386", "\[Rule]", "2383"}], ",", 
       RowBox[{"2710", "\[Rule]", "2723"}], ",", 
       RowBox[{"2710", "\[Rule]", "2711"}], ",", 
       RowBox[{"2710", "\[Rule]", "2707"}], ",", 
       RowBox[{"2278", "\[Rule]", "2291"}], ",", 
       RowBox[{"2278", "\[Rule]", "2279"}], ",", 
       RowBox[{"2278", "\[Rule]", "2275"}], ",", 
       RowBox[{"2938", "\[Rule]", "2923"}], ",", 
       RowBox[{"2938", "\[Rule]", "2953"}], ",", 
       RowBox[{"2938", "\[Rule]", "2939"}], ",", 
       RowBox[{"2506", "\[Rule]", "2491"}], ",", 
       RowBox[{"2506", "\[Rule]", "2521"}], ",", 
       RowBox[{"2506", "\[Rule]", "2507"}], ",", 
       RowBox[{"2830", "\[Rule]", "2815"}], ",", 
       RowBox[{"2830", "\[Rule]", "2845"}], ",", 
       RowBox[{"2830", "\[Rule]", "2831"}], ",", 
       RowBox[{"2398", "\[Rule]", "2383"}], ",", 
       RowBox[{"2398", "\[Rule]", "2413"}], ",", 
       RowBox[{"2398", "\[Rule]", "2399"}], ",", 
       RowBox[{"2722", "\[Rule]", "2707"}], ",", 
       RowBox[{"2722", "\[Rule]", "2737"}], ",", 
       RowBox[{"2722", "\[Rule]", "2723"}], ",", 
       RowBox[{"2290", "\[Rule]", "2275"}], ",", 
       RowBox[{"2290", "\[Rule]", "2305"}], ",", 
       RowBox[{"2290", "\[Rule]", "2291"}], ",", 
       RowBox[{"10", "\[Rule]", "23"}], ",", 
       RowBox[{"10", "\[Rule]", "11"}], ",", 
       RowBox[{"10", "\[Rule]", "7"}], ",", 
       RowBox[{"874", "\[Rule]", "887"}], ",", 
       RowBox[{"874", "\[Rule]", "875"}], ",", 
       RowBox[{"874", "\[Rule]", "871"}], ",", 
       RowBox[{"442", "\[Rule]", "455"}], ",", 
       RowBox[{"442", "\[Rule]", "443"}], ",", 
       RowBox[{"442", "\[Rule]", "439"}], ",", 
       RowBox[{"1738", "\[Rule]", "1751"}], ",", 
       RowBox[{"1738", "\[Rule]", "1739"}], ",", 
       RowBox[{"1738", "\[Rule]", "1735"}], ",", 
       RowBox[{"1306", "\[Rule]", "1319"}], ",", 
       RowBox[{"1306", "\[Rule]", "1307"}], ",", 
       RowBox[{"1306", "\[Rule]", "1303"}], ",", 
       RowBox[{"22", "\[Rule]", "7"}], ",", 
       RowBox[{"22", "\[Rule]", "37"}], ",", 
       RowBox[{"22", "\[Rule]", "23"}], ",", 
       RowBox[{"886", "\[Rule]", "871"}], ",", 
       RowBox[{"886", "\[Rule]", "901"}], ",", 
       RowBox[{"886", "\[Rule]", "887"}], ",", 
       RowBox[{"454", "\[Rule]", "439"}], ",", 
       RowBox[{"454", "\[Rule]", "469"}], ",", 
       RowBox[{"454", "\[Rule]", "455"}], ",", 
       RowBox[{"1750", "\[Rule]", "1735"}], ",", 
       RowBox[{"1750", "\[Rule]", "1765"}], ",", 
       RowBox[{"1750", "\[Rule]", "1751"}], ",", 
       RowBox[{"1318", "\[Rule]", "1303"}], ",", 
       RowBox[{"1318", "\[Rule]", "1333"}], ",", 
       RowBox[{"1318", "\[Rule]", "1319"}], ",", 
       RowBox[{"2602", "\[Rule]", "2615"}], ",", 
       RowBox[{"2602", "\[Rule]", "2603"}], ",", 
       RowBox[{"2602", "\[Rule]", "2599"}], ",", 
       RowBox[{"2170", "\[Rule]", "2183"}], ",", 
       RowBox[{"2170", "\[Rule]", "2171"}], ",", 
       RowBox[{"2170", "\[Rule]", "2167"}], ",", 
       RowBox[{"2614", "\[Rule]", "2599"}], ",", 
       RowBox[{"2614", "\[Rule]", "2629"}], ",", 
       RowBox[{"2614", "\[Rule]", "2615"}], ",", 
       RowBox[{"2182", "\[Rule]", "2167"}], ",", 
       RowBox[{"2182", "\[Rule]", "2197"}], ",", 
       RowBox[{"2182", "\[Rule]", "2183"}], ",", 
       RowBox[{"360", "\[Rule]", "373"}], ",", 
       RowBox[{"360", "\[Rule]", "361"}], ",", 
       RowBox[{"360", "\[Rule]", "357"}], ",", 
       RowBox[{"1224", "\[Rule]", "1237"}], ",", 
       RowBox[{"1224", "\[Rule]", "1225"}], ",", 
       RowBox[{"1224", "\[Rule]", "1221"}], ",", 
       RowBox[{"792", "\[Rule]", "805"}], ",", 
       RowBox[{"792", "\[Rule]", "793"}], ",", 
       RowBox[{"792", "\[Rule]", "789"}], ",", 
       RowBox[{"252", "\[Rule]", "265"}], ",", 
       RowBox[{"252", "\[Rule]", "253"}], ",", 
       RowBox[{"252", "\[Rule]", "249"}], ",", 
       RowBox[{"1116", "\[Rule]", "1129"}], ",", 
       RowBox[{"1116", "\[Rule]", "1117"}], ",", 
       RowBox[{"1116", "\[Rule]", "1113"}], ",", 
       RowBox[{"684", "\[Rule]", "697"}], ",", 
       RowBox[{"684", "\[Rule]", "685"}], ",", 
       RowBox[{"684", "\[Rule]", "681"}], ",", 
       RowBox[{"2088", "\[Rule]", "2101"}], ",", 
       RowBox[{"2088", "\[Rule]", "2089"}], ",", 
       RowBox[{"2088", "\[Rule]", "2085"}], ",", 
       RowBox[{"1656", "\[Rule]", "1669"}], ",", 
       RowBox[{"1656", "\[Rule]", "1657"}], ",", 
       RowBox[{"1656", "\[Rule]", "1653"}], ",", 
       RowBox[{"1980", "\[Rule]", "1993"}], ",", 
       RowBox[{"1980", "\[Rule]", "1981"}], ",", 
       RowBox[{"1980", "\[Rule]", "1977"}], ",", 
       RowBox[{"1548", "\[Rule]", "1561"}], ",", 
       RowBox[{"1548", "\[Rule]", "1549"}], ",", 
       RowBox[{"1548", "\[Rule]", "1545"}], ",", 
       RowBox[{"144", "\[Rule]", "157"}], ",", 
       RowBox[{"144", "\[Rule]", "145"}], ",", 
       RowBox[{"144", "\[Rule]", "141"}], ",", 
       RowBox[{"1008", "\[Rule]", "1021"}], ",", 
       RowBox[{"1008", "\[Rule]", "1009"}], ",", 
       RowBox[{"1008", "\[Rule]", "1005"}], ",", 
       RowBox[{"576", "\[Rule]", "589"}], ",", 
       RowBox[{"576", "\[Rule]", "577"}], ",", 
       RowBox[{"576", "\[Rule]", "573"}], ",", 
       RowBox[{"1872", "\[Rule]", "1885"}], ",", 
       RowBox[{"1872", "\[Rule]", "1873"}], ",", 
       RowBox[{"1872", "\[Rule]", "1869"}], ",", 
       RowBox[{"1440", "\[Rule]", "1453"}], ",", 
       RowBox[{"1440", "\[Rule]", "1441"}], ",", 
       RowBox[{"1440", "\[Rule]", "1437"}], ",", 
       RowBox[{"2952", "\[Rule]", "2965"}], ",", 
       RowBox[{"2952", "\[Rule]", "2953"}], ",", 
       RowBox[{"2952", "\[Rule]", "2949"}], ",", 
       RowBox[{"2520", "\[Rule]", "2533"}], ",", 
       RowBox[{"2520", "\[Rule]", "2521"}], ",", 
       RowBox[{"2520", "\[Rule]", "2517"}], ",", 
       RowBox[{"2844", "\[Rule]", "2857"}], ",", 
       RowBox[{"2844", "\[Rule]", "2845"}], ",", 
       RowBox[{"2844", "\[Rule]", "2841"}], ",", 
       RowBox[{"2412", "\[Rule]", "2425"}], ",", 
       RowBox[{"2412", "\[Rule]", "2413"}], ",", 
       RowBox[{"2412", "\[Rule]", "2409"}], ",", 
       RowBox[{"2736", "\[Rule]", "2749"}], ",", 
       RowBox[{"2736", "\[Rule]", "2737"}], ",", 
       RowBox[{"2736", "\[Rule]", "2733"}], ",", 
       RowBox[{"2304", "\[Rule]", "2317"}], ",", 
       RowBox[{"2304", "\[Rule]", "2305"}], ",", 
       RowBox[{"2304", "\[Rule]", "2301"}], ",", 
       RowBox[{"36", "\[Rule]", "49"}], ",", 
       RowBox[{"36", "\[Rule]", "37"}], ",", 
       RowBox[{"36", "\[Rule]", "33"}], ",", 
       RowBox[{"900", "\[Rule]", "913"}], ",", 
       RowBox[{"900", "\[Rule]", "901"}], ",", 
       RowBox[{"900", "\[Rule]", "897"}], ",", 
       RowBox[{"468", "\[Rule]", "481"}], ",", 
       RowBox[{"468", "\[Rule]", "469"}], ",", 
       RowBox[{"468", "\[Rule]", "465"}], ",", 
       RowBox[{"1764", "\[Rule]", "1777"}], ",", 
       RowBox[{"1764", "\[Rule]", "1765"}], ",", 
       RowBox[{"1764", "\[Rule]", "1761"}], ",", 
       RowBox[{"1332", "\[Rule]", "1345"}], ",", 
       RowBox[{"1332", "\[Rule]", "1333"}], ",", 
       RowBox[{"1332", "\[Rule]", "1329"}], ",", 
       RowBox[{"2628", "\[Rule]", "2641"}], ",", 
       RowBox[{"2628", "\[Rule]", "2629"}], ",", 
       RowBox[{"2628", "\[Rule]", "2625"}], ",", 
       RowBox[{"2196", "\[Rule]", "2209"}], ",", 
       RowBox[{"2196", "\[Rule]", "2197"}], ",", 
       RowBox[{"2196", "\[Rule]", "2193"}], ",", 
       RowBox[{"372", "\[Rule]", "357"}], ",", 
       RowBox[{"372", "\[Rule]", "387"}], ",", 
       RowBox[{"372", "\[Rule]", "373"}], ",", 
       RowBox[{"1236", "\[Rule]", "1221"}], ",", 
       RowBox[{"1236", "\[Rule]", "1251"}], ",", 
       RowBox[{"1236", "\[Rule]", "1237"}], ",", 
       RowBox[{"804", "\[Rule]", "789"}], ",", 
       RowBox[{"804", "\[Rule]", "819"}], ",", 
       RowBox[{"804", "\[Rule]", "805"}], ",", 
       RowBox[{"264", "\[Rule]", "249"}], ",", 
       RowBox[{"264", "\[Rule]", "279"}], ",", 
       RowBox[{"264", "\[Rule]", "265"}], ",", 
       RowBox[{"1128", "\[Rule]", "1113"}], ",", 
       RowBox[{"1128", "\[Rule]", "1143"}], ",", 
       RowBox[{"1128", "\[Rule]", "1129"}], ",", 
       RowBox[{"696", "\[Rule]", "681"}], ",", 
       RowBox[{"696", "\[Rule]", "711"}], ",", 
       RowBox[{"696", "\[Rule]", "697"}], ",", 
       RowBox[{"2100", "\[Rule]", "2085"}], ",", 
       RowBox[{"2100", "\[Rule]", "2115"}], ",", 
       RowBox[{"2100", "\[Rule]", "2101"}], ",", 
       RowBox[{"1668", "\[Rule]", "1653"}], ",", 
       RowBox[{"1668", "\[Rule]", "1683"}], ",", 
       RowBox[{"1668", "\[Rule]", "1669"}], ",", 
       RowBox[{"1992", "\[Rule]", "1977"}], ",", 
       RowBox[{"1992", "\[Rule]", "2007"}], ",", 
       RowBox[{"1992", "\[Rule]", "1993"}], ",", 
       RowBox[{"1560", "\[Rule]", "1545"}], ",", 
       RowBox[{"1560", "\[Rule]", "1575"}], ",", 
       RowBox[{"1560", "\[Rule]", "1561"}], ",", 
       RowBox[{"156", "\[Rule]", "141"}], ",", 
       RowBox[{"156", "\[Rule]", "171"}], ",", 
       RowBox[{"156", "\[Rule]", "157"}], ",", 
       RowBox[{"1020", "\[Rule]", "1005"}], ",", 
       RowBox[{"1020", "\[Rule]", "1035"}], ",", 
       RowBox[{"1020", "\[Rule]", "1021"}], ",", 
       RowBox[{"588", "\[Rule]", "573"}], ",", 
       RowBox[{"588", "\[Rule]", "603"}], ",", 
       RowBox[{"588", "\[Rule]", "589"}], ",", 
       RowBox[{"1884", "\[Rule]", "1869"}], ",", 
       RowBox[{"1884", "\[Rule]", "1899"}], ",", 
       RowBox[{"1884", "\[Rule]", "1885"}], ",", 
       RowBox[{"1452", "\[Rule]", "1437"}], ",", 
       RowBox[{"1452", "\[Rule]", "1467"}], ",", 
       RowBox[{"1452", "\[Rule]", "1453"}], ",", 
       RowBox[{"2964", "\[Rule]", "2949"}], ",", 
       RowBox[{"2964", "\[Rule]", "2979"}], ",", 
       RowBox[{"2964", "\[Rule]", "2965"}], ",", 
       RowBox[{"2532", "\[Rule]", "2517"}], ",", 
       RowBox[{"2532", "\[Rule]", "2547"}], ",", 
       RowBox[{"2532", "\[Rule]", "2533"}], ",", 
       RowBox[{"2856", "\[Rule]", "2841"}], ",", 
       RowBox[{"2856", "\[Rule]", "2871"}], ",", 
       RowBox[{"2856", "\[Rule]", "2857"}], ",", 
       RowBox[{"2424", "\[Rule]", "2409"}], ",", 
       RowBox[{"2424", "\[Rule]", "2439"}], ",", 
       RowBox[{"2424", "\[Rule]", "2425"}], ",", 
       RowBox[{"2748", "\[Rule]", "2733"}], ",", 
       RowBox[{"2748", "\[Rule]", "2763"}], ",", 
       RowBox[{"2748", "\[Rule]", "2749"}], ",", 
       RowBox[{"2316", "\[Rule]", "2301"}], ",", 
       RowBox[{"2316", "\[Rule]", "2331"}], ",", 
       RowBox[{"2316", "\[Rule]", "2317"}], ",", 
       RowBox[{"48", "\[Rule]", "33"}], ",", 
       RowBox[{"48", "\[Rule]", "63"}], ",", 
       RowBox[{"48", "\[Rule]", "49"}], ",", 
       RowBox[{"912", "\[Rule]", "897"}], ",", 
       RowBox[{"912", "\[Rule]", "927"}], ",", 
       RowBox[{"912", "\[Rule]", "913"}], ",", 
       RowBox[{"480", "\[Rule]", "465"}], ",", 
       RowBox[{"480", "\[Rule]", "495"}], ",", 
       RowBox[{"480", "\[Rule]", "481"}], ",", 
       RowBox[{"1776", "\[Rule]", "1761"}], ",", 
       RowBox[{"1776", "\[Rule]", "1791"}], ",", 
       RowBox[{"1776", "\[Rule]", "1777"}], ",", 
       RowBox[{"1344", "\[Rule]", "1329"}], ",", 
       RowBox[{"1344", "\[Rule]", "1359"}], ",", 
       RowBox[{"1344", "\[Rule]", "1345"}], ",", 
       RowBox[{"2640", "\[Rule]", "2625"}], ",", 
       RowBox[{"2640", "\[Rule]", "2655"}], ",", 
       RowBox[{"2640", "\[Rule]", "2641"}], ",", 
       RowBox[{"2208", "\[Rule]", "2193"}], ",", 
       RowBox[{"2208", "\[Rule]", "2223"}], ",", 
       RowBox[{"2208", "\[Rule]", "2209"}], ",", 
       RowBox[{"386", "\[Rule]", "401"}], ",", 
       RowBox[{"386", "\[Rule]", "387"}], ",", 
       RowBox[{"1250", "\[Rule]", "1265"}], ",", 
       RowBox[{"1250", "\[Rule]", "1251"}], ",", 
       RowBox[{"818", "\[Rule]", "833"}], ",", 
       RowBox[{"818", "\[Rule]", "819"}], ",", 
       RowBox[{"278", "\[Rule]", "293"}], ",", 
       RowBox[{"278", "\[Rule]", "279"}], ",", 
       RowBox[{"1142", "\[Rule]", "1157"}], ",", 
       RowBox[{"1142", "\[Rule]", "1143"}], ",", 
       RowBox[{"710", "\[Rule]", "725"}], ",", 
       RowBox[{"710", "\[Rule]", "711"}], ",", 
       RowBox[{"2114", "\[Rule]", "2129"}], ",", 
       RowBox[{"2114", "\[Rule]", "2115"}], ",", 
       RowBox[{"1682", "\[Rule]", "1697"}], ",", 
       RowBox[{"1682", "\[Rule]", "1683"}], ",", 
       RowBox[{"2006", "\[Rule]", "2021"}], ",", 
       RowBox[{"2006", "\[Rule]", "2007"}], ",", 
       RowBox[{"1574", "\[Rule]", "1589"}], ",", 
       RowBox[{"1574", "\[Rule]", "1575"}], ",", 
       RowBox[{"170", "\[Rule]", "185"}], ",", 
       RowBox[{"170", "\[Rule]", "171"}], ",", 
       RowBox[{"1034", "\[Rule]", "1049"}], ",", 
       RowBox[{"1034", "\[Rule]", "1035"}], ",", 
       RowBox[{"602", "\[Rule]", "617"}], ",", 
       RowBox[{"602", "\[Rule]", "603"}], ",", 
       RowBox[{"1898", "\[Rule]", "1913"}], ",", 
       RowBox[{"1898", "\[Rule]", "1899"}], ",", 
       RowBox[{"1466", "\[Rule]", "1481"}], ",", 
       RowBox[{"1466", "\[Rule]", "1467"}], ",", 
       RowBox[{"2978", "\[Rule]", "2993"}], ",", 
       RowBox[{"2978", "\[Rule]", "2979"}], ",", 
       RowBox[{"2546", "\[Rule]", "2561"}], ",", 
       RowBox[{"2546", "\[Rule]", "2547"}], ",", 
       RowBox[{"2870", "\[Rule]", "2885"}], ",", 
       RowBox[{"2870", "\[Rule]", "2871"}], ",", 
       RowBox[{"2438", "\[Rule]", "2453"}], ",", 
       RowBox[{"2438", "\[Rule]", "2439"}], ",", 
       RowBox[{"2762", "\[Rule]", "2777"}], ",", 
       RowBox[{"2762", "\[Rule]", "2763"}], ",", 
       RowBox[{"2330", "\[Rule]", "2345"}], ",", 
       RowBox[{"2330", "\[Rule]", "2331"}], ",", 
       RowBox[{"62", "\[Rule]", "77"}], ",", 
       RowBox[{"62", "\[Rule]", "63"}], ",", 
       RowBox[{"926", "\[Rule]", "941"}], ",", 
       RowBox[{"926", "\[Rule]", "927"}], ",", 
       RowBox[{"494", "\[Rule]", "509"}], ",", 
       RowBox[{"494", "\[Rule]", "495"}], ",", 
       RowBox[{"1790", "\[Rule]", "1805"}], ",", 
       RowBox[{"1790", "\[Rule]", "1791"}], ",", 
       RowBox[{"1358", "\[Rule]", "1373"}], ",", 
       RowBox[{"1358", "\[Rule]", "1359"}], ",", 
       RowBox[{"2654", "\[Rule]", "2669"}], ",", 
       RowBox[{"2654", "\[Rule]", "2655"}], ",", 
       RowBox[{"2222", "\[Rule]", "2237"}], ",", 
       RowBox[{"2222", "\[Rule]", "2223"}], ",", 
       RowBox[{"331", "\[Rule]", "764"}], ",", 
       RowBox[{"331", "\[Rule]", "764"}], ",", 
       RowBox[{"331", "\[Rule]", "656"}], ",", 
       RowBox[{"331", "\[Rule]", "656"}], ",", 
       RowBox[{"331", "\[Rule]", "332"}], ",", 
       RowBox[{"1195", "\[Rule]", "764"}], ",", 
       RowBox[{"1195", "\[Rule]", "764"}], ",", 
       RowBox[{"1195", "\[Rule]", "1628"}], ",", 
       RowBox[{"1195", "\[Rule]", "1628"}], ",", 
       RowBox[{"1195", "\[Rule]", "656"}], ",", 
       RowBox[{"1195", "\[Rule]", "656"}], ",", 
       RowBox[{"1195", "\[Rule]", "1520"}], ",", 
       RowBox[{"1195", "\[Rule]", "1520"}], ",", 
       RowBox[{"1195", "\[Rule]", "1196"}], ",", 
       RowBox[{"763", "\[Rule]", "332"}], ",", 
       RowBox[{"763", "\[Rule]", "332"}], ",", 
       RowBox[{"763", "\[Rule]", "1196"}], ",", 
       RowBox[{"763", "\[Rule]", "1196"}], ",", 
       RowBox[{"763", "\[Rule]", "764"}], ",", 
       RowBox[{"223", "\[Rule]", "656"}], ",", 
       RowBox[{"223", "\[Rule]", "656"}], ",", 
       RowBox[{"223", "\[Rule]", "548"}], ",", 
       RowBox[{"223", "\[Rule]", "224"}], ",", 
       RowBox[{"1087", "\[Rule]", "656"}], ",", 
       RowBox[{"1087", "\[Rule]", "656"}], ",", 
       RowBox[{"1087", "\[Rule]", "1520"}], ",", 
       RowBox[{"1087", "\[Rule]", "1520"}], ",", 
       RowBox[{"1087", "\[Rule]", "548"}], ",", 
       RowBox[{"1087", "\[Rule]", "548"}], ",", 
       RowBox[{"1087", "\[Rule]", "1412"}], ",", 
       RowBox[{"1087", "\[Rule]", "1412"}], ",", 
       RowBox[{"1087", "\[Rule]", "1088"}], ",", 
       RowBox[{"655", "\[Rule]", "332"}], ",", 
       RowBox[{"655", "\[Rule]", "332"}], ",", 
       RowBox[{"655", "\[Rule]", "1196"}], ",", 
       RowBox[{"655", "\[Rule]", "1196"}], ",", 
       RowBox[{"655", "\[Rule]", "224"}], ",", 
       RowBox[{"655", "\[Rule]", "224"}], ",", 
       RowBox[{"655", "\[Rule]", "1088"}], ",", 
       RowBox[{"655", "\[Rule]", "1088"}], ",", 
       RowBox[{"655", "\[Rule]", "656"}], ",", 
       RowBox[{"2059", "\[Rule]", "1628"}], ",", 
       RowBox[{"2059", "\[Rule]", "1628"}], ",", 
       RowBox[{"2059", "\[Rule]", "2492"}], ",", 
       RowBox[{"2059", "\[Rule]", "2492"}], ",", 
       RowBox[{"2059", "\[Rule]", "1520"}], ",", 
       RowBox[{"2059", "\[Rule]", "1520"}], ",", 
       RowBox[{"2059", "\[Rule]", "2384"}], ",", 
       RowBox[{"2059", "\[Rule]", "2384"}], ",", 
       RowBox[{"2059", "\[Rule]", "2060"}], ",", 
       RowBox[{"1627", "\[Rule]", "1196"}], ",", 
       RowBox[{"1627", "\[Rule]", "1196"}], ",", 
       RowBox[{"1627", "\[Rule]", "2060"}], ",", 
       RowBox[{"1627", "\[Rule]", "2060"}], ",", 
       RowBox[{"1627", "\[Rule]", "1628"}], ",", 
       RowBox[{"1951", "\[Rule]", "1520"}], ",", 
       RowBox[{"1951", "\[Rule]", "1520"}], ",", 
       RowBox[{"1951", "\[Rule]", "2384"}], ",", 
       RowBox[{"1951", "\[Rule]", "2384"}], ",", 
       RowBox[{"1951", "\[Rule]", "1412"}], ",", 
       RowBox[{"1951", "\[Rule]", "1412"}], ",", 
       RowBox[{"1951", "\[Rule]", "2276"}], ",", 
       RowBox[{"1951", "\[Rule]", "2276"}], ",", 
       RowBox[{"1951", "\[Rule]", "1952"}], ",", 
       RowBox[{"1519", "\[Rule]", "1196"}], ",", 
       RowBox[{"1519", "\[Rule]", "1196"}], ",", 
       RowBox[{"1519", "\[Rule]", "2060"}], ",", 
       RowBox[{"1519", "\[Rule]", "2060"}], ",", 
       RowBox[{"1519", "\[Rule]", "1088"}], ",", 
       RowBox[{"1519", "\[Rule]", "1088"}], ",", 
       RowBox[{"1519", "\[Rule]", "1952"}], ",", 
       RowBox[{"1519", "\[Rule]", "1952"}], ",", 
       RowBox[{"1519", "\[Rule]", "1520"}], ",", 
       RowBox[{"115", "\[Rule]", "440"}], ",", 
       RowBox[{"115", "\[Rule]", "116"}], ",", 
       RowBox[{"979", "\[Rule]", "548"}], ",", 
       RowBox[{"979", "\[Rule]", "1412"}], ",", 
       RowBox[{"979", "\[Rule]", "1412"}], ",", 
       RowBox[{"979", "\[Rule]", "440"}], ",", 
       RowBox[{"979", "\[Rule]", "1304"}], ",", 
       RowBox[{"979", "\[Rule]", "1304"}], ",", 
       RowBox[{"979", "\[Rule]", "980"}], ",", 
       RowBox[{"547", "\[Rule]", "224"}], ",", 
       RowBox[{"547", "\[Rule]", "1088"}], ",", 
       RowBox[{"547", "\[Rule]", "1088"}], ",", 
       RowBox[{"547", "\[Rule]", "980"}], ",", 
       RowBox[{"547", "\[Rule]", "548"}], ",", 
       RowBox[{"1843", "\[Rule]", "1412"}], ",", 
       RowBox[{"1843", "\[Rule]", "1412"}], ",", 
       RowBox[{"1843", "\[Rule]", "2276"}], ",", 
       RowBox[{"1843", "\[Rule]", "2276"}], ",", 
       RowBox[{"1843", "\[Rule]", "1304"}], ",", 
       RowBox[{"1843", "\[Rule]", "1304"}], ",", 
       RowBox[{"1843", "\[Rule]", "2168"}], ",", 
       RowBox[{"1843", "\[Rule]", "2168"}], ",", 
       RowBox[{"1843", "\[Rule]", "1844"}], ",", 
       RowBox[{"1411", "\[Rule]", "1088"}], ",", 
       RowBox[{"1411", "\[Rule]", "1088"}], ",", 
       RowBox[{"1411", "\[Rule]", "1952"}], ",", 
       RowBox[{"1411", "\[Rule]", "1952"}], ",", 
       RowBox[{"1411", "\[Rule]", "980"}], ",", 
       RowBox[{"1411", "\[Rule]", "980"}], ",", 
       RowBox[{"1411", "\[Rule]", "1844"}], ",", 
       RowBox[{"1411", "\[Rule]", "1844"}], ",", 
       RowBox[{"1411", "\[Rule]", "1412"}], ",", 
       RowBox[{"2923", "\[Rule]", "2492"}], ",", 
       RowBox[{"2923", "\[Rule]", "2492"}], ",", 
       RowBox[{"2923", "\[Rule]", "2384"}], ",", 
       RowBox[{"2923", "\[Rule]", "2384"}], ",", 
       RowBox[{"2923", "\[Rule]", "2924"}], ",", 
       RowBox[{"2491", "\[Rule]", "2060"}], ",", 
       RowBox[{"2491", "\[Rule]", "2060"}], ",", 
       RowBox[{"2491", "\[Rule]", "2924"}], ",", 
       RowBox[{"2491", "\[Rule]", "2924"}], ",", 
       RowBox[{"2491", "\[Rule]", "2492"}], ",", 
       RowBox[{"2815", "\[Rule]", "2384"}], ",", 
       RowBox[{"2815", "\[Rule]", "2384"}], ",", 
       RowBox[{"2815", "\[Rule]", "2276"}], ",", 
       RowBox[{"2815", "\[Rule]", "2276"}], ",", 
       RowBox[{"2815", "\[Rule]", "2816"}], ",", 
       RowBox[{"2383", "\[Rule]", "2060"}], ",", 
       RowBox[{"2383", "\[Rule]", "2060"}], ",", 
       RowBox[{"2383", "\[Rule]", "2924"}], ",", 
       RowBox[{"2383", "\[Rule]", "2924"}], ",", 
       RowBox[{"2383", "\[Rule]", "1952"}], ",", 
       RowBox[{"2383", "\[Rule]", "1952"}], ",", 
       RowBox[{"2383", "\[Rule]", "2816"}], ",", 
       RowBox[{"2383", "\[Rule]", "2816"}], ",", 
       RowBox[{"2383", "\[Rule]", "2384"}], ",", 
       RowBox[{"2707", "\[Rule]", "2276"}], ",", 
       RowBox[{"2707", "\[Rule]", "2276"}], ",", 
       RowBox[{"2707", "\[Rule]", "2168"}], ",", 
       RowBox[{"2707", "\[Rule]", "2168"}], ",", 
       RowBox[{"2707", "\[Rule]", "2708"}], ",", 
       RowBox[{"2275", "\[Rule]", "1952"}], ",", 
       RowBox[{"2275", "\[Rule]", "1952"}], ",", 
       RowBox[{"2275", "\[Rule]", "2816"}], ",", 
       RowBox[{"2275", "\[Rule]", "2816"}], ",", 
       RowBox[{"2275", "\[Rule]", "1844"}], ",", 
       RowBox[{"2275", "\[Rule]", "1844"}], ",", 
       RowBox[{"2275", "\[Rule]", "2708"}], ",", 
       RowBox[{"2275", "\[Rule]", "2708"}], ",", 
       RowBox[{"2275", "\[Rule]", "2276"}], ",", 
       RowBox[{"7", "\[Rule]", "440"}], ",", 
       RowBox[{"7", "\[Rule]", "440"}], ",", 
       RowBox[{"7", "\[Rule]", "8"}], ",", 
       RowBox[{"871", "\[Rule]", "440"}], ",", 
       RowBox[{"871", "\[Rule]", "440"}], ",", 
       RowBox[{"871", "\[Rule]", "1304"}], ",", 
       RowBox[{"871", "\[Rule]", "872"}], ",", 
       RowBox[{"439", "\[Rule]", "116"}], ",", 
       RowBox[{"439", "\[Rule]", "980"}], ",", 
       RowBox[{"439", "\[Rule]", "8"}], ",", 
       RowBox[{"439", "\[Rule]", "8"}], ",", 
       RowBox[{"439", "\[Rule]", "872"}], ",", 
       RowBox[{"439", "\[Rule]", "872"}], ",", 
       RowBox[{"439", "\[Rule]", "440"}], ",", 
       RowBox[{"1735", "\[Rule]", "1304"}], ",", 
       RowBox[{"1735", "\[Rule]", "2168"}], ",", 
       RowBox[{"1735", "\[Rule]", "2168"}], ",", 
       RowBox[{"1735", "\[Rule]", "1736"}], ",", 
       RowBox[{"1303", "\[Rule]", "980"}], ",", 
       RowBox[{"1303", "\[Rule]", "980"}], ",", 
       RowBox[{"1303", "\[Rule]", "1844"}], ",", 
       RowBox[{"1303", "\[Rule]", "1844"}], ",", 
       RowBox[{"1303", "\[Rule]", "872"}], ",", 
       RowBox[{"1303", "\[Rule]", "1736"}], ",", 
       RowBox[{"1303", "\[Rule]", "1304"}], ",", 
       RowBox[{"2599", "\[Rule]", "2168"}], ",", 
       RowBox[{"2599", "\[Rule]", "2168"}], ",", 
       RowBox[{"2599", "\[Rule]", "2600"}], ",", 
       RowBox[{"2167", "\[Rule]", "1844"}], ",", 
       RowBox[{"2167", "\[Rule]", "1844"}], ",", 
       RowBox[{"2167", "\[Rule]", "2708"}], ",", 
       RowBox[{"2167", "\[Rule]", "2708"}], ",", 
       RowBox[{"2167", "\[Rule]", "1736"}], ",", 
       RowBox[{"2167", "\[Rule]", "1736"}], ",", 
       RowBox[{"2167", "\[Rule]", "2600"}], ",", 
       RowBox[{"2167", "\[Rule]", "2600"}], ",", 
       RowBox[{"2167", "\[Rule]", "2168"}], ",", 
       RowBox[{"357", "\[Rule]", "790"}], ",", 
       RowBox[{"357", "\[Rule]", "790"}], ",", 
       RowBox[{"357", "\[Rule]", "682"}], ",", 
       RowBox[{"357", "\[Rule]", "682"}], ",", 
       RowBox[{"357", "\[Rule]", "358"}], ",", 
       RowBox[{"1221", "\[Rule]", "790"}], ",", 
       RowBox[{"1221", "\[Rule]", "790"}], ",", 
       RowBox[{"1221", "\[Rule]", "1654"}], ",", 
       RowBox[{"1221", "\[Rule]", "1654"}], ",", 
       RowBox[{"1221", "\[Rule]", "682"}], ",", 
       RowBox[{"1221", "\[Rule]", "682"}], ",", 
       RowBox[{"1221", "\[Rule]", "1546"}], ",", 
       RowBox[{"1221", "\[Rule]", "1546"}], ",", 
       RowBox[{"1221", "\[Rule]", "1222"}], ",", 
       RowBox[{"789", "\[Rule]", "358"}], ",", 
       RowBox[{"789", "\[Rule]", "358"}], ",", 
       RowBox[{"789", "\[Rule]", "1222"}], ",", 
       RowBox[{"789", "\[Rule]", "1222"}], ",", 
       RowBox[{"789", "\[Rule]", "790"}], ",", 
       RowBox[{"249", "\[Rule]", "682"}], ",", 
       RowBox[{"249", "\[Rule]", "682"}], ",", 
       RowBox[{"249", "\[Rule]", "574"}], ",", 
       RowBox[{"249", "\[Rule]", "574"}], ",", 
       RowBox[{"249", "\[Rule]", "250"}], ",", 
       RowBox[{"1113", "\[Rule]", "682"}], ",", 
       RowBox[{"1113", "\[Rule]", "682"}], ",", 
       RowBox[{"1113", "\[Rule]", "1546"}], ",", 
       RowBox[{"1113", "\[Rule]", "1546"}], ",", 
       RowBox[{"1113", "\[Rule]", "574"}], ",", 
       RowBox[{"1113", "\[Rule]", "574"}], ",", 
       RowBox[{"1113", "\[Rule]", "1438"}], ",", 
       RowBox[{"1113", "\[Rule]", "1438"}], ",", 
       RowBox[{"1113", "\[Rule]", "1114"}], ",", 
       RowBox[{"681", "\[Rule]", "358"}], ",", 
       RowBox[{"681", "\[Rule]", "358"}], ",", 
       RowBox[{"681", "\[Rule]", "1222"}], ",", 
       RowBox[{"681", "\[Rule]", "1222"}], ",", 
       RowBox[{"681", "\[Rule]", "250"}], ",", 
       RowBox[{"681", "\[Rule]", "250"}], ",", 
       RowBox[{"681", "\[Rule]", "1114"}], ",", 
       RowBox[{"681", "\[Rule]", "1114"}], ",", 
       RowBox[{"681", "\[Rule]", "682"}], ",", 
       RowBox[{"2085", "\[Rule]", "1654"}], ",", 
       RowBox[{"2085", "\[Rule]", "1654"}], ",", 
       RowBox[{"2085", "\[Rule]", "2518"}], ",", 
       RowBox[{"2085", "\[Rule]", "2518"}], ",", 
       RowBox[{"2085", "\[Rule]", "1546"}], ",", 
       RowBox[{"2085", "\[Rule]", "1546"}], ",", 
       RowBox[{"2085", "\[Rule]", "2410"}], ",", 
       RowBox[{"2085", "\[Rule]", "2410"}], ",", 
       RowBox[{"2085", "\[Rule]", "2086"}], ",", 
       RowBox[{"1653", "\[Rule]", "1222"}], ",", 
       RowBox[{"1653", "\[Rule]", "1222"}], ",", 
       RowBox[{"1653", "\[Rule]", "2086"}], ",", 
       RowBox[{"1653", "\[Rule]", "2086"}], ",", 
       RowBox[{"1653", "\[Rule]", "1654"}], ",", 
       RowBox[{"1977", "\[Rule]", "1546"}], ",", 
       RowBox[{"1977", "\[Rule]", "1546"}], ",", 
       RowBox[{"1977", "\[Rule]", "2410"}], ",", 
       RowBox[{"1977", "\[Rule]", "2410"}], ",", 
       RowBox[{"1977", "\[Rule]", "1438"}], ",", 
       RowBox[{"1977", "\[Rule]", "1438"}], ",", 
       RowBox[{"1977", "\[Rule]", "2302"}], ",", 
       RowBox[{"1977", "\[Rule]", "2302"}], ",", 
       RowBox[{"1977", "\[Rule]", "1978"}], ",", 
       RowBox[{"1545", "\[Rule]", "1222"}], ",", 
       RowBox[{"1545", "\[Rule]", "1222"}], ",", 
       RowBox[{"1545", "\[Rule]", "2086"}], ",", 
       RowBox[{"1545", "\[Rule]", "2086"}], ",", 
       RowBox[{"1545", "\[Rule]", "1114"}], ",", 
       RowBox[{"1545", "\[Rule]", "1114"}], ",", 
       RowBox[{"1545", "\[Rule]", "1978"}], ",", 
       RowBox[{"1545", "\[Rule]", "1978"}], ",", 
       RowBox[{"1545", "\[Rule]", "1546"}], ",", 
       RowBox[{"141", "\[Rule]", "574"}], ",", 
       RowBox[{"141", "\[Rule]", "466"}], ",", 
       RowBox[{"141", "\[Rule]", "142"}], ",", 
       RowBox[{"1005", "\[Rule]", "574"}], ",", 
       RowBox[{"1005", "\[Rule]", "1438"}], ",", 
       RowBox[{"1005", "\[Rule]", "1438"}], ",", 
       RowBox[{"1005", "\[Rule]", "1330"}], ",", 
       RowBox[{"1005", "\[Rule]", "1006"}], ",", 
       RowBox[{"573", "\[Rule]", "250"}], ",", 
       RowBox[{"573", "\[Rule]", "250"}], ",", 
       RowBox[{"573", "\[Rule]", "1114"}], ",", 
       RowBox[{"573", "\[Rule]", "1114"}], ",", 
       RowBox[{"573", "\[Rule]", "142"}], ",", 
       RowBox[{"573", "\[Rule]", "1006"}], ",", 
       RowBox[{"573", "\[Rule]", "574"}], ",", 
       RowBox[{"1869", "\[Rule]", "1438"}], ",", 
       RowBox[{"1869", "\[Rule]", "1438"}], ",", 
       RowBox[{"1869", "\[Rule]", "2302"}], ",", 
       RowBox[{"1869", "\[Rule]", "2302"}], ",", 
       RowBox[{"1869", "\[Rule]", "1330"}], ",", 
       RowBox[{"1869", "\[Rule]", "1330"}], ",", 
       RowBox[{"1869", "\[Rule]", "2194"}], ",", 
       RowBox[{"1869", "\[Rule]", "2194"}], ",", 
       RowBox[{"1869", "\[Rule]", "1870"}], ",", 
       RowBox[{"1437", "\[Rule]", "1114"}], ",", 
       RowBox[{"1437", "\[Rule]", "1114"}], ",", 
       RowBox[{"1437", "\[Rule]", "1978"}], ",", 
       RowBox[{"1437", "\[Rule]", "1978"}], ",", 
       RowBox[{"1437", "\[Rule]", "1006"}], ",", 
       RowBox[{"1437", "\[Rule]", "1006"}], ",", 
       RowBox[{"1437", "\[Rule]", "1870"}], ",", 
       RowBox[{"1437", "\[Rule]", "1870"}], ",", 
       RowBox[{"1437", "\[Rule]", "1438"}], ",", 
       RowBox[{"2949", "\[Rule]", "2518"}], ",", 
       RowBox[{"2949", "\[Rule]", "2518"}], ",", 
       RowBox[{"2949", "\[Rule]", "2410"}], ",", 
       RowBox[{"2949", "\[Rule]", "2410"}], ",", 
       RowBox[{"2949", "\[Rule]", "2950"}], ",", 
       RowBox[{"2517", "\[Rule]", "2086"}], ",", 
       RowBox[{"2517", "\[Rule]", "2086"}], ",", 
       RowBox[{"2517", "\[Rule]", "2950"}], ",", 
       RowBox[{"2517", "\[Rule]", "2950"}], ",", 
       RowBox[{"2517", "\[Rule]", "2518"}], ",", 
       RowBox[{"2841", "\[Rule]", "2410"}], ",", 
       RowBox[{"2841", "\[Rule]", "2410"}], ",", 
       RowBox[{"2841", "\[Rule]", "2302"}], ",", 
       RowBox[{"2841", "\[Rule]", "2302"}], ",", 
       RowBox[{"2841", "\[Rule]", "2842"}], ",", 
       RowBox[{"2409", "\[Rule]", "2086"}], ",", 
       RowBox[{"2409", "\[Rule]", "2086"}], ",", 
       RowBox[{"2409", "\[Rule]", "2950"}], ",", 
       RowBox[{"2409", "\[Rule]", "2950"}], ",", 
       RowBox[{"2409", "\[Rule]", "1978"}], ",", 
       RowBox[{"2409", "\[Rule]", "1978"}], ",", 
       RowBox[{"2409", "\[Rule]", "2842"}], ",", 
       RowBox[{"2409", "\[Rule]", "2842"}], ",", 
       RowBox[{"2409", "\[Rule]", "2410"}], ",", 
       RowBox[{"2733", "\[Rule]", "2302"}], ",", 
       RowBox[{"2733", "\[Rule]", "2302"}], ",", 
       RowBox[{"2733", "\[Rule]", "2194"}], ",", 
       RowBox[{"2733", "\[Rule]", "2194"}], ",", 
       RowBox[{"2733", "\[Rule]", "2734"}], ",", 
       RowBox[{"2301", "\[Rule]", "1978"}], ",", 
       RowBox[{"2301", "\[Rule]", "1978"}], ",", 
       RowBox[{"2301", "\[Rule]", "2842"}], ",", 
       RowBox[{"2301", "\[Rule]", "2842"}], ",", 
       RowBox[{"2301", "\[Rule]", "1870"}], ",", 
       RowBox[{"2301", "\[Rule]", "1870"}], ",", 
       RowBox[{"2301", "\[Rule]", "2734"}], ",", 
       RowBox[{"2301", "\[Rule]", "2734"}], ",", 
       RowBox[{"2301", "\[Rule]", "2302"}], ",", 
       RowBox[{"33", "\[Rule]", "466"}], ",", 
       RowBox[{"33", "\[Rule]", "466"}], ",", 
       RowBox[{"33", "\[Rule]", "34"}], ",", 
       RowBox[{"897", "\[Rule]", "466"}], ",", 
       RowBox[{"897", "\[Rule]", "898"}], ",", 
       RowBox[{"465", "\[Rule]", "142"}], ",", 
       RowBox[{"465", "\[Rule]", "34"}], ",", 
       RowBox[{"465", "\[Rule]", "34"}], ",", 
       RowBox[{"465", "\[Rule]", "898"}], ",", 
       RowBox[{"465", "\[Rule]", "466"}], ",", 
       RowBox[{"1761", "\[Rule]", "1330"}], ",", 
       RowBox[{"1761", "\[Rule]", "2194"}], ",", 
       RowBox[{"1761", "\[Rule]", "2194"}], ",", 
       RowBox[{"1761", "\[Rule]", "1762"}], ",", 
       RowBox[{"1329", "\[Rule]", "1006"}], ",", 
       RowBox[{"1329", "\[Rule]", "1870"}], ",", 
       RowBox[{"1329", "\[Rule]", "1870"}], ",", 
       RowBox[{"1329", "\[Rule]", "1762"}], ",", 
       RowBox[{"1329", "\[Rule]", "1330"}], ",", 
       RowBox[{"2625", "\[Rule]", "2194"}], ",", 
       RowBox[{"2625", "\[Rule]", "2194"}], ",", 
       RowBox[{"2625", "\[Rule]", "2626"}], ",", 
       RowBox[{"2193", "\[Rule]", "1870"}], ",", 
       RowBox[{"2193", "\[Rule]", "1870"}], ",", 
       RowBox[{"2193", "\[Rule]", "2734"}], ",", 
       RowBox[{"2193", "\[Rule]", "2734"}], ",", 
       RowBox[{"2193", "\[Rule]", "1762"}], ",", 
       RowBox[{"2193", "\[Rule]", "1762"}], ",", 
       RowBox[{"2193", "\[Rule]", "2626"}], ",", 
       RowBox[{"2193", "\[Rule]", "2626"}], ",", 
       RowBox[{"2193", "\[Rule]", "2194"}], ",", 
       RowBox[{"764", "\[Rule]", "777"}], ",", 
       RowBox[{"764", "\[Rule]", "765"}], ",", 
       RowBox[{"764", "\[Rule]", "761"}], ",", 
       RowBox[{"656", "\[Rule]", "669"}], ",", 
       RowBox[{"656", "\[Rule]", "657"}], ",", 
       RowBox[{"656", "\[Rule]", "653"}], ",", 
       RowBox[{"332", "\[Rule]", "345"}], ",", 
       RowBox[{"332", "\[Rule]", "333"}], ",", 
       RowBox[{"332", "\[Rule]", "329"}], ",", 
       RowBox[{"1628", "\[Rule]", "1641"}], ",", 
       RowBox[{"1628", "\[Rule]", "1629"}], ",", 
       RowBox[{"1628", "\[Rule]", "1625"}], ",", 
       RowBox[{"1520", "\[Rule]", "1533"}], ",", 
       RowBox[{"1520", "\[Rule]", "1521"}], ",", 
       RowBox[{"1520", "\[Rule]", "1517"}], ",", 
       RowBox[{"1196", "\[Rule]", "1209"}], ",", 
       RowBox[{"1196", "\[Rule]", "1197"}], ",", 
       RowBox[{"1196", "\[Rule]", "1193"}], ",", 
       RowBox[{"548", "\[Rule]", "561"}], ",", 
       RowBox[{"548", "\[Rule]", "549"}], ",", 
       RowBox[{"548", "\[Rule]", "545"}], ",", 
       RowBox[{"224", "\[Rule]", "237"}], ",", 
       RowBox[{"224", "\[Rule]", "225"}], ",", 
       RowBox[{"224", "\[Rule]", "221"}], ",", 
       RowBox[{"1412", "\[Rule]", "1425"}], ",", 
       RowBox[{"1412", "\[Rule]", "1413"}], ",", 
       RowBox[{"1412", "\[Rule]", "1409"}], ",", 
       RowBox[{"1088", "\[Rule]", "1101"}], ",", 
       RowBox[{"1088", "\[Rule]", "1089"}], ",", 
       RowBox[{"1088", "\[Rule]", "1085"}], ",", 
       RowBox[{"2492", "\[Rule]", "2505"}], ",", 
       RowBox[{"2492", "\[Rule]", "2493"}], ",", 
       RowBox[{"2492", "\[Rule]", "2489"}], ",", 
       RowBox[{"2384", "\[Rule]", "2397"}], ",", 
       RowBox[{"2384", "\[Rule]", "2385"}], ",", 
       RowBox[{"2384", "\[Rule]", "2381"}], ",", 
       RowBox[{"2060", "\[Rule]", "2073"}], ",", 
       RowBox[{"2060", "\[Rule]", "2061"}], ",", 
       RowBox[{"2060", "\[Rule]", "2057"}], ",", 
       RowBox[{"2276", "\[Rule]", "2289"}], ",", 
       RowBox[{"2276", "\[Rule]", "2277"}], ",", 
       RowBox[{"2276", "\[Rule]", "2273"}], ",", 
       RowBox[{"1952", "\[Rule]", "1965"}], ",", 
       RowBox[{"1952", "\[Rule]", "1953"}], ",", 
       RowBox[{"1952", "\[Rule]", "1949"}], ",", 
       RowBox[{"440", "\[Rule]", "453"}], ",", 
       RowBox[{"440", "\[Rule]", "441"}], ",", 
       RowBox[{"440", "\[Rule]", "437"}], ",", 
       RowBox[{"116", "\[Rule]", "129"}], ",", 
       RowBox[{"116", "\[Rule]", "117"}], ",", 
       RowBox[{"116", "\[Rule]", "113"}], ",", 
       RowBox[{"1304", "\[Rule]", "1317"}], ",", 
       RowBox[{"1304", "\[Rule]", "1305"}], ",", 
       RowBox[{"1304", "\[Rule]", "1301"}], ",", 
       RowBox[{"980", "\[Rule]", "993"}], ",", 
       RowBox[{"980", "\[Rule]", "981"}], ",", 
       RowBox[{"980", "\[Rule]", "977"}], ",", 
       RowBox[{"2168", "\[Rule]", "2181"}], ",", 
       RowBox[{"2168", "\[Rule]", "2169"}], ",", 
       RowBox[{"2168", "\[Rule]", "2165"}], ",", 
       RowBox[{"1844", "\[Rule]", "1857"}], ",", 
       RowBox[{"1844", "\[Rule]", "1845"}], ",", 
       RowBox[{"1844", "\[Rule]", "1841"}], ",", 
       RowBox[{"2924", "\[Rule]", "2937"}], ",", 
       RowBox[{"2924", "\[Rule]", "2925"}], ",", 
       RowBox[{"2924", "\[Rule]", "2921"}], ",", 
       RowBox[{"2816", "\[Rule]", "2829"}], ",", 
       RowBox[{"2816", "\[Rule]", "2817"}], ",", 
       RowBox[{"2816", "\[Rule]", "2813"}], ",", 
       RowBox[{"2708", "\[Rule]", "2721"}], ",", 
       RowBox[{"2708", "\[Rule]", "2709"}], ",", 
       RowBox[{"2708", "\[Rule]", "2705"}], ",", 
       RowBox[{"8", "\[Rule]", "21"}], ",", 
       RowBox[{"8", "\[Rule]", "9"}], ",", 
       RowBox[{"8", "\[Rule]", "5"}], ",", 
       RowBox[{"872", "\[Rule]", "885"}], ",", 
       RowBox[{"872", "\[Rule]", "873"}], ",", 
       RowBox[{"872", "\[Rule]", "869"}], ",", 
       RowBox[{"1736", "\[Rule]", "1749"}], ",", 
       RowBox[{"1736", "\[Rule]", "1737"}], ",", 
       RowBox[{"1736", "\[Rule]", "1733"}], ",", 
       RowBox[{"2600", "\[Rule]", "2613"}], ",", 
       RowBox[{"2600", "\[Rule]", "2601"}], ",", 
       RowBox[{"2600", "\[Rule]", "2597"}], ",", 
       RowBox[{"790", "\[Rule]", "775"}], ",", 
       RowBox[{"790", "\[Rule]", "803"}], ",", 
       RowBox[{"790", "\[Rule]", "791"}], ",", 
       RowBox[{"790", "\[Rule]", "787"}], ",", 
       RowBox[{"682", "\[Rule]", "667"}], ",", 
       RowBox[{"682", "\[Rule]", "695"}], ",", 
       RowBox[{"682", "\[Rule]", "683"}], ",", 
       RowBox[{"682", "\[Rule]", "679"}], ",", 
       RowBox[{"358", "\[Rule]", "343"}], ",", 
       RowBox[{"358", "\[Rule]", "371"}], ",", 
       RowBox[{"358", "\[Rule]", "359"}], ",", 
       RowBox[{"358", "\[Rule]", "355"}], ",", 
       RowBox[{"1654", "\[Rule]", "1639"}], ",", 
       RowBox[{"1654", "\[Rule]", "1667"}], ",", 
       RowBox[{"1654", "\[Rule]", "1655"}], ",", 
       RowBox[{"1654", "\[Rule]", "1651"}], ",", 
       RowBox[{"1546", "\[Rule]", "1531"}], ",", 
       RowBox[{"1546", "\[Rule]", "1559"}], ",", 
       RowBox[{"1546", "\[Rule]", "1547"}], ",", 
       RowBox[{"1546", "\[Rule]", "1543"}], ",", 
       RowBox[{"1222", "\[Rule]", "1207"}], ",", 
       RowBox[{"1222", "\[Rule]", "1235"}], ",", 
       RowBox[{"1222", "\[Rule]", "1223"}], ",", 
       RowBox[{"1222", "\[Rule]", "1219"}], ",", 
       RowBox[{"574", "\[Rule]", "559"}], ",", 
       RowBox[{"574", "\[Rule]", "587"}], ",", 
       RowBox[{"574", "\[Rule]", "575"}], ",", 
       RowBox[{"574", "\[Rule]", "571"}], ",", 
       RowBox[{"250", "\[Rule]", "235"}], ",", 
       RowBox[{"250", "\[Rule]", "263"}], ",", 
       RowBox[{"250", "\[Rule]", "251"}], ",", 
       RowBox[{"250", "\[Rule]", "247"}], ",", 
       RowBox[{"1438", "\[Rule]", "1423"}], ",", 
       RowBox[{"1438", "\[Rule]", "1451"}], ",", 
       RowBox[{"1438", "\[Rule]", "1439"}], ",", 
       RowBox[{"1438", "\[Rule]", "1435"}], ",", 
       RowBox[{"1114", "\[Rule]", "1099"}], ",", 
       RowBox[{"1114", "\[Rule]", "1127"}], ",", 
       RowBox[{"1114", "\[Rule]", "1115"}], ",", 
       RowBox[{"1114", "\[Rule]", "1111"}], ",", 
       RowBox[{"2518", "\[Rule]", "2503"}], ",", 
       RowBox[{"2518", "\[Rule]", "2531"}], ",", 
       RowBox[{"2518", "\[Rule]", "2519"}], ",", 
       RowBox[{"2518", "\[Rule]", "2515"}], ",", 
       RowBox[{"2410", "\[Rule]", "2395"}], ",", 
       RowBox[{"2410", "\[Rule]", "2423"}], ",", 
       RowBox[{"2410", "\[Rule]", "2411"}], ",", 
       RowBox[{"2410", "\[Rule]", "2407"}], ",", 
       RowBox[{"2086", "\[Rule]", "2071"}], ",", 
       RowBox[{"2086", "\[Rule]", "2099"}], ",", 
       RowBox[{"2086", "\[Rule]", "2087"}], ",", 
       RowBox[{"2086", "\[Rule]", "2083"}], ",", 
       RowBox[{"2302", "\[Rule]", "2287"}], ",", 
       RowBox[{"2302", "\[Rule]", "2315"}], ",", 
       RowBox[{"2302", "\[Rule]", "2303"}], ",", 
       RowBox[{"2302", "\[Rule]", "2299"}], ",", 
       RowBox[{"1978", "\[Rule]", "1963"}], ",", 
       RowBox[{"1978", "\[Rule]", "1991"}], ",", 
       RowBox[{"1978", "\[Rule]", "1979"}], ",", 
       RowBox[{"1978", "\[Rule]", "1975"}], ",", 
       RowBox[{"466", "\[Rule]", "451"}], ",", 
       RowBox[{"466", "\[Rule]", "479"}], ",", 
       RowBox[{"466", "\[Rule]", "467"}], ",", 
       RowBox[{"466", "\[Rule]", "463"}], ",", 
       RowBox[{"142", "\[Rule]", "127"}], ",", 
       RowBox[{"142", "\[Rule]", "155"}], ",", 
       RowBox[{"142", "\[Rule]", "143"}], ",", 
       RowBox[{"142", "\[Rule]", "139"}], ",", 
       RowBox[{"1330", "\[Rule]", "1315"}], ",", 
       RowBox[{"1330", "\[Rule]", "1343"}], ",", 
       RowBox[{"1330", "\[Rule]", "1331"}], ",", 
       RowBox[{"1330", "\[Rule]", "1327"}], ",", 
       RowBox[{"1006", "\[Rule]", "991"}], ",", 
       RowBox[{"1006", "\[Rule]", "1019"}], ",", 
       RowBox[{"1006", "\[Rule]", "1007"}], ",", 
       RowBox[{"1006", "\[Rule]", "1003"}], ",", 
       RowBox[{"2194", "\[Rule]", "2179"}], ",", 
       RowBox[{"2194", "\[Rule]", "2207"}], ",", 
       RowBox[{"2194", "\[Rule]", "2195"}], ",", 
       RowBox[{"2194", "\[Rule]", "2191"}], ",", 
       RowBox[{"1870", "\[Rule]", "1855"}], ",", 
       RowBox[{"1870", "\[Rule]", "1883"}], ",", 
       RowBox[{"1870", "\[Rule]", "1871"}], ",", 
       RowBox[{"1870", "\[Rule]", "1867"}], ",", 
       RowBox[{"2950", "\[Rule]", "2935"}], ",", 
       RowBox[{"2950", "\[Rule]", "2963"}], ",", 
       RowBox[{"2950", "\[Rule]", "2951"}], ",", 
       RowBox[{"2950", "\[Rule]", "2947"}], ",", 
       RowBox[{"2842", "\[Rule]", "2827"}], ",", 
       RowBox[{"2842", "\[Rule]", "2855"}], ",", 
       RowBox[{"2842", "\[Rule]", "2843"}], ",", 
       RowBox[{"2842", "\[Rule]", "2839"}], ",", 
       RowBox[{"2734", "\[Rule]", "2719"}], ",", 
       RowBox[{"2734", "\[Rule]", "2747"}], ",", 
       RowBox[{"2734", "\[Rule]", "2735"}], ",", 
       RowBox[{"2734", "\[Rule]", "2731"}], ",", 
       RowBox[{"34", "\[Rule]", "19"}], ",", 
       RowBox[{"34", "\[Rule]", "47"}], ",", 
       RowBox[{"34", "\[Rule]", "35"}], ",", 
       RowBox[{"34", "\[Rule]", "31"}], ",", 
       RowBox[{"898", "\[Rule]", "883"}], ",", 
       RowBox[{"898", "\[Rule]", "911"}], ",", 
       RowBox[{"898", "\[Rule]", "899"}], ",", 
       RowBox[{"898", "\[Rule]", "895"}], ",", 
       RowBox[{"1762", "\[Rule]", "1747"}], ",", 
       RowBox[{"1762", "\[Rule]", "1775"}], ",", 
       RowBox[{"1762", "\[Rule]", "1763"}], ",", 
       RowBox[{"1762", "\[Rule]", "1759"}], ",", 
       RowBox[{"2626", "\[Rule]", "2611"}], ",", 
       RowBox[{"2626", "\[Rule]", "2639"}], ",", 
       RowBox[{"2626", "\[Rule]", "2627"}], ",", 
       RowBox[{"2626", "\[Rule]", "2623"}], ",", 
       RowBox[{"761", "\[Rule]", "330"}], ",", 
       RowBox[{"761", "\[Rule]", "330"}], ",", 
       RowBox[{"761", "\[Rule]", "1194"}], ",", 
       RowBox[{"761", "\[Rule]", "1194"}], ",", 
       RowBox[{"761", "\[Rule]", "762"}], ",", 
       RowBox[{"653", "\[Rule]", "330"}], ",", 
       RowBox[{"653", "\[Rule]", "330"}], ",", 
       RowBox[{"653", "\[Rule]", "1194"}], ",", 
       RowBox[{"653", "\[Rule]", "1194"}], ",", 
       RowBox[{"653", "\[Rule]", "222"}], ",", 
       RowBox[{"653", "\[Rule]", "222"}], ",", 
       RowBox[{"653", "\[Rule]", "1086"}], ",", 
       RowBox[{"653", "\[Rule]", "1086"}], ",", 
       RowBox[{"653", "\[Rule]", "654"}], ",", 
       RowBox[{"329", "\[Rule]", "762"}], ",", 
       RowBox[{"329", "\[Rule]", "762"}], ",", 
       RowBox[{"329", "\[Rule]", "654"}], ",", 
       RowBox[{"329", "\[Rule]", "654"}], ",", 
       RowBox[{"329", "\[Rule]", "330"}], ",", 
       RowBox[{"1625", "\[Rule]", "1194"}], ",", 
       RowBox[{"1625", "\[Rule]", "1194"}], ",", 
       RowBox[{"1625", "\[Rule]", "2058"}], ",", 
       RowBox[{"1625", "\[Rule]", "2058"}], ",", 
       RowBox[{"1625", "\[Rule]", "1626"}], ",", 
       RowBox[{"1517", "\[Rule]", "1194"}], ",", 
       RowBox[{"1517", "\[Rule]", "1194"}], ",", 
       RowBox[{"1517", "\[Rule]", "2058"}], ",", 
       RowBox[{"1517", "\[Rule]", "2058"}], ",", 
       RowBox[{"1517", "\[Rule]", "1086"}], ",", 
       RowBox[{"1517", "\[Rule]", "1086"}], ",", 
       RowBox[{"1517", "\[Rule]", "1950"}], ",", 
       RowBox[{"1517", "\[Rule]", "1950"}], ",", 
       RowBox[{"1517", "\[Rule]", "1518"}], ",", 
       RowBox[{"1193", "\[Rule]", "762"}], ",", 
       RowBox[{"1193", "\[Rule]", "762"}], ",", 
       RowBox[{"1193", "\[Rule]", "1626"}], ",", 
       RowBox[{"1193", "\[Rule]", "1626"}], ",", 
       RowBox[{"1193", "\[Rule]", "654"}], ",", 
       RowBox[{"1193", "\[Rule]", "654"}], ",", 
       RowBox[{"1193", "\[Rule]", "1518"}], ",", 
       RowBox[{"1193", "\[Rule]", "1518"}], ",", 
       RowBox[{"1193", "\[Rule]", "1194"}], ",", 
       RowBox[{"545", "\[Rule]", "222"}], ",", 
       RowBox[{"545", "\[Rule]", "222"}], ",", 
       RowBox[{"545", "\[Rule]", "1086"}], ",", 
       RowBox[{"545", "\[Rule]", "1086"}], ",", 
       RowBox[{"545", "\[Rule]", "114"}], ",", 
       RowBox[{"545", "\[Rule]", "978"}], ",", 
       RowBox[{"545", "\[Rule]", "546"}], ",", 
       RowBox[{"221", "\[Rule]", "654"}], ",", 
       RowBox[{"221", "\[Rule]", "654"}], ",", 
       RowBox[{"221", "\[Rule]", "546"}], ",", 
       RowBox[{"221", "\[Rule]", "546"}], ",", 
       RowBox[{"221", "\[Rule]", "222"}], ",", 
       RowBox[{"1409", "\[Rule]", "1086"}], ",", 
       RowBox[{"1409", "\[Rule]", "1086"}], ",", 
       RowBox[{"1409", "\[Rule]", "1950"}], ",", 
       RowBox[{"1409", "\[Rule]", "1950"}], ",", 
       RowBox[{"1409", "\[Rule]", "978"}], ",", 
       RowBox[{"1409", "\[Rule]", "978"}], ",", 
       RowBox[{"1409", "\[Rule]", "1842"}], ",", 
       RowBox[{"1409", "\[Rule]", "1842"}], ",", 
       RowBox[{"1409", "\[Rule]", "1410"}], ",", 
       RowBox[{"1085", "\[Rule]", "654"}], ",", 
       RowBox[{"1085", "\[Rule]", "654"}], ",", 
       RowBox[{"1085", "\[Rule]", "1518"}], ",", 
       RowBox[{"1085", "\[Rule]", "1518"}], ",", 
       RowBox[{"1085", "\[Rule]", "546"}], ",", 
       RowBox[{"1085", "\[Rule]", "546"}], ",", 
       RowBox[{"1085", "\[Rule]", "1410"}], ",", 
       RowBox[{"1085", "\[Rule]", "1410"}], ",", 
       RowBox[{"1085", "\[Rule]", "1086"}], ",", 
       RowBox[{"2489", "\[Rule]", "2058"}], ",", 
       RowBox[{"2489", "\[Rule]", "2058"}], ",", 
       RowBox[{"2489", "\[Rule]", "2922"}], ",", 
       RowBox[{"2489", "\[Rule]", "2922"}], ",", 
       RowBox[{"2489", "\[Rule]", "2490"}], ",", 
       RowBox[{"2381", "\[Rule]", "2058"}], ",", 
       RowBox[{"2381", "\[Rule]", "2058"}], ",", 
       RowBox[{"2381", "\[Rule]", "2922"}], ",", 
       RowBox[{"2381", "\[Rule]", "2922"}], ",", 
       RowBox[{"2381", "\[Rule]", "1950"}], ",", 
       RowBox[{"2381", "\[Rule]", "1950"}], ",", 
       RowBox[{"2381", "\[Rule]", "2814"}], ",", 
       RowBox[{"2381", "\[Rule]", "2814"}], ",", 
       RowBox[{"2381", "\[Rule]", "2382"}], ",", 
       RowBox[{"2057", "\[Rule]", "1626"}], ",", 
       RowBox[{"2057", "\[Rule]", "1626"}], ",", 
       RowBox[{"2057", "\[Rule]", "2490"}], ",", 
       RowBox[{"2057", "\[Rule]", "2490"}], ",", 
       RowBox[{"2057", "\[Rule]", "1518"}], ",", 
       RowBox[{"2057", "\[Rule]", "1518"}], ",", 
       RowBox[{"2057", "\[Rule]", "2382"}], ",", 
       RowBox[{"2057", "\[Rule]", "2382"}], ",", 
       RowBox[{"2057", "\[Rule]", "2058"}], ",", 
       RowBox[{"2273", "\[Rule]", "1950"}], ",", 
       RowBox[{"2273", "\[Rule]", "1950"}], ",", 
       RowBox[{"2273", "\[Rule]", "2814"}], ",", 
       RowBox[{"2273", "\[Rule]", "2814"}], ",", 
       RowBox[{"2273", "\[Rule]", "1842"}], ",", 
       RowBox[{"2273", "\[Rule]", "1842"}], ",", 
       RowBox[{"2273", "\[Rule]", "2706"}], ",", 
       RowBox[{"2273", "\[Rule]", "2706"}], ",", 
       RowBox[{"2273", "\[Rule]", "2274"}], ",", 
       RowBox[{"1949", "\[Rule]", "1518"}], ",", 
       RowBox[{"1949", "\[Rule]", "1518"}], ",", 
       RowBox[{"1949", "\[Rule]", "2382"}], ",", 
       RowBox[{"1949", "\[Rule]", "2382"}], ",", 
       RowBox[{"1949", "\[Rule]", "1410"}], ",", 
       RowBox[{"1949", "\[Rule]", "1410"}], ",", 
       RowBox[{"1949", "\[Rule]", "2274"}], ",", 
       RowBox[{"1949", "\[Rule]", "2274"}], ",", 
       RowBox[{"1949", "\[Rule]", "1950"}], ",", 
       RowBox[{"437", "\[Rule]", "114"}], ",", 
       RowBox[{"437", "\[Rule]", "978"}], ",", 
       RowBox[{"437", "\[Rule]", "6"}], ",", 
       RowBox[{"437", "\[Rule]", "6"}], ",", 
       RowBox[{"437", "\[Rule]", "870"}], ",", 
       RowBox[{"437", "\[Rule]", "870"}], ",", 
       RowBox[{"437", "\[Rule]", "438"}], ",", 
       RowBox[{"113", "\[Rule]", "546"}], ",", 
       RowBox[{"113", "\[Rule]", "438"}], ",", 
       RowBox[{"113", "\[Rule]", "114"}], ",", 
       RowBox[{"1301", "\[Rule]", "978"}], ",", 
       RowBox[{"1301", "\[Rule]", "978"}], ",", 
       RowBox[{"1301", "\[Rule]", "1842"}], ",", 
       RowBox[{"1301", "\[Rule]", "1842"}], ",", 
       RowBox[{"1301", "\[Rule]", "870"}], ",", 
       RowBox[{"1301", "\[Rule]", "1734"}], ",", 
       RowBox[{"1301", "\[Rule]", "1302"}], ",", 
       RowBox[{"977", "\[Rule]", "546"}], ",", 
       RowBox[{"977", "\[Rule]", "1410"}], ",", 
       RowBox[{"977", "\[Rule]", "1410"}], ",", 
       RowBox[{"977", "\[Rule]", "438"}], ",", 
       RowBox[{"977", "\[Rule]", "1302"}], ",", 
       RowBox[{"977", "\[Rule]", "1302"}], ",", 
       RowBox[{"977", "\[Rule]", "978"}], ",", 
       RowBox[{"2165", "\[Rule]", "1842"}], ",", 
       RowBox[{"2165", "\[Rule]", "1842"}], ",", 
       RowBox[{"2165", "\[Rule]", "2706"}], ",", 
       RowBox[{"2165", "\[Rule]", "2706"}], ",", 
       RowBox[{"2165", "\[Rule]", "1734"}], ",", 
       RowBox[{"2165", "\[Rule]", "1734"}], ",", 
       RowBox[{"2165", "\[Rule]", "2598"}], ",", 
       RowBox[{"2165", "\[Rule]", "2598"}], ",", 
       RowBox[{"2165", "\[Rule]", "2166"}], ",", 
       RowBox[{"1841", "\[Rule]", "1410"}], ",", 
       RowBox[{"1841", "\[Rule]", "1410"}], ",", 
       RowBox[{"1841", "\[Rule]", "2274"}], ",", 
       RowBox[{"1841", "\[Rule]", "2274"}], ",", 
       RowBox[{"1841", "\[Rule]", "1302"}], ",", 
       RowBox[{"1841", "\[Rule]", "1302"}], ",", 
       RowBox[{"1841", "\[Rule]", "2166"}], ",", 
       RowBox[{"1841", "\[Rule]", "2166"}], ",", 
       RowBox[{"1841", "\[Rule]", "1842"}], ",", 
       RowBox[{"2921", "\[Rule]", "2490"}], ",", 
       RowBox[{"2921", "\[Rule]", "2490"}], ",", 
       RowBox[{"2921", "\[Rule]", "2382"}], ",", 
       RowBox[{"2921", "\[Rule]", "2382"}], ",", 
       RowBox[{"2921", "\[Rule]", "2922"}], ",", 
       RowBox[{"2813", "\[Rule]", "2382"}], ",", 
       RowBox[{"2813", "\[Rule]", "2382"}], ",", 
       RowBox[{"2813", "\[Rule]", "2274"}], ",", 
       RowBox[{"2813", "\[Rule]", "2274"}], ",", 
       RowBox[{"2813", "\[Rule]", "2814"}], ",", 
       RowBox[{"2705", "\[Rule]", "2274"}], ",", 
       RowBox[{"2705", "\[Rule]", "2274"}], ",", 
       RowBox[{"2705", "\[Rule]", "2166"}], ",", 
       RowBox[{"2705", "\[Rule]", "2166"}], ",", 
       RowBox[{"2705", "\[Rule]", "2706"}], ",", 
       RowBox[{"5", "\[Rule]", "438"}], ",", 
       RowBox[{"5", "\[Rule]", "438"}], ",", 
       RowBox[{"5", "\[Rule]", "6"}], ",", 
       RowBox[{"869", "\[Rule]", "438"}], ",", 
       RowBox[{"869", "\[Rule]", "438"}], ",", 
       RowBox[{"869", "\[Rule]", "1302"}], ",", 
       RowBox[{"869", "\[Rule]", "870"}], ",", 
       RowBox[{"1733", "\[Rule]", "1302"}], ",", 
       RowBox[{"1733", "\[Rule]", "2166"}], ",", 
       RowBox[{"1733", "\[Rule]", "2166"}], ",", 
       RowBox[{"1733", "\[Rule]", "1734"}], ",", 
       RowBox[{"2597", "\[Rule]", "2166"}], ",", 
       RowBox[{"2597", "\[Rule]", "2166"}], ",", 
       RowBox[{"2597", "\[Rule]", "2598"}], ",", 
       RowBox[{"775", "\[Rule]", "344"}], ",", 
       RowBox[{"775", "\[Rule]", "344"}], ",", 
       RowBox[{"775", "\[Rule]", "1208"}], ",", 
       RowBox[{"775", "\[Rule]", "1208"}], ",", 
       RowBox[{"775", "\[Rule]", "776"}], ",", 
       RowBox[{"787", "\[Rule]", "356"}], ",", 
       RowBox[{"787", "\[Rule]", "356"}], ",", 
       RowBox[{"787", "\[Rule]", "1220"}], ",", 
       RowBox[{"787", "\[Rule]", "1220"}], ",", 
       RowBox[{"787", "\[Rule]", "788"}], ",", 
       RowBox[{"667", "\[Rule]", "344"}], ",", 
       RowBox[{"667", "\[Rule]", "344"}], ",", 
       RowBox[{"667", "\[Rule]", "1208"}], ",", 
       RowBox[{"667", "\[Rule]", "1208"}], ",", 
       RowBox[{"667", "\[Rule]", "236"}], ",", 
       RowBox[{"667", "\[Rule]", "236"}], ",", 
       RowBox[{"667", "\[Rule]", "1100"}], ",", 
       RowBox[{"667", "\[Rule]", "1100"}], ",", 
       RowBox[{"667", "\[Rule]", "668"}], ",", 
       RowBox[{"679", "\[Rule]", "356"}], ",", 
       RowBox[{"679", "\[Rule]", "356"}], ",", 
       RowBox[{"679", "\[Rule]", "1220"}], ",", 
       RowBox[{"679", "\[Rule]", "1220"}], ",", 
       RowBox[{"679", "\[Rule]", "248"}], ",", 
       RowBox[{"679", "\[Rule]", "248"}], ",", 
       RowBox[{"679", "\[Rule]", "1112"}], ",", 
       RowBox[{"679", "\[Rule]", "1112"}], ",", 
       RowBox[{"679", "\[Rule]", "680"}], ",", 
       RowBox[{"343", "\[Rule]", "776"}], ",", 
       RowBox[{"343", "\[Rule]", "776"}], ",", 
       RowBox[{"343", "\[Rule]", "668"}], ",", 
       RowBox[{"343", "\[Rule]", "668"}], ",", 
       RowBox[{"343", "\[Rule]", "344"}], ",", 
       RowBox[{"355", "\[Rule]", "788"}], ",", 
       RowBox[{"355", "\[Rule]", "788"}], ",", 
       RowBox[{"355", "\[Rule]", "680"}], ",", 
       RowBox[{"355", "\[Rule]", "680"}], ",", 
       RowBox[{"355", "\[Rule]", "356"}], ",", 
       RowBox[{"1639", "\[Rule]", "1208"}], ",", 
       RowBox[{"1639", "\[Rule]", "1208"}], ",", 
       RowBox[{"1639", "\[Rule]", "2072"}], ",", 
       RowBox[{"1639", "\[Rule]", "2072"}], ",", 
       RowBox[{"1639", "\[Rule]", "1640"}], ",", 
       RowBox[{"1651", "\[Rule]", "1220"}], ",", 
       RowBox[{"1651", "\[Rule]", "1220"}], ",", 
       RowBox[{"1651", "\[Rule]", "2084"}], ",", 
       RowBox[{"1651", "\[Rule]", "2084"}], ",", 
       RowBox[{"1651", "\[Rule]", "1652"}], ",", 
       RowBox[{"1531", "\[Rule]", "1208"}], ",", 
       RowBox[{"1531", "\[Rule]", "1208"}], ",", 
       RowBox[{"1531", "\[Rule]", "2072"}], ",", 
       RowBox[{"1531", "\[Rule]", "2072"}], ",", 
       RowBox[{"1531", "\[Rule]", "1100"}], ",", 
       RowBox[{"1531", "\[Rule]", "1100"}], ",", 
       RowBox[{"1531", "\[Rule]", "1964"}], ",", 
       RowBox[{"1531", "\[Rule]", "1964"}], ",", 
       RowBox[{"1531", "\[Rule]", "1532"}], ",", 
       RowBox[{"1543", "\[Rule]", "1220"}], ",", 
       RowBox[{"1543", "\[Rule]", "1220"}], ",", 
       RowBox[{"1543", "\[Rule]", "2084"}], ",", 
       RowBox[{"1543", "\[Rule]", "2084"}], ",", 
       RowBox[{"1543", "\[Rule]", "1112"}], ",", 
       RowBox[{"1543", "\[Rule]", "1112"}], ",", 
       RowBox[{"1543", "\[Rule]", "1976"}], ",", 
       RowBox[{"1543", "\[Rule]", "1976"}], ",", 
       RowBox[{"1543", "\[Rule]", "1544"}], ",", 
       RowBox[{"1207", "\[Rule]", "776"}], ",", 
       RowBox[{"1207", "\[Rule]", "776"}], ",", 
       RowBox[{"1207", "\[Rule]", "1640"}], ",", 
       RowBox[{"1207", "\[Rule]", "1640"}], ",", 
       RowBox[{"1207", "\[Rule]", "668"}], ",", 
       RowBox[{"1207", "\[Rule]", "668"}], ",", 
       RowBox[{"1207", "\[Rule]", "1532"}], ",", 
       RowBox[{"1207", "\[Rule]", "1532"}], ",", 
       RowBox[{"1207", "\[Rule]", "1208"}], ",", 
       RowBox[{"1219", "\[Rule]", "788"}], ",", 
       RowBox[{"1219", "\[Rule]", "788"}], ",", 
       RowBox[{"1219", "\[Rule]", "1652"}], ",", 
       RowBox[{"1219", "\[Rule]", "1652"}], ",", 
       RowBox[{"1219", "\[Rule]", "680"}], ",", 
       RowBox[{"1219", "\[Rule]", "680"}], ",", 
       RowBox[{"1219", "\[Rule]", "1544"}], ",", 
       RowBox[{"1219", "\[Rule]", "1544"}], ",", 
       RowBox[{"1219", "\[Rule]", "1220"}], ",", 
       RowBox[{"559", "\[Rule]", "236"}], ",", 
       RowBox[{"559", "\[Rule]", "236"}], ",", 
       RowBox[{"559", "\[Rule]", "1100"}], ",", 
       RowBox[{"559", "\[Rule]", "1100"}], ",", 
       RowBox[{"559", "\[Rule]", "128"}], ",", 
       RowBox[{"559", "\[Rule]", "992"}], ",", 
       RowBox[{"559", "\[Rule]", "560"}], ",", 
       RowBox[{"571", "\[Rule]", "248"}], ",", 
       RowBox[{"571", "\[Rule]", "248"}], ",", 
       RowBox[{"571", "\[Rule]", "1112"}], ",", 
       RowBox[{"571", "\[Rule]", "1112"}], ",", 
       RowBox[{"571", "\[Rule]", "140"}], ",", 
       RowBox[{"571", "\[Rule]", "1004"}], ",", 
       RowBox[{"571", "\[Rule]", "572"}], ",", 
       RowBox[{"235", "\[Rule]", "668"}], ",", 
       RowBox[{"235", "\[Rule]", "668"}], ",", 
       RowBox[{"235", "\[Rule]", "560"}], ",", 
       RowBox[{"235", "\[Rule]", "560"}], ",", 
       RowBox[{"235", "\[Rule]", "236"}], ",", 
       RowBox[{"247", "\[Rule]", "680"}], ",", 
       RowBox[{"247", "\[Rule]", "680"}], ",", 
       RowBox[{"247", "\[Rule]", "572"}], ",", 
       RowBox[{"247", "\[Rule]", "572"}], ",", 
       RowBox[{"247", "\[Rule]", "248"}], ",", 
       RowBox[{"1423", "\[Rule]", "1100"}], ",", 
       RowBox[{"1423", "\[Rule]", "1100"}], ",", 
       RowBox[{"1423", "\[Rule]", "1964"}], ",", 
       RowBox[{"1423", "\[Rule]", "1964"}], ",", 
       RowBox[{"1423", "\[Rule]", "992"}], ",", 
       RowBox[{"1423", "\[Rule]", "992"}], ",", 
       RowBox[{"1423", "\[Rule]", "1856"}], ",", 
       RowBox[{"1423", "\[Rule]", "1856"}], ",", 
       RowBox[{"1423", "\[Rule]", "1424"}], ",", 
       RowBox[{"1435", "\[Rule]", "1112"}], ",", 
       RowBox[{"1435", "\[Rule]", "1112"}], ",", 
       RowBox[{"1435", "\[Rule]", "1976"}], ",", 
       RowBox[{"1435", "\[Rule]", "1976"}], ",", 
       RowBox[{"1435", "\[Rule]", "1004"}], ",", 
       RowBox[{"1435", "\[Rule]", "1004"}], ",", 
       RowBox[{"1435", "\[Rule]", "1868"}], ",", 
       RowBox[{"1435", "\[Rule]", "1868"}], ",", 
       RowBox[{"1435", "\[Rule]", "1436"}], ",", 
       RowBox[{"1099", "\[Rule]", "668"}], ",", 
       RowBox[{"1099", "\[Rule]", "668"}], ",", 
       RowBox[{"1099", "\[Rule]", "1532"}], ",", 
       RowBox[{"1099", "\[Rule]", "1532"}], ",", 
       RowBox[{"1099", "\[Rule]", "560"}], ",", 
       RowBox[{"1099", "\[Rule]", "560"}], ",", 
       RowBox[{"1099", "\[Rule]", "1424"}], ",", 
       RowBox[{"1099", "\[Rule]", "1424"}], ",", 
       RowBox[{"1099", "\[Rule]", "1100"}], ",", 
       RowBox[{"1111", "\[Rule]", "680"}], ",", 
       RowBox[{"1111", "\[Rule]", "680"}], ",", 
       RowBox[{"1111", "\[Rule]", "1544"}], ",", 
       RowBox[{"1111", "\[Rule]", "1544"}], ",", 
       RowBox[{"1111", "\[Rule]", "572"}], ",", 
       RowBox[{"1111", "\[Rule]", "572"}], ",", 
       RowBox[{"1111", "\[Rule]", "1436"}], ",", 
       RowBox[{"1111", "\[Rule]", "1436"}], ",", 
       RowBox[{"1111", "\[Rule]", "1112"}], ",", 
       RowBox[{"2503", "\[Rule]", "2072"}], ",", 
       RowBox[{"2503", "\[Rule]", "2072"}], ",", 
       RowBox[{"2503", "\[Rule]", "2936"}], ",", 
       RowBox[{"2503", "\[Rule]", "2936"}], ",", 
       RowBox[{"2503", "\[Rule]", "2504"}], ",", 
       RowBox[{"2515", "\[Rule]", "2084"}], ",", 
       RowBox[{"2515", "\[Rule]", "2084"}], ",", 
       RowBox[{"2515", "\[Rule]", "2948"}], ",", 
       RowBox[{"2515", "\[Rule]", "2948"}], ",", 
       RowBox[{"2515", "\[Rule]", "2516"}], ",", 
       RowBox[{"2395", "\[Rule]", "2072"}], ",", 
       RowBox[{"2395", "\[Rule]", "2072"}], ",", 
       RowBox[{"2395", "\[Rule]", "2936"}], ",", 
       RowBox[{"2395", "\[Rule]", "2936"}], ",", 
       RowBox[{"2395", "\[Rule]", "1964"}], ",", 
       RowBox[{"2395", "\[Rule]", "1964"}], ",", 
       RowBox[{"2395", "\[Rule]", "2828"}], ",", 
       RowBox[{"2395", "\[Rule]", "2828"}], ",", 
       RowBox[{"2395", "\[Rule]", "2396"}], ",", 
       RowBox[{"2407", "\[Rule]", "2084"}], ",", 
       RowBox[{"2407", "\[Rule]", "2084"}], ",", 
       RowBox[{"2407", "\[Rule]", "2948"}], ",", 
       RowBox[{"2407", "\[Rule]", "2948"}], ",", 
       RowBox[{"2407", "\[Rule]", "1976"}], ",", 
       RowBox[{"2407", "\[Rule]", "1976"}], ",", 
       RowBox[{"2407", "\[Rule]", "2840"}], ",", 
       RowBox[{"2407", "\[Rule]", "2840"}], ",", 
       RowBox[{"2407", "\[Rule]", "2408"}], ",", 
       RowBox[{"2071", "\[Rule]", "1640"}], ",", 
       RowBox[{"2071", "\[Rule]", "1640"}], ",", 
       RowBox[{"2071", "\[Rule]", "2504"}], ",", 
       RowBox[{"2071", "\[Rule]", "2504"}], ",", 
       RowBox[{"2071", "\[Rule]", "1532"}], ",", 
       RowBox[{"2071", "\[Rule]", "1532"}], ",", 
       RowBox[{"2071", "\[Rule]", "2396"}], ",", 
       RowBox[{"2071", "\[Rule]", "2396"}], ",", 
       RowBox[{"2071", "\[Rule]", "2072"}], ",", 
       RowBox[{"2083", "\[Rule]", "1652"}], ",", 
       RowBox[{"2083", "\[Rule]", "1652"}], ",", 
       RowBox[{"2083", "\[Rule]", "2516"}], ",", 
       RowBox[{"2083", "\[Rule]", "2516"}], ",", 
       RowBox[{"2083", "\[Rule]", "1544"}], ",", 
       RowBox[{"2083", "\[Rule]", "1544"}], ",", 
       RowBox[{"2083", "\[Rule]", "2408"}], ",", 
       RowBox[{"2083", "\[Rule]", "2408"}], ",", 
       RowBox[{"2083", "\[Rule]", "2084"}], ",", 
       RowBox[{"2287", "\[Rule]", "1964"}], ",", 
       RowBox[{"2287", "\[Rule]", "1964"}], ",", 
       RowBox[{"2287", "\[Rule]", "2828"}], ",", 
       RowBox[{"2287", "\[Rule]", "2828"}], ",", 
       RowBox[{"2287", "\[Rule]", "1856"}], ",", 
       RowBox[{"2287", "\[Rule]", "1856"}], ",", 
       RowBox[{"2287", "\[Rule]", "2720"}], ",", 
       RowBox[{"2287", "\[Rule]", "2720"}], ",", 
       RowBox[{"2287", "\[Rule]", "2288"}], ",", 
       RowBox[{"2299", "\[Rule]", "1976"}], ",", 
       RowBox[{"2299", "\[Rule]", "1976"}], ",", 
       RowBox[{"2299", "\[Rule]", "2840"}], ",", 
       RowBox[{"2299", "\[Rule]", "2840"}], ",", 
       RowBox[{"2299", "\[Rule]", "1868"}], ",", 
       RowBox[{"2299", "\[Rule]", "1868"}], ",", 
       RowBox[{"2299", "\[Rule]", "2732"}], ",", 
       RowBox[{"2299", "\[Rule]", "2732"}], ",", 
       RowBox[{"2299", "\[Rule]", "2300"}], ",", 
       RowBox[{"1963", "\[Rule]", "1532"}], ",", 
       RowBox[{"1963", "\[Rule]", "1532"}], ",", 
       RowBox[{"1963", "\[Rule]", "2396"}], ",", 
       RowBox[{"1963", "\[Rule]", "2396"}], ",", 
       RowBox[{"1963", "\[Rule]", "1424"}], ",", 
       RowBox[{"1963", "\[Rule]", "1424"}], ",", 
       RowBox[{"1963", "\[Rule]", "2288"}], ",", 
       RowBox[{"1963", "\[Rule]", "2288"}], ",", 
       RowBox[{"1963", "\[Rule]", "1964"}], ",", 
       RowBox[{"1975", "\[Rule]", "1544"}], ",", 
       RowBox[{"1975", "\[Rule]", "1544"}], ",", 
       RowBox[{"1975", "\[Rule]", "2408"}], ",", 
       RowBox[{"1975", "\[Rule]", "2408"}], ",", 
       RowBox[{"1975", "\[Rule]", "1436"}], ",", 
       RowBox[{"1975", "\[Rule]", "1436"}], ",", 
       RowBox[{"1975", "\[Rule]", "2300"}], ",", 
       RowBox[{"1975", "\[Rule]", "2300"}], ",", 
       RowBox[{"1975", "\[Rule]", "1976"}], ",", 
       RowBox[{"451", "\[Rule]", "128"}], ",", 
       RowBox[{"451", "\[Rule]", "992"}], ",", 
       RowBox[{"451", "\[Rule]", "20"}], ",", 
       RowBox[{"451", "\[Rule]", "20"}], ",", 
       RowBox[{"451", "\[Rule]", "884"}], ",", 
       RowBox[{"451", "\[Rule]", "884"}], ",", 
       RowBox[{"451", "\[Rule]", "452"}], ",", 
       RowBox[{"463", "\[Rule]", "140"}], ",", 
       RowBox[{"463", "\[Rule]", "1004"}], ",", 
       RowBox[{"463", "\[Rule]", "32"}], ",", 
       RowBox[{"463", "\[Rule]", "32"}], ",", 
       RowBox[{"463", "\[Rule]", "896"}], ",", 
       RowBox[{"463", "\[Rule]", "896"}], ",", 
       RowBox[{"463", "\[Rule]", "464"}], ",", 
       RowBox[{"127", "\[Rule]", "560"}], ",", 
       RowBox[{"127", "\[Rule]", "452"}], ",", 
       RowBox[{"127", "\[Rule]", "128"}], ",", 
       RowBox[{"139", "\[Rule]", "572"}], ",", 
       RowBox[{"139", "\[Rule]", "464"}], ",", 
       RowBox[{"139", "\[Rule]", "140"}], ",", 
       RowBox[{"1315", "\[Rule]", "992"}], ",", 
       RowBox[{"1315", "\[Rule]", "992"}], ",", 
       RowBox[{"1315", "\[Rule]", "1856"}], ",", 
       RowBox[{"1315", "\[Rule]", "1856"}], ",", 
       RowBox[{"1315", "\[Rule]", "884"}], ",", 
       RowBox[{"1315", "\[Rule]", "1748"}], ",", 
       RowBox[{"1315", "\[Rule]", "1316"}], ",", 
       RowBox[{"1327", "\[Rule]", "1004"}], ",", 
       RowBox[{"1327", "\[Rule]", "1004"}], ",", 
       RowBox[{"1327", "\[Rule]", "1868"}], ",", 
       RowBox[{"1327", "\[Rule]", "1868"}], ",", 
       RowBox[{"1327", "\[Rule]", "896"}], ",", 
       RowBox[{"1327", "\[Rule]", "1760"}], ",", 
       RowBox[{"1327", "\[Rule]", "1328"}], ",", 
       RowBox[{"991", "\[Rule]", "560"}], ",", 
       RowBox[{"991", "\[Rule]", "1424"}], ",", 
       RowBox[{"991", "\[Rule]", "1424"}], ",", 
       RowBox[{"991", "\[Rule]", "452"}], ",", 
       RowBox[{"991", "\[Rule]", "1316"}], ",", 
       RowBox[{"991", "\[Rule]", "1316"}], ",", 
       RowBox[{"991", "\[Rule]", "992"}], ",", 
       RowBox[{"1003", "\[Rule]", "572"}], ",", 
       RowBox[{"1003", "\[Rule]", "1436"}], ",", 
       RowBox[{"1003", "\[Rule]", "1436"}], ",", 
       RowBox[{"1003", "\[Rule]", "464"}], ",", 
       RowBox[{"1003", "\[Rule]", "1328"}], ",", 
       RowBox[{"1003", "\[Rule]", "1328"}], ",", 
       RowBox[{"1003", "\[Rule]", "1004"}], ",", 
       RowBox[{"2179", "\[Rule]", "1856"}], ",", 
       RowBox[{"2179", "\[Rule]", "1856"}], ",", 
       RowBox[{"2179", "\[Rule]", "2720"}], ",", 
       RowBox[{"2179", "\[Rule]", "2720"}], ",", 
       RowBox[{"2179", "\[Rule]", "1748"}], ",", 
       RowBox[{"2179", "\[Rule]", "1748"}], ",", 
       RowBox[{"2179", "\[Rule]", "2612"}], ",", 
       RowBox[{"2179", "\[Rule]", "2612"}], ",", 
       RowBox[{"2179", "\[Rule]", "2180"}], ",", 
       RowBox[{"2191", "\[Rule]", "1868"}], ",", 
       RowBox[{"2191", "\[Rule]", "1868"}], ",", 
       RowBox[{"2191", "\[Rule]", "2732"}], ",", 
       RowBox[{"2191", "\[Rule]", "2732"}], ",", 
       RowBox[{"2191", "\[Rule]", "1760"}], ",", 
       RowBox[{"2191", "\[Rule]", "1760"}], ",", 
       RowBox[{"2191", "\[Rule]", "2624"}], ",", 
       RowBox[{"2191", "\[Rule]", "2624"}], ",", 
       RowBox[{"2191", "\[Rule]", "2192"}], ",", 
       RowBox[{"1855", "\[Rule]", "1424"}], ",", 
       RowBox[{"1855", "\[Rule]", "1424"}], ",", 
       RowBox[{"1855", "\[Rule]", "2288"}], ",", 
       RowBox[{"1855", "\[Rule]", "2288"}], ",", 
       RowBox[{"1855", "\[Rule]", "1316"}], ",", 
       RowBox[{"1855", "\[Rule]", "1316"}], ",", 
       RowBox[{"1855", "\[Rule]", "2180"}], ",", 
       RowBox[{"1855", "\[Rule]", "2180"}], ",", 
       RowBox[{"1855", "\[Rule]", "1856"}], ",", 
       RowBox[{"1867", "\[Rule]", "1436"}], ",", 
       RowBox[{"1867", "\[Rule]", "1436"}], ",", 
       RowBox[{"1867", "\[Rule]", "2300"}], ",", 
       RowBox[{"1867", "\[Rule]", "2300"}], ",", 
       RowBox[{"1867", "\[Rule]", "1328"}], ",", 
       RowBox[{"1867", "\[Rule]", "1328"}], ",", 
       RowBox[{"1867", "\[Rule]", "2192"}], ",", 
       RowBox[{"1867", "\[Rule]", "2192"}], ",", 
       RowBox[{"1867", "\[Rule]", "1868"}], ",", 
       RowBox[{"2935", "\[Rule]", "2504"}], ",", 
       RowBox[{"2935", "\[Rule]", "2504"}], ",", 
       RowBox[{"2935", "\[Rule]", "2396"}], ",", 
       RowBox[{"2935", "\[Rule]", "2396"}], ",", 
       RowBox[{"2935", "\[Rule]", "2936"}], ",", 
       RowBox[{"2947", "\[Rule]", "2516"}], ",", 
       RowBox[{"2947", "\[Rule]", "2516"}], ",", 
       RowBox[{"2947", "\[Rule]", "2408"}], ",", 
       RowBox[{"2947", "\[Rule]", "2408"}], ",", 
       RowBox[{"2947", "\[Rule]", "2948"}], ",", 
       RowBox[{"2827", "\[Rule]", "2396"}], ",", 
       RowBox[{"2827", "\[Rule]", "2396"}], ",", 
       RowBox[{"2827", "\[Rule]", "2288"}], ",", 
       RowBox[{"2827", "\[Rule]", "2288"}], ",", 
       RowBox[{"2827", "\[Rule]", "2828"}], ",", 
       RowBox[{"2839", "\[Rule]", "2408"}], ",", 
       RowBox[{"2839", "\[Rule]", "2408"}], ",", 
       RowBox[{"2839", "\[Rule]", "2300"}], ",", 
       RowBox[{"2839", "\[Rule]", "2300"}], ",", 
       RowBox[{"2839", "\[Rule]", "2840"}], ",", 
       RowBox[{"2719", "\[Rule]", "2288"}], ",", 
       RowBox[{"2719", "\[Rule]", "2288"}], ",", 
       RowBox[{"2719", "\[Rule]", "2180"}], ",", 
       RowBox[{"2719", "\[Rule]", "2180"}], ",", 
       RowBox[{"2719", "\[Rule]", "2720"}], ",", 
       RowBox[{"2731", "\[Rule]", "2300"}], ",", 
       RowBox[{"2731", "\[Rule]", "2300"}], ",", 
       RowBox[{"2731", "\[Rule]", "2192"}], ",", 
       RowBox[{"2731", "\[Rule]", "2192"}], ",", 
       RowBox[{"2731", "\[Rule]", "2732"}], ",", 
       RowBox[{"19", "\[Rule]", "452"}], ",", 
       RowBox[{"19", "\[Rule]", "452"}], ",", 
       RowBox[{"19", "\[Rule]", "20"}], ",", 
       RowBox[{"31", "\[Rule]", "464"}], ",", 
       RowBox[{"31", "\[Rule]", "464"}], ",", 
       RowBox[{"31", "\[Rule]", "32"}], ",", 
       RowBox[{"883", "\[Rule]", "452"}], ",", 
       RowBox[{"883", "\[Rule]", "452"}], ",", 
       RowBox[{"883", "\[Rule]", "1316"}], ",", 
       RowBox[{"883", "\[Rule]", "884"}], ",", 
       RowBox[{"895", "\[Rule]", "464"}], ",", 
       RowBox[{"895", "\[Rule]", "464"}], ",", 
       RowBox[{"895", "\[Rule]", "1328"}], ",", 
       RowBox[{"895", "\[Rule]", "896"}], ",", 
       RowBox[{"1747", "\[Rule]", "1316"}], ",", 
       RowBox[{"1747", "\[Rule]", "2180"}], ",", 
       RowBox[{"1747", "\[Rule]", "2180"}], ",", 
       RowBox[{"1747", "\[Rule]", "1748"}], ",", 
       RowBox[{"1759", "\[Rule]", "1328"}], ",", 
       RowBox[{"1759", "\[Rule]", "2192"}], ",", 
       RowBox[{"1759", "\[Rule]", "2192"}], ",", 
       RowBox[{"1759", "\[Rule]", "1760"}], ",", 
       RowBox[{"2611", "\[Rule]", "2180"}], ",", 
       RowBox[{"2611", "\[Rule]", "2180"}], ",", 
       RowBox[{"2611", "\[Rule]", "2612"}], ",", 
       RowBox[{"2623", "\[Rule]", "2192"}], ",", 
       RowBox[{"2623", "\[Rule]", "2192"}], ",", 
       RowBox[{"2623", "\[Rule]", "2624"}], ",", 
       RowBox[{"330", "\[Rule]", "331"}], ",", 
       RowBox[{"330", "\[Rule]", "327"}], ",", 
       RowBox[{"1194", "\[Rule]", "1195"}], ",", 
       RowBox[{"1194", "\[Rule]", "1191"}], ",", 
       RowBox[{"762", "\[Rule]", "763"}], ",", 
       RowBox[{"762", "\[Rule]", "759"}], ",", 
       RowBox[{"222", "\[Rule]", "223"}], ",", 
       RowBox[{"222", "\[Rule]", "219"}], ",", 
       RowBox[{"1086", "\[Rule]", "1087"}], ",", 
       RowBox[{"1086", "\[Rule]", "1083"}], ",", 
       RowBox[{"654", "\[Rule]", "655"}], ",", 
       RowBox[{"654", "\[Rule]", "651"}], ",", 
       RowBox[{"2058", "\[Rule]", "2059"}], ",", 
       RowBox[{"2058", "\[Rule]", "2055"}], ",", 
       RowBox[{"1626", "\[Rule]", "1627"}], ",", 
       RowBox[{"1626", "\[Rule]", "1623"}], ",", 
       RowBox[{"1950", "\[Rule]", "1951"}], ",", 
       RowBox[{"1950", "\[Rule]", "1947"}], ",", 
       RowBox[{"1518", "\[Rule]", "1519"}], ",", 
       RowBox[{"1518", "\[Rule]", "1515"}], ",", 
       RowBox[{"114", "\[Rule]", "115"}], ",", 
       RowBox[{"114", "\[Rule]", "111"}], ",", 
       RowBox[{"978", "\[Rule]", "979"}], ",", 
       RowBox[{"978", "\[Rule]", "975"}], ",", 
       RowBox[{"546", "\[Rule]", "547"}], ",", 
       RowBox[{"546", "\[Rule]", "543"}], ",", 
       RowBox[{"1842", "\[Rule]", "1843"}], ",", 
       RowBox[{"1842", "\[Rule]", "1839"}], ",", 
       RowBox[{"1410", "\[Rule]", "1411"}], ",", 
       RowBox[{"1410", "\[Rule]", "1407"}], ",", 
       RowBox[{"2922", "\[Rule]", "2923"}], ",", 
       RowBox[{"2922", "\[Rule]", "2919"}], ",", 
       RowBox[{"2490", "\[Rule]", "2491"}], ",", 
       RowBox[{"2490", "\[Rule]", "2487"}], ",", 
       RowBox[{"2814", "\[Rule]", "2815"}], ",", 
       RowBox[{"2814", "\[Rule]", "2811"}], ",", 
       RowBox[{"2382", "\[Rule]", "2383"}], ",", 
       RowBox[{"2382", "\[Rule]", "2379"}], ",", 
       RowBox[{"2706", "\[Rule]", "2707"}], ",", 
       RowBox[{"2706", "\[Rule]", "2703"}], ",", 
       RowBox[{"2274", "\[Rule]", "2275"}], ",", 
       RowBox[{"2274", "\[Rule]", "2271"}], ",", 
       RowBox[{"6", "\[Rule]", "7"}], ",", 
       RowBox[{"6", "\[Rule]", "3"}], ",", 
       RowBox[{"870", "\[Rule]", "871"}], ",", 
       RowBox[{"870", "\[Rule]", "867"}], ",", 
       RowBox[{"438", "\[Rule]", "439"}], ",", 
       RowBox[{"438", "\[Rule]", "435"}], ",", 
       RowBox[{"1734", "\[Rule]", "1735"}], ",", 
       RowBox[{"1734", "\[Rule]", "1731"}], ",", 
       RowBox[{"1302", "\[Rule]", "1303"}], ",", 
       RowBox[{"1302", "\[Rule]", "1299"}], ",", 
       RowBox[{"2598", "\[Rule]", "2599"}], ",", 
       RowBox[{"2598", "\[Rule]", "2595"}], ",", 
       RowBox[{"2166", "\[Rule]", "2167"}], ",", 
       RowBox[{"2166", "\[Rule]", "2163"}], ",", 
       RowBox[{"344", "\[Rule]", "327"}], ",", 
       RowBox[{"344", "\[Rule]", "357"}], ",", 
       RowBox[{"344", "\[Rule]", "341"}], ",", 
       RowBox[{"1208", "\[Rule]", "1191"}], ",", 
       RowBox[{"1208", "\[Rule]", "1221"}], ",", 
       RowBox[{"1208", "\[Rule]", "1205"}], ",", 
       RowBox[{"776", "\[Rule]", "759"}], ",", 
       RowBox[{"776", "\[Rule]", "789"}], ",", 
       RowBox[{"776", "\[Rule]", "773"}], ",", 
       RowBox[{"356", "\[Rule]", "341"}], ",", 
       RowBox[{"356", "\[Rule]", "357"}], ",", 
       RowBox[{"1220", "\[Rule]", "1205"}], ",", 
       RowBox[{"1220", "\[Rule]", "1221"}], ",", 
       RowBox[{"788", "\[Rule]", "773"}], ",", 
       RowBox[{"788", "\[Rule]", "789"}], ",", 
       RowBox[{"236", "\[Rule]", "219"}], ",", 
       RowBox[{"236", "\[Rule]", "249"}], ",", 
       RowBox[{"236", "\[Rule]", "233"}], ",", 
       RowBox[{"1100", "\[Rule]", "1083"}], ",", 
       RowBox[{"1100", "\[Rule]", "1113"}], ",", 
       RowBox[{"1100", "\[Rule]", "1097"}], ",", 
       RowBox[{"668", "\[Rule]", "651"}], ",", 
       RowBox[{"668", "\[Rule]", "681"}], ",", 
       RowBox[{"668", "\[Rule]", "665"}], ",", 
       RowBox[{"248", "\[Rule]", "233"}], ",", 
       RowBox[{"248", "\[Rule]", "249"}], ",", 
       RowBox[{"1112", "\[Rule]", "1097"}], ",", 
       RowBox[{"1112", "\[Rule]", "1113"}], ",", 
       RowBox[{"680", "\[Rule]", "665"}], ",", 
       RowBox[{"680", "\[Rule]", "681"}], ",", 
       RowBox[{"2072", "\[Rule]", "2055"}], ",", 
       RowBox[{"2072", "\[Rule]", "2085"}], ",", 
       RowBox[{"2072", "\[Rule]", "2069"}], ",", 
       RowBox[{"1640", "\[Rule]", "1623"}], ",", 
       RowBox[{"1640", "\[Rule]", "1653"}], ",", 
       RowBox[{"1640", "\[Rule]", "1637"}], ",", 
       RowBox[{"2084", "\[Rule]", "2069"}], ",", 
       RowBox[{"2084", "\[Rule]", "2085"}], ",", 
       RowBox[{"1652", "\[Rule]", "1637"}], ",", 
       RowBox[{"1652", "\[Rule]", "1653"}], ",", 
       RowBox[{"1964", "\[Rule]", "1947"}], ",", 
       RowBox[{"1964", "\[Rule]", "1977"}], ",", 
       RowBox[{"1964", "\[Rule]", "1961"}], ",", 
       RowBox[{"1532", "\[Rule]", "1515"}], ",", 
       RowBox[{"1532", "\[Rule]", "1545"}], ",", 
       RowBox[{"1532", "\[Rule]", "1529"}], ",", 
       RowBox[{"1976", "\[Rule]", "1961"}], ",", 
       RowBox[{"1976", "\[Rule]", "1977"}], ",", 
       RowBox[{"1544", "\[Rule]", "1529"}], ",", 
       RowBox[{"1544", "\[Rule]", "1545"}], ",", 
       RowBox[{"128", "\[Rule]", "111"}], ",", 
       RowBox[{"128", "\[Rule]", "141"}], ",", 
       RowBox[{"128", "\[Rule]", "125"}], ",", 
       RowBox[{"992", "\[Rule]", "975"}], ",", 
       RowBox[{"992", "\[Rule]", "1005"}], ",", 
       RowBox[{"992", "\[Rule]", "989"}], ",", 
       RowBox[{"560", "\[Rule]", "543"}], ",", 
       RowBox[{"560", "\[Rule]", "573"}], ",", 
       RowBox[{"560", "\[Rule]", "557"}], ",", 
       RowBox[{"140", "\[Rule]", "125"}], ",", 
       RowBox[{"140", "\[Rule]", "141"}], ",", 
       RowBox[{"1004", "\[Rule]", "989"}], ",", 
       RowBox[{"1004", "\[Rule]", "1005"}], ",", 
       RowBox[{"572", "\[Rule]", "557"}], ",", 
       RowBox[{"572", "\[Rule]", "573"}], ",", 
       RowBox[{"1856", "\[Rule]", "1839"}], ",", 
       RowBox[{"1856", "\[Rule]", "1869"}], ",", 
       RowBox[{"1856", "\[Rule]", "1853"}], ",", 
       RowBox[{"1424", "\[Rule]", "1407"}], ",", 
       RowBox[{"1424", "\[Rule]", "1437"}], ",", 
       RowBox[{"1424", "\[Rule]", "1421"}], ",", 
       RowBox[{"1868", "\[Rule]", "1853"}], ",", 
       RowBox[{"1868", "\[Rule]", "1869"}], ",", 
       RowBox[{"1436", "\[Rule]", "1421"}], ",", 
       RowBox[{"1436", "\[Rule]", "1437"}], ",", 
       RowBox[{"2936", "\[Rule]", "2919"}], ",", 
       RowBox[{"2936", "\[Rule]", "2949"}], ",", 
       RowBox[{"2936", "\[Rule]", "2933"}], ",", 
       RowBox[{"2504", "\[Rule]", "2487"}], ",", 
       RowBox[{"2504", "\[Rule]", "2517"}], ",", 
       RowBox[{"2504", "\[Rule]", "2501"}], ",", 
       RowBox[{"2948", "\[Rule]", "2933"}], ",", 
       RowBox[{"2948", "\[Rule]", "2949"}], ",", 
       RowBox[{"2516", "\[Rule]", "2501"}], ",", 
       RowBox[{"2516", "\[Rule]", "2517"}], ",", 
       RowBox[{"2828", "\[Rule]", "2811"}], ",", 
       RowBox[{"2828", "\[Rule]", "2841"}], ",", 
       RowBox[{"2828", "\[Rule]", "2825"}], ",", 
       RowBox[{"2396", "\[Rule]", "2379"}], ",", 
       RowBox[{"2396", "\[Rule]", "2409"}], ",", 
       RowBox[{"2396", "\[Rule]", "2393"}], ",", 
       RowBox[{"2840", "\[Rule]", "2825"}], ",", 
       RowBox[{"2840", "\[Rule]", "2841"}], ",", 
       RowBox[{"2408", "\[Rule]", "2393"}], ",", 
       RowBox[{"2408", "\[Rule]", "2409"}], ",", 
       RowBox[{"2720", "\[Rule]", "2703"}], ",", 
       RowBox[{"2720", "\[Rule]", "2733"}], ",", 
       RowBox[{"2720", "\[Rule]", "2717"}], ",", 
       RowBox[{"2288", "\[Rule]", "2271"}], ",", 
       RowBox[{"2288", "\[Rule]", "2301"}], ",", 
       RowBox[{"2288", "\[Rule]", "2285"}], ",", 
       RowBox[{"2732", "\[Rule]", "2717"}], ",", 
       RowBox[{"2732", "\[Rule]", "2733"}], ",", 
       RowBox[{"2300", "\[Rule]", "2285"}], ",", 
       RowBox[{"2300", "\[Rule]", "2301"}], ",", 
       RowBox[{"20", "\[Rule]", "3"}], ",", 
       RowBox[{"20", "\[Rule]", "33"}], ",", 
       RowBox[{"20", "\[Rule]", "17"}], ",", 
       RowBox[{"884", "\[Rule]", "867"}], ",", 
       RowBox[{"884", "\[Rule]", "897"}], ",", 
       RowBox[{"884", "\[Rule]", "881"}], ",", 
       RowBox[{"452", "\[Rule]", "435"}], ",", 
       RowBox[{"452", "\[Rule]", "465"}], ",", 
       RowBox[{"452", "\[Rule]", "449"}], ",", 
       RowBox[{"32", "\[Rule]", "17"}], ",", 
       RowBox[{"32", "\[Rule]", "33"}], ",", 
       RowBox[{"896", "\[Rule]", "881"}], ",", 
       RowBox[{"896", "\[Rule]", "897"}], ",", 
       RowBox[{"464", "\[Rule]", "449"}], ",", 
       RowBox[{"464", "\[Rule]", "465"}], ",", 
       RowBox[{"1748", "\[Rule]", "1731"}], ",", 
       RowBox[{"1748", "\[Rule]", "1761"}], ",", 
       RowBox[{"1748", "\[Rule]", "1745"}], ",", 
       RowBox[{"1316", "\[Rule]", "1299"}], ",", 
       RowBox[{"1316", "\[Rule]", "1329"}], ",", 
       RowBox[{"1316", "\[Rule]", "1313"}], ",", 
       RowBox[{"1760", "\[Rule]", "1745"}], ",", 
       RowBox[{"1760", "\[Rule]", "1761"}], ",", 
       RowBox[{"1328", "\[Rule]", "1313"}], ",", 
       RowBox[{"1328", "\[Rule]", "1329"}], ",", 
       RowBox[{"2612", "\[Rule]", "2595"}], ",", 
       RowBox[{"2612", "\[Rule]", "2625"}], ",", 
       RowBox[{"2612", "\[Rule]", "2609"}], ",", 
       RowBox[{"2180", "\[Rule]", "2163"}], ",", 
       RowBox[{"2180", "\[Rule]", "2193"}], ",", 
       RowBox[{"2180", "\[Rule]", "2177"}], ",", 
       RowBox[{"2624", "\[Rule]", "2609"}], ",", 
       RowBox[{"2624", "\[Rule]", "2625"}], ",", 
       RowBox[{"2192", "\[Rule]", "2177"}], ",", 
       RowBox[{"2192", "\[Rule]", "2193"}], ",", 
       RowBox[{"327", "\[Rule]", "760"}], ",", 
       RowBox[{"327", "\[Rule]", "760"}], ",", 
       RowBox[{"327", "\[Rule]", "652"}], ",", 
       RowBox[{"327", "\[Rule]", "652"}], ",", 
       RowBox[{"327", "\[Rule]", "328"}], ",", 
       RowBox[{"1191", "\[Rule]", "760"}], ",", 
       RowBox[{"1191", "\[Rule]", "760"}], ",", 
       RowBox[{"1191", "\[Rule]", "1624"}], ",", 
       RowBox[{"1191", "\[Rule]", "1624"}], ",", 
       RowBox[{"1191", "\[Rule]", "652"}], ",", 
       RowBox[{"1191", "\[Rule]", "652"}], ",", 
       RowBox[{"1191", "\[Rule]", "1516"}], ",", 
       RowBox[{"1191", "\[Rule]", "1516"}], ",", 
       RowBox[{"1191", "\[Rule]", "1192"}], ",", 
       RowBox[{"759", "\[Rule]", "328"}], ",", 
       RowBox[{"759", "\[Rule]", "328"}], ",", 
       RowBox[{"759", "\[Rule]", "1192"}], ",", 
       RowBox[{"759", "\[Rule]", "1192"}], ",", 
       RowBox[{"759", "\[Rule]", "760"}], ",", 
       RowBox[{"219", "\[Rule]", "652"}], ",", 
       RowBox[{"219", "\[Rule]", "652"}], ",", 
       RowBox[{"219", "\[Rule]", "544"}], ",", 
       RowBox[{"219", "\[Rule]", "544"}], ",", 
       RowBox[{"219", "\[Rule]", "220"}], ",", 
       RowBox[{"1083", "\[Rule]", "652"}], ",", 
       RowBox[{"1083", "\[Rule]", "652"}], ",", 
       RowBox[{"1083", "\[Rule]", "1516"}], ",", 
       RowBox[{"1083", "\[Rule]", "1516"}], ",", 
       RowBox[{"1083", "\[Rule]", "544"}], ",", 
       RowBox[{"1083", "\[Rule]", "544"}], ",", 
       RowBox[{"1083", "\[Rule]", "1408"}], ",", 
       RowBox[{"1083", "\[Rule]", "1408"}], ",", 
       RowBox[{"1083", "\[Rule]", "1084"}], ",", 
       RowBox[{"651", "\[Rule]", "328"}], ",", 
       RowBox[{"651", "\[Rule]", "328"}], ",", 
       RowBox[{"651", "\[Rule]", "1192"}], ",", 
       RowBox[{"651", "\[Rule]", "1192"}], ",", 
       RowBox[{"651", "\[Rule]", "220"}], ",", 
       RowBox[{"651", "\[Rule]", "220"}], ",", 
       RowBox[{"651", "\[Rule]", "1084"}], ",", 
       RowBox[{"651", "\[Rule]", "1084"}], ",", 
       RowBox[{"651", "\[Rule]", "652"}], ",", 
       RowBox[{"2055", "\[Rule]", "1624"}], ",", 
       RowBox[{"2055", "\[Rule]", "1624"}], ",", 
       RowBox[{"2055", "\[Rule]", "2488"}], ",", 
       RowBox[{"2055", "\[Rule]", "2488"}], ",", 
       RowBox[{"2055", "\[Rule]", "1516"}], ",", 
       RowBox[{"2055", "\[Rule]", "1516"}], ",", 
       RowBox[{"2055", "\[Rule]", "2380"}], ",", 
       RowBox[{"2055", "\[Rule]", "2380"}], ",", 
       RowBox[{"2055", "\[Rule]", "2056"}], ",", 
       RowBox[{"1623", "\[Rule]", "1192"}], ",", 
       RowBox[{"1623", "\[Rule]", "1192"}], ",", 
       RowBox[{"1623", "\[Rule]", "2056"}], ",", 
       RowBox[{"1623", "\[Rule]", "2056"}], ",", 
       RowBox[{"1623", "\[Rule]", "1624"}], ",", 
       RowBox[{"1947", "\[Rule]", "1516"}], ",", 
       RowBox[{"1947", "\[Rule]", "1516"}], ",", 
       RowBox[{"1947", "\[Rule]", "2380"}], ",", 
       RowBox[{"1947", "\[Rule]", "2380"}], ",", 
       RowBox[{"1947", "\[Rule]", "1408"}], ",", 
       RowBox[{"1947", "\[Rule]", "1408"}], ",", 
       RowBox[{"1947", "\[Rule]", "2272"}], ",", 
       RowBox[{"1947", "\[Rule]", "2272"}], ",", 
       RowBox[{"1947", "\[Rule]", "1948"}], ",", 
       RowBox[{"1515", "\[Rule]", "1192"}], ",", 
       RowBox[{"1515", "\[Rule]", "1192"}], ",", 
       RowBox[{"1515", "\[Rule]", "2056"}], ",", 
       RowBox[{"1515", "\[Rule]", "2056"}], ",", 
       RowBox[{"1515", "\[Rule]", "1084"}], ",", 
       RowBox[{"1515", "\[Rule]", "1084"}], ",", 
       RowBox[{"1515", "\[Rule]", "1948"}], ",", 
       RowBox[{"1515", "\[Rule]", "1948"}], ",", 
       RowBox[{"1515", "\[Rule]", "1516"}], ",", 
       RowBox[{"111", "\[Rule]", "544"}], ",", 
       RowBox[{"111", "\[Rule]", "112"}], ",", 
       RowBox[{"975", "\[Rule]", "544"}], ",", 
       RowBox[{"975", "\[Rule]", "1408"}], ",", 
       RowBox[{"975", "\[Rule]", "1408"}], ",", 
       RowBox[{"975", "\[Rule]", "436"}], ",", 
       RowBox[{"975", "\[Rule]", "1300"}], ",", 
       RowBox[{"975", "\[Rule]", "1300"}], ",", 
       RowBox[{"975", "\[Rule]", "976"}], ",", 
       RowBox[{"543", "\[Rule]", "220"}], ",", 
       RowBox[{"543", "\[Rule]", "220"}], ",", 
       RowBox[{"543", "\[Rule]", "1084"}], ",", 
       RowBox[{"543", "\[Rule]", "1084"}], ",", 
       RowBox[{"543", "\[Rule]", "112"}], ",", 
       RowBox[{"543", "\[Rule]", "976"}], ",", 
       RowBox[{"543", "\[Rule]", "544"}], ",", 
       RowBox[{"1839", "\[Rule]", "1408"}], ",", 
       RowBox[{"1839", "\[Rule]", "1408"}], ",", 
       RowBox[{"1839", "\[Rule]", "2272"}], ",", 
       RowBox[{"1839", "\[Rule]", "2272"}], ",", 
       RowBox[{"1839", "\[Rule]", "1300"}], ",", 
       RowBox[{"1839", "\[Rule]", "1300"}], ",", 
       RowBox[{"1839", "\[Rule]", "2164"}], ",", 
       RowBox[{"1839", "\[Rule]", "2164"}], ",", 
       RowBox[{"1839", "\[Rule]", "1840"}], ",", 
       RowBox[{"1407", "\[Rule]", "1084"}], ",", 
       RowBox[{"1407", "\[Rule]", "1084"}], ",", 
       RowBox[{"1407", "\[Rule]", "1948"}], ",", 
       RowBox[{"1407", "\[Rule]", "1948"}], ",", 
       RowBox[{"1407", "\[Rule]", "976"}], ",", 
       RowBox[{"1407", "\[Rule]", "976"}], ",", 
       RowBox[{"1407", "\[Rule]", "1840"}], ",", 
       RowBox[{"1407", "\[Rule]", "1840"}], ",", 
       RowBox[{"1407", "\[Rule]", "1408"}], ",", 
       RowBox[{"2919", "\[Rule]", "2488"}], ",", 
       RowBox[{"2919", "\[Rule]", "2488"}], ",", 
       RowBox[{"2919", "\[Rule]", "2380"}], ",", 
       RowBox[{"2919", "\[Rule]", "2380"}], ",", 
       RowBox[{"2919", "\[Rule]", "2920"}], ",", 
       RowBox[{"2487", "\[Rule]", "2056"}], ",", 
       RowBox[{"2487", "\[Rule]", "2056"}], ",", 
       RowBox[{"2487", "\[Rule]", "2920"}], ",", 
       RowBox[{"2487", "\[Rule]", "2920"}], ",", 
       RowBox[{"2487", "\[Rule]", "2488"}], ",", 
       RowBox[{"2811", "\[Rule]", "2380"}], ",", 
       RowBox[{"2811", "\[Rule]", "2380"}], ",", 
       RowBox[{"2811", "\[Rule]", "2272"}], ",", 
       RowBox[{"2811", "\[Rule]", "2272"}], ",", 
       RowBox[{"2811", "\[Rule]", "2812"}], ",", 
       RowBox[{"2379", "\[Rule]", "2056"}], ",", 
       RowBox[{"2379", "\[Rule]", "2056"}], ",", 
       RowBox[{"2379", "\[Rule]", "2920"}], ",", 
       RowBox[{"2379", "\[Rule]", "2920"}], ",", 
       RowBox[{"2379", "\[Rule]", "1948"}], ",", 
       RowBox[{"2379", "\[Rule]", "1948"}], ",", 
       RowBox[{"2379", "\[Rule]", "2812"}], ",", 
       RowBox[{"2379", "\[Rule]", "2812"}], ",", 
       RowBox[{"2379", "\[Rule]", "2380"}], ",", 
       RowBox[{"2703", "\[Rule]", "2272"}], ",", 
       RowBox[{"2703", "\[Rule]", "2272"}], ",", 
       RowBox[{"2703", "\[Rule]", "2164"}], ",", 
       RowBox[{"2703", "\[Rule]", "2164"}], ",", 
       RowBox[{"2703", "\[Rule]", "2704"}], ",", 
       RowBox[{"2271", "\[Rule]", "1948"}], ",", 
       RowBox[{"2271", "\[Rule]", "1948"}], ",", 
       RowBox[{"2271", "\[Rule]", "2812"}], ",", 
       RowBox[{"2271", "\[Rule]", "2812"}], ",", 
       RowBox[{"2271", "\[Rule]", "1840"}], ",", 
       RowBox[{"2271", "\[Rule]", "1840"}], ",", 
       RowBox[{"2271", "\[Rule]", "2704"}], ",", 
       RowBox[{"2271", "\[Rule]", "2704"}], ",", 
       RowBox[{"2271", "\[Rule]", "2272"}], ",", 
       RowBox[{"3", "\[Rule]", "436"}], ",", 
       RowBox[{"3", "\[Rule]", "4"}], ",", 
       RowBox[{"867", "\[Rule]", "436"}], ",", 
       RowBox[{"867", "\[Rule]", "436"}], ",", 
       RowBox[{"867", "\[Rule]", "1300"}], ",", 
       RowBox[{"867", "\[Rule]", "868"}], ",", 
       RowBox[{"435", "\[Rule]", "976"}], ",", 
       RowBox[{"435", "\[Rule]", "4"}], ",", 
       RowBox[{"435", "\[Rule]", "868"}], ",", 
       RowBox[{"435", "\[Rule]", "868"}], ",", 
       RowBox[{"435", "\[Rule]", "436"}], ",", 
       RowBox[{"1731", "\[Rule]", "1300"}], ",", 
       RowBox[{"1731", "\[Rule]", "2164"}], ",", 
       RowBox[{"1731", "\[Rule]", "2164"}], ",", 
       RowBox[{"1731", "\[Rule]", "1732"}], ",", 
       RowBox[{"1299", "\[Rule]", "976"}], ",", 
       RowBox[{"1299", "\[Rule]", "976"}], ",", 
       RowBox[{"1299", "\[Rule]", "1840"}], ",", 
       RowBox[{"1299", "\[Rule]", "1840"}], ",", 
       RowBox[{"1299", "\[Rule]", "868"}], ",", 
       RowBox[{"1299", "\[Rule]", "1732"}], ",", 
       RowBox[{"1299", "\[Rule]", "1300"}], ",", 
       RowBox[{"2595", "\[Rule]", "2164"}], ",", 
       RowBox[{"2595", "\[Rule]", "2164"}], ",", 
       RowBox[{"2595", "\[Rule]", "2596"}], ",", 
       RowBox[{"2163", "\[Rule]", "1840"}], ",", 
       RowBox[{"2163", "\[Rule]", "1840"}], ",", 
       RowBox[{"2163", "\[Rule]", "2704"}], ",", 
       RowBox[{"2163", "\[Rule]", "2704"}], ",", 
       RowBox[{"2163", "\[Rule]", "1732"}], ",", 
       RowBox[{"2163", "\[Rule]", "1732"}], ",", 
       RowBox[{"2163", "\[Rule]", "2596"}], ",", 
       RowBox[{"2163", "\[Rule]", "2596"}], ",", 
       RowBox[{"2163", "\[Rule]", "2164"}], ",", 
       RowBox[{"341", "\[Rule]", "774"}], ",", 
       RowBox[{"341", "\[Rule]", "774"}], ",", 
       RowBox[{"341", "\[Rule]", "666"}], ",", 
       RowBox[{"341", "\[Rule]", "666"}], ",", 
       RowBox[{"341", "\[Rule]", "342"}], ",", 
       RowBox[{"1205", "\[Rule]", "774"}], ",", 
       RowBox[{"1205", "\[Rule]", "774"}], ",", 
       RowBox[{"1205", "\[Rule]", "1638"}], ",", 
       RowBox[{"1205", "\[Rule]", "1638"}], ",", 
       RowBox[{"1205", "\[Rule]", "666"}], ",", 
       RowBox[{"1205", "\[Rule]", "666"}], ",", 
       RowBox[{"1205", "\[Rule]", "1530"}], ",", 
       RowBox[{"1205", "\[Rule]", "1530"}], ",", 
       RowBox[{"1205", "\[Rule]", "1206"}], ",", 
       RowBox[{"773", "\[Rule]", "342"}], ",", 
       RowBox[{"773", "\[Rule]", "342"}], ",", 
       RowBox[{"773", "\[Rule]", "1206"}], ",", 
       RowBox[{"773", "\[Rule]", "1206"}], ",", 
       RowBox[{"773", "\[Rule]", "774"}], ",", 
       RowBox[{"233", "\[Rule]", "666"}], ",", 
       RowBox[{"233", "\[Rule]", "666"}], ",", 
       RowBox[{"233", "\[Rule]", "558"}], ",", 
       RowBox[{"233", "\[Rule]", "558"}], ",", 
       RowBox[{"233", "\[Rule]", "234"}], ",", 
       RowBox[{"1097", "\[Rule]", "666"}], ",", 
       RowBox[{"1097", "\[Rule]", "666"}], ",", 
       RowBox[{"1097", "\[Rule]", "1530"}], ",", 
       RowBox[{"1097", "\[Rule]", "1530"}], ",", 
       RowBox[{"1097", "\[Rule]", "558"}], ",", 
       RowBox[{"1097", "\[Rule]", "558"}], ",", 
       RowBox[{"1097", "\[Rule]", "1422"}], ",", 
       RowBox[{"1097", "\[Rule]", "1422"}], ",", 
       RowBox[{"1097", "\[Rule]", "1098"}], ",", 
       RowBox[{"665", "\[Rule]", "342"}], ",", 
       RowBox[{"665", "\[Rule]", "342"}], ",", 
       RowBox[{"665", "\[Rule]", "1206"}], ",", 
       RowBox[{"665", "\[Rule]", "1206"}], ",", 
       RowBox[{"665", "\[Rule]", "234"}], ",", 
       RowBox[{"665", "\[Rule]", "234"}], ",", 
       RowBox[{"665", "\[Rule]", "1098"}], ",", 
       RowBox[{"665", "\[Rule]", "1098"}], ",", 
       RowBox[{"665", "\[Rule]", "666"}], ",", 
       RowBox[{"2069", "\[Rule]", "1638"}], ",", 
       RowBox[{"2069", "\[Rule]", "1638"}], ",", 
       RowBox[{"2069", "\[Rule]", "2502"}], ",", 
       RowBox[{"2069", "\[Rule]", "2502"}], ",", 
       RowBox[{"2069", "\[Rule]", "1530"}], ",", 
       RowBox[{"2069", "\[Rule]", "1530"}], ",", 
       RowBox[{"2069", "\[Rule]", "2394"}], ",", 
       RowBox[{"2069", "\[Rule]", "2394"}], ",", 
       RowBox[{"2069", "\[Rule]", "2070"}], ",", 
       RowBox[{"1637", "\[Rule]", "1206"}], ",", 
       RowBox[{"1637", "\[Rule]", "1206"}], ",", 
       RowBox[{"1637", "\[Rule]", "2070"}], ",", 
       RowBox[{"1637", "\[Rule]", "2070"}], ",", 
       RowBox[{"1637", "\[Rule]", "1638"}], ",", 
       RowBox[{"1961", "\[Rule]", "1530"}], ",", 
       RowBox[{"1961", "\[Rule]", "1530"}], ",", 
       RowBox[{"1961", "\[Rule]", "2394"}], ",", 
       RowBox[{"1961", "\[Rule]", "2394"}], ",", 
       RowBox[{"1961", "\[Rule]", "1422"}], ",", 
       RowBox[{"1961", "\[Rule]", "1422"}], ",", 
       RowBox[{"1961", "\[Rule]", "2286"}], ",", 
       RowBox[{"1961", "\[Rule]", "2286"}], ",", 
       RowBox[{"1961", "\[Rule]", "1962"}], ",", 
       RowBox[{"1529", "\[Rule]", "1206"}], ",", 
       RowBox[{"1529", "\[Rule]", "1206"}], ",", 
       RowBox[{"1529", "\[Rule]", "2070"}], ",", 
       RowBox[{"1529", "\[Rule]", "2070"}], ",", 
       RowBox[{"1529", "\[Rule]", "1098"}], ",", 
       RowBox[{"1529", "\[Rule]", "1098"}], ",", 
       RowBox[{"1529", "\[Rule]", "1962"}], ",", 
       RowBox[{"1529", "\[Rule]", "1962"}], ",", 
       RowBox[{"1529", "\[Rule]", "1530"}], ",", 
       RowBox[{"125", "\[Rule]", "558"}], ",", 
       RowBox[{"125", "\[Rule]", "450"}], ",", 
       RowBox[{"125", "\[Rule]", "126"}], ",", 
       RowBox[{"989", "\[Rule]", "558"}], ",", 
       RowBox[{"989", "\[Rule]", "1422"}], ",", 
       RowBox[{"989", "\[Rule]", "1422"}], ",", 
       RowBox[{"989", "\[Rule]", "450"}], ",", 
       RowBox[{"989", "\[Rule]", "1314"}], ",", 
       RowBox[{"989", "\[Rule]", "1314"}], ",", 
       RowBox[{"989", "\[Rule]", "990"}], ",", 
       RowBox[{"557", "\[Rule]", "234"}], ",", 
       RowBox[{"557", "\[Rule]", "234"}], ",", 
       RowBox[{"557", "\[Rule]", "1098"}], ",", 
       RowBox[{"557", "\[Rule]", "1098"}], ",", 
       RowBox[{"557", "\[Rule]", "126"}], ",", 
       RowBox[{"557", "\[Rule]", "990"}], ",", 
       RowBox[{"557", "\[Rule]", "558"}], ",", 
       RowBox[{"1853", "\[Rule]", "1422"}], ",", 
       RowBox[{"1853", "\[Rule]", "1422"}], ",", 
       RowBox[{"1853", "\[Rule]", "2286"}], ",", 
       RowBox[{"1853", "\[Rule]", "2286"}], ",", 
       RowBox[{"1853", "\[Rule]", "1314"}], ",", 
       RowBox[{"1853", "\[Rule]", "1314"}], ",", 
       RowBox[{"1853", "\[Rule]", "2178"}], ",", 
       RowBox[{"1853", "\[Rule]", "2178"}], ",", 
       RowBox[{"1853", "\[Rule]", "1854"}], ",", 
       RowBox[{"1421", "\[Rule]", "1098"}], ",", 
       RowBox[{"1421", "\[Rule]", "1098"}], ",", 
       RowBox[{"1421", "\[Rule]", "1962"}], ",", 
       RowBox[{"1421", "\[Rule]", "1962"}], ",", 
       RowBox[{"1421", "\[Rule]", "990"}], ",", 
       RowBox[{"1421", "\[Rule]", "990"}], ",", 
       RowBox[{"1421", "\[Rule]", "1854"}], ",", 
       RowBox[{"1421", "\[Rule]", "1854"}], ",", 
       RowBox[{"1421", "\[Rule]", "1422"}], ",", 
       RowBox[{"2933", "\[Rule]", "2502"}], ",", 
       RowBox[{"2933", "\[Rule]", "2502"}], ",", 
       RowBox[{"2933", "\[Rule]", "2394"}], ",", 
       RowBox[{"2933", "\[Rule]", "2394"}], ",", 
       RowBox[{"2933", "\[Rule]", "2934"}], ",", 
       RowBox[{"2501", "\[Rule]", "2070"}], ",", 
       RowBox[{"2501", "\[Rule]", "2070"}], ",", 
       RowBox[{"2501", "\[Rule]", "2934"}], ",", 
       RowBox[{"2501", "\[Rule]", "2934"}], ",", 
       RowBox[{"2501", "\[Rule]", "2502"}], ",", 
       RowBox[{"2825", "\[Rule]", "2394"}], ",", 
       RowBox[{"2825", "\[Rule]", "2394"}], ",", 
       RowBox[{"2825", "\[Rule]", "2286"}], ",", 
       RowBox[{"2825", "\[Rule]", "2286"}], ",", 
       RowBox[{"2825", "\[Rule]", "2826"}], ",", 
       RowBox[{"2393", "\[Rule]", "2070"}], ",", 
       RowBox[{"2393", "\[Rule]", "2070"}], ",", 
       RowBox[{"2393", "\[Rule]", "2934"}], ",", 
       RowBox[{"2393", "\[Rule]", "2934"}], ",", 
       RowBox[{"2393", "\[Rule]", "1962"}], ",", 
       RowBox[{"2393", "\[Rule]", "1962"}], ",", 
       RowBox[{"2393", "\[Rule]", "2826"}], ",", 
       RowBox[{"2393", "\[Rule]", "2826"}], ",", 
       RowBox[{"2393", "\[Rule]", "2394"}], ",", 
       RowBox[{"2717", "\[Rule]", "2286"}], ",", 
       RowBox[{"2717", "\[Rule]", "2286"}], ",", 
       RowBox[{"2717", "\[Rule]", "2178"}], ",", 
       RowBox[{"2717", "\[Rule]", "2178"}], ",", 
       RowBox[{"2717", "\[Rule]", "2718"}], ",", 
       RowBox[{"2285", "\[Rule]", "1962"}], ",", 
       RowBox[{"2285", "\[Rule]", "1962"}], ",", 
       RowBox[{"2285", "\[Rule]", "2826"}], ",", 
       RowBox[{"2285", "\[Rule]", "2826"}], ",", 
       RowBox[{"2285", "\[Rule]", "1854"}], ",", 
       RowBox[{"2285", "\[Rule]", "1854"}], ",", 
       RowBox[{"2285", "\[Rule]", "2718"}], ",", 
       RowBox[{"2285", "\[Rule]", "2718"}], ",", 
       RowBox[{"2285", "\[Rule]", "2286"}], ",", 
       RowBox[{"17", "\[Rule]", "450"}], ",", 
       RowBox[{"17", "\[Rule]", "18"}], ",", 
       RowBox[{"881", "\[Rule]", "450"}], ",", 
       RowBox[{"881", "\[Rule]", "1314"}], ",", 
       RowBox[{"881", "\[Rule]", "882"}], ",", 
       RowBox[{"449", "\[Rule]", "126"}], ",", 
       RowBox[{"449", "\[Rule]", "990"}], ",", 
       RowBox[{"449", "\[Rule]", "18"}], ",", 
       RowBox[{"449", "\[Rule]", "882"}], ",", 
       RowBox[{"449", "\[Rule]", "450"}], ",", 
       RowBox[{"1745", "\[Rule]", "1314"}], ",", 
       RowBox[{"1745", "\[Rule]", "2178"}], ",", 
       RowBox[{"1745", "\[Rule]", "2178"}], ",", 
       RowBox[{"1745", "\[Rule]", "1746"}], ",", 
       RowBox[{"1313", "\[Rule]", "990"}], ",", 
       RowBox[{"1313", "\[Rule]", "990"}], ",", 
       RowBox[{"1313", "\[Rule]", "1854"}], ",", 
       RowBox[{"1313", "\[Rule]", "1854"}], ",", 
       RowBox[{"1313", "\[Rule]", "882"}], ",", 
       RowBox[{"1313", "\[Rule]", "1746"}], ",", 
       RowBox[{"1313", "\[Rule]", "1314"}], ",", 
       RowBox[{"2609", "\[Rule]", "2178"}], ",", 
       RowBox[{"2609", "\[Rule]", "2178"}], ",", 
       RowBox[{"2609", "\[Rule]", "2610"}], ",", 
       RowBox[{"2177", "\[Rule]", "1854"}], ",", 
       RowBox[{"2177", "\[Rule]", "1854"}], ",", 
       RowBox[{"2177", "\[Rule]", "2718"}], ",", 
       RowBox[{"2177", "\[Rule]", "2718"}], ",", 
       RowBox[{"2177", "\[Rule]", "1746"}], ",", 
       RowBox[{"2177", "\[Rule]", "1746"}], ",", 
       RowBox[{"2177", "\[Rule]", "2610"}], ",", 
       RowBox[{"2177", "\[Rule]", "2610"}], ",", 
       RowBox[{"2177", "\[Rule]", "2178"}], ",", 
       RowBox[{"760", "\[Rule]", "775"}], ",", 
       RowBox[{"760", "\[Rule]", "761"}], ",", 
       RowBox[{"760", "\[Rule]", "757"}], ",", 
       RowBox[{"652", "\[Rule]", "667"}], ",", 
       RowBox[{"652", "\[Rule]", "653"}], ",", 
       RowBox[{"652", "\[Rule]", "649"}], ",", 
       RowBox[{"328", "\[Rule]", "343"}], ",", 
       RowBox[{"328", "\[Rule]", "329"}], ",", 
       RowBox[{"328", "\[Rule]", "325"}], ",", 
       RowBox[{"1624", "\[Rule]", "1639"}], ",", 
       RowBox[{"1624", "\[Rule]", "1625"}], ",", 
       RowBox[{"1624", "\[Rule]", "1621"}], ",", 
       RowBox[{"1516", "\[Rule]", "1531"}], ",", 
       RowBox[{"1516", "\[Rule]", "1517"}], ",", 
       RowBox[{"1516", "\[Rule]", "1513"}], ",", 
       RowBox[{"1192", "\[Rule]", "1207"}], ",", 
       RowBox[{"1192", "\[Rule]", "1193"}], ",", 
       RowBox[{"1192", "\[Rule]", "1189"}], ",", 
       RowBox[{"544", "\[Rule]", "559"}], ",", 
       RowBox[{"544", "\[Rule]", "545"}], ",", 
       RowBox[{"544", "\[Rule]", "541"}], ",", 
       RowBox[{"220", "\[Rule]", "235"}], ",", 
       RowBox[{"220", "\[Rule]", "221"}], ",", 
       RowBox[{"220", "\[Rule]", "217"}], ",", 
       RowBox[{"1408", "\[Rule]", "1423"}], ",", 
       RowBox[{"1408", "\[Rule]", "1409"}], ",", 
       RowBox[{"1408", "\[Rule]", "1405"}], ",", 
       RowBox[{"1084", "\[Rule]", "1099"}], ",", 
       RowBox[{"1084", "\[Rule]", "1085"}], ",", 
       RowBox[{"1084", "\[Rule]", "1081"}], ",", 
       RowBox[{"2488", "\[Rule]", "2503"}], ",", 
       RowBox[{"2488", "\[Rule]", "2489"}], ",", 
       RowBox[{"2488", "\[Rule]", "2485"}], ",", 
       RowBox[{"2380", "\[Rule]", "2395"}], ",", 
       RowBox[{"2380", "\[Rule]", "2381"}], ",", 
       RowBox[{"2380", "\[Rule]", "2377"}], ",", 
       RowBox[{"2056", "\[Rule]", "2071"}], ",", 
       RowBox[{"2056", "\[Rule]", "2057"}], ",", 
       RowBox[{"2056", "\[Rule]", "2053"}], ",", 
       RowBox[{"2272", "\[Rule]", "2287"}], ",", 
       RowBox[{"2272", "\[Rule]", "2273"}], ",", 
       RowBox[{"2272", "\[Rule]", "2269"}], ",", 
       RowBox[{"1948", "\[Rule]", "1963"}], ",", 
       RowBox[{"1948", "\[Rule]", "1949"}], ",", 
       RowBox[{"1948", "\[Rule]", "1945"}], ",", 
       RowBox[{"112", "\[Rule]", "127"}], ",", 
       RowBox[{"112", "\[Rule]", "113"}], ",", 
       RowBox[{"112", "\[Rule]", "109"}], ",", 
       RowBox[{"436", "\[Rule]", "451"}], ",", 
       RowBox[{"436", "\[Rule]", "437"}], ",", 
       RowBox[{"436", "\[Rule]", "433"}], ",", 
       RowBox[{"1300", "\[Rule]", "1315"}], ",", 
       RowBox[{"1300", "\[Rule]", "1301"}], ",", 
       RowBox[{"1300", "\[Rule]", "1297"}], ",", 
       RowBox[{"976", "\[Rule]", "991"}], ",", 
       RowBox[{"976", "\[Rule]", "977"}], ",", 
       RowBox[{"976", "\[Rule]", "973"}], ",", 
       RowBox[{"2164", "\[Rule]", "2179"}], ",", 
       RowBox[{"2164", "\[Rule]", "2165"}], ",", 
       RowBox[{"2164", "\[Rule]", "2161"}], ",", 
       RowBox[{"1840", "\[Rule]", "1855"}], ",", 
       RowBox[{"1840", "\[Rule]", "1841"}], ",", 
       RowBox[{"1840", "\[Rule]", "1837"}], ",", 
       RowBox[{"2920", "\[Rule]", "2935"}], ",", 
       RowBox[{"2920", "\[Rule]", "2921"}], ",", 
       RowBox[{"2920", "\[Rule]", "2917"}], ",", 
       RowBox[{"2812", "\[Rule]", "2827"}], ",", 
       RowBox[{"2812", "\[Rule]", "2813"}], ",", 
       RowBox[{"2812", "\[Rule]", "2809"}], ",", 
       RowBox[{"2704", "\[Rule]", "2719"}], ",", 
       RowBox[{"2704", "\[Rule]", "2705"}], ",", 
       RowBox[{"2704", "\[Rule]", "2701"}], ",", 
       RowBox[{"4", "\[Rule]", "19"}], ",", 
       RowBox[{"4", "\[Rule]", "5"}], ",", 
       RowBox[{"4", "\[Rule]", "1"}], ",", 
       RowBox[{"868", "\[Rule]", "883"}], ",", 
       RowBox[{"868", "\[Rule]", "869"}], ",", 
       RowBox[{"868", "\[Rule]", "865"}], ",", 
       RowBox[{"1732", "\[Rule]", "1747"}], ",", 
       RowBox[{"1732", "\[Rule]", "1733"}], ",", 
       RowBox[{"1732", "\[Rule]", "1729"}], ",", 
       RowBox[{"2596", "\[Rule]", "2611"}], ",", 
       RowBox[{"2596", "\[Rule]", "2597"}], ",", 
       RowBox[{"2596", "\[Rule]", "2593"}], ",", 
       RowBox[{"774", "\[Rule]", "757"}], ",", 
       RowBox[{"774", "\[Rule]", "787"}], ",", 
       RowBox[{"774", "\[Rule]", "775"}], ",", 
       RowBox[{"666", "\[Rule]", "649"}], ",", 
       RowBox[{"666", "\[Rule]", "679"}], ",", 
       RowBox[{"666", "\[Rule]", "667"}], ",", 
       RowBox[{"342", "\[Rule]", "325"}], ",", 
       RowBox[{"342", "\[Rule]", "355"}], ",", 
       RowBox[{"342", "\[Rule]", "343"}], ",", 
       RowBox[{"1638", "\[Rule]", "1621"}], ",", 
       RowBox[{"1638", "\[Rule]", "1651"}], ",", 
       RowBox[{"1638", "\[Rule]", "1639"}], ",", 
       RowBox[{"1530", "\[Rule]", "1513"}], ",", 
       RowBox[{"1530", "\[Rule]", "1543"}], ",", 
       RowBox[{"1530", "\[Rule]", "1531"}], ",", 
       RowBox[{"1206", "\[Rule]", "1189"}], ",", 
       RowBox[{"1206", "\[Rule]", "1219"}], ",", 
       RowBox[{"1206", "\[Rule]", "1207"}], ",", 
       RowBox[{"558", "\[Rule]", "541"}], ",", 
       RowBox[{"558", "\[Rule]", "571"}], ",", 
       RowBox[{"558", "\[Rule]", "559"}], ",", 
       RowBox[{"234", "\[Rule]", "217"}], ",", 
       RowBox[{"234", "\[Rule]", "247"}], ",", 
       RowBox[{"234", "\[Rule]", "235"}], ",", 
       RowBox[{"1422", "\[Rule]", "1405"}], ",", 
       RowBox[{"1422", "\[Rule]", "1435"}], ",", 
       RowBox[{"1422", "\[Rule]", "1423"}], ",", 
       RowBox[{"1098", "\[Rule]", "1081"}], ",", 
       RowBox[{"1098", "\[Rule]", "1111"}], ",", 
       RowBox[{"1098", "\[Rule]", "1099"}], ",", 
       RowBox[{"2502", "\[Rule]", "2485"}], ",", 
       RowBox[{"2502", "\[Rule]", "2515"}], ",", 
       RowBox[{"2502", "\[Rule]", "2503"}], ",", 
       RowBox[{"2394", "\[Rule]", "2377"}], ",", 
       RowBox[{"2394", "\[Rule]", "2407"}], ",", 
       RowBox[{"2394", "\[Rule]", "2395"}], ",", 
       RowBox[{"2070", "\[Rule]", "2053"}], ",", 
       RowBox[{"2070", "\[Rule]", "2083"}], ",", 
       RowBox[{"2070", "\[Rule]", "2071"}], ",", 
       RowBox[{"2286", "\[Rule]", "2269"}], ",", 
       RowBox[{"2286", "\[Rule]", "2299"}], ",", 
       RowBox[{"2286", "\[Rule]", "2287"}], ",", 
       RowBox[{"1962", "\[Rule]", "1945"}], ",", 
       RowBox[{"1962", "\[Rule]", "1975"}], ",", 
       RowBox[{"1962", "\[Rule]", "1963"}], ",", 
       RowBox[{"450", "\[Rule]", "433"}], ",", 
       RowBox[{"450", "\[Rule]", "463"}], ",", 
       RowBox[{"450", "\[Rule]", "451"}], ",", 
       RowBox[{"126", "\[Rule]", "109"}], ",", 
       RowBox[{"126", "\[Rule]", "139"}], ",", 
       RowBox[{"126", "\[Rule]", "127"}], ",", 
       RowBox[{"1314", "\[Rule]", "1297"}], ",", 
       RowBox[{"1314", "\[Rule]", "1327"}], ",", 
       RowBox[{"1314", "\[Rule]", "1315"}], ",", 
       RowBox[{"990", "\[Rule]", "973"}], ",", 
       RowBox[{"990", "\[Rule]", "1003"}], ",", 
       RowBox[{"990", "\[Rule]", "991"}], ",", 
       RowBox[{"2178", "\[Rule]", "2161"}], ",", 
       RowBox[{"2178", "\[Rule]", "2191"}], ",", 
       RowBox[{"2178", "\[Rule]", "2179"}], ",", 
       RowBox[{"1854", "\[Rule]", "1837"}], ",", 
       RowBox[{"1854", "\[Rule]", "1867"}], ",", 
       RowBox[{"1854", "\[Rule]", "1855"}], ",", 
       RowBox[{"2934", "\[Rule]", "2917"}], ",", 
       RowBox[{"2934", "\[Rule]", "2947"}], ",", 
       RowBox[{"2934", "\[Rule]", "2935"}], ",", 
       RowBox[{"2826", "\[Rule]", "2809"}], ",", 
       RowBox[{"2826", "\[Rule]", "2839"}], ",", 
       RowBox[{"2826", "\[Rule]", "2827"}], ",", 
       RowBox[{"2718", "\[Rule]", "2701"}], ",", 
       RowBox[{"2718", "\[Rule]", "2731"}], ",", 
       RowBox[{"2718", "\[Rule]", "2719"}], ",", 
       RowBox[{"18", "\[Rule]", "1"}], ",", 
       RowBox[{"18", "\[Rule]", "31"}], ",", 
       RowBox[{"18", "\[Rule]", "19"}], ",", 
       RowBox[{"882", "\[Rule]", "865"}], ",", 
       RowBox[{"882", "\[Rule]", "895"}], ",", 
       RowBox[{"882", "\[Rule]", "883"}], ",", 
       RowBox[{"1746", "\[Rule]", "1729"}], ",", 
       RowBox[{"1746", "\[Rule]", "1759"}], ",", 
       RowBox[{"1746", "\[Rule]", "1747"}], ",", 
       RowBox[{"2610", "\[Rule]", "2593"}], ",", 
       RowBox[{"2610", "\[Rule]", "2623"}], ",", 
       RowBox[{"2610", "\[Rule]", "2611"}], ",", 
       RowBox[{"757", "\[Rule]", "326"}], ",", 
       RowBox[{"757", "\[Rule]", "326"}], ",", 
       RowBox[{"757", "\[Rule]", "1190"}], ",", 
       RowBox[{"757", "\[Rule]", "1190"}], ",", 
       RowBox[{"757", "\[Rule]", "758"}], ",", 
       RowBox[{"649", "\[Rule]", "326"}], ",", 
       RowBox[{"649", "\[Rule]", "326"}], ",", 
       RowBox[{"649", "\[Rule]", "1190"}], ",", 
       RowBox[{"649", "\[Rule]", "1190"}], ",", 
       RowBox[{"649", "\[Rule]", "218"}], ",", 
       RowBox[{"649", "\[Rule]", "218"}], ",", 
       RowBox[{"649", "\[Rule]", "1082"}], ",", 
       RowBox[{"649", "\[Rule]", "1082"}], ",", 
       RowBox[{"649", "\[Rule]", "650"}], ",", 
       RowBox[{"325", "\[Rule]", "758"}], ",", 
       RowBox[{"325", "\[Rule]", "758"}], ",", 
       RowBox[{"325", "\[Rule]", "650"}], ",", 
       RowBox[{"325", "\[Rule]", "650"}], ",", 
       RowBox[{"325", "\[Rule]", "326"}], ",", 
       RowBox[{"1621", "\[Rule]", "1190"}], ",", 
       RowBox[{"1621", "\[Rule]", "1190"}], ",", 
       RowBox[{"1621", "\[Rule]", "2054"}], ",", 
       RowBox[{"1621", "\[Rule]", "2054"}], ",", 
       RowBox[{"1621", "\[Rule]", "1622"}], ",", 
       RowBox[{"1513", "\[Rule]", "1190"}], ",", 
       RowBox[{"1513", "\[Rule]", "1190"}], ",", 
       RowBox[{"1513", "\[Rule]", "2054"}], ",", 
       RowBox[{"1513", "\[Rule]", "2054"}], ",", 
       RowBox[{"1513", "\[Rule]", "1082"}], ",", 
       RowBox[{"1513", "\[Rule]", "1082"}], ",", 
       RowBox[{"1513", "\[Rule]", "1946"}], ",", 
       RowBox[{"1513", "\[Rule]", "1946"}], ",", 
       RowBox[{"1513", "\[Rule]", "1514"}], ",", 
       RowBox[{"1189", "\[Rule]", "758"}], ",", 
       RowBox[{"1189", "\[Rule]", "758"}], ",", 
       RowBox[{"1189", "\[Rule]", "1622"}], ",", 
       RowBox[{"1189", "\[Rule]", "1622"}], ",", 
       RowBox[{"1189", "\[Rule]", "650"}], ",", 
       RowBox[{"1189", "\[Rule]", "650"}], ",", 
       RowBox[{"1189", "\[Rule]", "1514"}], ",", 
       RowBox[{"1189", "\[Rule]", "1514"}], ",", 
       RowBox[{"1189", "\[Rule]", "1190"}], ",", 
       RowBox[{"541", "\[Rule]", "218"}], ",", 
       RowBox[{"541", "\[Rule]", "218"}], ",", 
       RowBox[{"541", "\[Rule]", "1082"}], ",", 
       RowBox[{"541", "\[Rule]", "1082"}], ",", 
       RowBox[{"541", "\[Rule]", "110"}], ",", 
       RowBox[{"541", "\[Rule]", "974"}], ",", 
       RowBox[{"541", "\[Rule]", "542"}], ",", 
       RowBox[{"217", "\[Rule]", "650"}], ",", 
       RowBox[{"217", "\[Rule]", "650"}], ",", 
       RowBox[{"217", "\[Rule]", "542"}], ",", 
       RowBox[{"217", "\[Rule]", "542"}], ",", 
       RowBox[{"217", "\[Rule]", "218"}], ",", 
       RowBox[{"1405", "\[Rule]", "1082"}], ",", 
       RowBox[{"1405", "\[Rule]", "1082"}], ",", 
       RowBox[{"1405", "\[Rule]", "1946"}], ",", 
       RowBox[{"1405", "\[Rule]", "1946"}], ",", 
       RowBox[{"1405", "\[Rule]", "974"}], ",", 
       RowBox[{"1405", "\[Rule]", "974"}], ",", 
       RowBox[{"1405", "\[Rule]", "1838"}], ",", 
       RowBox[{"1405", "\[Rule]", "1838"}], ",", 
       RowBox[{"1405", "\[Rule]", "1406"}], ",", 
       RowBox[{"1081", "\[Rule]", "650"}], ",", 
       RowBox[{"1081", "\[Rule]", "650"}], ",", 
       RowBox[{"1081", "\[Rule]", "1514"}], ",", 
       RowBox[{"1081", "\[Rule]", "1514"}], ",", 
       RowBox[{"1081", "\[Rule]", "542"}], ",", 
       RowBox[{"1081", "\[Rule]", "542"}], ",", 
       RowBox[{"1081", "\[Rule]", "1406"}], ",", 
       RowBox[{"1081", "\[Rule]", "1406"}], ",", 
       RowBox[{"1081", "\[Rule]", "1082"}], ",", 
       RowBox[{"2485", "\[Rule]", "2054"}], ",", 
       RowBox[{"2485", "\[Rule]", "2054"}], ",", 
       RowBox[{"2485", "\[Rule]", "2918"}], ",", 
       RowBox[{"2485", "\[Rule]", "2918"}], ",", 
       RowBox[{"2485", "\[Rule]", "2486"}], ",", 
       RowBox[{"2377", "\[Rule]", "2054"}], ",", 
       RowBox[{"2377", "\[Rule]", "2054"}], ",", 
       RowBox[{"2377", "\[Rule]", "2918"}], ",", 
       RowBox[{"2377", "\[Rule]", "2918"}], ",", 
       RowBox[{"2377", "\[Rule]", "1946"}], ",", 
       RowBox[{"2377", "\[Rule]", "1946"}], ",", 
       RowBox[{"2377", "\[Rule]", "2810"}], ",", 
       RowBox[{"2377", "\[Rule]", "2810"}], ",", 
       RowBox[{"2377", "\[Rule]", "2378"}], ",", 
       RowBox[{"2053", "\[Rule]", "1622"}], ",", 
       RowBox[{"2053", "\[Rule]", "1622"}], ",", 
       RowBox[{"2053", "\[Rule]", "2486"}], ",", 
       RowBox[{"2053", "\[Rule]", "2486"}], ",", 
       RowBox[{"2053", "\[Rule]", "1514"}], ",", 
       RowBox[{"2053", "\[Rule]", "1514"}], ",", 
       RowBox[{"2053", "\[Rule]", "2378"}], ",", 
       RowBox[{"2053", "\[Rule]", "2378"}], ",", 
       RowBox[{"2053", "\[Rule]", "2054"}], ",", 
       RowBox[{"2269", "\[Rule]", "1946"}], ",", 
       RowBox[{"2269", "\[Rule]", "1946"}], ",", 
       RowBox[{"2269", "\[Rule]", "2810"}], ",", 
       RowBox[{"2269", "\[Rule]", "2810"}], ",", 
       RowBox[{"2269", "\[Rule]", "1838"}], ",", 
       RowBox[{"2269", "\[Rule]", "1838"}], ",", 
       RowBox[{"2269", "\[Rule]", "2702"}], ",", 
       RowBox[{"2269", "\[Rule]", "2702"}], ",", 
       RowBox[{"2269", "\[Rule]", "2270"}], ",", 
       RowBox[{"1945", "\[Rule]", "1514"}], ",", 
       RowBox[{"1945", "\[Rule]", "1514"}], ",", 
       RowBox[{"1945", "\[Rule]", "2378"}], ",", 
       RowBox[{"1945", "\[Rule]", "2378"}], ",", 
       RowBox[{"1945", "\[Rule]", "1406"}], ",", 
       RowBox[{"1945", "\[Rule]", "1406"}], ",", 
       RowBox[{"1945", "\[Rule]", "2270"}], ",", 
       RowBox[{"1945", "\[Rule]", "2270"}], ",", 
       RowBox[{"1945", "\[Rule]", "1946"}], ",", 
       RowBox[{"109", "\[Rule]", "542"}], ",", 
       RowBox[{"109", "\[Rule]", "434"}], ",", 
       RowBox[{"109", "\[Rule]", "110"}], ",", 
       RowBox[{"433", "\[Rule]", "110"}], ",", 
       RowBox[{"433", "\[Rule]", "974"}], ",", 
       RowBox[{"433", "\[Rule]", "2"}], ",", 
       RowBox[{"433", "\[Rule]", "2"}], ",", 
       RowBox[{"433", "\[Rule]", "866"}], ",", 
       RowBox[{"433", "\[Rule]", "866"}], ",", 
       RowBox[{"433", "\[Rule]", "434"}], ",", 
       RowBox[{"1297", "\[Rule]", "974"}], ",", 
       RowBox[{"1297", "\[Rule]", "974"}], ",", 
       RowBox[{"1297", "\[Rule]", "1838"}], ",", 
       RowBox[{"1297", "\[Rule]", "1838"}], ",", 
       RowBox[{"1297", "\[Rule]", "866"}], ",", 
       RowBox[{"1297", "\[Rule]", "1730"}], ",", 
       RowBox[{"1297", "\[Rule]", "1298"}], ",", 
       RowBox[{"973", "\[Rule]", "542"}], ",", 
       RowBox[{"973", "\[Rule]", "1406"}], ",", 
       RowBox[{"973", "\[Rule]", "1406"}], ",", 
       RowBox[{"973", "\[Rule]", "434"}], ",", 
       RowBox[{"973", "\[Rule]", "1298"}], ",", 
       RowBox[{"973", "\[Rule]", "1298"}], ",", 
       RowBox[{"973", "\[Rule]", "974"}], ",", 
       RowBox[{"2161", "\[Rule]", "1838"}], ",", 
       RowBox[{"2161", "\[Rule]", "1838"}], ",", 
       RowBox[{"2161", "\[Rule]", "2702"}], ",", 
       RowBox[{"2161", "\[Rule]", "2702"}], ",", 
       RowBox[{"2161", "\[Rule]", "1730"}], ",", 
       RowBox[{"2161", "\[Rule]", "1730"}], ",", 
       RowBox[{"2161", "\[Rule]", "2594"}], ",", 
       RowBox[{"2161", "\[Rule]", "2594"}], ",", 
       RowBox[{"2161", "\[Rule]", "2162"}], ",", 
       RowBox[{"1837", "\[Rule]", "1406"}], ",", 
       RowBox[{"1837", "\[Rule]", "1406"}], ",", 
       RowBox[{"1837", "\[Rule]", "2270"}], ",", 
       RowBox[{"1837", "\[Rule]", "2270"}], ",", 
       RowBox[{"1837", "\[Rule]", "1298"}], ",", 
       RowBox[{"1837", "\[Rule]", "1298"}], ",", 
       RowBox[{"1837", "\[Rule]", "2162"}], ",", 
       RowBox[{"1837", "\[Rule]", "2162"}], ",", 
       RowBox[{"1837", "\[Rule]", "1838"}], ",", 
       RowBox[{"2917", "\[Rule]", "2486"}], ",", 
       RowBox[{"2917", "\[Rule]", "2486"}], ",", 
       RowBox[{"2917", "\[Rule]", "2378"}], ",", 
       RowBox[{"2917", "\[Rule]", "2378"}], ",", 
       RowBox[{"2917", "\[Rule]", "2918"}], ",", 
       RowBox[{"2809", "\[Rule]", "2378"}], ",", 
       RowBox[{"2809", "\[Rule]", "2378"}], ",", 
       RowBox[{"2809", "\[Rule]", "2270"}], ",", 
       RowBox[{"2809", "\[Rule]", "2270"}], ",", 
       RowBox[{"2809", "\[Rule]", "2810"}], ",", 
       RowBox[{"2701", "\[Rule]", "2270"}], ",", 
       RowBox[{"2701", "\[Rule]", "2270"}], ",", 
       RowBox[{"2701", "\[Rule]", "2162"}], ",", 
       RowBox[{"2701", "\[Rule]", "2162"}], ",", 
       RowBox[{"2701", "\[Rule]", "2702"}], ",", 
       RowBox[{"1", "\[Rule]", "434"}], ",", 
       RowBox[{"1", "\[Rule]", "434"}], ",", 
       RowBox[{"1", "\[Rule]", "2"}], ",", 
       RowBox[{"865", "\[Rule]", "434"}], ",", 
       RowBox[{"865", "\[Rule]", "434"}], ",", 
       RowBox[{"865", "\[Rule]", "1298"}], ",", 
       RowBox[{"865", "\[Rule]", "866"}], ",", 
       RowBox[{"1729", "\[Rule]", "1298"}], ",", 
       RowBox[{"1729", "\[Rule]", "2162"}], ",", 
       RowBox[{"1729", "\[Rule]", "2162"}], ",", 
       RowBox[{"1729", "\[Rule]", "1730"}], ",", 
       RowBox[{"2593", "\[Rule]", "2162"}], ",", 
       RowBox[{"2593", "\[Rule]", "2162"}], ",", 
       RowBox[{"2593", "\[Rule]", "2594"}], ",", 
       RowBox[{"326", "\[Rule]", "341"}], ",", 
       RowBox[{"326", "\[Rule]", "327"}], ",", 
       RowBox[{"1190", "\[Rule]", "1205"}], ",", 
       RowBox[{"1190", "\[Rule]", "1191"}], ",", 
       RowBox[{"758", "\[Rule]", "773"}], ",", 
       RowBox[{"758", "\[Rule]", "759"}], ",", 
       RowBox[{"218", "\[Rule]", "233"}], ",", 
       RowBox[{"218", "\[Rule]", "219"}], ",", 
       RowBox[{"1082", "\[Rule]", "1097"}], ",", 
       RowBox[{"1082", "\[Rule]", "1083"}], ",", 
       RowBox[{"650", "\[Rule]", "665"}], ",", 
       RowBox[{"650", "\[Rule]", "651"}], ",", 
       RowBox[{"2054", "\[Rule]", "2069"}], ",", 
       RowBox[{"2054", "\[Rule]", "2055"}], ",", 
       RowBox[{"1622", "\[Rule]", "1637"}], ",", 
       RowBox[{"1622", "\[Rule]", "1623"}], ",", 
       RowBox[{"1946", "\[Rule]", "1961"}], ",", 
       RowBox[{"1946", "\[Rule]", "1947"}], ",", 
       RowBox[{"1514", "\[Rule]", "1529"}], ",", 
       RowBox[{"1514", "\[Rule]", "1515"}], ",", 
       RowBox[{"110", "\[Rule]", "125"}], ",", 
       RowBox[{"110", "\[Rule]", "111"}], ",", 
       RowBox[{"974", "\[Rule]", "989"}], ",", 
       RowBox[{"974", "\[Rule]", "975"}], ",", 
       RowBox[{"542", "\[Rule]", "557"}], ",", 
       RowBox[{"542", "\[Rule]", "543"}], ",", 
       RowBox[{"1838", "\[Rule]", "1853"}], ",", 
       RowBox[{"1838", "\[Rule]", "1839"}], ",", 
       RowBox[{"1406", "\[Rule]", "1421"}], ",", 
       RowBox[{"1406", "\[Rule]", "1407"}], ",", 
       RowBox[{"2918", "\[Rule]", "2933"}], ",", 
       RowBox[{"2918", "\[Rule]", "2919"}], ",", 
       RowBox[{"2486", "\[Rule]", "2501"}], ",", 
       RowBox[{"2486", "\[Rule]", "2487"}], ",", 
       RowBox[{"2810", "\[Rule]", "2825"}], ",", 
       RowBox[{"2810", "\[Rule]", "2811"}], ",", 
       RowBox[{"2378", "\[Rule]", "2393"}], ",", 
       RowBox[{"2378", "\[Rule]", "2379"}], ",", 
       RowBox[{"2702", "\[Rule]", "2717"}], ",", 
       RowBox[{"2702", "\[Rule]", "2703"}], ",", 
       RowBox[{"2270", "\[Rule]", "2285"}], ",", 
       RowBox[{"2270", "\[Rule]", "2271"}], ",", 
       RowBox[{"434", "\[Rule]", "449"}], ",", 
       RowBox[{"434", "\[Rule]", "435"}], ",", 
       RowBox[{"2", "\[Rule]", "17"}], ",", 
       RowBox[{"2", "\[Rule]", "3"}], ",", 
       RowBox[{"866", "\[Rule]", "881"}], ",", 
       RowBox[{"866", "\[Rule]", "867"}], ",", 
       RowBox[{"1730", "\[Rule]", "1745"}], ",", 
       RowBox[{"1730", "\[Rule]", "1731"}], ",", 
       RowBox[{"1298", "\[Rule]", "1313"}], ",", 
       RowBox[{"1298", "\[Rule]", "1299"}], ",", 
       RowBox[{"2594", "\[Rule]", "2609"}], ",", 
       RowBox[{"2594", "\[Rule]", "2595"}], ",", 
       RowBox[{"2162", "\[Rule]", "2177"}], ",", 
       RowBox[{"2162", "\[Rule]", "2163"}]}], "}"}], ",", 
     RowBox[{"EdgeWeight", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "c", ",", "d", ",", "i", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "i", ",", "c", ",", "d", ",", "i", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "c", ",", "g", ",", "i", ",", "c", ",", "g", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", 
        "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "i", ",", "c", ",", "d", ",", "i", ",", 
        "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "c", ",", 
        "d", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "g", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "i", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "i", ",", "b", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "e", ",", "f", ",", 
        "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "b", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "c", ",", "g", ",", "i", ",", "b", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "i", ",", "c", ",", "d", ",", "i", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "e", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "d", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "e", ",", "f", ",", "g", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "e", ",", "f", ",", "g", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", 
        "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "e", ",", "f", ",", "g", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "e", ",", "f", ",", "g", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "e", ",", "f", ",", 
        "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "b", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "b", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "b", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "e", ",", "f", ",", "g", ",", 
        "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "e", ",", "f", ",", "g", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "e", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", "b", ",", "i", ",", 
        "a", ",", "b", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", "b", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", 
        "b", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "f", ",", "i", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "e", ",", 
        "f", ",", "g", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "e", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "e", ",", "f", ",", "g", ",", "i", ",", 
        "a", ",", "b", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "e", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "e", ",", "f", ",", "g", ",", "i", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "g", ",", "i", ",", "b", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "i", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", 
        "b", ",", "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", "b", ",", 
        "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", "b", ",", "i", ",", 
        "a", ",", "b", ",", "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", 
        "b", ",", "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", "b", ",", 
        "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "i", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "i", ",", "f", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "d", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "i", ",", "f", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "b", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", 
        "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "b", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "b", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "b", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", "c", ",", 
        "e", ",", "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", 
        "b", ",", "d", ",", "f", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "i", ",", "f", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "i", ",", "b", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "d", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "c", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", 
        "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "i", ",", 
        "a", ",", "b", ",", "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "i", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "c", ",", "d", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "i", ",", "b", ",", "i", ",", "b", ",", 
        "e", ",", "f", ",", "g", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "b", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "i", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", 
        "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "g", ",", "h", ",", "i", ",", "c", ",", "d", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "g", ",", "i", ",", "c", ",", "g", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", 
        "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "c", ",", "d", ",", "i", ",", "c", ",", 
        "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", 
        "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "i", ",", 
        "a", ",", "b", ",", "i", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "c", ",", "d", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "e", ",", "f", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "i", ",", "d", ",", "e", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", "g", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "c", ",", "i", ",", "a", ",", "c", ",", "i", ",", "b", ",", 
        "d", ",", "f", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "g", ",", "h", ",", "i", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
        "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "f", ",", "h", ",", "i", ",", "c", ",", 
        "d", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", 
        "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", 
        "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "c", ",", "g", ",", "i", ",", "b", ",", "d", ",", "e", ",", "f", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "f", ",", "h", ",", "i", ",", "a", ",", "c", ",", "d", ",", "e", ",", 
        "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
        "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", "a", ",", "b", ",", 
        "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", 
        "e", ",", "f", ",", "i", ",", "a", ",", "b", ",", "e", ",", "f", ",", 
        "i", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", "c", ",", 
        "i", ",", "a", ",", "c", ",", "d", ",", "i", ",", "a", ",", "b", ",", 
        "i", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", "u", ",", 
        "u"}], "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"init9", "=", 
   RowBox[{"{", "107", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bad9", "=", 
   RowBox[{"{", 
    RowBox[{
    "2", ",", "114", ",", "226", ",", "338", ",", "452", ",", "562", ",", 
     "674", ",", "786", ",", "896", ",", "1008", ",", "1120", ",", "1232", 
     ",", "1344", ",", "1456", ",", "1568", ",", "1680", ",", "1790", ",", 
     "1902", ",", "2014", ",", "2126", ",", "2240", ",", "2352", ",", "2464", 
     ",", "2576", ",", "2686", ",", "2798", ",", "2910", ",", "3022", ",", 
     "1", ",", "113", ",", "225", ",", "337", ",", "451", ",", "561", ",", 
     "673", ",", "785", ",", "895", ",", "1007", ",", "1119", ",", "1231", 
     ",", "1343", ",", "1455", ",", "1567", ",", "1679", ",", "1789", ",", 
     "1901", ",", "2013", ",", "2125", ",", "2239", ",", "2351", ",", "2463", 
     ",", "2575", ",", "2685", ",", "2797", ",", "2909", ",", "3021"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lag9", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"graphical9", "=", "0"}], ";"}]}], "Input",
 CellChangeTimes->{{3.679290280863879*^9, 3.679290334241673*^9}, {
   3.679290504696708*^9, 3.67929051929695*^9}, {3.679290627540678*^9, 
   3.679290646162645*^9}, {3.679290676691043*^9, 3.679290749174502*^9}, {
   3.67929089973089*^9, 3.679290911059611*^9}, {3.679290948233796*^9, 
   3.679290990883844*^9}, {3.679291164264686*^9, 3.679291210405404*^9}, {
   3.679296297585969*^9, 3.679296312880332*^9}, {3.679297255110785*^9, 
   3.67929728224135*^9}, {3.679298728331581*^9, 3.679298875905641*^9}, 
   3.679298940274908*^9, {3.679299134034567*^9, 3.679299184389367*^9}, {
   3.679303531395106*^9, 3.679303544554354*^9}, {3.679303608922887*^9, 
   3.679303639506028*^9}, {3.679303980910127*^9, 3.679303986325524*^9}, {
   3.679335615401274*^9, 3.679335623430876*^9}, {3.679335744327502*^9, 
   3.679335766784133*^9}, 3.679335823213298*^9, {3.679335983824042*^9, 
   3.679335984261932*^9}, 3.679345060627506*^9, {3.679345101558879*^9, 
   3.679345112772768*^9}, 3.679345479078967*^9, 3.679349498904059*^9, 
   3.679349536594214*^9, {3.679349600050577*^9, 3.67934962905582*^9}, 
   3.679349661608243*^9, {3.679351400809895*^9, 3.679351401467813*^9}, {
   3.679351450028281*^9, 3.679351451046861*^9}, {3.679351510988296*^9, 
   3.679351511620798*^9}, {3.679351634514476*^9, 3.679351635015629*^9}, 
   3.683091811391354*^9, {3.683092894743585*^9, 3.683092894834948*^9}, {
   3.68603364313111*^9, 3.686033643305373*^9}, {3.686033963132012*^9, 
   3.686033963385147*^9}, {3.686038456625434*^9, 3.686038457152603*^9}, 
   3.686039476145979*^9, {3.686039765194613*^9, 3.686039765777108*^9}, {
   3.6860400079460697`*^9, 3.686040011873623*^9}, {3.6860456182789392`*^9, 
   3.6860456186205263`*^9}, {3.686046033270814*^9, 3.68604603343496*^9}, 
   3.686068229925735*^9, 3.686068578190002*^9, {3.6930354502060337`*^9, 
   3.693035455589672*^9}, {3.693035680711351*^9, 3.693035683406238*^9}, {
   3.693035735036788*^9, 3.693035830541695*^9}, {3.69303629913402*^9, 
   3.693036299316936*^9}, 3.6930368977904654`*^9, {3.693036958021305*^9, 
   3.693036958205016*^9}, {3.693096257624858*^9, 3.6930962579203043`*^9}, 
   3.693096438641191*^9, {3.6933825750532618`*^9, 3.6933826039006233`*^9}, {
   3.6934422003517*^9, 3.693442215314032*^9}, {3.693442393675651*^9, 
   3.6934423937437553`*^9}, {3.693801424757148*^9, 3.693801454004681*^9}, {
   3.6938034434144*^9, 3.693803466301813*^9}, 3.693831405130426*^9, {
   3.693831472993683*^9, 3.6938314737608213`*^9}, 3.6938319231218147`*^9, {
   3.694087968977194*^9, 3.694088006987527*^9}, 3.6941497259271927`*^9, {
   3.694245257162525*^9, 3.6942452760625277`*^9}, {3.694245342697908*^9, 
   3.694245369562891*^9}, 3.694245458359255*^9, {3.694245652561439*^9, 
   3.694245668103788*^9}, {3.69424570907092*^9, 3.694245730377326*^9}, 
   3.694245797438344*^9, 3.6942458336916103`*^9, {3.694245987924288*^9, 
   3.694246007913909*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"main", "[", 
  RowBox[{"g9", ",", "init9", ",", "bad9", ",", "lag9", ",", "graphical9"}], 
  "]"}]], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBmIQfW21KfuEzNeOrbdXcoBowzfzBEF0kgOHEIiubF5b
D6LfLYptBNEyLkpHQfSL83PAtM1r24iJQFqp/kYUiN6bP6EBROv/uQmm05SO
zdoApFd59s8G0ZHf89Q3Amm/HYvA9LnuXZGbgbT8/H1gWq3gRBKIltwZnQyi
4yYXZ4BoW60ZYLr3vMfpLUDa/P3pcyD6bbLctZ6y1468VzzAtNmxtT+eNwPt
K3gApi2Ot4i+ANJbDhwC05Om26qDaJms5xog+viaqvVmba8dXXL3bAbRdufN
BcyB9IV4HUEQ/e/xRjMQXfWUzRxEAwApQKIx
  "]],

Cell[CellGroupData[{

Cell[BoxData["\<\"Under delay = 0 :\"\>"], "Print",
 CellChangeTimes->{3.694246415472714*^9, 3.7148213286852713`*^9}],

Cell[BoxData["\<\"(*hidden for the sake of space*)\"\>"], "Print",
 CellChangeTimes->{3.694246415472714*^9, 3.7148213286861877`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Under delay = \"\>", "\[InvisibleSpace]", "1", 
   "\[InvisibleSpace]", "\<\" :\"\>"}],
  SequenceForm["Under delay = ", 1, " :"],
  Editable->False]], "Print",
 CellChangeTimes->{3.694246415472714*^9, 3.714821328687091*^9}],

Cell[BoxData["\<\"(*hidden for the sake of space*)\"\>"], "Print",
 CellChangeTimes->{3.694246415472714*^9, 3.714821333491418*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Under delay = \"\>", "\[InvisibleSpace]", "2", 
   "\[InvisibleSpace]", "\<\" :\"\>"}],
  SequenceForm["Under delay = ", 2, " :"],
  Editable->False]], "Print",
 CellChangeTimes->{3.694246415472714*^9, 3.714821333492936*^9}],

Cell[BoxData["\<\"(*hidden for the sake of space*)\"\>"], "Print",
 CellChangeTimes->{3.694246415472714*^9, 3.714821347920566*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Under delay = \"\>", "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\" :\"\>"}],
  SequenceForm["Under delay = ", 3, " :"],
  Editable->False]], "Print",
 CellChangeTimes->{3.694246415472714*^9, 3.714821347929325*^9}],

Cell[BoxData["\<\"(*hidden for the sake of space*)\"\>"], "Print",
 CellChangeTimes->{3.694246415472714*^9, 3.714821423786952*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Not possible for sure-winning anymore under delay=\"\>", 
   "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\" with uncontrollable states \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "1570", ",", "1584", ",", "2466", ",", "2448", ",", "2016", ",", "2480", 
     ",", "2462", ",", "2354", ",", "2030", ",", "2368", ",", "354", ",", 
     "368", ",", "380", ",", "1244", ",", "2108", ",", "3008", ",", "2990", 
     ",", "2972", ",", "3004", ",", "2896", ",", "2986", ",", "2878", ",", 
     "2446", ",", "2892", ",", "2784", ",", "2676", ",", "2690", ",", "772", 
     ",", "340", ",", "802", ",", "784", ",", "676", ",", "352", ",", "1666", 
     ",", "1234", ",", "1216", ",", "814", ",", "1696", ",", "1678", ",", 
     "1246", ",", "798", ",", "690", ",", "366", ",", "1554", ",", "1230", 
     ",", "1122", ",", "1566", ",", "1458", ",", "1134", ",", "2560", ",", 
     "2128", ",", "2542", ",", "2110", ",", "2592", ",", "2574", ",", "2142", 
     ",", "2556", ",", "2124", ",", "1998", ",", "1472", ",", "2336", ",", 
     "2012", ",", "1904", ",", "2350", ",", "2242", ",", "1918", ",", "3024", 
     ",", "3006", ",", "2988", ",", "3020", ",", "2912", ",", "3002", ",", 
     "2894", ",", "2908", ",", "2800", ",", "2782", ",", "2674", ",", "2256", 
     ",", "2796", ",", "2688", ",", "770", ",", "800", ",", "350", ",", "782",
      ",", "242", ",", "1664", ",", "812", ",", "1694", ",", "1676", ",", 
     "364", ",", "796", ",", "256", ",", "688", ",", "2558", ",", "2540", ",",
      "2590", ",", "2572", ",", "2554", ",", "1794", ",", "2766", ",", "2658",
      ",", "2226", ",", "1808", ",", "2780", ",", "2672", ",", "660", ",", 
     "336", ",", "228", ",", "672", ",", "348", ",", "564", ",", "240", ",", 
     "1104", ",", "578", ",", "1442", ",", "1118", ",", "1010", ",", "1454", 
     ",", "1346", ",", "1022", ",", "1886", ",", "1360", ",", "2224", ",", 
     "1900", ",", "1792", ",", "2656", ",", "2238", ",", "1806", ",", "2670", 
     ",", "238", ",", "36", ",", "900", ",", "48", ",", "912", ",", "1776", 
     ",", "2640", ",", "2654", ",", "548", ",", "224", ",", "116", ",", "466",
      ",", "1330", ",", "1006", ",", "34", ",", "898", ",", "6", ",", "20", 
     ",", "884", ",", "32", ",", "112", ",", "436", ",", "4", ",", "450", ",",
      "18", ",", "882", ",", "1662", ",", "412", ",", "394", ",", "1276", ",",
      "1258", ",", "828", ",", "2140", ",", "1616", ",", "1598", ",", "2122", 
     ",", "1692", ",", "810", ",", "286", ",", "1136", ",", "1150", ",", 
     "718", ",", "702", ",", "734", ",", "378", ",", "1674", ",", "1582", ",",
      "1166", ",", "1242", ",", "2526", ",", "2538", ",", "2000", ",", "2430",
      ",", "2106", ",", "2154", ",", "3018", ",", "2476", ",", "2588", ",", 
     "2136", ",", "3000", ",", "2570", ",", "1272", ",", "1164", ",", "2028", 
     ",", "1612", ",", "1504", ",", "2044", ",", "1596", ",", "1580", ",", 
     "2552", ",", "2444", ",", "1906", ",", "1920", ",", "1798", ",", "2770", 
     ",", "2662", ",", "2230", ",", "2228", ",", "2970", ",", "2984", ",", 
     "2876", ",", "2340", ",", "2232", ",", "2338", ",", "1908", ",", "2768", 
     ",", "2660", ",", "1228", ",", "2092", ",", "1660", ",", "842", ",", 
     "426", ",", "408", ",", "1290", ",", "824", ",", "410", ",", "392", ",", 
     "1274", ",", "1256", ",", "826", ",", "1706", ",", "1688", ",", "2138", 
     ",", "1614", ",", "2478", ",", "2460", ",", "2120", ",", "1690", ",", 
     "376", ",", "1240", ",", "808", ",", "716", ",", "608", ",", "284", ",", 
     "268", ",", "300", ",", "732", ",", "748", ",", "1148", ",", "700", ",", 
     "2104", ",", "1672", ",", "1564", ",", "1350", ",", "2322", ",", "2214", 
     ",", "1890", ",", "1782", ",", "1780", ",", "2956", ",", "2524", ",", 
     "2968", ",", "2536", ",", "2860", ",", "2428", ",", "2754", ",", "2752", 
     ",", "1462", ",", "2434", ",", "2326", ",", "2002", ",", "1892", ",", 
     "2864", ",", "2756", ",", "2324", ",", "2862", ",", "2432", ",", "2004", 
     ",", "2320", ",", "2646", ",", "2644", ",", "1784", ",", "2648", ",", 
     "2216", ",", "2218", ",", "2212", ",", "856", ",", "838", ",", "424", 
     ",", "406", ",", "1288", ",", "1270", ",", "840", ",", "1720", ",", 
     "2152", ",", "1702", ",", "2134", ",", "1704", ",", "2584", ",", "3016", 
     ",", "2586", ",", "2566", ",", "2998", ",", "2568", ",", "730", ",", 
     "390", ",", "422", ",", "1286", ",", "1594", ",", "1254", ",", "822", 
     ",", "2150", ",", "3014", ",", "2458", ",", "2118", ",", "1686", ",", 
     "2010", ",", "2982", ",", "2550", ",", "2874", ",", "2042", ",", "2906", 
     ",", "2474", ",", "2026", ",", "2890", ",", "2366", ",", "2442", ",", 
     "2580", ",", "2472", ",", "3012", ",", "2996", ",", "2364", ",", "2904", 
     ",", "2888", ",", "768", ",", "780", ",", "1644", ",", "1212", ",", 
     "2508", ",", "794", ",", "686", ",", "362", ",", "1658", ",", "1550", 
     ",", "1226", ",", "254", ",", "2522", ",", "2414", ",", "2090", ",", 
     "1984", ",", "1446", ",", "2418", ",", "2310", ",", "1986", ",", "1996", 
     ",", "1876", ",", "1888", ",", "2848", ",", "2740", ",", "2308", ",", 
     "2306", ",", "1552", ",", "1444", ",", "1982", ",", "148", ",", "160", 
     ",", "1012", ",", "594", ",", "486", ",", "1026", ",", "1024", ",", 
     "500", ",", "1364", ",", "1040", ",", "40", ",", "52", ",", "904", ",", 
     "916", ",", "472", ",", "484", ",", "470", ",", "582", ",", "474", ",", 
     "150", ",", "162", ",", "176", ",", "580", ",", "272", ",", "706", ",", 
     "720", ",", "598", ",", "612", ",", "1476", ",", "1138", ",", "1152", 
     ",", "164", ",", "1028", ",", "596", ",", "626", ",", "1182", ",", 
     "2032", ",", "2046", ",", "1490", ",", "178", ",", "1042", ",", "610", 
     ",", "258", ",", "260", ",", "274", ",", "288", ",", "692", ",", "694", 
     ",", "276", ",", "1140", ",", "290", ",", "1154", ",", "262", ",", 
     "1126", ",", "704", ",", "304", ",", "1168", ",", "584", ",", "270", ",",
      "302", ",", "318", ",", "1014", ",", "592", ",", "192", ",", "1056", 
     ",", "624", ",", "640", ",", "316", ",", "1180", ",", "1474", ",", 
     "1488", ",", "146", ",", "586", ",", "1124", ",", "152", ",", "1016", 
     ",", "1338", ",", "1768", ",", "1336", ",", "1334", ",", "2632", ",", 
     "2200", ",", "2198", ",", "2202", ",", "1878", ",", "1558", ",", "1450", 
     ",", "1988", ",", "1880", ",", "1448", ",", "1874", ",", "42", ",", "54",
      ",", "68", ",", "38", ",", "918", ",", "932", ",", "56", ",", "70", ",",
      "920", ",", "934", ",", "488", ",", "502", ",", "84", ",", "948", ",", 
     "516", ",", "490", ",", "504", ",", "166", ",", "180", ",", "518", ",", 
     "194", ",", "532", ",", "208", ",", "58", ",", "72", ",", "86", ",", 
     "100", ",", "1348", ",", "1368", ",", "2018", ",", "1910", ",", "1382", 
     ",", "2246", ",", "1922", ",", "1352", ",", "1366", ",", "1396", ",", 
     "2260", ",", "1936", ",", "1812", ",", "1380", ",", "1354", ",", "1030", 
     ",", "1044", ",", "1058", ",", "168", ",", "182", ",", "1032", ",", 
     "1046", ",", "600", ",", "614", ",", "196", ",", "1060", ",", "628", ",",
      "616", ",", "630", ",", "644", ",", "210", ",", "1074", ",", "642", ",",
      "1460", ",", "1480", ",", "1494", ",", "1508", ",", "1924", ",", "1478",
      ",", "1492", ",", "1938", ",", "1506", ",", "1072", ",", "1894", ",", 
     "1896", ",", "1464", ",", "922", ",", "936", ",", "950", ",", "60", ",", 
     "74", ",", "924", ",", "938", ",", "492", ",", "506", ",", "88", ",", 
     "952", ",", "520", ",", "508", ",", "184", ",", "522", ",", "198", ",", 
     "536", ",", "212", ",", "76", ",", "90", ",", "104", ",", "102", ",", 
     "966", ",", "534", ",", "964", ",", "1786", ",", "1800", ",", "1814", 
     ",", "1788", ",", "1802", ",", "1356", ",", "1370", ",", "1816", ",", 
     "1384", ",", "1372", ",", "1048", ",", "1386", ",", "1062", ",", "200", 
     ",", "1064", ",", "214", ",", "1078", ",", "1400", ",", "1076", ",", 
     "940", ",", "954", ",", "92", ",", "956", ",", "524", ",", "540", ",", 
     "108", ",", "106", ",", "970", ",", "538", ",", "968", ",", "1830", ",", 
     "1398", ",", "1796", ",", "1828", ",", "2244", ",", "906", ",", "44", 
     ",", "908", ",", "476", ",", "478", ",", "154", ",", "46", ",", "902", 
     ",", "107"}], "}"}], "\[InvisibleSpace]", "\<\".\\n\"\>"}],
  SequenceForm[
  "Not possible for sure-winning anymore under delay=", 3, 
   " with uncontrollable states ", CompressedData["
1:eJwl1XFE32sUx/Hv7XZ/t9udZJKZTDeZmSQzkyTXXElmfib5SWaSpJvdJDOT
JDMzmVwzSWYmSWaSJJMkSSZJZiZJZiaTZGaS5L6O+8fb55zznOc853m+3+/z
/aPln1t3f0qSpCErSUpSSVKBV78lyRB2f02SKfoCV3DA/5O2mNCFXmxnJ0l1
TpIs/p4kbzCKeaQxiRo8NecG3c1Nkh4MIPtna5pfQvMxZv07/AHrb6q5iHLx
l/yn2OFf4E/Li4bPiq2LtUScPf2LODtRO62fA2vW0GJ+Hm6zT6IPum4fi/KL
+dvsLpSzl4z1sTf0uoDXWMMdvMVNNONQvR10Y8OcfdqPLP0V47b+8ug37fTr
rYz9gg6i01gRP6FT9nJq3X1cMP8MjtlZelhnt2Ba/Xz+NrsLz8xJm/tZiZfs
ZvZVeshP2/919it7u83+Zp037Os4jb7USbOn1OxkJ7ij5gI/j32XfSBciofy
K+gQPdR3Os4Qpervivdg09pX1DuQU8IfoFKTghiPs6BdmJEXj2YpnhvtNtYn
cZT/BCcGv8Z7JN6sl7SxGtSzR+ll8Qvxzsnpw7oeFrCDB1FDTnm8J8a2sOMM
v2LDnvpolTodeBfPlF9kHxn+HD+XfWTOIPbl31Bn155O2NXx7HBkziC6xfqR
wqZ5bZhVZwYjak2gGqVy58RKaE+8T/JasWaNMvHe2Js9Tep9GLnWq+SPsB/j
WN4eqiJH7jCazLtJ36g5irpYk39f/ke5l+SuxTeEIrEzKIvvk7+PXjnztNK8
x+YVoda6Z9UaF2vR5w+x7/Ge2sO2+DDdo2W0N74Pe1iMPZs3wC/EpnmtqJCz
bKxArJzdT9+L59NG8YY4Z7UzdMJ6kxhDRt+1mNDrc+So/UOvdWJz8tvljNNG
OkHPmb+q/nmail7YOXTL3h6ZP46UGlVyv6hzTZ02c1fkjeillv3c2JbexsV+
xPtBj/lNcWfFu8Ouj7uL/QQF0TNdFpuJZ8zO0Dok6p9Bp5rz1lszdj6+O/10
6OWBeB7eGTuVvmX8Li7HnRk96LWbn4rz5a+hIb5LFMd6cVfGnYB8dcbkLxh7
Ft8/vlvrlrW+WCsrPjJ8ZzfIy4/3QugqHst7ho9xd+ADas3binM3/gpT+Ess
X2yJbqARrViOPtXrx1gsk/3/P6MbL9iHejqN70LetPGzcTcby4pvP757FGNG
bBYF7B45JXHn0xRti3vfWAV7KN4Bdh67HDX4of+02KL6xca72P2oNjbKX7L2
Bv41Xh99iw2zj8yrEt9zfpX0Guqc63C8C/EdoVHvhcYnjS2zM5hg36KX1bgW
Z4OLeB7/K1SyazHMHsde9BhnH3ceP1sPX/lH8V5GDCmxpbgj43xpFerQiNZY
w5oZfLLuPbSxV/Q3wK5jN6IH78WGxAri++PXI2W/BXGmmFBrFjnsQmSs1xbP
Me53fg+7HffwEJviV8QH2DNqreIDPuOhNVZizThb9idaIbeN3Y45/kh8w5hF
dZw/RuP+wn7caciIzfFzrHHCn4vfNXuFnqPv6Q00oR1tWJFfGH3TY88nJ54T
Tti5cV9buwnnohfaHLbeOuhFuqrGJfohniG9L36VvlbvbfxvxOfjG457E538
DrwTO89fpRfjWZiXTUux7OyfiJfJG6Tb9rKDEX45Hon9Tf8DSdUtWQ==
   "], ".\n"],
  Editable->False]], "Print",
 CellChangeTimes->{3.694246415472714*^9, 3.714821423801057*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Computation time under increasing delays : \\n\"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "13.439999999999998`", ",", "18.24800000000002`", ",", 
     "32.68800000000002`", ",", "108.59600000000006`"}], "}"}]}],
  SequenceForm[
  "Computation time under increasing delays : \n", {13.439999999999998`, 
   18.24800000000002, 32.68800000000002, 108.59600000000006`}],
  Editable->False]], "Print",
 CellChangeTimes->{3.694246415472714*^9, 3.714821423806332*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{Full, Full},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"10.0 for Linux x86 (64-bit) (December 4, 2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 198, 6, 93, "Title"],
Cell[781, 30, 3240, 74, 341, "Text",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[4046, 108, 72, 1, 65, "Section"],
Cell[4121, 111, 94128, 1935, 7315, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[98286, 2051, 83, 1, 65, "Section"],
Cell[CellGroupData[{
Cell[98394, 2056, 95, 1, 45, "Subsection"],
Cell[98492, 2059, 4969, 93, 275, "Input"],
Cell[CellGroupData[{
Cell[103486, 2156, 1046, 18, 55, "Input"],
Cell[CellGroupData[{
Cell[104557, 2178, 360, 5, 23, "Print"],
Cell[104920, 2185, 14631, 277, 256, "Print"],
Cell[119554, 2464, 362, 5, 23, "Print"],
Cell[119919, 2471, 24220, 512, 256, "Print"],
Cell[144142, 2985, 520, 10, 23, "Print"],
Cell[144665, 2997, 24566, 520, 256, "Print"],
Cell[169234, 3519, 522, 10, 23, "Print"],
Cell[169759, 3531, 25663, 547, 256, "Print"],
Cell[195425, 4080, 520, 10, 23, "Print"],
Cell[195948, 4092, 26371, 560, 256, "Print"],
Cell[222322, 4654, 518, 10, 23, "Print"],
Cell[222843, 4666, 28684, 612, 256, "Print"],
Cell[251530, 5280, 520, 10, 23, "Print"],
Cell[252053, 5292, 30199, 642, 256, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[282301, 5940, 715, 17, 77, "Input"],
Cell[283019, 5959, 898, 18, 43, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[283966, 5983, 97, 1, 45, "Subsection"],
Cell[284066, 5986, 3627, 72, 165, "Input"],
Cell[CellGroupData[{
Cell[287718, 6062, 853, 13, 32, "Input"],
Cell[CellGroupData[{
Cell[288596, 6079, 119, 1, 23, "Print"],
Cell[288718, 6082, 1036, 35, 23, "Print"],
Cell[289757, 6119, 279, 6, 23, "Print"],
Cell[290039, 6127, 1236, 44, 43, "Print"],
Cell[291278, 6173, 277, 6, 23, "Print"],
Cell[291558, 6181, 2180, 76, 62, "Print"],
Cell[293741, 6259, 277, 6, 23, "Print"],
Cell[294021, 6267, 1448, 51, 43, "Print"],
Cell[295472, 6320, 560, 13, 43, "Print"],
Cell[296035, 6335, 525, 12, 43, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[296621, 6354, 101, 1, 45, "Subsection"],
Cell[296725, 6357, 44301, 874, 2695, "Input"],
Cell[CellGroupData[{
Cell[341051, 7235, 275, 5, 32, "Input"],
Cell[CellGroupData[{
Cell[341351, 7244, 93, 1, 23, "Print"],
Cell[341447, 7247, 18849, 658, 461, "Print"],
Cell[360299, 7907, 251, 6, 23, "Print"],
Cell[360553, 7915, 16963, 609, 404, "Print"],
Cell[377519, 8526, 251, 6, 23, "Print"],
Cell[377773, 8534, 68273, 2375, 1544, "Print"],
Cell[446049, 10911, 251, 6, 23, "Print"],
Cell[446303, 10919, 4538, 162, 100, "Print"],
Cell[450844, 11083, 1271, 23, 81, "Print"],
Cell[452118, 11108, 517, 12, 43, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[452696, 11127, 103, 1, 45, "Subsection"],
Cell[452802, 11130, 79891, 1555, 5027, "Input"],
Cell[CellGroupData[{
Cell[532718, 12689, 346, 6, 32, "Input"],
Cell[CellGroupData[{
Cell[533089, 12699, 144, 2, 23, "Print"],
Cell[533236, 12703, 159, 2, 23, "Print"],
Cell[533398, 12707, 300, 7, 23, "Print"],
Cell[533701, 12716, 157, 2, 23, "Print"],
Cell[533861, 12720, 300, 7, 23, "Print"],
Cell[534164, 12729, 157, 2, 23, "Print"],
Cell[534324, 12733, 302, 7, 23, "Print"],
Cell[534629, 12742, 157, 2, 23, "Print"],
Cell[534789, 12746, 1788, 30, 119, "Print"],
Cell[536580, 12778, 566, 13, 43, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[537207, 12798, 99, 1, 45, "Subsection"],
Cell[537309, 12801, 137668, 2669, 8921, "Input"],
Cell[CellGroupData[{
Cell[675002, 15474, 305, 6, 32, "Input"],
Cell[CellGroupData[{
Cell[675332, 15484, 158, 2, 23, "Print"],
Cell[675493, 15488, 176, 2, 23, "Print"],
Cell[675672, 15492, 317, 7, 23, "Print"],
Cell[675992, 15501, 174, 2, 23, "Print"],
Cell[676169, 15505, 317, 7, 23, "Print"],
Cell[676489, 15514, 174, 2, 23, "Print"],
Cell[676666, 15518, 319, 7, 23, "Print"],
Cell[676988, 15527, 176, 2, 23, "Print"],
Cell[677167, 15531, 2225, 38, 138, "Print"],
Cell[679395, 15571, 582, 13, 43, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[680038, 15591, 98, 1, 37, "Subsection"],
Cell[680139, 15594, 209856, 4060, 13717, "Input"],
Cell[CellGroupData[{
Cell[890020, 19658, 350, 6, 32, "Input"],
Cell[CellGroupData[{
Cell[890395, 19668, 164, 2, 23, "Print"],
Cell[890562, 19672, 179, 2, 23, "Print"],
Cell[890744, 19676, 322, 7, 23, "Print"],
Cell[891069, 19685, 179, 2, 23, "Print"],
Cell[891251, 19689, 322, 7, 23, "Print"],
Cell[891576, 19698, 181, 2, 23, "Print"],
Cell[891760, 19702, 324, 7, 23, "Print"],
Cell[892087, 19711, 179, 2, 23, "Print"],
Cell[892269, 19715, 3151, 51, 195, "Print"],
Cell[895423, 19768, 550, 13, 43, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[896034, 19788, 101, 1, 37, "Subsection"],
Cell[896138, 19791, 326054, 6259, 21527, "Input"],
Cell[CellGroupData[{
Cell[1222217, 26054, 971, 15, 32, "Input"],
Cell[CellGroupData[{
Cell[1223213, 26073, 140, 2, 23, "Print"],
Cell[1223356, 26077, 155, 2, 23, "Print"],
Cell[1223514, 26081, 298, 7, 23, "Print"],
Cell[1223815, 26090, 157, 2, 23, "Print"],
Cell[1223975, 26094, 298, 7, 23, "Print"],
Cell[1224276, 26103, 155, 2, 23, "Print"],
Cell[1224434, 26107, 296, 7, 23, "Print"],
Cell[1224733, 26116, 155, 2, 23, "Print"],
Cell[1224891, 26120, 3768, 59, 233, "Print"],
Cell[1228662, 26181, 558, 13, 43, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1229281, 26201, 99, 1, 37, "Subsection"],
Cell[1229383, 26204, 672081, 12716, 47069, "Input"],
Cell[CellGroupData[{
Cell[1901489, 38924, 201, 4, 32, "Input"],
Cell[CellGroupData[{
Cell[1901715, 38932, 142, 2, 23, "Print"],
Cell[1901860, 38936, 159, 2, 23, "Print"],
Cell[1902022, 38940, 300, 7, 23, "Print"],
Cell[1902325, 38949, 157, 2, 23, "Print"],
Cell[1902485, 38953, 300, 7, 23, "Print"],
Cell[1902788, 38962, 157, 2, 23, "Print"],
Cell[1902948, 38966, 300, 7, 23, "Print"],
Cell[1903251, 38975, 157, 2, 23, "Print"],
Cell[1903411, 38979, 7577, 110, 499, "Print"],
Cell[1910991, 39091, 533, 13, 43, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1911585, 39111, 101, 1, 45, "Subsection"],
Cell[1911689, 39114, 903187, 17009, 63327, "Input"],
Cell[CellGroupData[{
Cell[2814901, 56127, 518, 11, 32, "Input"],
Cell[CellGroupData[{
Cell[2815444, 56142, 117, 1, 23, "Print"],
Cell[2815564, 56145, 132, 1, 23, "Print"],
Cell[2815699, 56148, 273, 6, 23, "Print"],
Cell[2815975, 56156, 130, 1, 23, "Print"],
Cell[2816108, 56159, 273, 6, 23, "Print"],
Cell[2816384, 56167, 130, 1, 23, "Print"],
Cell[2816517, 56170, 273, 6, 23, "Print"],
Cell[2816793, 56178, 130, 1, 23, "Print"],
Cell[2816926, 56181, 10365, 147, 689, "Print"],
Cell[2827294, 56330, 531, 12, 43, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
